import QtQuick 2.4
import Components 1.0

Item {
    id: root

    property real minValue: 0
    property real maxValue: 100
    property real startValue: 0
    property string startDisplayValue: startValue
    property real finishValue: maxValue
    property string finishDisplayValue: finishValue
    property int precision: 0
    property bool clickableTrack: true
    property real stepValue: 1
    property int _minpos: 0
    property int _maxpos: (orientation == Qt.Horizontal) ? trackWidth: track.height
    property url thumbImage: "../qml/" + main.graphicsPath + "Components/DualSlider/Double_Arrow_Slider_Thumb_Horz.png"
    property url trackImage: ""
    property int trackWidth: 1000 * main.screenScaleX
    property real trackImageOpacity: 1.0
    property url trackFillImage: ""
    property real trackFillImageOpacity: 1.0
    property bool showValue: true
    property string startLabel: qsTr("START") + application.emptyString
    property string finishLabel: qsTr("FINISH") + application.emptyString
    property int valueOffsetX: 0
    property int valueOffsetY: 0
    property int buttonOffsetX: 0
    property int buttonOffsetY: 0
    property int buttonMargin: 20 * main.screenScaleY
    property int orientation: Qt.Horizontal
    property real thumbMouseAreaScale: 1.0
    property real buttonAreaScale: 2.0
    property int dragAreaMargin: 0
    property bool rightToLeft: false// Qt.application.layoutDirection === Qt.RightToLeft && orientation === Qt.Horizontal
    property bool showSelectionCursor: false
    property ListModel indexPoints
    property color fillLineColor: "#c74136"
    property bool showLabels: true
    property int labelOverlapDistance: (leftSliderKnob.x + -(labelKnobLeft.width - leftSliderKnob.width)/2 + labelKnobLeft.width) - (rightSliderKnob.x + -(labelKnobRight.width - rightSliderKnob.width)/2)

    signal released()

    width: trackWidth //trackImage != "" ? trackGraphic.implicitWidth : (orientation == Qt.Horizontal ? 100 : 5) * main.screenScaleX
    height: trackImage != "" ? trackGraphic.implicitHeight : (orientation == Qt.Horizontal ? 5 : 100) * main.screenScaleY
    enabled: visible && opacity > 0

    onStartValueChanged: startValue = setValue(startValue)
    onFinishValueChanged: finishValue = setValue(finishValue)

    Component.onCompleted: {
        root.startValue = validateRangeStartValue(root.startValue)
        root.finishValue = validateRangeFinishValue(root.finishValue)
    }

    function setValue(newValue) {
        if (newValue >= maxValue) {
            // Allow value at end of slider to be set, even though
            // it may not be a multiple of the step value
            return maxValue
        }
        newValue = (newValue / stepValue).toFixed(0) * stepValue
        newValue = validateRange(newValue)
        return newValue
    }

    function validateRangeStartValue(newValue) {
        if (newValue > root.finishValue) {
            newValue = root.finishValue - 1
        }
        newValue = validateRange(newValue)
        return newValue
    }

    function validateRangeFinishValue(newValue) {
        if (newValue < root.startValue) {
            newValue = root.startValue + 1
        }
        newValue = validateRange(newValue)
        return newValue
    }


    function validateRange(newValue) {
        if( newValue < root.minValue )
            newValue = root.minValue
        if( newValue > root.maxValue )
            newValue = root.maxValue
        return newValue
    }

    function positionFromValue(value) {
        var pos = (value-minValue) * (_maxpos / (maxValue - minValue))
        if (isNaN(pos)) {
            pos = 0
        }
        return rightToLeft ? _maxpos-pos : pos
    }

    function valueFromPosition(position) {
        if (rightToLeft)
            position = _maxpos - position
        var newValue = minValue + position *(maxValue-minValue)/(_maxpos-_minpos)
        newValue = validateRange(newValue)
        return newValue.toFixed(precision)
    }

    Item {
        id: track
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.verticalCenter: parent.verticalCenter
        anchors.verticalCenterOffset: 10 * main.screenScaleY
        width: root.width
        height: root.height

        Rectangle {
            id: fillLine
            z: 2 // Place below thumb grips, but on top of track
            color: root.fillLineColor
            height: 10 * main.screenScaleY
            anchors.verticalCenter: parent.verticalCenter
            x: leftSliderKnob.x + leftSliderKnob.width/2
            width: rightSliderKnob.x - x + rightSliderKnob.width/2
        }

        Repeater {
            id: indexLines
            anchors {
                left: track.left
                top: track.top
            }

            model: root.indexPoints
            delegate: Component {
                    Item {
                        id: indexItem
                        Text {
                            id: labelDisplay
                            color: "black"
                            font.pixelSize: 14 * main.screenScaleY
                            font.bold: true
                            text: model.label
                            horizontalAlignment: Text.AlignRight
                            anchors {
                                right: index === 0 ? undefined : line.right
                                rightMargin: index === 0 ? 0 : (model.offset ? -model.offset : 0)
                                // First item is a special case, being anchored on left
                                left: index === 0 ? line.left : undefined
                                leftMargin: index === 0 ? (model.offset ? model.offset : 0) : 0
                                bottom: valueDisplay.top
                                bottomMargin: -2 * main.screenScaleY
                            }
                        }
                        Text {
                            id: valueDisplay
                            color: "black"
                            font.pixelSize: 14 * main.screenScaleY
                            font.bold: true
                            text: options.metricUnits ? Globals.formatWithSeparator(Globals.feetToMeters(model.value).toFixed(0)) : Globals.formatWithSeparator(model.value)
                            anchors {
                                right: index === 0 ? undefined : labelDisplay.right
                                // First item is a special case, being anchored on left
                                left: index === 0 ? labelDisplay.left : undefined
                                bottom: line.top
                                bottomMargin: 3 * main.screenScaleY
                            }
                        }

                        Rectangle {
                            id: line
                            color: "black"
                            height: 40 * main.screenScaleY
                            width: 2 * main.screenScaleX
                            anchors.left: parent.left
                            anchors.leftMargin: root.positionFromValue(model.value) - 1 // Subtract half of width for centering
                            anchors.top: parent.top
                            anchors.topMargin: -5 * main.screenScaleY
                        }
                    }
            }
        }

        // track line when there's no background image
        Rectangle {
            id: track_line
            height: 2 * main.screenScaleY
            width: parent.width
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.verticalCenter: parent.verticalCenter
            color: "black"
            visible: root.trackImage != "" ? false : true
        }

        // image to display over the "filled" area of slider
        BorderImage {
            anchors.left: parent.left
            anchors.leftMargin: 1 * main.screenScaleX
            anchors.right: leftSliderKnob.horizontalCenter
            anchors.verticalCenter: parent.verticalCenter
            source: root.trackFillImage
            opacity: trackFillImageOpacity
        }
        BorderImage {
            id: trackGraphic
            source: root.trackImage
            opacity: trackImageOpacity
            anchors {
                top: parent.top
                bottom: parent.bottom
                horizontalCenter: root.orientation == Qt.Vertical ? parent.horizontalCenter : undefined
            }
        }

        // mouse area for clicking the track to move the slider
        MouseArea {
            id: track_mouse

            enabled: clickableTrack
            anchors.fill: parent
            onPressed: {
                // TODO If position is after finish, move forward
                // If position is before start, move backward
                // If position is inbetween, ???
//                var position = (root.orientation == Qt.Horizontal ? (_minpos + mouseX ) : (_maxpos -_minpos - mouseY))
//                value = valueFromPosition( position )
//                buzzer.buttonPress()
            }
            Rectangle{
                opacity: 0.3
                color: "green"
                anchors.fill: parent
                visible: main.showStimulusArea
            }
        }

        Image {
            id: leftSliderKnob

            anchors.left: parent.left
            anchors.leftMargin: positionFromValue(startValue) - width/2
            anchors.bottomMargin: positionFromValue(startValue) - height/2
            source: root.thumbImage
            z: 99

            BorderImage {
                visible: root.showSelectionCursor
                border { left: 40 * main.screenScaleX; top: 5 * main.screenScaleY; bottom: 5 * main.screenScaleY; right: 40 * main.screenScaleX }
                source: "../qml/" + main.graphicsPath + "Components/SliderControl/maintenance_menus_cursor_new.png"
                width: 100 * main.screenScaleX
                anchors.centerIn: parent
                anchors.horizontalCenterOffset: -3 * main.screenScaleX
                horizontalTileMode: BorderImage.Stretch
            }

            Text {
                id: labelKnobLeft
                font.bold: true
                font.pixelSize: 24 * main.screenScaleY
                horizontalAlignment: Text.AlignHCenter
                lineHeight: 0.7 * main.screenScaleY
                text: root.startLabel + "\n" + root.startDisplayValue
                anchors {
                    top: parent.bottom
                    topMargin: -10 * main.screenScaleY
                }
                x: -(labelKnobLeft.width - leftSliderKnob.width)/2 - (labelOverlapDistance > 0 ? labelOverlapDistance/2 + 5 : 0)
            }

            MouseArea {
                id: knobMouseArea
                property int knobMargin: (root.orientation == Qt.Horizontal ? (leftSliderKnob.width/2) : (leftSliderKnob.height/2))

                anchors.fill: parent
                anchors.margins: root.dragAreaMargin
                scale: root.thumbMouseAreaScale

                drag {
                    target: leftSliderKnob ;
                    axis: (root.orientation === Qt.Horizontal) ? Drag.XAxis : Drag.YAxis;
                    minimumX: _minpos - knobMargin ; minimumY: _minpos - knobMargin
                    //maximumX: _maxpos - knobMargin + 5  ; maximumY: _maxpos - knobMargin + 5    // +5 fudge factor need for some reason to allow full sliding to max value
                    maximumX: rightSliderKnob.x - rightSliderKnob.width/2 - 15; maximumY: rightSliderKnob.y
                }

                onPressed: {
                    leftSliderKnob.anchors.left = undefined
                    leftSliderKnob.anchors.bottom = undefined
                    buzzer.buttonPress()
                } // un-anchor to allow drag
                onReleased: {
                    if(root.orientation == Qt.Horizontal)
                        leftSliderKnob.anchors.left = leftSliderKnob.parent.left
                    else
                        leftSliderKnob.anchors.bottom = leftSliderKnob.parent.bottom
                    root.released()
                } // re-anchor at end of drag

                onMouseXChanged: {
                    if( root.orientation == Qt.Horizontal )
                        root.startValue = setValue(valueFromPosition(leftSliderKnob.x + leftSliderKnob.width/2))
                }
                onMouseYChanged: {
                    if( root.orientation != Qt.Horizontal )
                        setValue(valueFromPosition(_maxpos - _minpos - leftSliderKnob.y - leftSliderKnob.height/2))
                }

                Rectangle{
                    opacity: 0.3
                    color: "blue"
                    anchors.fill: parent
                    visible: main.showStimulusArea
                }
            }
        }

        Image {
            id: rightSliderKnob

            anchors.left: parent.left
            anchors.leftMargin: positionFromValue(finishValue) - width/2
            anchors.bottomMargin: positionFromValue(finishValue) - height/2
            source: root.thumbImage
            z: leftSliderKnob.z + 1

            BorderImage {
                visible: root.showSelectionCursor
                border { right: 40 * main.screenScaleX; top: 5 * main.screenScaleY; bottom: 5 * main.screenScaleY; left: 40 * main.screenScaleX }
                source: "../qml/" + main.graphicsPath + "Components/SliderControl/maintenance_menus_cursor_new.png"
                width: 100 * main.screenScaleX
                anchors.centerIn: parent
                anchors.horizontalCenterOffset: -3 * main.screenScaleX
                horizontalTileMode: BorderImage.Stretch
            }

            Text {
                id: labelKnobRight
                font.bold: true
                font.pixelSize: 24 * main.screenScaleY
                text: root.finishLabel + "\n" + root.finishDisplayValue
                horizontalAlignment: Text.AlignHCenter
                lineHeight: 0.7
                anchors {
                    top: parent.bottom
                    topMargin: -10 * main.screenScaleY

                }
                x: -(labelKnobRight.width - rightSliderKnob.width)/2 + (labelOverlapDistance > 0 ? labelOverlapDistance/2 + 5 : 0)
            }

            MouseArea {
                id: knobMouseAreaRight
                property int knobMargin: (root.orientation == Qt.Horizontal ? (rightSliderKnob.width/2) : (rightSliderKnob.height/2))

                anchors.fill: parent
                anchors.margins: root.dragAreaMargin
                scale: root.thumbMouseAreaScale

                drag {
                    target: rightSliderKnob ;
                    axis: (root.orientation === Qt.Horizontal) ? Drag.XAxis : Drag.YAxis;
                    minimumX: leftSliderKnob.x + leftSliderKnob.width/2 + 15; minimumY: _minpos - knobMargin
                    maximumX: _maxpos - rightSliderKnob.width/2 ; maximumY: rightSliderKnob.y
                }

                onPressed: {
                    rightSliderKnob.anchors.left = undefined
                    rightSliderKnob.anchors.bottom = undefined
                    buzzer.buttonPress()
                } // un-anchor to allow drag
                onReleased: {
                    if(root.orientation == Qt.Horizontal)
                        rightSliderKnob.anchors.left = rightSliderKnob.parent.left
                    else
                        rightSliderKnob.anchors.bottom = rightSliderKnob.parent.bottom
                    root.released()
                } // re-anchor at end of drag

                onMouseXChanged: {
                    if( root.orientation == Qt.Horizontal )
                        root.finishValue = setValue(valueFromPosition(rightSliderKnob.x + rightSliderKnob.width/2))
                }
                onMouseYChanged: {
                    if( root.orientation != Qt.Horizontal )
                        setValue(valueFromPosition(_maxpos - _minpos - rightSliderKnob.y - rightSliderKnob.height/2))
                }

                Rectangle{
                    opacity: 0.3
                    color: "blue"
                    anchors.fill: parent
                    visible: main.showStimulusArea
                }
            }
        }
    }

    states: [
        State {
            name: "Horizontal"
            when: orientation == Qt.Horizontal

            PropertyChanges {
                target: track
                width: root.trackWidth
                height: root.height
            }

            AnchorChanges {
                target: track
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.verticalCenter: parent.verticalCenter
            }

            PropertyChanges {
                target: track_line
                height: 3 * main.screenScaleY
                width: parent.width
            }

            AnchorChanges {
                target: leftSliderKnob
                anchors { verticalCenter: parent.verticalCenter ; left: parent.left }
            }
            AnchorChanges {
                target: rightSliderKnob
                anchors { verticalCenter: parent.verticalCenter ; left: parent.left }
            }
        },
        State {
            name: "Vertical"
            when: orientation == Qt.Vertical

            PropertyChanges {
                target: track
                height: root.height
                width: root.width
            }

            AnchorChanges {
                target: track
                anchors {
                    left: undefined
                    right: undefined
                    top: root.top
                    bottom: root.bottom
                    horizontalCenter: root.horizontalCenter
                    verticalCenter: undefined
                }
            }

            PropertyChanges {
                target: track_line
                height: track.height;
                width: 3 * main.screenScaleX
                opacity: 0.5
            }

            AnchorChanges {
                target: leftSliderKnob
                anchors { verticalCenter: undefined ; left: undefined ; bottom: parent.bottom ; horizontalCenter: parent.horizontalCenter }
            }
        }
    ]

}
