import QtQuick 2.4
import "Globals.js" as Globals

Rectangle {
    id: root

    property bool alpha: false
    property int value: defaultValue
    property string printedValue: zeroPadding > 0 ? Globals.padZeros(value, zeroPadding) : (alpha ? String.fromCharCode(value) : value)
    property int minValue: 1
    property int maxValue: Number.POSITIVE_INFINITY
    property int defaultValue: 1
    property bool valueWraps: false
    property int zeroPadding: 0
    property bool listenKeys: false
    property int columnSpacing: 20
    property alias font: valueText.font
    property url upImage: "../qml/" + main.graphicsPath + "Components/NumberPicker/UpArrow_blue.png"
    property url upImagePressed: "../qml/" + main.graphicsPath + "Components/NumberPicker/UpArrow_PRESSED.png"
    property url downImage: "../qml/" + main.graphicsPath + "Components/NumberPicker/DownArrow_blue.png"
    property url downImagePressed: "../qml/" + main.graphicsPath + "Components/NumberPicker/DownArrow_PRESSED.png"
    property bool showArrows: true

    Connections {
        target: main.isTft && listenKeys ? keymapper : null

        onUpButtonPressed: {
            main.debugKeys("upButtonPressed", "NumberPicker")
            root.valueUp()
        }
        onDownButtonPressed: {
            main.debugKeys("downButtonPressed", "NumberPicker")
            root.valueDown()
        }
    }

    function valueUp() {
        if (root.value + 1 > maxValue) {
            if (valueWraps) {
                root.value = minValue
            } else {
            }
        } else {
            root.value ++
        }
    }

    function valueDown() {
        if (root.value - 1 < minValue) {
            if (valueWraps) {
                root.value = maxValue
            } else {
            }
        } else {
            root.value --
        }
    }


    color: "transparent"
    height: 250 * main.screenScaleY
    width: 300 * main.screenScaleX

    onMaxValueChanged: {
        if (root.value > maxValue) {
            root.value = maxValue
        }
    }

    onMinValueChanged: {
        if (root.value < minValue) {
            root.value = minValue
        }
    }

    Column{
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.verticalCenter: parent.verticalCenter
        spacing: root.columnSpacing
        ImageButton{
            id: upButton
            anchors.horizontalCenter: parent.horizontalCenter
            opacity: root.showArrows ? 1.0 : 0.0
            upimage: root.upImage
            downimage: root.upImagePressed
            onClicked: {
                root.valueUp()
            }
        }
        Text{
            id: valueText
            anchors.horizontalCenter: parent.horizontalCenter
            text: root.printedValue
            font.pixelSize: 40 * main.screenScaleY
            font.bold: true
        }

        ImageButton{
            id: downButton
            anchors.horizontalCenter: parent.horizontalCenter
            opacity: root.showArrows ? 1.0 : 0.0
            upimage: root.downImage
            downimage: root.downImagePressed
            onClicked: {
                root.valueDown()
            }
        }
    }

}
