// import QtQuick 2.4 // to target S60 5th Edition or Maemo 5
import QtQuick 2.4
import Components 1.0

ModalDialog {
    id: root

    blockKeys: true
    isTransparent: true

    signal acceptClicked()
    signal cancelClicked()

    Connections {
        target: main.isTft && root.visible ? keymapper : null

        onEnter2Pressed: {
            main.debugKeys("upButtonPressed", "WorkoutMenuAll")
            acceptClicked()
        }
    }

    BorderImage {   // pop-up dialog background
        id: border

        anchors.horizontalCenter: root.horizontalCenter
        anchors.verticalCenter: root.verticalCenter
        width: 800 * main.screenScaleX
        height: 350 * main.screenScaleY
        source: main.graphicsPath + "Pop_Up_Lrg_Grey.png"
        border { top: 152 * main.screenScaleY; bottom: 165 * main.screenScaleY; left: 145 * main.screenScaleX; right: 144 * main.screenScaleX }

        Text {
            id: bikeModePromptText
            x: 149 * main.screenScaleX
            y: 35 * main.screenScaleY
            width: 501 * main.screenScaleX
            height: 40 * main.screenScaleY
            color: "#ffffff"
            text: qsTr("Bike Mode?") + application.emptyString
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.top: parent.top
            anchors.topMargin: 35 * main.screenScaleY
            horizontalAlignment: Text.AlignHCenter
            wrapMode: Text.WordWrap
            font.bold: true
            font.pixelSize: 40 * main.screenScaleY
        }

        ImageButton {
            id: cancelButton
            visible: main.isTouch

            x: 538 * main.screenScaleX
            y: 157 * main.screenScaleY
            label_y_offset: -65 * main.screenScaleY
            label: qsTr("CANCEL") + application.emptyString
            smooth: true
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 22 * main.screenScaleY
            upimage: main.graphicsPath + "224/224_Data_ToolBar_Round_Disabled.png"
            downimage: main.graphicsPath + "224/224_Data_ToolBar_Round_Down.png"
            onClicked: cancelClicked()
        }

        ImageButton {
            id: acceptButton
            visible: main.isTouch

            x: 149 * main.screenScaleX
            y: 178 * main.screenScaleY
            label_y_offset: -65 * main.screenScaleY
            label: qsTr("ACCEPT") + application.emptyString
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 22 * main.screenScaleY
            upimage: main.graphicsPath + "224/224_Data_ToolBar_Round_Green.png"
            downimage: main.graphicsPath + "224/224_Data_ToolBar_Round_Down.png"
            onClicked: acceptClicked()
        }

        Text {
            visible: main.isTft
            anchors.top: bikeModePromptText.bottom
            anchors.topMargin: 20 * main.screenScaleY
            anchors.horizontalCenter: parent.horizontalCenter
            text: qsTr("press ENTER again to confirm") + application.emptyString
            color: "#ffffff"
            font.bold: true
            font.pixelSize: 24 * main.screenScaleY

        }

        Text {
            id: cancelText
            visible: main.isTft

            anchors.horizontalCenter: parent.horizontalCenter
            anchors.horizontalCenterOffset: -countdownText.width/2
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 73 * main.screenScaleY
            text: qsTr("CANCEL IN") + application.emptyString
            color: "#ffffff"
            font.bold: true
            font.pixelSize: 24 * main.screenScaleY
        }

        Text { // show count down to timeout of prompt (started by startTimeout(seconds) method of ModalDialog superclass
            id: countdownText

            x: 350 * main.screenScaleX
            y: 168 * main.screenScaleY
            color: "#ffffff"

            // display count down (with a leading 0 if remaining seconds < 10
            text: ":" + ((countDown.toString().length < 2) ? "0" : "") + countDown
            font.bold: true
            font.pixelSize: 96 * main.screenScaleY

            anchors.horizontalCenter: parent.horizontalCenter
            anchors.horizontalCenterOffset: main.isTft ? cancelText.width/2 : 0
            anchors.bottom: parent.bottom
            anchors.bottomMargin: main.isTft ? 73 - cancelText.height/2 - 5 : 73
        }
    }


}
