import QtQuick 2.4
import Components 1.0

Rectangle {
    id: root

    property variant model
    property string iconPath:"../qml/" +  main.graphicsPath+ "TvIcons/default/channelIcons/"
    property bool acceptKeys: false

    signal channelSelected(string id)

    color: "#B0B0B0"

    Connections {
        target: !main.blockKeys && main.isTft && root.visible && root.acceptKeys ? keymapper : null

        onDoubleLeftPressed: {
            main.debugKeys("doubleLeftPressed", "ChannelListView")
            channelFlow.moveCurrentIndexLeft()
        }

        onDoubleRightPressed: {
            main.debugKeys("doubleRightPressed", "ChannelListView")
            channelFlow.moveCurrentIndexRight()
        }

        onEnter2Pressed: {
            main.debugKeys("enter2Pressed", "ChannelListView")
            if("id" in root.model.get(channelFlow.currentIndex))
                root.channelSelected(root.model.get(channelFlow.currentIndex).id)
            else
                root.channelSelected(-1)
        }
    }

    GridView {
        id: channelFlow
        Image {
            id: highlightImage
            visible: main.isTft
            source: main.graphicsPath + "tft/TV_menus_cursor.png"
            x: channelFlow.currentItem ? (channelFlow.currentItem.x - 8 * main.screenScaleX - channelFlow.contentX) : -9 * main.screenScaleX
            y: channelFlow.currentItem ? (channelFlow.currentItem.y - 8 * main.screenScaleY - channelFlow.contentY) : -9 * main.screenScaleY
        }

        anchors.fill: parent
        anchors {
            topMargin: 15 * main.screenScaleY
            bottomMargin: 15 * main.screenScaleY
            leftMargin: 15 * main.screenScaleX
            rightMargin: ( main.rightToLeft ? 40 : 25 ) * main.screenScaleX
        }
        width: parent.width
        height: parent.height
        cellWidth: 135 * main.screenScaleX
        cellHeight: 155 * main.screenScaleY
        model: root.model
        delegate: channelDelegate
        currentIndex: tv.currentChannel >= 0 ? tv.currentChannel : 0
    }

    Item {
        id: dataArrows

        width: 40 * main.screenScaleX
        height: parent.height

        anchors { top: parent.top; right: parent.right ; rightMargin: ( Qt.application.layoutDirection === Qt.RightToLeft ? -20 : -5 ) * main.screenScaleX }
        Image {
            id: dataUpArrow
            visible: channelFlow.contentY > 10
            source: main.graphicsPath + "Swipe_Arrows_Left.png"
            rotation: 90
            anchors { top: parent.top; topMargin: 50 * main.screenScaleY; right: parent.right }
        }
        Image {
            id: dataDownArrow
            visible: !(channelFlow.contentY > (channelFlow.contentHeight - channelFlow.height - 10))
            source: main.graphicsPath + "Swipe_Arrows_Right.png"
            rotation: 90
            anchors { bottom: parent.bottom; bottomMargin: 50 * main.screenScaleY; right: parent.right }
        }
    }

    Component {
        id: channelDelegate

        Column {
            id: channelColumn
            Rectangle {
                id: channelBox

                width: 115 * main.screenScaleX
                height: 115 * main.screenScaleY

                border.color: main.isTouch && (channelFlow.currentIndex === index) ? "gold" : "black"
                border.width: main.isTouch && (channelFlow.currentIndex === index) ? 3 * main.screenScaleX : 1 * main.screenScaleX
                color: "lightgray"

                Image {
                    id: channelIcon
                    x: 3 * main.screenScaleX
                    y: 3 * main.screenScaleY
                    source: if('icon' in model && model.icon)
                                return icon ? root.iconPath + icon : ""
                            else
                                return ""
                    onStatusChanged: {
                        if (channelIcon.status == Image.Error)
                            channelIcon.source = ""
                    }
                }

                MouseArea { // mouse area which allows choosing the channel, can be interrupted by scrolling
                    visible: (model.enabled === "true")
                    anchors.fill: channelBox

                    onClicked: {
                        if("id" in model)
                            root.channelSelected(id)
                        else
                            root.channelSelected(-1)
                    }
                } // end MouseArea

                MouseArea {  // smaller mouse area in center which allows choosing but not scrolling
                    visible: (model.enabled === "true")
                    anchors.fill: channelBox
                    scale: 0.3
                    preventStealing: true

                    onClicked: {
                        if("id" in model)
                            root.channelSelected(id)
                        else
                            root.channelSelected(-1)
                    }
                }

                Text {
                    visible: channelIcon.source == ""
                    text: if("number" in model)
                              return number
                          else
                              return index
                    font.pointSize: 36 * main.screenScaleY
                    width: 113 * main.screenScaleX
                    height: 113 * main.screenScaleY
                    horizontalAlignment: Text.AlignHCenter
                    verticalAlignment: Text.AlignVCenter
                }
            }

            Text {
                text: {
                    if (number && name && number != name) {
                        return Globals.truncate(name, 23) + " " + number
                    } else if (name) {
                        return Globals.truncate(name, 26)
                    } else if (number) {
                        return number
                    } else {
                        return ""
                    }
                }
                font.pointSize: 12 * main.screenScaleY
                width: 110 * main.screenScaleX
                horizontalAlignment: Text.AlignHCenter
                lineHeight: 0.85
                wrapMode: Text.WrapAnywhere
            }
        } // end Column

    }
}

