// import QtQuick 2.4 // to target S60 5th Edition or Maemo 5
import QtQuick 2.4
import "string_format.js" as Format

Item {
    id: root
    property alias topLabel: topLevelLabel.text
    property alias topValue: topLevelValue.text
    property alias topUnits: topLevelUnit.text

    width: 100 * main.screenScaleX
    height: 100 * main.screenScaleY
    opacity: parent.opacity

    // REQUIRED property: for translation to work (via qsTranslate), it must know where the external model is stored.
    // Without this you will likely see blank strings in your data table.
    property string sourceFile: ""

    property variant displayModel
    property bool useMetric: false
    property bool onRight: false
    property int rotateDataCounter: 0
    property bool _noData: false
    property alias headerToggleBool: topLevelToggleButton.state
    property alias headerToggleIndex: topLevelToggleButton.dataIndex


    property string headerBackgroundSource: main.graphicsPath + "224/224_Data_Top_Data_Bar_Leftt.png"
    property string dataElementActiveBackgroundSource: main.graphicsPath + "224/224_Data_Bar_2a.png"
    property string dataElementInactiveBackgroundSource: main.graphicsPath + "224/224_Data_Bar_4.png"
    property string toggleButtonActiveSource: main.graphicsPath + "224/Toggle_On.png"
    property string toggleButtonInactiveSource: main.graphicsPath + "224/Toggle_Off.png"
    property string unitSelectionBackgroundSource: main.graphicsPath + "224/224_Data_Bar_Rounded_Bottom.png"

    state: "Disabled"

    function reset() {
        rotateDataCounter = 0;
        rotateThruData()
    }

    function getNextIndex (indexNow)
    {
        for(var j = 1; j <= displayModel.count; j++)
        {
            var y = (indexNow + j) % displayModel.count
            var item = displayModel.get(y)

            var enabled = dataToggleModel.get(item.dataIndex).thestate

            if(item.isDisplayed && enabled == "Enabled"){
                return y
            }
        }

        return -1
    }

    function rotateThruData ()
    {
        var nextIndex = getNextIndex(rotateDataCounter)
        if (nextIndex === -1) {
            _noData = true
            rotateDataCounter = 0
        } else {
            _noData = false
            rotateDataCounter = nextIndex
        }
    }

    states: [
        State{name: "Enabled"
            PropertyChanges { target: topBarBackground; opacity: 1.0}
            PropertyChanges { target: dropdownDisplay; opacity: 1.0}
            PropertyChanges { target: dropdownDisplay; anchors.topMargin: -12 * main.screenScaleY}
        },
        State{name: "Disabled"
            PropertyChanges { target: topBarBackground; opacity: 0.0}
            PropertyChanges { target: dropdownDisplay; opacity: 1.0}
            PropertyChanges { target: dropdownDisplay; anchors.topMargin: -800 * main.screenScaleY}
        }
    ]


    transitions: [
        Transition {
            from: "Disabled"
            to: "Enabled"
            reversible: true
            SequentialAnimation {
                NumberAnimation { duration: 250; properties: "opacity" }
                NumberAnimation { duration: 500; properties: "anchors.topMargin" ;easing.type:Easing.OutBack }
            }
        }
    ]

    Item{
        id: header
        property int shadowBorder: 21 * main.screenScaleX
        property int originalImageWidth: 324 * main.screenScaleX
        property int originalImageHeight: 160 * main.screenScaleY

        width: originalImageWidth
        height: originalImageHeight
        clip: false

        x: (!onRight) ? parent.x - 20 * main.screenScaleX : parent.x + root.parent.width + 19 * main.screenScaleX - originalImageWidth
        y: parent.y - 21 * main.screenScaleY
        Image {
            id: topBarBackground
            source: headerBackgroundSource
            visible: true
            mirror: onRight

            //Behavior on opacity{PropertyAnimation{}}

        }

        Text {
            id: topLevelLabel

            anchors.left: (!onRight) ? topBarBackground.left : undefined;
            anchors.leftMargin: ( (!onRight) ? 46 : 0 ) * main.screenScaleX;

            anchors.right: (onRight)? topBarBackground.right : undefined;
            anchors.rightMargin: ( (onRight) ? 46 : 0 ) * main.screenScaleX;

            anchors.top: parent.top
            anchors.topMargin: 40 * main.screenScaleY

            color: "black"
            font.pointSize: 11 * main.screenScaleY
            font.bold: true
            text: {
                if (!root.visible)
                    return "" // avoid unnecessary processing

                var item
                if(root.state == "Disabled") {
                    if (_noData) {
                        return ""
                    }
                    item = testRepeater.model.get(rotateDataCounter)
                } else {
                    item = testRepeater.model.get(0)
                }

                return qsTranslate(root.sourceFile, item.label) + application.emptyString
            }
        }
        Text {
            id: topLevelValue
            anchors.left: (!onRight) ? topBarBackground.left : undefined;
            anchors.leftMargin: ( (!onRight) ? 46 : 0 ) * main.screenScaleX;

            anchors.right: (onRight) ? topLevelUnit.left : undefined;
            anchors.rightMargin: ( (onRight) ? 5 : 0 ) * main.screenScaleX;

            y: 54 * main.screenScaleY
            color: "black"
            font.pointSize: 40 * main.screenScaleY
            font.bold: true
            text: {
                if (!root.visible)
                    return "" // avoid unnecessary processing

                if(root.state == "Disabled"){
                      if(!_noData) return getData(rotateDataCounter)
                      else return ""
                  }
                  else{
                      return getData(0);
                  }
            }
        }

        Text {
            id: topLevelUnit

            anchors.left: (!onRight) ? topLevelValue.right : undefined;
            anchors.leftMargin: ( (!onRight) ? 5 : 0 ) * main.screenScaleX;

            anchors.right: (onRight) ? topBarBackground.right : undefined;
            anchors.rightMargin: ( (onRight) ? 46 : 0 ) * main.screenScaleX;

            anchors.baseline: topLevelValue.baseline
            visible: true

            color: "black"
            font.pointSize: 12 * main.screenScaleY
            font.bold: true
            text: {
                if (!root.visible)
                    return "" // avoid unnecessary processing

                if(root.state == "Disabled") {
                      if(!_noData)
                          return getUnit(rotateDataCounter)
                      else return ""
                  }
                  else return getUnit(0)
            }
        }

        Image {
            id: topLevelButton
            visible: main.isTouch // user cannot hide on TFT
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.horizontalCenterOffset: ( onRight ? 45 : -45 ) * main.screenScaleX
            anchors.bottom: topBarBackground.bottom
            anchors.bottomMargin: 20 * main.screenScaleY
            source: main.graphicsPath + "224/224_Data_Data_Grey_Arrow.png"
            transform: Rotation{
                angle: root.state == "Enabled" ? 180 : 0
                origin.x: 13 * main.screenScaleX
                origin.y: 6 * main.screenScaleY
                Behavior on angle{PropertyAnimation{}}
            }
        }

        MouseArea{
            id: headerMouseArea
            anchors.fill: parent
            anchors.bottomMargin: 15 * main.screenScaleY
            anchors.rightMargin: ( onRight ? 0 : 0 ) * main.screenScaleX
            anchors.leftMargin: onRight? 0 : 0
            onClicked:{
                if(root.state == "Enabled") root.state = "Disabled"
                else root.state = "Enabled"
                buzzer.buttonPress()
            }
        }

        Image {
            id: topLevelToggleButton

            property int dataIndex: 0

            anchors.left: (onRight) ? topBarBackground.left : undefined;
            anchors.leftMargin: ( (onRight) ? 75 : 0 ) * main.screenScaleX;

            anchors.right: (!onRight) ? topBarBackground.right : undefined;
            anchors.rightMargin: ( (!onRight) ? 75 : 0 ) * main.screenScaleX;

            anchors.bottom: topBarBackground.bottom
            anchors.bottomMargin: 25 * main.screenScaleY
            mirror: onRight
            opacity: topBarBackground.opacity

            states: [
                State{name: "Enabled"
                    PropertyChanges { target: topLevelToggleButton; source: toggleButtonActiveSource}
                },
                State{name: "Disabled"
                    PropertyChanges { target: topLevelToggleButton; source: toggleButtonInactiveSource}
                }
            ]

            MouseArea{
                id: headerToggleButtonMouseArea
                anchors.fill: parent
                transform: Scale { xScale: 2 ; yScale: 8 ; origin.x: width/8; origin.y:height/8}
                onClicked:{
                    if(parent.state == "Enabled") {
                        parent.state = "Disabled"
                        dataToggleModel.setProperty(topLevelToggleButton.dataIndex,"thestate", "Disabled")
                    }
                    else
                    {
                        parent.state = "Enabled"
                        dataToggleModel.setProperty(topLevelToggleButton.dataIndex,"thestate", "Enabled")
                    }
                    rotateThruData()
                    buzzer.buttonPress()
                }
            }
        }


    }


    Column{

        id: dropdownDisplay
        anchors.top: header.bottom
        anchors.topMargin: -12 * main.screenScaleY

        anchors.left: (!onRight) ? header.left : undefined
        anchors.leftMargin: ( (!onRight) ? 20 : 0 ) * main.screenScaleX

        anchors.right: (onRight) ? header.right : undefined
        anchors.rightMargin: ( (onRight) ? 20 : 0 ) * main.screenScaleX

        visible: true

        z: header - 1

        //Behavior on anchors.topMargin {PropertyAnimation{}}

        Repeater{
            id: testRepeater
            model: displayModel
            delegate: _delegate
        }

        Item{
            id: unitDisplay
            property int shadowBorder: 21 * main.screenScaleX
            property int originalImageWidth: 199 * main.screenScaleX
            property int originalImageHeight: 92 * main.screenScaleY

            width: originalImageWidth
            height: originalImageHeight-(shadowBorder)
            clip: false
            state: workoutScreen.unitState

            onStateChanged: {
                workoutScreen.unitState = state
            }

            Image{
                id: backgroundImage
                anchors.bottom: parent.bottom
                anchors.horizontalCenter: parent.horizontalCenter
                x: parent.x - unitDisplay.shadowBorder
                y: parent.y - unitDisplay.shadowBorder
                source: unitSelectionBackgroundSource
                mirror: onRight

            }

            Text {
                id: kilometersLabel
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.horizontalCenterOffset: -50 * main.screenScaleX
                anchors.verticalCenter: parent.verticalCenter
                anchors.verticalCenterOffset: -10 * main.screenScaleY
                color: "black"
                font.pointSize: 11 * main.screenScaleY
                font.bold: true
                text: qsTr("KM")
            }

            Text {
                id: milesLabel
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.horizontalCenterOffset: 50 * main.screenScaleX
                anchors.verticalCenter: parent.verticalCenter
                anchors.verticalCenterOffset: -10 * main.screenScaleY
                color: "black"
                font.pointSize: 11 * main.screenScaleY
                font.bold: true
                text: qsTr("MI")
            }

            Image {
                id: unitSelectionButton
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.horizontalCenterOffset: 0
                anchors.verticalCenter: parent.verticalCenter
                anchors.verticalCenterOffset: -10 * main.screenScaleY
                source: toggleButtonActiveSource
            }

            MouseArea{
                id: unitSelectionMouseArea
                anchors.fill: parent
                onClicked:{
                    if(workoutScreen.unitState == "ENGLISH") workoutScreen.unitState = "METRIC"
                    else workoutScreen.unitState = "ENGLISH"
                    buzzer.buttonPress()
                }
            }

            states: [
                State {
                    name: "ENGLISH";
                    PropertyChanges {
                        target: unitSelectionButton
                        source: toggleButtonActiveSource
                    }
                },
                State {
                    name: "METRIC";
                    PropertyChanges {
                        target: unitSelectionButton
                        source: toggleButtonInactiveSource
                    }
                }
            ]
        }
    }



    Component{
        id:_delegate
        Item{
            id: _delegateRoot

            property int shadowBorder: 21 * main.screenScaleX
            property int originalImageWidth: 199 * main.screenScaleX
            property int originalImageHeight: 128 * main.screenScaleY

            state: {return dataToggleModel.get(model.dataIndex).thestate }

            width: originalImageWidth
            height: originalImageHeight-(shadowBorder*2)
            clip: false
            visible: model.isDisplayed && index !== 0

            Image{
                id: backgroundImage
                anchors.centerIn: parent
                x: parent.x - shadowBorder
                y: parent.y - shadowBorder
                source: dataElementActiveBackgroundSource
                mirror: onRight

            }

            Text {
                id: label
                anchors.left:  _delegateRoot.left;
                anchors.leftMargin: 10 * main.screenScaleX + shadowBorder;

                anchors.right: _delegateRoot.right;
                anchors.rightMargin: 10 * main.screenScaleX + shadowBorder;

                anchors.top: _delegateRoot.top;
                anchors.topMargin: 10 * main.screenScaleY;

                height: paintedHeight

                horizontalAlignment: (onRight) ? Text.AlignRight:Text.AlignLeft

                color: "black"
                font.pointSize: 11 * main.screenScaleY
                font.bold: true
                text: qsTranslate(root.sourceFile, model.label) + application.emptyString
                wrapMode: Text.WordWrap
            }

            Text {
                id: value

                anchors.left: (!onRight) ? _delegateRoot.left : undefined;
                anchors.leftMargin: (!onRight) ? 10 + shadowBorder : 0;

                anchors.right: (onRight) ? unit.left : undefined;
                anchors.rightMargin: ( (onRight) ? 5 : 0 ) * main.screenScaleX;

                anchors.bottom: _delegateRoot.bottom;
                anchors.bottomMargin: 2 * main.screenScaleY;
                visible: true

                color: "black"
                font.pointSize: 24 * main.screenScaleY
                font.bold: true
                text: root.visible && root.opacity > 0 ? getData(index) : ""
            }
            Text {
                id: unit

                anchors.left: (!onRight) ? value.right : undefined;
                anchors.leftMargin: ( (!onRight) ? 5 : 0 ) * main.screenScaleX;

                anchors.right: (onRight) ? _delegateRoot.right : undefined;
                anchors.rightMargin: (onRight) ? 10 + shadowBorder : 0;

                anchors.baseline: value.baseline
                visible: true

                color: "black"
                font.pointSize: 8 * main.screenScaleY
                font.bold: true
                text: getUnit(index)
            }

            Image {
                id: button
                anchors.left: (onRight) ? _delegateRoot.left : undefined;
                anchors.leftMargin: (onRight) ? 10 + shadowBorder : 0;

                anchors.right: (!onRight) ? _delegateRoot.right : undefined;
                anchors.rightMargin: (!onRight) ? 10 + shadowBorder : 0;

                anchors.bottom: _delegateRoot.bottom
                anchors.bottomMargin: 10 * main.screenScaleY
                mirror: onRight
            }


            MouseArea{
                id: mouseArea
                anchors.fill: parent
                onClicked:{
                    if(parent.state == "Enabled") {
                        parent.state = "Disabled"
                        dataToggleModel.setProperty(model.dataIndex,"thestate", "Disabled")
                    }
                    else{
                        parent.state = "Enabled"
                        dataToggleModel.setProperty(model.dataIndex,"thestate", "Enabled")
                    }
                    rotateThruData()
                    buzzer.buttonPress()
                }

                //                Rectangle{
                //                    color: "red"
                //                    anchors.fill: parent
                //                    opacity: 0.3
                //                }
            }

            states: [
                State{name: "Enabled"
                    PropertyChanges { target: _delegateRoot; originalImageHeight: 128 * main.screenScaleY; originalImageWidth: 199 * main.screenScaleX}
                    PropertyChanges { target: backgroundImage; source: dataElementActiveBackgroundSource; mirror: onRight}
                    PropertyChanges { target: value; visible: true}
                    PropertyChanges { target: unit; visible: true}
                    PropertyChanges { target: button; source: toggleButtonActiveSource}
                },
                State{name: "Disabled"
                    PropertyChanges { target: _delegateRoot; originalImageHeight: 99 * main.screenScaleY; originalImageWidth: 199 * main.screenScaleX}
                    PropertyChanges { target: backgroundImage; source: dataElementInactiveBackgroundSource; mirror: onRight}
                    PropertyChanges { target: value; visible: false}
                    PropertyChanges { target: unit; visible: false}
                    PropertyChanges { target: button; source: toggleButtonInactiveSource}
                }
            ]
        }
    }
}
