import QtQuick 2.4
import Components 1.0
import ".."

ModalDialog {
    id: root
    dismissable: true

    property string networkId: networkIdPicker.lumpValue()
    property string frequency: frequencyPicker.lumpValue()
    property string modulation: modulationForWscan(modPicker.lumpValue())
    property string symbolRate: symbolratePicker.lumpValue()

    function modulationForWscan() {
        // Translate into a form to be used by wscan "initial tuning data"
        switch (modPicker.lumpValue()) {
            case "64 QAM":
                return "QAM64"
            case "128 QAM":
                return "QAM128"
            case "256 QAM":
                return "QAM256"
        }
        return "QAMUNKNOWN"
    }

    onDismissed: {
        root.hide()
    }

    BorderImage {   // pop-up dialog background
        id: border2

        x: 332 * main.screenScaleX
        y: 21 * main.screenScaleY
        width: 800 * main.screenScaleX
        height: 730 * main.screenScaleY
        source: "../" + main.graphicsPath + "Pop_Up_Lrg_Grey.png"
        border { top: 152 * main.screenScaleY; bottom: 165 * main.screenScaleY; left: 145 * main.screenScaleX; right: 144 * main.screenScaleX }
        ImageButton {
            id: close_button2
            visible: main.isTouch

            z: 200

            width: 36 * main.screenScaleX
            height: 36 * main.screenScaleY
            anchors {   right: parent.right ; rightMargin: 100 * main.screenScaleX ;
                top: parent.top ; topMargin: 40 * main.screenScaleY
            }
            upimage: "../" + main.graphicsPath + "Keypad/KeyPad_X_Large.png"
            downimage: "../" + main.graphicsPath + "Keypad/KeyPad_X_Large.png"

            onClicked: root.dismissed()
            mouseAreaScale: 2.0

        }
        Text {
            id: scanHeader
            width: 501 * main.screenScaleX
            height: 99 * main.screenScaleY
            color: "#ffffff"
            text: qsTr("Network Scan") + application.emptyString
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.top: parent.top
            anchors.topMargin: 35 * main.screenScaleY
            horizontalAlignment: Text.AlignHCenter
            wrapMode: Text.WordWrap
            font.bold: true
            font.pixelSize: 40 * main.screenScaleY
        }

        ListView {
            id: scanControls
            anchors {
                top: scanHeader.bottom
                topMargin: -20 * main.screenScaleY
                horizontalCenter: parent.horizontalCenter
            }
            width: 430 * main.screenScaleX
            height: 700 * main.screenScaleY
            spacing: 5 * main.screenScaleX
            z: 100
            model: controlList.model
            snapMode: ListView.SnapToItem
            interactive: false
            highlightRangeMode: ListView.ApplyRange
            preferredHighlightBegin: height/2 - 30
            preferredHighlightEnd: height/2 + 30
            highlightMoveVelocity: 10000
            currentIndex: controlList.curIndex
            onVisibleChanged: if (visible) controlList.curIndex = 0
            highlight: Component {
                BorderImage {
                    id: selectionCursor
                    visible: main.isTft && controlList.listening
                    border { left: 70 * main.screenScaleX; top: 5 * main.screenScaleY; bottom: 5 * main.screenScaleY; right: 70 * main.screenScaleX }
                    source: "../" + main.graphicsPath + "tft/maintenance_menus_cursor2.png"
                    width: scanControls.currentItem ? scanControls.currentItem.navCursorWidth : 0
                    height: 71 * main.screenScaleY
                    horizontalTileMode: BorderImage.Stretch
                }
            }
        }
        KeyedControlList {
            id: controlList
            listening: main.isTft && root.visible
            listView: scanControls
            width: scanControls.width
            curIndex: 0
            edgeBehavior: "wrap"

            Row {
                id: networkIdRow
                property bool selected: false
                width: parent.width
                height: 100 * main.screenScaleY
                spacing: 10 * main.screenScaleX
                Text {
                    text: qsTr("Network ID") + application.emptyString
                    width: 100 * main.screenScaleX
                    height: 50 * main.screenScaleY
                    anchors.verticalCenter: parent.verticalCenter
                }
                Item {
                    // Spacer
                    height: 50 * main.screenScaleY
                    width: 40 * main.screenScaleX
                }

                ValuePickerRow {
                    id: networkIdPicker
                    property bool selected: false
                    //                onExitedLeft: { channelRow.currentIndex = 1; root.navState = "channel" }
                    //                onExitedRight: { frequencyRow.currentIndex = 0; root.navState = "frequency" }
                    numberOfItems: 5
                    height: 100 * main.screenScaleY
                    width: 260 * main.screenScaleX
                    anchors.verticalCenter: parent.verticalCenter
                    delegate: Component {
                        NumberPicker {
                            id: picker
                            minValue: 0
                            maxValue: 9
                            defaultValue: 0
                            valueWraps: true
                            font { pixelSize: 24 * main.screenScaleY; bold: true }
                            columnSpacing: 5
                            upImage: "../" + main.graphicsPath + "tft/arrow_up.png"
                            upImagePressed: upImage
                            downImage: "../" + main.graphicsPath + "tft/arrow_down.png"
                            downImagePressed: downImage
                            width: 50 * main.screenScaleX
                            height: 90 * main.screenScaleY
                            showArrows: true
                        }
                    }
                }
            }
            Row {
                id: frequencyRow
                property bool selected: false
                width: parent.width
                height: 100 * main.screenScaleY
                spacing: 10 * main.screenScaleX
                Text {
                    text: qsTr("Frequency") + application.emptyString
                    width: 100 * main.screenScaleX
                    height: 50 * main.screenScaleY
                    anchors.verticalCenter: parent.verticalCenter
                }
                Item {
                    // Spacer
                    height: 50 * main.screenScaleY
                    width: 40 * main.screenScaleX
                }
                ValuePickerRow {
                    id: frequencyPicker
                    //                onExitedLeft: { channelRow.currentIndex = 1; root.navState = "channel" }
                    //                onExitedRight: { frequencyRow.currentIndex = 0; root.navState = "frequency" }
                    numberOfItems: 6
                    height: 100 * main.screenScaleY
                    width: 310 * main.screenScaleX
                    anchors.verticalCenter: parent.verticalCenter
                    delegate: Component {
                        NumberPicker {
                            id: picker
                            minValue: 0
                            maxValue: 9
                            defaultValue: 0
                            valueWraps: true
                            font { pixelSize: 24 * main.screenScaleY; bold: true }
                            columnSpacing: 5
                            upImage: "../" + main.graphicsPath + "tft/arrow_up.png"
                            upImagePressed: upImage
                            downImage: "../" + main.graphicsPath + "tft/arrow_down.png"
                            downImagePressed: downImage
                            width: 50 * main.screenScaleX
                            height: 90 * main.screenScaleY
                            showArrows: true
                        }
                    }
                }
                Text {
                    text: "KHz"
                    width: 100 * main.screenScaleX
                    height: 50 * main.screenScaleY
                    anchors.verticalCenter: parent.verticalCenter
                }
            }
            Row {
                id: modulationRow
                property bool selected: false
                width: parent.width
                height: 100 * main.screenScaleY
                spacing: 10 * main.screenScaleX
                Text {
                    text: qsTr("Modulation") + application.emptyString
                    width: 100 * main.screenScaleX
                    height: 50 * main.screenScaleY
                    anchors.verticalCenter: parent.verticalCenter
                }
                Item {
                    // Spacer
                    height: 50 * main.screenScaleY
                    width: 40 * main.screenScaleX
                }
                Item {
                    id: centeringRow
                    width: 300 * main.screenScaleX
                    height: 100 * main.screenScaleY
                    anchors.verticalCenter: parent.verticalCenter
                    ValuePickerRow {
                        id: modPicker
                        //                onExitedLeft: { channelRow.currentIndex = 1; root.navState = "channel" }
                        //                onExitedRight: { frequencyRow.currentIndex = 0; root.navState = "frequency" }
                        numberOfItems: 1
                        height: 100 * main.screenScaleY
                        width: 100 * main.screenScaleX
                        anchors.centerIn: parent
                        delegate: Component {
                            NumberPicker {
                                id: picker
                                ListModel {
                                    id: qamModel
                                    ListElement { label: "64 QAM"; value: 64 }
                                    ListElement { label: "128 QAM"; value: 128 }
                                    ListElement { label: "256 QAM"; value: 256 }
                                }
                                minValue: 0
                                maxValue: qamModel.count - 1
                                printedValue: qamModel.get(value).label
                                defaultValue: 0
                                valueWraps: true
                                font { pixelSize: 24 * main.screenScaleY; bold: true }
                                columnSpacing: 5
                                upImage: "../" + main.graphicsPath + "tft/arrow_up.png"
                                upImagePressed: upImage
                                downImage: "../" + main.graphicsPath + "tft/arrow_down.png"
                                downImagePressed: downImage
                                width: 100 * main.screenScaleX
                                height: 90 * main.screenScaleY
                                showArrows: true
                            }
                        }
                    }
                }

            }
            Row {
                id: symbolrateRow
                property bool selected: false
                width: parent.width
                height: 100 * main.screenScaleY
                spacing: 10 * main.screenScaleX
                Text {
                    text: qsTr("Symbol Rate") + application.emptyString
                    width: 100 * main.screenScaleX
                    height: 50 * main.screenScaleY
                    anchors.verticalCenter: parent.verticalCenter
                }
                Item {
                    // Spacer
                    height: 50 * main.screenScaleY
                    width: 40 * main.screenScaleX
                }
                ValuePickerRow {
                    id: symbolratePicker
                    //                onExitedLeft: { channelRow.currentIndex = 1; root.navState = "channel" }
                    //                onExitedRight: { frequencyRow.currentIndex = 0; root.navState = "frequency" }
                    numberOfItems: 4
                    height: 100 * main.screenScaleY
                    width: 210 * main.screenScaleX
                    anchors.verticalCenter: parent.verticalCenter
                    delegate: Component {
                        NumberPicker {
                            id: picker
                            minValue: 0
                            maxValue: 9
                            defaultValue: 0
                            valueWraps: true
                            font { pixelSize: 24 * main.screenScaleY; bold: true }
                            columnSpacing: 5
                            upImage: "../" + main.graphicsPath + "tft/arrow_up.png"
                            upImagePressed: upImage
                            downImage: "../" + main.graphicsPath + "tft/arrow_down.png"
                            downImagePressed: downImage
                            width: 50 * main.screenScaleX
                            height: 90 * main.screenScaleY
                            showArrows: true
                        }
                    }
                }
                Text {
                    text: "KS/s"
                    width: 100 * main.screenScaleX
                    height: 50 * main.screenScaleY
                    anchors.verticalCenter: parent.verticalCenter
                }
            }
        }
        ImageButton {
            id: okButton

            anchors {
                top: scanControls.bottom
                topMargin: -260 * main.screenScaleY
                horizontalCenter: parent.horizontalCenter
            }
            label: qsTr("OK") + application.emptyString
            label_color: "black"
            label_under: true
            label_y_offset: 4 * main.screenScaleY
            upimage: "../" + main.graphicsPath + "205/Lrg_Button_Up.png"
            downimage: "../" + main.graphicsPath + "205/Lrg_Button_Down.png"

            onClicked: {
                root.dismissed()
            }
        }
    }
    Component.onCompleted: hide()
}
