import QtQuick 2.4

import FileIO 1.0
import QtQuick 2.4
import ".."
import Process 0.1
import "../string_format.js" as Format
import Components 1.0


Rectangle {
    id: root
    width: 1366 * main.screenScaleX
    height: 768 * main.screenScaleY
    anchors.fill: parent
    state: ""
    color: "transparent"

    property int topOffset: 130
    property int itemSpacing: -10

    property int menuItemWidth: 150
    property int menuItemHeight: 75

    property bool datadirty: false

    signal close()

    Component.onCompleted: {
        dataExport.getNetworkAddresses()
        simMode.value = options.simulationMode ? true : false
        pedalTimeout.value = options.disableNoPedalStop ? false : true
        showStimulusAreaMode.value = options.showStimulusArea ? true : false
        showCursorMode.value = options.showCursor ? true : false
        standAloneMode.value = options.ignoreFaults ? true: false
        scaleHDTVMode.value = options.scaleHDTV
        tvAccelerationMode.value = options.tvHwAccel
        tvFrameDropMode.value = !options.tvNoFrameDrop
        erpEnabled.value = options.erpEnabled ? true: false
        disableBuzzerMode.value = options.disableBuzzer
        logginEnabledMode.value = options.loggingEnabled ? true : false
        modestyModeSwitch.value = options.modestyMode
        brainboardDebugLevelMode.value = options.brainboardDebugLogLevel
        en957EnableControl.value = options.en957Enabled ? true : false
        
        // set developmentSoftware.value 
        checkDailyRepo.start()

        if(options.fanOption === "2-Wire")
            fanOption.value = false;
        else
            fanOption.value = true;

        messageCenterBrightnessControl.value = options.messageCenterBrightness
        messageCenterContrastControl.value = options.messageCenterContrast
        manufacturingTestMode.value = options.manufacturingTestModeEnabled
        autoChannelChangeControl.value = options.autoChannelChangeInterval
    }

    Connections {
        target: main.isTft && main.state === "DiagnosticState" && root.visible && diagnostics_screen.item !== null && diagnostics_screen.item.currentSelectedIndex >= 0 ? keymapper : null

        onBackPressed: {
            main.debugKeys("backPressed", "DiagnosticsDevelop")
            diagnostics_screen.item.unselectScreen()
        }
    }

    KeyedControlList {
        id: controlList
        listening: root.visible && diagnostics_screen.item !== null && diagnostics_screen.item.currentSelectedIndex >= 0
        listView: mode

        ToggleButtonLabeled{
            id: simMode
            labelString: qsTr("Enable Demo Run Screen") + application.emptyString

            onValueChanged:
            {
                options.simulationMode = value ? true : false
                datadirty = true
            }
        }

        ToggleButtonLabeled{
            id: pedalTimeout
            labelString: qsTr("Zero RPM Timeout") + application.emptyString

            onValueChanged:
            {
                options.disableNoPedalStop = value ? false : true
                datadirty = true
            }
        }

        ToggleButtonLabeled{
            id: showStimulusAreaMode
            labelString: qsTr("Stimulus Area Enabled") + application.emptyString
            onValueChanged:
            {
                options.showStimulusArea = value ? true : false
                datadirty = true
            }
        }

        ToggleButtonLabeled{
            id: showCursorMode
            labelString: qsTr("Show Cursor") + application.emptyString
            onValueChanged:
            {
                options.showCursor = value ? true : false
                datadirty = true
            }
        }

        ToggleButtonLabeled{
            id: standAloneMode
            labelString: qsTr("Stand Alone Mode") + application.emptyString
            onValueChanged:
            {
                options.ignoreFaults = value ? true : false
                if(value == true) {
                    errorManager.fatalError = false
                    errorManager.preventUse = false
                    errorManager.degradedUse = false
                }
                datadirty = true
            }
        }

        ToggleButtonLabeled{
            id: manufacturingTestMode
            labelString: qsTr("Manufacturing Test Mode") + application.emptyString
            onValueChanged:
            {
                if (value) {
                    options.manufacturingTestModeEnabled = true
                    standAloneMode.value = true
                } else {
                    options.manufacturingTestModeEnabled = false
                    standAloneMode.value = false
                }
            }
            MouseArea {
                // Block mouse area of toggle button to show confirmation
                // prompt before changing setting
                anchors.fill: parent
                onClicked: {
                    buzzer.buttonPress()
                    if (manufacturingTestMode.value === false) {
                        confirmPrompt.text = manufacturingTestMode.labelString
                        confirmPrompt.show()
                    } else {
                        manufacturingTestMode.value = false
                    }
                }
            }
        }


        ToggleButtonLabeled {
            id: developmentSoftware
            labelString:  qsTr("Enable verum-daily repository") + application.emptyString
            onValueChanged: {
                if (value) {
                    enableDailyRepo.start()
                } else {
                    disableDailyRepo.start()
                }
            }
        }


        ToggleButtonLabeled{
            id: erpEnabled
            visible: main.erpIsSupported
            labelString: qsTr("Energy Saving Timer Enabled") + application.emptyString
            onValueChanged:
            {
                options.erpEnabled = value ? true : false
                datadirty = true
                nucleus.setERPSupport(value)
            }
        }

        ToggleButtonLabeled{
            id: scaleHDTVMode
            labelString: qsTr("HDTV frame smoothing") + application.emptyString
            onValueChanged:
            {
                options.scaleHDTV = value ? true : false
                datadirty = true
                console.debug("HDTVscale: "+options.scaleHDTV)
            }
        }

        ToggleButtonLabeled{
            id: tvFrameDropMode
            labelString: qsTr("TV Drop Late Frames (restart needed)") + application.emptyString
            onValueChanged:
            {
                options.tvNoFrameDrop = value ? false : true
                datadirty = true
            }
        }

        ToggleButtonLabeled{
            id: tvAccelerationMode
            labelString: qsTr("TV Acceleration (restart needed)") + application.emptyString
            onValueChanged:
            {
                options.tvHwAccel = value ? true : false
                datadirty = true
            }
        }
        ToggleButtonLabeled {
            id: remoteAccessToggle
            labelString: qsTr("Remote Access Enabled") + application.emptyString
            value: remoteAccess.isEnabled
            onValueChanged:
            {
                remoteAccess.isEnabled = value
                if (remoteAccess.isEnabled) {
                    accessConnecting.show()
                } else {
                    // Hide in progress popup
                    accessConnecting.hide()
                }
            }
        }
        ToggleButtonLabeled {
            id: diagnosticsUploadToggle
            labelString: qsTr("Send Diagnostics Reports to TRUE") + application.emptyString
            value: options.diagnosticsUploadEnabled
            onValueChanged:
            {
                options.diagnosticsUploadEnabled = value
                datadirty = true
            }
        }
        ToggleButtonLabeled{
            id: disableBuzzerMode
            labelString: qsTr("Disable Buzzer") + application.emptyString
            onValueChanged:
            {
                options.disableBuzzer = value
                datadirty = true
            }
        }

        ToggleButtonLabeled{
            id: fanOption
            labelString: qsTr("3 Wire Fan?") + application.emptyString
            onValueChanged:
            {
                options.fanOption = value ? "3-Wire" : "2-Wire"
                datadirty = true
            }
        }

        SliderControlLabeled{
            id: messageCenterBrightnessControl
            headingString: qsTr("Message Center Brightness:") + application.emptyString
            minValue: 0
            maxValue: 100
            stepValue: 1
            onValueChanged:
            {
                options.messageCenterBrightness = value
                datadirty = true
            }
        }

        SliderControlLabeled{
            id: messageCenterContrastControl
            headingString: qsTr("Message Center Contrast:") + application.emptyString
            minValue: 0
            maxValue: 100
            stepValue: 1
            onValueChanged:
            {
                options.messageCenterContrast = value
                datadirty = true
            }
        }

        ToggleButtonLabeled{
            id: en957EnableControl
            labelString: qsTr("EN957 Mode") + application.emptyString
            onValueChanged:
            {
                options.en957Enabled = value ? true : false
                datadirty = true
            }
        }

        ToggleButtonLabeled{
            id: logginEnabledMode
            labelString: qsTr("Logging Enabled") + application.emptyString
            onValueChanged:
            {
                if(value == false){
                    console.debug("Logging Enabled is off");
                }

                options.loggingEnabled = value ? true : false
                datadirty = true

                if(value == true){
                    console.debug("Logging Enabled is on");
                }

                nucleus.setDiagnostics(options.loggingEnabled)
            }
        }
        ToggleButtonLabeled{
            id: modestyModeSwitch
            labelString: qsTr("Display Images M.E.") + application.emptyString
            onValueChanged: {
                options.modestyMode = value
            }
        }

        SliderControlLabeled{
            id: brainboardDebugLevelMode
            headingString: qsTr("Brainboard Debug Level") + application.emptyString
            minValue: 0
            maxValue: 3
            stepValue: 1
            displayValue: value
            onValueChanged:
            {
                options.brainboardDebugLogLevel = value
                datadirty = true
            }
        }


        SliderControlLabeled{
            id: autoChannelChangeControl
            headingString: qsTr("Automatic Channel Change Interval:") + application.emptyString
            minValue: 0
            maxValue: 600000
            stepValue: 500
            displayValue: value
            onValueChanged:
            {
                options.autoChannelChangeInterval = value
                tvTestHud.channelChangeTime = value
                datadirty = true
            }
        }

        InlineButton {
            property string progressDots: dotAnim.txt

            label: qsTr("Export Diagnostics") + progressDots + application.emptyString
            labelWidth: 300 * main.screenScaleX
            enabled: main.isTft && storageMgr.usbDeviceLoaded && diagExportProcess.processState == Process.NotRunning
            labelColor: enabled ? "black" : "green"
            visible: main.isTft && storageMgr.usbDeviceLoaded
            onPressed: {
                if (diagExportProcess.processState == Process.NotRunning)
                    diagExportProcess.startExport()
            }
            Timer {
                id: dotAnim

                property string txt: ""
                property int i: 0

                interval: 400
                running: diagExportProcess.processState != Process.NotRunning
                repeat: true
                onTriggered: {
                    i = (i + 1) % 4
                    txt = (new Array(i+1)).join(".")
                }

                onRunningChanged: {
                    if (!running) {
                        txt = ""
                        i = 0
                    }
                }
            }
        }
    }

    Item {
        id: dataArrows

        width: 40 * main.screenScaleX
        height: parent.height - 90

        anchors { left: parent.left; leftMargin: 630 * main.screenScaleX; verticalCenter: mode.verticalCenter }
        Image {
            id: dataUpArrow
            visible: !mode.atYBeginning
            source: "../" + main.graphicsPath + "Swipe_Arrows_Left.png"
            rotation: 90
            anchors { top: parent.top; topMargin: 50 * main.screenScaleY; right: parent.right }
        }
        Image {
            id: dataDownArrow
            visible: !mode.atYEnd
            source: "../" + main.graphicsPath + "Swipe_Arrows_Right.png"
            rotation: 90
            anchors { bottom: parent.bottom; bottomMargin: 50 * main.screenScaleY; right: parent.right }
        }

    }

    ListView{
        id: mode
        anchors.horizontalCenter: root.horizontalCenter
        anchors.top: root.top
        anchors.topMargin: 20 * main.screenScaleY
        width: root.width * 0.8
        height: 540 * main.screenScaleY
        model: controlList.model
        clip: true
        snapMode: ListView.SnapToItem
        highlightRangeMode: ListView.ApplyRange
        preferredHighlightBegin: height/2 - 30
        preferredHighlightEnd: height/2 + 30
        highlightMoveVelocity: 10000
        currentIndex: controlList.curIndex
        highlight: Component {
            Item {
                BorderImage {
                    id: selectionCursor
                    visible: main.isTft && controlList.listening
                    border { left: 70 * main.screenScaleX; top: 5 * main.screenScaleY; bottom: 5 * main.screenScaleY; right: 70 * main.screenScaleX }
                    source: "../" + main.graphicsPath + "tft/maintenance_menus_cursor.png"
                    width: mode.currentItem ? mode.currentItem.navCursorWidth + 30 * main.screenScaleX : 0
                    height: 56 * main.screenScaleY
                    horizontalTileMode: BorderImage.Stretch
                }
            }
        }
    }

    Text {
        id: bottomHelpText
        visible: main.isTft && diagnostics_screen.item !== null && diagnostics_screen.item.currentSelectedIndex >= 0

        height: 48 * main.screenScaleY
        font { family: "arial"; pixelSize: 36 * main.screenScaleY; bold: true }
        color: "#6c6c6c"
        text: qsTr("use <img src='../graphics/tft/arrow_up.png' /><img src='../graphics/tft/arrow_down.png' /> to navigate, use <img src='../graphics/tft/arrow_left.png' /> <img src='../graphics/tft/arrow_right.png' /> to change value") + application.emptyString

        anchors.bottom: parent.bottom
        anchors.bottomMargin: 25 * main.screenScaleY
        anchors.horizontalCenter: parent.horizontalCenter
    }

    // Hide convesion button for now
    /*ImageButton {
        label: qsTr("Convert to New TrueUI") + application.emptyString
        enabled: main.isTouch && convertUIProcess.processState == Process.NotRunning
        visible: !main.isTft
        anchors {
            right: parent.right
            rightMargin: 50 * main.screenScaleX
            top: mode.top
        }

        label_color: enabled ? "black" : "green"
        wrapWidth: 150 * main.screenScaleX
        label_under: true
        label_y_offset: 35 * main.screenScaleY
        upimage:"../" + main.graphicsPath + "200/TRU_200_other_small_Button_Up.png"
        downimage:"../" + main.graphicsPath + "200/TRU_200_other_small_Button_Down.png"
        onClicked: confirmUIChangePrompt.show()
    }*/

    ImageButton {
        id: networkExportButton

        enabled: logUploader.state !== "Terminating" && !logUploader.running
        visible: main.isTouch && !storageMgr.usbDeviceLoaded && dataExport.ipAddress && !logUploader.uploading && !uploadTerminatingDialog.visible

        upimage:"../" + main.graphicsPath + "200/TRU_200_other_small_Button_Up.png"
        downimage:"../" + main.graphicsPath + "200/TRU_200_other_small_Button_Down.png"
        anchors { right: parent.right ; rightMargin: 50 * main.screenScaleX;  bottom: mode.bottom }
        label: qsTr("Upload Diagnostics to TRUE Server") + application.emptyString
        wrapWidth: 150 * main.screenScaleX
        label_under: true
        label_y_offset: 35 * main.screenScaleY
        label_color: "black"

        onClicked: {
            // Start upload
            logUploader.start()
            connectingDialog.show()
        }
    }
    ModalDialog {
        id: uploadingDialog
        dismissable: true

        property string errorMessage: ""

        onDismissed: {
        }

        BorderImage {   // pop-up dialog background
            id: border

            x: 332 * main.screenScaleX
            y: 161 * main.screenScaleY
            width: 800 * main.screenScaleX
            height: 390 * main.screenScaleY
            source: "../" + main.graphicsPath + "Pop_Up_Lrg_Grey.png"
            border { top: 152 * main.screenScaleY; bottom: 165 * main.screenScaleY; left: 145 * main.screenScaleX; right: 144 * main.screenScaleX }
            Text {
                id: warningText
                width: 501 * main.screenScaleX
                height: 99 * main.screenScaleY
                color: "#ffffff"
                text: (logUploader.state === "Failed" ? uploadingDialog.errorMessage : qsTr("Uploading")) + application.emptyString
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.top: parent.top
                anchors.topMargin: 35 * main.screenScaleY
                horizontalAlignment: Text.AlignHCenter
                wrapMode: Text.WordWrap
                font.bold: true
                font.pixelSize: 50 * main.screenScaleY
            }

            Rectangle {
                id: progressBar

                property real progress: logUploader.percentComplete / 100.0

                x: 240 * main.screenScaleX
                y: 125 * main.screenScaleY
                visible: logUploader.transferStarted
                width: 300 * main.screenScaleX
                height: 40 * main.screenScaleY
                radius: 5 * main.screenScaleX
                opacity: logUploader.state === "Failed" ? 0.5 : 1.0

                color: "transparent"
                border.color: "black"
                border.width: 3 * main.screenScaleX

                Rectangle {
                    anchors {left: parent.left; top: parent.top ; bottom: parent.bottom }
                    radius: 5 * main.screenScaleX
                    color: "steelblue"
                    width: progressBar.progress * parent.width
                    height: parent.height
                }

                Text {
                    text: (100 * progressBar.progress | 0) + "%"
                    anchors.fill: parent
                    horizontalAlignment: Text.AlignHCenter
                    verticalAlignment: Text.AlignVCenter
                }
            }

//            ImageButton {
//                id: tryAgainButton

//                visible: logUploader.state === "Failed"
//                enabled: !logUploader.running
//                anchors {
//                    bottom: parent.bottom
//                    bottomMargin: 50 * main.screenScaleY
//                    horizontalCenter: parent.horizontalCenter
//                }
//                label: qsTr("Try Again") + application.emptyString
//                label_color: "black"
//                label_under: true
//                label_y_offset: 3 * main.screenScaleY
//                upimage: "../" + main.graphicsPath + "205/SM_Button_Up.png"
//                downimage: "../" + main.graphicsPath + "205/SM_Button_Down.png"

//                onClicked: {
//                    logUploader.start()
//                }
//            }
        }
        Component.onCompleted: hide()
        onTimedOut: hide()
    }
    ModalDialog {
        id: connectingDialog
        dismissable: true

        onDismissed: {
            logUploader.stop()
            connectingDialog.hide()
            uploadTerminatingDialog.show()
            uploadTerminatingDialog.startTimeout(2)
        }

        BorderImage {   // pop-up dialog background
            x: 332 * main.screenScaleX
            y: 161 * main.screenScaleY
            width: 800 * main.screenScaleX
            height: 390 * main.screenScaleY
            source: "../" + main.graphicsPath + "Pop_Up_Lrg_Grey.png"
            border { top: 152 * main.screenScaleY; bottom: 165 * main.screenScaleY; left: 145 * main.screenScaleX; right: 144 * main.screenScaleX }
            Text {
                width: 501 * main.screenScaleX
                height: 99 * main.screenScaleY
                color: "#ffffff"
                text: qsTr("Connecting") + application.emptyString
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.top: parent.top
                anchors.topMargin: 35 * main.screenScaleY
                horizontalAlignment: Text.AlignHCenter
                wrapMode: Text.WordWrap
                font.bold: true
                font.pixelSize: 50 * main.screenScaleY
            }

            ImageButton {
                id: cancelConnectButton

                visible: logUploader.state === "Connecting"
                anchors {
                    bottom: parent.bottom
                    bottomMargin: 50 * main.screenScaleY
                    horizontalCenter: parent.horizontalCenter
                }
                label: qsTr("Cancel") + application.emptyString
                label_color: "black"
                label_under: true
                label_y_offset: 3 * main.screenScaleY
                upimage: "../" + main.graphicsPath + "205/Lrg_Button_Up.png"
                downimage: "../" + main.graphicsPath + "205/Lrg_Button_Down.png"

                onClicked: {
                    connectingDialog.dismissed()
                }
            }
        }
        Component.onCompleted: hide()
        onTimedOut: hide()
    }

    MessagePopup {
        id: accessConnecting
        message: qsTr("Connecting...") + application.emptyString
        isTransparent: true

        Component.onCompleted: hide()

        Connections {
            target: remoteAccess
            onSuccessChanged: {
                if (remoteAccess.success) {
                    accessConnecting.hide()
                }
            }
        }
    }
    MessagePopup {
        id: logUploadSuccessful
        dismissable: true
        dismissAnywhere: true
        isTransparent: true
        message: qsTr("Log Upload Successful") + application.emptyString
        Component.onCompleted: hide()
    }
    MessagePopup {
        id: connectionErrorDialog
        dismissable: true
        dismissAnywhere: true
        message: qsTr("Connection Error") + application.emptyString
        Component.onCompleted: hide()
    }
    MessagePopup {
        id: uploadTerminatingDialog
        dismissable: false
        message: qsTr("Stopping Upload") + application.emptyString
        Component.onCompleted: hide()
    }

    Connections {
        target: logUploader

        onTransferComplete: {
            buzzer.buttonPress()
            logUploadSuccessful.show()
            //logUploadSuccessful.startTimeout(5)
            uploadingDialog.hide()
        }

        onDataTransferStarted: {
            connectingDialog.hide()
            uploadingDialog.show()
        }

        onUploadFailed: {
            buzzer.buttonPress()
            uploadingDialog.errorMessage = qsTr("Log Upload Failed")
        }

        onConnectionError: {
            buzzer.buttonPress()
            connectingDialog.hide()
            connectionErrorDialog.show()
        }

        onTerminated: {
        }
    }

    ImageButton {
        id: exportDiagButton
        property bool exportPending: false

        enabled: storageMgr.usbDeviceLoaded && !(diagExportProcess.processState != Process.NotRunning)
        visible: main.isTouch && storageMgr.usbDeviceLoaded && !logUploader.uploading

        upimage:"../" + main.graphicsPath + "200/TRU_200_other_small_Button_Up.png"
        downimage:"../" + main.graphicsPath + "200/TRU_200_other_small_Button_Down.png"
        anchors { right: parent.right ; rightMargin: 100 * main.screenScaleX;  bottom: mode.bottom }
        label: qsTr("Export Diagnostics") + application.emptyString
        label_under: true
        label_y_offset: 5 * main.screenScaleY
        label_color: "black"

        onClicked: {
            if(main.lowerSystem === "NUCLEUS") {
                exportPending = true
                errorManager.retrieveFaultLogs()
            } else {
                diagExportProcess.startExport()
            }
        }
    }

    Connections {
        target: errorManager
        onRetrieveNucleusFaultLogComplete: {
            if(exportDiagButton.exportPending === true) {
                exportDiagButton.exportPending = false
                diagExportProcess.startExport()
            }
        }
    }

    Connections {
        target: language_menu
        onLanguageSelected: {
            if (languageDiagnosticMenu) {
               main.state = "DiagnosticState"
               if (lang)
               {
                   application.selectLanguage(lang)
                   options.defaultLanguage = lang
                   defaultLanguageText.text = language_menu.getLanguageName(options.defaultLanguage)
                   defaultLanguageIcon.source = "../LanguageMenu/" + language_menu.getLanguageIcon(options.defaultLanguage)
               }
               languageDiagnosticMenu = false
            }
        }
    }

    FileIO {
        id: fileio
    }

    Process {
        id: diagExportProcess

        function startExport() {
            // Run export script
            var unixTime = (new Date).getTime()
            var dirName = main.serialNumber + "-diag-" + unixTime
            diagExportProcess.arguments = ["/media/usb/"+dirName]
            diagExportProcess.start()
        }

        program: "scripts/export-diagnostics/export_diag.sh"
    }

    Process {
        id: checkDailyRepo
        program: "scripts/toggleDailyRepo.sh"
        arguments: "2"
        onReadyReadStandardOutput: {
            var out = new String(readAllStandardOutput())
            if( out.match(/active/)){
	     developmentSoftware.value =true
	     console.log("checkDailyRepo: active"  + developmentSoftware.value)
	   }else{
	      developmentSoftware.value = false
	      console.log("checkDailyRepo: disabled "  + developmentSoftware.value)
            }
        }

        onReadyReadStandardError: {
            var out=String(readAllStandardError())
            console.log("enableDailyRepo (error):" + out )
        }

    }
    Process {
        id: enableDailyRepo
        program: "scripts/toggleDailyRepo.sh"
        arguments: "1"
        onReadyReadStandardOutput: {
            var out=String(readAllStandardOutput())
            console.log("enableDailyRepo: " + out )
        }

        onReadyReadStandardError: {
            var out=String(readAllStandardError())
            console.log("enableDailyRepo (error):" + out )
        }

    }

    Process {
        id: disableDailyRepo
        program: "scripts/toggleDailyRepo.sh"
        arguments: "0"
        onReadyReadStandardOutput: {
            var out=String(readAllStandardOutput())
            console.log("disableDailyRepo: " + out )
        }

        onReadyReadStandardError: {
            var out=String(readAllStandardError())
            console.log("disableDailyRepo (error):" + out )
        }

    }

    // Hide convesion button for now
    /*Process {
        id: convertUIProcess

        program: "scripts/uiSelect.sh"
        arguments: "trueui"

        onReadyReadStandardOutput: {
            var out=String(readAllStandardOutput())
            console.log("uiSelect.sh " + out )
        }

        onReadyReadStandardError: {
            var out=String(readAllStandardError())
            console.log("uiSelect.sh (error):" + out )
        }
    }

    ConfirmationPrompt {
        id: confirmUIChangePrompt
        x: 300  * main.screenScaleX; y: 200 * main.screenScaleY
        visible: false
        prompt: qsTr("Enter access code and confirm upgrade to TrueUI.") + application.emptyString

        Keypad{
            id:accessKeyPad
            length: 5
            allow_close: false
            clear_after_enter: false
            anchors.left: parent.left
            anchors.leftMargin: -0.9*accessKeyPad.width
            anchors.top: parent.top
            z:parent.z + 1
        }

        onNoClicked: {
            // Do nothing
            hide()
        }

        onYesClicked: {
            if(accessKeyPad.value === "48362" || accessKeyPad.value === "20173") {
                convertUIProcess.start()
                main.restartRequired = true
                prompt = qsTr("Upgrading UI...") + application.emptyString
                startTimeout(3)
            }
            else {
                console.log("UI not upgraded. Incorrect access code entered: " + accessKeyPad.value )
                prompt = qsTr("Incorrect Access Code.") + application.emptyString
                accessKeyPad.clear()
            }
        }

        onTimedOut: {
            hide()
        }
    } */

    ConfirmationPrompt {
        id: confirmPrompt
        property string text: ""
        x: 300 * main.screenScaleX ; y: 200 * main.screenScaleY
        visible: false
        prompt: qsTr("Enable") + " " + confirmPrompt.text + "?"
        onNoClicked: {
            // Do nothing
            hide()
        }
        onYesClicked: {
            manufacturingTestMode.value = true
            hide()
        }
    }
}
