import QtQuick 2.4

import ".."
import FileIO 1.0
import Components 1.0

Item {

    id: root
    property QtObject filteredCountryList
    property int tuner_id: 1
    property QtObject errorModel
    property string cursorState: "log" // log, export, or clear
    property bool isNucleus: (machineinfo.systemConfig === "NUCLEUS" || machineinfo.systemConfig === "NUCBOOT")

    Component.onCompleted: {
        errorManager.retrieveFaultLogs()
    }

    Connections{
        target:errorManager
        onErrorListModelChanged: {
            var newModel = errorListModel
            errorList.model = newModel
        }
    }

    Connections {
        target: main.isTft && main.state === "DiagnosticState" && root.visible && diagnostics_screen.item !== null && diagnostics_screen.item.currentSelectedIndex >= 0 ? keymapper : null

        onBackPressed: {
            main.debugKeys("backPressed", "DiagnosticsError")
            diagnostics_screen.item.unselectScreen()
        }

        onLeftButtonPressed: {
            main.debugKeys("leftPressed", "DiagnosticsError")
            if (root.cursorState === "log") {
                root.cursorState = "clear"
            } else if (root.cursorState === "clear") {
                root.cursorState = "export"
            } else {
                root.cursorState = "log"
            }
        }

        onRightButtonPressed: {
            main.debugKeys("rightPressed", "DiagnosticsError")
            if (root.cursorState === "log") {
                root.cursorState = "export"
            } else if (root.cursorState === "export") {
                root.cursorState = "clear"
            } else {
                root.cursorState = "log"
            }
        }

        onEnter2Pressed: {
            main.debugKeys("enter2Pressed", "DiagnosticsError")
            if (root.cursorState === "export" && exportButton.enabled) {
                exportButton.clicked()
            } else if (root.cursorState === "clear" && clearButton.enabled) {
                clearButton.clicked()
            }
        }
    }

    Connections {
        target: main.isTft && main.state === "DiagnosticState" && root.cursorState === "log" ? keymapper : null

        onUpButtonPressed: {
            main.debugKeys("upButtonPressed", "DiagnosticsError")
            var index = errorList.currentIndex - 10 < 0 ? 0 : errorList.currentIndex - 10
            errorList.currentIndex = index
//            errorList.positionViewAtIndex(index, ListView.Beginning)
        }

        onDownButtonPressed: {
            main.debugKeys("downButtonPressed", "DiagnosticsError")
            var index = errorList.currentIndex + 10 > errorList.count-10 ? errorList.count - 10 : errorList.currentIndex + 10
            errorList.currentIndex = index
//            errorList.positionViewAtIndex(index, ListView.Beginning)
        }
    }

    Text {
        id: emptyMessage

        anchors.horizontalCenter: errorList.horizontalCenter
        anchors.top: errorList.top
        visible: errorList.model.count === 0
        text: qsTr("The Fault Log is empty") + application.emptyString
    }

    ListView {
        id: errorList

        anchors.top: parent.top
        anchors.topMargin: 10 * main.screenScaleY
        anchors.left: parent.left
        anchors.leftMargin: 10 * main.screenScaleX
        anchors.right: parent.right
        anchors.rightMargin: 60 * main.screenScaleX
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 200 * main.screenScaleY
        clip: true

        visible: true
        model: root.errorModel
        snapMode: ListView.SnapToItem
        highlightRangeMode: ListView.StrictlyEnforceRange
        preferredHighlightBegin: 0
        preferredHighlightEnd: 20
        highlightMoveVelocity: 2000

        delegate: Component {
            Row {
                spacing: 10 * main.screenScaleX
                Text { text: ""+index; color: "gray"; width: 35 * main.screenScaleX }
                Text {
                    property string odometer: options.metricUnits ? Globals.mileToKm(mileage) : mileage
                    property string odometer_units: options.metricUnits ? qsTr("km") : qsTr("mi")

                    text: (odometer/100).toFixed(2) + (odometer_units) + " :  " +  timestamp
                }
                Text { text: errordescription }
            }
        }
    }

    Item {
        id: dataArrows

        width: 40 * main.screenScaleX
        height: errorList.height

        anchors {
            left: errorList.right;
            leftMargin: 30 * main.screenScaleX;
            verticalCenter: errorList.verticalCenter }
        Image {
            id: dataUpArrow
            visible: !errorList.atYBeginning
            source: "../" + main.graphicsPath + "Swipe_Arrows_Left.png"
            rotation: 90
            anchors {
                top: parent.top;
                topMargin: 20 * main.screenScaleY;
                left: parent.left
                leftMargin: -23 * main.screenScaleX
            }
        }
        Image {
            id: dataDownArrow
            visible: !(errorList.currentIndex + 10 >= errorList.count)
            source: "../" + main.graphicsPath + "Swipe_Arrows_Right.png"
            rotation: 90
            anchors {
                bottom: parent.bottom;
                bottomMargin: 20 * main.screenScaleY;
                left: parent.left
                leftMargin: -23 * main.screenScaleX
            }
        }
    }

    Image {
        source: "../" + main.graphicsPath + "tft/NAV_selector_2.png"
        visible: main.isTft && cursorState === "clear"
        anchors.centerIn: clearButton
        z: clearButton.z - 1
    }

    Image {
        source: "../" + main.graphicsPath + "tft/NAV_selector_2.png"
        visible: main.isTft && cursorState === "export"
        anchors.centerIn: exportButton
        z: exportButton.z - 1
    }

    ImageButton{
        id: clearButton
        label: qsTr("CLEAR") + application.emptyString
        upimage:"../" + main.graphicsPath + "200/TRU_200_other_small_Button_Up.png"
        downimage:"../" + main.graphicsPath + "200/TRU_200_other_small_Button_Down.png"
        label_under: false
        label_y_offset: -3 * main.screenScaleY
        anchors.right: parent.right
        anchors.rightMargin: 70 * main.screenScaleX
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 50 * main.screenScaleY
        onClicked: {
            errorManager.clearAllError()

            dialogText.text = qsTr("Error Log was cleared")
            actionSuccessfulDialog.show()
            actionSuccessfulDialog.startTimeout(1)
        }
    }

    ImageButton{
        id: exportButton
        enabled: (errorList.model.count > 0 || errorManager.nucleusFaultListModel.count > 0) && storageMgr.usbDeviceLoaded
        label: qsTr("EXPORT") + application.emptyString
        upimage:"../" + main.graphicsPath + "200/TRU_200_other_small_Button_Up.png"
        downimage:"../" + main.graphicsPath + "200/TRU_200_other_small_Button_Down.png"
        label_under: false
        label_y_offset: -3 * main.screenScaleY
        anchors.right: clearButton.left
        anchors.rightMargin: 20 * main.screenScaleX
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 50 * main.screenScaleY
        onClicked: {
            if(errorList.model.count > 0) {
                exportErrorLog("/media/usb/")
            }

            console.debug("nucleus fault list count:" + errorManager.nucleusFaultListModel.count)
            if(isNucleus === true && errorManager.nucleusFaultListModel.count > 0) {
                exportNucleusErrorLog("/media/usb/")
            }

            dialogText.text = qsTr("Error Log was exported")
            actionSuccessfulDialog.show()
            actionSuccessfulDialog.startTimeout(1)
        }
    }

    ModalDialog {
        id: actionSuccessfulDialog
        BorderImage {   // pop-up dialog background
            id: border

            x: 332 * main.screenScaleX
            y: 161 * main.screenScaleY
            width: 800 * main.screenScaleX
            height: 350 * main.screenScaleY
            source: "../" + main.graphicsPath + "Pop_Up_Lrg_Grey.png"
            border { top: 152 * main.screenScaleY; bottom: 165 * main.screenScaleY; left: 145 * main.screenScaleX; right: 144 * main.screenScaleX }

            Text {
                id: dialogText
                anchors.fill: parent
                anchors.verticalCenter: parent.verticalCenter
                color: "#ffffff"
                anchors.horizontalCenter: parent.horizontalCenter
                horizontalAlignment: Text.AlignHCenter
                verticalAlignment: Text.AlignVCenter
                wrapMode: Text.WordWrap
                font.bold: true
                font.pixelSize: 50 * main.screenScaleY
            }
        }
        Component.onCompleted: hide()
        onTimedOut: hide()
    }

    FileIO {
        id: fileio
    }

    Text {
        id: bottomHelpText
        visible: main.isTft && diagnostics_screen.item !== null && diagnostics_screen.item.currentSelectedIndex >= 0

        height: 48 * main.screenScaleY
        font { family: "arial"; pixelSize: 36 * main.screenScaleY; bold: true }
        color: "#6c6c6c"
        text: {
            if (cursorState === "log")
                return qsTr("use <img src='../graphics/tft/arrow_left.png' /> <img src='../graphics/tft/arrow_right.png' /> to navigate, use <img src='../graphics/tft/arrow_up.png' /><img src='../graphics/tft/arrow_down.png' /> to view log") + application.emptyString
            else
                return qsTr("use <img src='../graphics/tft/arrow_left.png' /> <img src='../graphics/tft/arrow_right.png' /> to navigate, press ENTER to select") + application.emptyString
        }

        anchors.bottom: parent.bottom
        anchors.bottomMargin: 25 * main.screenScaleY
        anchors.horizontalCenter: parent.horizontalCenter
    }

    function exportErrorLog(path) {
        var serialstring
        var datestring
        var filename

        if(path === "")
            return;

        if(main.serialNumber === undefined){
            serialstring = "unknown-serial"
        } else {
            serialstring = main.serialNumber
        }
        datestring = Qt.formatDateTime(new Date(),"yyyyMMdd")
        filename = "faults_" + serialstring + "_" + datestring + ".log"
        path = path + filename

        console.debug("Writing log file to: "+path)

        fileio.source = path
        fileio.fileMode = FileIO.READ_WRITE
        fileio.open()
        fileio.clear()
        for(var i=0 ; i < errorList.model.count ; i++) {
            var item = errorList.model.get(i)
            fileio.writeLine(item.timestamp + "," + item.mileage + "," + item.errordescription +"\r\n")
        }
        fileio.close()
        syncDisk.start()
    }

    function exportNucleusErrorLog(path) {
        var serialstring
        var datestring
        var filename

        if(path === "")
            return;

        if(main.serialNumber === undefined){
            serialstring = "unknown-serial"
        } else {
            serialstring = main.serialNumber
        }
        datestring = Qt.formatDateTime(new Date(),"yyyyMMdd")
        filename = "faults_nucleus_" + serialstring + "_" + datestring + ".log"
        path = path + filename

        console.debug("Writing log file to: "+path)

        fileio.source = path
        fileio.fileMode = FileIO.READ_WRITE
        fileio.open()
        fileio.clear()
        for(var i=0 ; i < errorManager.nucleusFaultListModel.count ; i++) {
            var item = errorManager.nucleusFaultListModel.get(i)
            fileio.writeLine((item.usageStamp/100).toFixed(2) + "," + item.categoryString + "," + item.codeString +"\r\n")
        }
        fileio.close()
        syncDisk.start()
    }
}
