
import QtQuick 2.4
import Process 0.1
import "."
import "../Television"
import ".."
import FileIO 1.0
import Components 1.0

Item {
    id: root
    property bool isUsbDeviceLoaded: storageMgr.usbDeviceLoaded
    property bool isSetupWizard: false
    property bool isActive: (main.state === "DiagnosticState" && diagnostics_screen.item !== null && diagnostics_screen.item.currentSelectedIndex >= 0) || root.isSetupWizard
    property string cursorState: "setup" // setup or next
    property bool refreshing: false

    anchors.fill: parent
    width: 1166 * main.screenScaleX
    height: 568 * main.screenScaleY
    Component.onCompleted: netConnections.refreshList()

    function updateChannelList() {

        if (sapManager.item.channelList.count <= 0) {
            console.log("no SAP channels found. making no changes to TV list")
            return
        }

        var found = {}
        // Update all existing channels
        for (var i = 0; i < sapManager.item.channelList.count; i++) {
            var channelItem = sapManager.item.channelList.get(i)

            // SAP items are keyed by name
            // If item exists, just update it
            var id = "sap-" + channelItem.name
            // Store for later
            found[id] = channelItem

            var item = {}
            var index = tv.channelList.findChannel(id)
            if (index >= 0) {
                item = tv.channelList.channels.get(index)
            }

            item.id = id
            item.source = "sap"
            item.mrl = channelItem.mrl
            item.category = channelItem.category
            item.name = channelItem.name

            tv.channelList.addChannel(item)
        }

        // Now delete all channels that were not in this batch
        for (var i = tv.channelList.channels.count - 1; i >= 0; i--) {
            var chanItem = tv.channelList.channels.get(i)
            if (chanItem.source === "sap" && found[chanItem.id] === undefined) {
                tv.channelList.removeChannel(chanItem.id)
            }
        }

        // Finally, re-sort list by category
        tv.channelList.sortByCategory()
    }

    Row {
        id: iptvConfigRow
        anchors { left: channelListBox.left; bottom: channelListBox.top; bottomMargin: 20 * main.screenScaleY }
        visible: main.isTouch
        height: 50 * main.screenScaleY
        spacing: 40 * main.screenScaleX

        Text {
            id:iptvModeText
            font { pointSize: 16 * main.screenScaleY }
            text: qsTr("IPTV")
        }
        ToggleButton {
            id: iptvToggle

            pos0image: "../" + main.graphicsPath + "tft/maintenance_toggle.png"
            pos0image_disabled: "../" + main.graphicsPath + "tft/maintenance_toggle_GRAYED.png"
            pos1image: "../" + main.graphicsPath + "maintenance_toggle_OFF_gray.png"
            pos1image_disabled: "../" + main.graphicsPath + "maintenance_toggle_OFF_gray.png"
            labelcolor: "black"
            pos1label: ""
            pos0label: ""
            posFont { pixelSize: 18 * main.screenScaleY; bold: true }
            value: options.iptvEnabled
            onValueChanged: {
                options.iptvEnabled = value
            }
            Component.onCompleted: value = options.iptvEnabled

            enabled: true
        }
        Item {
            id: configureNetworkItem
            height: 60 * main.screenScaleY
            width: 250 * main.screenScaleX

            Text{
                id: configNetLabel
                text: qsTr("Configure Network") + application.emptyString
                anchors.left: parent.left
                anchors.top: parent.top
                color: "black"
                font { pixelSize: 18 * main.screenScaleY; bold: true }
            }
            ImageButton {
                id: configNetButton

                enabled: !netConnections.wireDisconnected

                anchors.left: configNetLabel.right
                anchors.leftMargin: 15 * main.screenScaleX
                anchors.top: parent.top
                anchors.topMargin: -20 * main.screenScaleY

                upimage: "../" + main.graphicsPath + "205/SM_Button_Up.png"
                downimage: "../" + main.graphicsPath + "205/SM_Button_Down.png"

                onClicked: {
                    netBrowser.visible = true
                }
            }
            Row {
                id: netConfigRow
                anchors.top: configNetLabel.bottom
                anchors.left: configNetLabel.left
                Image {
                    id: warningIcon
                    visible: !netConnections.wiredConfigured || netConnections.wireDisconnected || !netConnections.wiredEnabled
                    source: "../" + main.graphicsPath + "Icon_Warning_Small.png"
                    y: -7
                }

                Text {
                    id: netConfig
                    color: warningIcon.visible ? "#c0c0c0" : "#000000"
                    font { pixelSize: 14 * main.screenScaleY }
                    text: {
                        if (!netConnections.wiredConfigured) {
                            return qsTr("Not Configured")
                        }  else if (netConnections.wireDisconnected) {
                            return qsTr("Wire Disconnected")
                        } else if (!netConnections.wiredEnabled) {
                            return qsTr("Not Connected")
                        } else {
                            return qsTr("Connected: Wired Ethernet")
                        }
                    }
                }
            }

        }
    }

    Rectangle {
        id: channelListBox

        visible: options.iptvEnabled
        color: "lightgray"
        width: 725 * main.screenScaleX
        height: 460 * main.screenScaleY
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.horizontalCenterOffset: -mode.width/2
        anchors.top: rightControlArea.top

        Text {
            id: refreshText
            text: qsTr("Refreshing") + "..." + application.emptyString
            font.pixelSize: 18 * main.screenScaleY
            anchors { left: parent.left; top: parent.top; margins: 20 }
            visible: autoRefreshTimer.running
        }

        AnimatedImage {
            id: loadingImage
            source: "../" + main.graphicsPath + "Loading.gif"
            visible: root.refreshing || refreshTimer.running
            anchors.centerIn: parent
            anchors.verticalCenterOffset: -30 * main.screenScaleY
        }

        Item {
            id: dataArrows

            width: 40 * main.screenScaleX
            height: parent.height

            anchors { top: parent.top; right: parent.right ; rightMargin: ( Qt.application.layoutDirection === Qt.RightToLeft ? -20 : -5 ) * main.screenScaleX }
            Image {
                id: dataUpArrow
                visible: !channelList.atYBeginning
                source: "../" + main.graphicsPath + "Swipe_Arrows_Left.png"
                rotation: 90
                anchors { top: parent.top; topMargin: 35 * main.screenScaleY; right: parent.right }
            }
            Image {
                id: dataDownArrow
                visible: !channelList.atYEnd
                source: "../" + main.graphicsPath + "Swipe_Arrows_Right.png"
                rotation: 90
                anchors { bottom: parent.bottom; bottomMargin: 35 * main.screenScaleY; right: parent.right }
            }
        }

        GridView {
            id: channelList

            visible: !loadingImage.visible
            clip: true
            anchors.fill: parent
            anchors {
                leftMargin: 30 * main.screenScaleX
                topMargin: 10 * main.screenScaleY
                bottomMargin: 5 * main.screenScaleY
                rightMargin: 5 * main.screenScaleX
            }
            model: tv.channelList.channels
            cellWidth: 160 * main.screenScaleX
            cellHeight: 150 * main.screenScaleY

            delegate: Component {
                Item {
                    width: 160 * main.screenScaleX; height: 150 * main.screenScaleY
                    Item {
                        width: 110 * main.screenScaleX; height: 135 * main.screenScaleY
                        anchors { left: parent.left; top: parent.top }

                        Rectangle{
                            id: iconBg
                            color: "white"
                            height: 110 * main.screenScaleY; width: 110 * main.screenScaleX

                            Image {
                                id: iconImage
                                anchors.horizontalCenter: parent.horizontalCenter
                                anchors.top: parent.top
                                source: icon ?"../" +  main.graphicsPath+ "TvIcons/default/channelIcons/" + icon :"../" +  main.graphicsPath+ "TvIcons/default/channelIcons/tv_default.png"
                            }
                        }

                        Text {
                            anchors { horizontalCenter: iconBg.horizontalCenter; top: iconBg.bottom; topMargin: 0 }
                            verticalAlignment: Text.AlignVCenter
                            text: {
                                if (number && name && number != name) {
                                    return name + " " + number
                                } else if (name) {
                                    return name
                                } else if (number) {
                                    return number
                                } else {
                                    return ""
                                }
                            }
                            font.pointSize: 13 * main.screenScaleY
                            font.bold: true
                        }
                    }
                }
            }
        }
    }

    Rectangle {
        id: rightControlArea
        visible: options.iptvEnabled

        width: 280 * main.screenScaleX
        height: 460 * main.screenScaleY
        color: "#7f8082"
        anchors { left: channelListBox.right; top: parent.top; topMargin: 98 * main.screenScaleY }
    }

    ListView{
        id: mode
        anchors {
            top: rightControlArea.top; topMargin: 20 * main.screenScaleY
            left: rightControlArea.left
        }
        visible: options.iptvEnabled
        width: 280 * main.screenScaleX
        height: 700 * main.screenScaleY
        spacing: 5 * main.screenScaleX
        z: 100
        model: controlList.model
        snapMode: ListView.SnapToItem
        interactive: false
        highlightRangeMode: ListView.ApplyRange
        preferredHighlightBegin: height/2 - 30
        preferredHighlightEnd: height/2 + 30
        highlightMoveVelocity: 10000
        currentIndex: controlList.curIndex
    }

    WifiBrowser {
        id: netBrowser
        hideWireless: true
        visible: false
        z: 999999999

        onCanceled: visible = false
        anchors { horizontalCenter: parent.horizontalCenter ; verticalCenter: parent.verticalCenter }
        onSelected: {
            visible = false
            var args = []
            if (options.iptvEnabled) {
                args.push("-b")
            }

            args = args.concat([accessPoint.interface, accessPoint.essid, accessPoint.password])
            configureNetworkProcess.arguments = args

            // IPTV allows multiple connections
            // So we don't need to prompt the user
            configureNetworkProcess.start()

        }
    }

    MessagePopup {
        id: reconfiguringNotice

        message: qsTr("Reconfiguring Network Settings...") + application.emptyString
    }

    Process {
        id: configureNetworkProcess

        onStarted: { reconfiguringNotice.show() }
        onFinished: {
            netConnections.refreshList()
            reconfiguringNotice.hide()
            dataExport.getNetworkAddresses()
            sapLoader.reload()
        }

        program: "scripts/configure_network.sh"
        arguments: ["enp2s0"]
    }

    Text {
        id: channelsFoundText
        text: {
            if (root.refreshing || refreshTimer.running)
                return ""
            else if (channelList.count > 0)
                return qsTr("Number of Channels:") + " " + channelList.count + application.emptyString
            else
                return qsTr("No Channels Configured") + application.emptyString
        }
        anchors.bottom: channelListBox.top
        anchors.bottomMargin: 7 * main.screenScaleY
        anchors.left: channelListBox.left
        font { pixelSize: 18 * main.screenScaleY; bold: true }
    }
    KeyedControlList {
        id: controlList
        listening: main.isTft && root.visible && root.isActive && !root.scanner.scanning && root.cursorState === "setup"
        listView: mode
        width: mode.width
        curIndex: 4

        edgeBehavior: isSetupWizard ? "emit" : "wrap"
        onFirstExited: root.cursorState = "next"
        onLastExited: root.cursorState = "next"


        Item {
            id: refreshItem
            height: ( visible ? 71 : 0 ) * main.screenScaleX
            width: mode.width
            x: 30 * main.screenScaleX
            visible: tv.channelList.channels.count > 0 && netConnections.wiredConfigured && !netConnections.wireDisconnected

            ImageButton {
                id: refreshButton

                enabled: netConnections.wiredEnabled

                upimage: "../" + main.graphicsPath + "205/SM_Button_Up.png"
                downimage: "../" + main.graphicsPath + "205/SM_Button_Down.png"

                onClicked: {
                    root.refreshing = true
                    refreshTimer.restart()
                    if (sapManager && sapManager.item) {
                        sapManager.item.refreshSources()
                    } else {
                        console.log("cannot refresh: sapManager not created yet")
                    }

                    //console.log("finished refresh", JSON.stringify(sapManager.channelList))
                    root.updateChannelList()
                    root.refreshing = false

                    tv.channelList.saveChannels(tv.channelFile)
                    tv.channelList.readChannels(tv.channelFile)
                }
            }
            Text{
                id: refreshLabel
                text: qsTr("Refresh List") + application.emptyString
                anchors.left: refreshButton.right
                anchors.verticalCenter: parent.verticalCenter
                anchors.verticalCenterOffset: -8 * main.screenScaleY
                color: "black"
                font { pixelSize: 18 * main.screenScaleY; bold: true }
            }
        }
        // Disable IPTV button
        Item {
            id: disableItem
            height: 71 * main.screenScaleY
            width: mode.width
            x: 30 * main.screenScaleX

            ImageButton {
                id: button3

                enabled: true

                upimage: "../" + main.graphicsPath + "205/SM_Button_RED.png"
                downimage: "../" + main.graphicsPath + "205/SM_Button_Down.png"
                onClicked: {
                    options.iptvEnabled = false

                }
            }
            Text{
                id: item3label
                text: qsTr("Disable IPTV") + application.emptyString
                anchors.left: button3.right
                anchors.verticalCenter: parent.verticalCenter
                anchors.verticalCenterOffset: -8 * main.screenScaleY
                color: "black"
                font { pixelSize: 18 * main.screenScaleY; bold: true }
            }
        }
    }

    MessagePopup {
        id: autofindPopup
        message: qsTr("Looking for channels...") + application.emptyString
        visible: autoRefreshTimer.running
        dismissable: true
    }

    Timer {
        id: autoRefreshTimer
        interval: 5000
        running: tv.channelList.channels.count === 0 && netConnections.wiredConfigured && !netConnections.wireDisconnected
        repeat: true
        onTriggered: {
            refreshButton.clicked()
        }
    }

    Timer {
        // Display loading image for at least 1 second
        id: refreshTimer
        interval: 1000
        repeat: false; running: false
    }

}
