// import QtQuick 2.4 // to target S60 5th Edition or Maemo 5
import QtQuick 2.4
import Components 1.0

Item {
    id: root

    property string cursorState: "log" // log or clear

    Component.onCompleted: {
        loadUsageIntoModel()
    }

    function loadUsageIntoModel() {
        var usage = miscStats.getUsageAll()

        usageData.clear()

        if(!usage) {
            usageData.append({name:qsTr("NO USAGE DATA"), count: 0})
            return
        }

        for (var i = 0; i < usage.length; i++) {
            usageData.append({name: usage.item(i).name, count: usage.item(i).count})
        }
    }

    function clearStats() {
        miscStats.clearAll()
        loadUsageIntoModel()
    }

    Connections {
        target: main.isTft && main.state === "DiagnosticState" && root.visible && diagnostics_screen.item !== null && diagnostics_screen.item.currentSelectedIndex >= 0 ? keymapper : null

        onLeftButtonPressed: {
            main.debugKeys("leftButtonPressed", "DiagnosticsMiscStatistics")
            cursorState = (cursorState === "log") ? "clear" : "log"
        }

        onRightButtonPressed: {
            main.debugKeys("rightButtonPressed", "DiagnosticsMiscStatistics")
            cursorState = (cursorState === "log") ? "clear" : "log"
        }

        onBackPressed: {
            main.debugKeys("backPressed", "DiagnosticsMiscStatistics")
            diagnostics_screen.item.unselectScreen()
        }

        onEnter2Pressed: {
            main.debugKeys("enter2Pressed", "DiagnosticsMiscStatistics")
            if (cursorState === "clear")
                root.clearStats()
        }
    }

    ListModel {
        id: usageData
    }

    Rectangle {
        id: dataScreen
        color: "lightgray"
        radius: 10 * main.screenScaleX
        width: 888 * main.screenScaleX
        height: dataTable.itemsToShow * 40
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.top: parent.top
        anchors.topMargin: 50 * main.screenScaleY

        ListView {
            id: dataTable

            property int itemsToShow: 13
            property bool moreItemsToScroll: currentIndex < dataTable.count - dataTable.itemsToShow

            function scrollPageUp() {
                dataTable.currentIndex = Math.max(0, dataTable.currentIndex - dataTable.itemsToShow)
            }

            function scrollPageDown() {
                dataTable.currentIndex = Math.min(dataTable.count - dataTable.itemsToShow,
                                                  dataTable.currentIndex + dataTable.itemsToShow)
            }

            Connections {
                id: keyhandler
                target: main.isTft && main.state === "DiagnosticState" && root.visible && diagnostics_screen.item !== null && diagnostics_screen.item.currentSelectedIndex >= 0 && root.cursorState === "log" ? keymapper : null

                property string lastDirection: "up"

                onUpButtonPressed: {
                    main.debugKeys("upButtonPressed", "DiagnosticsMiscStatistics")
                    dataTable.decrementCurrentIndex()
                    keyhandler.lastDirection = "up"
                }

                onDownButtonPressed: {
                    main.debugKeys("downButtonPressed", "DiagnosticsMiscStatistics")
                    if (dataTable.moreItemsToScroll)
                        dataTable.incrementCurrentIndex()
                    keyhandler.lastDirection = "down"
                }

                onEnter2Pressed: {
                    main.debugKeys("downButtonPressed", "DiagnosticsMiscStatistics", "(cursorState = log)")
                    if (keyhandler.lastDirection === "up")
                        dataTable.scrollPageUp()
                    else
                        dataTable.scrollPageDown()
                }
            }

            clip: true
            anchors.fill: parent
            highlightRangeMode: ListView.ApplyRange
            preferredHighlightBegin: 0
            preferredHighlightEnd: 40

            model: usageData
            delegate: Component {
                Item {
                    width: 888 * main.screenScaleX
                    height: 40 * main.screenScaleY

                    Text {
                        id: dataName
                        width: 800 * main.screenScaleX
                        height: 40 * main.screenScaleY
                        text: model.name
                        font.pixelSize: 28 * main.screenScaleY
                    }

                    Text {
                        id: dataCount
                        visible: model.count
                        width: 50 * main.screenScaleX
                        height: 40 * main.screenScaleY
                        anchors.left: dataName.right
                        anchors.leftMargin: 5 * main.screenScaleX
                        text: model.count
                        font.pixelSize: 28 * main.screenScaleY
                    }
                }
            }
        }
    }

    Item {
        id: dataArrows

        width: 40 * main.screenScaleX
        height: dataScreen.height / 2
        anchors.left: dataScreen.right
        anchors.leftMargin: -50 * main.screenScaleX
        anchors.verticalCenter: dataScreen.verticalCenter

        Image {
            id: dataUpArrow
            source: "../" + main.graphicsPath + "Swipe_Arrows_Left.png"
            rotation: 90
            anchors { top: parent.top ; left: parent.right }
            opacity: dataTable.currentIndex > 0 ? 1.0 : 0.5
        }
        Image {
            id: dataDownArrow
            source: "../" + main.graphicsPath + "Swipe_Arrows_Left.png"
            rotation: -90
            anchors { bottom: parent.bottom ; left: parent.right }
            opacity: dataTable.moreItemsToScroll ? 1.0 : 0.5
        }

        BorderImage {
            id: selectionCursor
            visible: main.isTft && diagnostics_screen.item !== null && diagnostics_screen.item.currentSelectedIndex >= 0 && cursorState === "log"
            border { left: 35 * main.screenScaleX; top: 5 * main.screenScaleY; bottom: 5 * main.screenScaleY; right: 35 * main.screenScaleX }
            source: "../" + main.graphicsPath + "tft/maintenance_menus_cursor_new.png"
            width: 100 * main.screenScaleX
            height: 56 * main.screenScaleY
            horizontalTileMode: BorderImage.Stretch
            anchors {
                left: parent.left
                leftMargin: 33 * main.screenScaleX
                verticalCenter: keyhandler.lastDirection === "up" ? dataUpArrow.verticalCenter : dataDownArrow.verticalCenter
            }
        }
    }

    ImageButton {
        id: clearButton
        upimage:"../" + main.graphicsPath + "200/TRU_200_other_small_Button_Up.png"
        downimage:"../" + main.graphicsPath + "200/TRU_200_other_small_Button_Down.png"
        label: qsTr("CLEAR") + application.emptyString
        label_under: true
        label_y_offset: -3 * main.screenScaleY
        label_color: "black"
        font.pointSize: 14 * main.screenScaleY
        anchors { right: root.right ; rightMargin: 65 * main.screenScaleX
                    bottom: root.bottom ; bottomMargin: 40 * main.screenScaleY}

        onClicked: {
            root.clearStats()
        }
    }

    Image {
        source: "../" + main.graphicsPath + "tft/NAV_selector_2.png"
        visible: main.isTft && diagnostics_screen.item !== null && diagnostics_screen.item.currentSelectedIndex >= 0 && cursorState === "clear"
        anchors.centerIn: clearButton
        z: clearButton.z - 1
    }

    Text {
        id: bottomHelpText
        visible: main.isTft && diagnostics_screen.item !== null && diagnostics_screen.item.currentSelectedIndex >= 0

        height: 48 * main.screenScaleY
        font { family: "arial"; pixelSize: 36 * main.screenScaleY; bold: true }
        color: "#6c6c6c"
        text: {
            if (cursorState === "log")
                return qsTr("use <img src='../graphics/tft/arrow_up.png' /><img src='../graphics/tft/arrow_down.png' /> to view log, use <img src='../graphics/tft/arrow_left.png' /> <img src='../graphics/tft/arrow_right.png' /> to navigate") + application.emptyString
            else if (cursorState === "clear")
                return qsTr("press ENTER to select") + application.emptyString
        }

        anchors.bottom: parent.bottom
        anchors.bottomMargin: 25 * main.screenScaleY
        anchors.horizontalCenter: parent.horizontalCenter
    }
}
