import QtQuick 2.4
import ".."
import Components 1.0

Item{
    id: root
    anchors.fill: parent

    property int fontSize: 24 * main.screenScaleY
    property int topOffset: 80 * main.screenScaleY
    property int itemSpacing: 5 * main.screenScaleY
    property int itemColumnSpacing: 50 * main.screenScaleY
    property int currentSelectedIndex
    property bool isSetupWizard: false
    property string cursorState: "product" // product, or save

    signal declineTogglePressed()

    onDeclineTogglePressed: saveButton.visible = (main.isTouch && !root.isSetupWizard)

    Component.onCompleted: {
        nucleus.getOptions()
    }

    Connections {
        target: nucleus
        onTreadmillSetInclineOptionCompleted: {
            if(result === true) {
                setOptionComplete.show()
            }
        }
    }

    Connections {
        id: arrowHandler
        target: main.isTft && root.visible && ((!isSetupWizard && main.state === "DiagnosticState" && diagnostics_screen.item !== null && diagnostics_screen.item.currentSelectedIndex >= 0) || (isSetupWizard && main.state === "SetupWizardState")) && cursorState === "product" ? keymapper : null

        function handleLeftPress() {
            if (root.currentSelectedIndex > 0) {
                if (productList.itemAt(root.currentSelectedIndex - 1).visible)
                    root.currentSelectedIndex--
            }
        }
        onLeftButtonPressed: {
            main.debugKeys("leftButtonPressed", "DiagnosticsSetup")
            arrowHandler.handleLeftPress()
        }

        // Allow minus to act as left, as workaround for unconfigured keypad during Setup Wizard
        onMinusPressed: {
            main.debugKeys("minusPressed", "DiagnosticsSetup")
            arrowHandler.handleLeftPress()
        }

        onRightButtonPressed: {
            main.debugKeys("rightButtonPressed", "DiagnosticsSetup")
            if (root.currentSelectedIndex < productList.model.count - 1){
                if (productList.itemAt(root.currentSelectedIndex + 1).visible)
                    root.currentSelectedIndex++
            } else if (root.currentSelectedIndex === productList.model.count - 1){
                root.currentSelectedIndex = 0
            }
        }

        onUpButtonPressed: {
            main.debugKeys("upButtonPressed", "DiagnosticsSetup")
            // since a Flow is used, we have to make the assumption that there are three items in a row
            // if the layout changes then this code will break
            if (root.currentSelectedIndex - 3 >= 0)
                root.currentSelectedIndex -= 3
        }

        onDownButtonPressed: {
            main.debugKeys("downButtonPressed", "DiagnosticsSetup")
            // since a Flow is used, we have to make the assumption that there are three items in a row
            // if the layout changes then this code will break
            if (root.currentSelectedIndex +3 <= productList.model.count-1)
                root.currentSelectedIndex += 3
        }

    }

    Connections {
        target: main.isTft && root.visible && ((!isSetupWizard && main.state === "DiagnosticState" && diagnostics_screen.item !== null && diagnostics_screen.item.currentSelectedIndex >= 0) || (isSetupWizard && main.state === "SetupWizardState")) ? keymapper : null

        onEnter2Pressed: {
            main.debugKeys("enter2Pressed", "DiagnosticsSetup")
            switch (cursorState) {
                case "product": {
                    itemSelected()
                    if (!isSetupWizard) saveProduct()
                    if (!isSetupWizard) diagnostics_screen.item.unselectScreen()
                    break
                }
            }
        }

        onBackPressed: {
            main.debugKeys("backPressed", "DiagnosticsSetup")
            if (cursorState === "product") {
                if (!isSetupWizard) diagnostics_screen.item.unselectScreen()
            }
        }
    }

    ListModel {
        id: productListModel

        ListElement {
            name: "TES900"
            imageName: "product_images/2013/TRU_TES900_sideview.png"
        }
        ListElement {
            name: "TCS400"
            imageName: "product_images/2013/TRU_TCS400_sideview.png"
        }
        ListElement {
            name: "TCS600"
            imageName: "product_images/2013/TRU_TCS600_sideview.png"
        }
        ListElement {
            name: "TCS650"
            imageName: "product_images/2013/TRU_TCS650_sideview.png"
        }
        ListElement {
            name: "TCS650"
            imageName: "product_images/2013/TRU_TCS650_sideview.png"
        }
        ListElement {
            name: "TCS900"
            imageName: "product_images/2013/TRU_TCS900_sideview.png"
        }
        ListElement {
            name: "TCS900"
            imageName: "product_images/2013/TRU_TCS900_sideview.png"
        }
        ListElement {
            name: "TPS825"
            imageName: "product_images/2013/TRU_TES900_sideview.png"
        }
        ListElement {
            name: "XCS400"
            imageName: "product_images/2013/TRU_XCS400_sideview.png"
        }
        ListElement {
            name: "XCS900"
            imageName: "product_images/2013/TRU_XCS900_sideview.png"
        }
        ListElement {
            name: "TS1000"
            imageName: "product_images/2015/TRU_TS1000_sideview.png"
        }
        ListElement {
            name: "RCS400"
            imageName: "product_images/2013/TRU_RCS400_sideview.png"
        }
        ListElement {
            name: "UCS400"
            imageName: "product_images/2013/TRU_UCS400_sideview.png"
        }
        ListElement {
            name: "UCS900"
            imageName: "product_images/2013/TRU_UCS900_sideview.png"
        }
        ListElement {
            name: "RCS900"
            imageName: "product_images/2013/TRU_RCS900_sideview.png"
        }
        ListElement {
            name: "TL1000"
            imageName: "product_images/2015/TRU_TL1000_sideview.png"
        }
        ListElement {
            name: "XL1000"
            imageName: "product_images/2015/TRU_TL1000_sideview.png"
        }
        ListElement {
            name: "TI1000"
            imageName: "product_images/2016/TRU_TI1000_sideview.png"
        }
        /* Following elements uses new model names for each machine */
        ListElement {
            name: "TE900"
            imageName: "product_images/2013/TRU_TES900_sideview.png"
        }
        ListElement {
            name: "TC400"
            imageName: "product_images/2013/TRU_TCS400_sideview.png"
        }
        ListElement {
            name: "TC650"
            imageName: "product_images/2013/TRU_TCS650_sideview.png"
        }
        ListElement {
            name: "TC900"
            imageName: "product_images/2013/TRU_TCS900_sideview.png"
        }
        ListElement {
            name: "XC400"
            imageName: "product_images/2013/TRU_XCS400_sideview.png"
        }
        ListElement {
            name: "XC900"
            imageName: "product_images/2013/TRU_XCS900_sideview.png"
        }
        ListElement {
            name: "XS1000"
            imageName: "product_images/2015/TRU_TS1000_sideview.png"
        }
        ListElement {
            name: "RC400"
            imageName: "product_images/2013/TRU_RCS400_sideview.png"
        }
        ListElement {
            name: "UC400"
            imageName: "product_images/2013/TRU_UCS400_sideview.png"
        }
        ListElement {
            name: "UC900"
            imageName: "product_images/2013/TRU_UCS900_sideview.png"
        }
        ListElement {
            name: "RC900"
            imageName: "product_images/2013/TRU_RCS900_sideview.png"
        }
    }

    Text {
        id: currentConfigurationText
        text: qsTr("Current Machine Configuration")+application.emptyString
        font.pixelSize: 36 * main.screenScaleY
        font.bold: true
        font.underline: true
        anchors.top: parent.top
        anchors.topMargin: 20 * main.screenScaleY
        anchors.horizontalCenter: parent.horizontalCenter
    }
    Text {
        id: currentProductConfigurationText
        text: machineinfo.modelString + " " + qsTr(machineinfo.productTypeString) + application.emptyString
        font.pixelSize: 36 * main.screenScaleY
        font.bold: true
        anchors.top: currentConfigurationText.bottom
        anchors.topMargin: 10 * main.screenScaleY
        anchors.horizontalCenter: parent.horizontalCenter
    }

    Item {

        id: machineConfigurationArea
        width: 400 * main.screenScaleX

        anchors {
            top: currentProductConfigurationText.bottom
            topMargin: 25 * main.screenScaleY
            right: parent.horizontalCenter
            rightMargin: 25 * main.screenScaleX
            bottom: parent.bottom
            bottomMargin: 50 * main.screenScaleY
        }

        Column {
            spacing: 5 * main.screenScaleX
            width: parent.width
            Text {
                visible: (machineinfo.modelString === "XS1000" || machineinfo.modelString === "TS1000")
                font.pixelSize: 28 * main.screenScaleY
                text: "Max. Stride Length: " + (machineinfo.adjustableStrideEllipticalMaxStrideIn / 10).toFixed(1) + " Inches"
            }

            Text {
                visible: (machineinfo.modelString === "XS1000" || machineinfo.modelString === "TS1000")
                font.pixelSize: 28 * main.screenScaleY
                text: "Min. Stride Length: " + (machineinfo.adjustableStrideEllipticalMinStrideIn / 10).toFixed(1) + " Inches"
            }

            Text {
                visible: nucleus.machineTypeString === "Treadmill"
                font.pixelSize: 28 * main.screenScaleY
                text: "Max. Speed: " + (machineinfo.treadmillSpeedMaxMph / 10).toFixed(1) + "MPH"
            }

            Text {
                visible: nucleus.machineTypeString === "Treadmill"
                font.pixelSize: 28 * main.screenScaleY
                text: "Max. Incline: " + (machineinfo.treadmillInclineMaxPercentGrade / 10).toFixed(1) + "%"
            }

            Text {
                visible: nucleus.machineTypeString === "Treadmill"
                font.pixelSize: 28 * main.screenScaleY
                text: "Min. Incline: " + (machineinfo.treadmillInclineMinPercentGrade / 10).toFixed(1) + "%"
            }

            Row {
                visible: nucleus.declineOption && nucleus.machineTypeString === "Treadmill"
                width: parent.width
                spacing: 50 * main.screenScaleX
                Text {
                    id: declineToggleLabel
                    font.pixelSize: 28 * main.screenScaleY
                    text: machineinfo.treadmillInclineMinPercentGrade < 0 ? "Set Non-Decline" : "Set Decline"
                }

                ImageButton{
                    id: declineToggleButton
                    useParentContainerSize: true
                    width: 50 * main.screenScaleX
                    height: 50 * main.screenScaleY
                    upimage:"../" + main.graphicsPath + "200/TRU_200_other_small_Button_Up.png"
                    downimage:"../" + main.graphicsPath + "200/TRU_200_other_small_Button_Down.png"
                    label_under: false
                    label_y_offset: -3 * main.screenScaleY
                    anchors.verticalCenter: declineToggleLabel.verticalCenter
                    onClicked: machineinfo.treadmillInclineMinPercentGrade < 0 ? nucleus.treadmillSetNonDeclineOption() : nucleus.treadmillSetDeclineOption()
                    visible: true
                }
            }
        }
    }

    function getImageElementFromModelString(modelStr)
    {
        var i
        for(i = 0; i < productListModel.count; i++) {
            var item = productListModel.get(i)
            if(item.name === modelStr) {
                return "../" + main.graphicsPath + item.imageName;
            }
        }
        return "";
    }

    Item {
        id: productImageArea
        width: height
        height: parent.width * 0.25
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.horizontalCenterOffset: parent.width / 4
        anchors.top: machineConfigurationArea.top

        Image{
            id:productImage
            anchors.fill: parent
            smooth: true
            source: getImageElementFromModelString(machineinfo.modelString)
        }
    }

    MessagePopup {   // pop-up dialog background
        id: setOptionComplete
        message: qsTr("Power Cycle Required.")
    }
}
