import QtQuick 2.4
import StatisticManager 1.0
import Components 1.0

Item{
    id: root
    anchors.fill: parent

    property int fontSize: 24 * main.screenScaleY
    property int topOffset: -150 * main.screenScaleY
    property int itemSpacing: 5 * main.screenScaleY
    property int itemColumnSpacing: 50 * main.screenScaleY
    property string cursorState: "clear" // clear is the only state

    property string runHoursLabel: qsTr("Run Hours") + application.emptyString
    property string machineDistanceLabel: qsTr("Machine Distance") + application.emptyString
    property string distanceLabel: qsTr("Distance") + application.emptyString
    property string runHoursValue: Number(statisticManager.runHours/3600).toFixed(1) + " " + qsTr("Hours") + application.emptyString
    property string machineDistanceValue: options.metricUnits ? Globals.mileToKm(statisticManager.totalDistance/100).toFixed(2) + " " + qsTr("KM") : (statisticManager.totalDistance/100).toFixed(2) + " " + qsTr("miles") + application.emptyString
    property string distanceValue: options.metricUnits ? Globals.mileToKm(statisticManager.mileage/100).toFixed(2) + " " + qsTr("KM") : (statisticManager.mileage/100).toFixed(2) + " " + qsTr("miles") + application.emptyString

    function clearMileage() {
        statisticManager.resetMileage()
    }

    Connections {
        target: main.isTft && main.state === "DiagnosticState" && root.visible && diagnostics_screen.item !== null && diagnostics_screen.item.currentSelectedIndex >= 0 ? keymapper : null

        onBackPressed: {
            main.debugKeys("backPressed", "DiagnosticsStatistics")
            diagnostics_screen.item.unselectScreen()
        }

        onEnter2Pressed: {
            main.debugKeys("enter2Pressed", "DiagnosticsStatistics")
            if (cursorState === "clear")
                root.clearMileage()
        }
    }

    Column{
        id: labels
        spacing: itemSpacing
        anchors.left: parent.left
        anchors.leftMargin: 200 * main.screenScaleX
        anchors.verticalCenter: parent.verticalCenter
        anchors.verticalCenterOffset: topOffset

        Text{
            text: runHoursLabel
            font.pointSize: fontSize
        }

        Text{
            text: machineDistanceLabel
            font.pointSize: fontSize
        }

        Text{
            text: distanceLabel
            font.pointSize: fontSize
        }


//        Text{
//            text: qsTr("Average Speed") + application.emptyString
//            font.pointSize: fontSize
//            visible: isTreadmill
//        }

//        Text{
//            text: qsTr("Max Speed") + application.emptyString
//            font.pointSize: fontSize
//            visible: isTreadmill
//        }


    }
    Column{
        id:values
        spacing: itemSpacing
        anchors.left: labels.right
        anchors.leftMargin: 200 * main.screenScaleX
        anchors.verticalCenter: parent.verticalCenter
        anchors.verticalCenterOffset: topOffset

        Text{

            text: runHoursValue
            font.pointSize: fontSize
        }

        Text{
            text: machineDistanceValue
            font.pointSize: fontSize
        }

        Text{
            id: tripMilesValue
            text: distanceValue
            font.pointSize: fontSize
        }

//        Text{
//            text: (statisticManager.averageSpeed / 10).toFixed(1)
//            font.pointSize: fontSize
//            visible: isTreadmill
//        }

//        Text{
//            text: (statisticManager.maxSpeed / 10).toFixed(1)
//            font.pointSize: fontSize
//            visible: isTreadmill
//        }

    }
    ImageButton{
        id: clearButton
        wrapWidth: 150
        label: qsTr("CLEAR MILEAGE") + application.emptyString
        upimage:"../" + main.graphicsPath + "200/TRU_200_other_small_Button_Up.png"
        downimage:"../" + main.graphicsPath + "200/TRU_200_other_small_Button_Down.png"
        label_under: true
        label_y_offset: -3 * main.screenScaleY
        label_color: "black"
        font.pointSize: 14 * main.screenScaleY
        y: tripMilesValue.y + height - 20
        anchors { left: values.right ; leftMargin: 40 * main.screenScaleX }
        onClicked: root.clearMileage()
    }

    Image {
        source: "../" + main.graphicsPath + "tft/NAV_selector_2.png"
        visible: main.isTft && diagnostics_screen.item !== null && diagnostics_screen.item.currentSelectedIndex >= 0 && cursorState === "clear"
        anchors.centerIn: clearButton
        anchors.horizontalCenterOffset: -25 * main.screenScaleX
        z: clearButton.z - 1
    }

    Text {
        id: bottomHelpText
        visible: main.isTft && diagnostics_screen.item !== null && diagnostics_screen.item.currentSelectedIndex >= 0

        height: 48 * main.screenScaleY
        font { family: "arial"; pixelSize: 36 * main.screenScaleY; bold: true }
        color: "#6c6c6c"
        text: qsTr("press ENTER to select") + application.emptyString

        anchors.bottom: parent.bottom
        anchors.bottomMargin: 25 * main.screenScaleY
        anchors.horizontalCenter: parent.horizontalCenter
    }
}
