import QtQuick 2.4
import StatisticManager 1.0
import Components 1.0

Item{
    id: root
    anchors.fill: parent

    property int fontSize: 24 * main.screenScaleY
    property int topOffset: -150 * main.screenScaleY
    property int itemSpacing: 5 * main.screenScaleY
    property int itemColumnSpacing: 50 * main.screenScaleY

    property string beltMotorUsageMilesLabel: qsTr("Belt Motor Usage in Miles") + application.emptyString
    property string beltMotorUsageSecondLabel: qsTr("Belt Motor Usage Time") + application.emptyString
    property string inclineMotorUsageSecondLabel: qsTr("Incline Motor Usage Time") + application.emptyString
    property string staticBrakeEnagagementCountLabel: qsTr("Static Brake Engagement Count") + application.emptyString
    property string staticBrakeUsageRevolutionsLabel: qsTr("Static Brake Usage in Revolutions") + application.emptyString

    property string pedalUsageMileLabel: qsTr("Distance") + application.emptyString
    property string pedalRevolutionsLabel: qsTr("Pedal Revolutions") + application.emptyString
    property string strideMotorUsageSecondLabel: qsTr("Stride Motor Usage Time") + application.emptyString

    property string runHoursValue: Number(statisticManager.runHours/3600).toFixed(1) + " " + qsTr("Hours") + application.emptyString
    property string machineDistanceValue: options.metricUnits ? Globals.mileToKm(statisticManager.totalDistance/100).toFixed(2) + " " + qsTr("KM") : (statisticManager.totalDistance/100).toFixed(2) + " " + qsTr("miles") + application.emptyString
    property string distanceValue: options.metricUnits ? Globals.mileToKm(statisticManager.mileage/100).toFixed(2) + " " + qsTr("KM") : (statisticManager.mileage/100).toFixed(2) + " " + qsTr("miles") + application.emptyString

    property bool isTreadmill: machineinfo.productTypeString === "Treadmill"
    property bool isPedalSystem: {
        if(machineinfo.productTypeString.search("Elliptical") != -1 ||
                machineinfo.productTypeString.search("Bike") != -1) {
            return true
        } else {
            return false
        }
    }

    Component.onCompleted: {
        statisticManager.getNucleusStatistics();
    }

    Connections {
        target: main.isTft && main.state === "DiagnosticState" && root.visible && diagnostics_screen.item !== null && diagnostics_screen.item.currentSelectedIndex >= 0 ? keymapper : null

        onBackPressed: {
            main.debugKeys("backPressed", "DiagnosticsStatistics")
            diagnostics_screen.item.unselectScreen()
        }
    }

    Column{
        id: labels
        spacing: itemSpacing
        anchors.left: parent.left
        anchors.leftMargin: 200 * main.screenScaleX
        anchors.verticalCenter: parent.verticalCenter
        anchors.verticalCenterOffset: topOffset

        Text{
            text: beltMotorUsageMilesLabel
            font.pointSize: fontSize
            visible: isTreadmill
        }

        Text{
            text: beltMotorUsageSecondLabel
            font.pointSize: fontSize
            visible: isTreadmill
        }

        Text{
            text: inclineMotorUsageSecondLabel
            font.pointSize: fontSize
            visible: isTreadmill
        }

        Text{
            text: staticBrakeEnagagementCountLabel
            font.pointSize: fontSize
            visible: isTreadmill
        }

        Text{
            text: staticBrakeUsageRevolutionsLabel
            font.pointSize: fontSize
            visible: isTreadmill
        }

        Text{
            text: pedalUsageMileLabel
            font.pointSize: fontSize
            visible: isPedalSystem
        }

        Text{
            text: pedalRevolutionsLabel
            font.pointSize: fontSize
            visible: isPedalSystem
        }

        Text{
            text: strideMotorUsageSecondLabel
            font.pointSize: fontSize
            visible: isPedalSystem && main.isCSA
        }

    }
    Column{
        id:values
        spacing: itemSpacing
        anchors.left: labels.right
        anchors.leftMargin: 200 * main.screenScaleX
        anchors.verticalCenter: parent.verticalCenter
        anchors.verticalCenterOffset: topOffset

        Text{
            text: statisticManager.beltMotorUsageMile.toFixed(2);
            font.pointSize: fontSize
            visible: isTreadmill
        }

        Text{
            text: (statisticManager.beltMotorUsageSecond / 3600).toFixed(0) + " Hrs. " + (statisticManager.beltMotorUsageSecond / 60).toFixed(0) + " Mins. "
            font.pointSize: fontSize
            visible: isTreadmill
        }

        Text{
            text: (statisticManager.inclineMotorUsageSecond / 3600).toFixed(0) + " Hrs. " + (statisticManager.inclineMotorUsageSecond / 60).toFixed(0) + " Mins. "
            font.pointSize: fontSize
            visible: isTreadmill
        }

        Text{
            text: statisticManager.staticBrakeEngagementCount
            font.pointSize: fontSize
            visible: isTreadmill
        }

        Text{
            text: statisticManager.staticBrakeUsageRevolutions
            font.pointSize: fontSize
            visible: isTreadmill
        }

        Text{
            text: options.metricUnits ? Globals.mileToKm(statisticManager.pedalUsageMile).toFixed(2) + " " + qsTr("KM") : (statisticManager.pedalUsageMile).toFixed(2) + " " + qsTr("Miles") + application.emptyString
            font.pointSize: fontSize
            visible: isPedalSystem
        }

        Text{
            text: statisticManager.pedalRevolutions
            font.pointSize: fontSize
            visible: isPedalSystem
        }

        Text{
            text: (statisticManager.strideMotorUsageSecond / 3600).toFixed(0) + " Hrs. " + (statisticManager.strideMotorUsageSecond / 60).toFixed(0) + " Mins. "
            font.pointSize: fontSize
            visible: isPedalSystem && main.isCSA
        }


    }

    Text {
        id: bottomHelpText
        visible: main.isTft && diagnostics_screen.item !== null && diagnostics_screen.item.currentSelectedIndex >= 0

        height: 48 * main.screenScaleY
        font { family: "arial"; pixelSize: 36 * main.screenScaleY; bold: true }
        color: "#6c6c6c"
        text: qsTr("press ENTER to select") + application.emptyString

        anchors.bottom: parent.bottom
        anchors.bottomMargin: 25 * main.screenScaleY
        anchors.horizontalCenter: parent.horizontalCenter
    }
}
