import QtQuick 2.4
import ".."
import Process 0.1
import Components 1.0

Item{
    id: root
    anchors.fill: parent

    property int fontSize: 24 * main.screenScaleY
    property int topOffset: -150 * main.screenScaleY
    property int itemSpacing: 5 * main.screenScaleY
    property int itemColumnSpacing: 50 * main.screenScaleY
    property bool isSetupWizard: false
    property bool showPkgList: false
    property bool showLowerboardInfoList: false
    property string systemChecksum
    property string biosVersion

    property string cursorState: "softwareSum" // softwareSum, lowerboardInfo or reset

    Connections {
        id: keys1
        target: main.isTft && main.state === "DiagnosticState" && root.visible && diagnostics_screen.item !== null && diagnostics_screen.item.currentSelectedIndex >= 0 && !root.showPkgList && !resetConfirmationPrompt.visible ? keymapper : null

        function nextState() {
            if (root.cursorState === "softwareSum") {
                if(main.lowerSystem === "NUCLEUS") {
                    root.cursorState = "lowerboardInfo"
                } else {
                    root.cursorState = "reset"
                }
            } else if (root.cursorState === "lowerboardInfo") {
                root.cursorState = "reset"
            } else {
                root.cursorState = "softwareSum"
            }
        }

        onLeftButtonPressed: {
            main.debugKeys("leftButtonPressed", "DiagnosticsSummary")
            keys1.nextState()
        }

        onRightButtonPressed: {
            main.debugKeys("rightButtonPressed", "DiagnosticsSummary")
            keys1.nextState()
        }

        onEnter2Pressed: {
            main.debugKeys("enter2Pressed", "DiagnosticsSummary")

            if (cursorState === "reset") {
                resetConfirmationPrompt.show()
            } else if(cursorState === "softwareSum") {
                root.showPkgList = true
            } else if(cursorState === "lowerboardInfo") {
                root.showLowerboardInfoList = true
            }
        }
    }

    Connections {
        target: main.isTft && main.state === "DiagnosticState" && root.visible && diagnostics_screen.item !== null && diagnostics_screen.item.currentSelectedIndex >= 0 && !root.showPkgList && !resetConfirmationPrompt.visible ? keymapper : null

        onBackPressed: {
            main.debugKeys("backPressed", "DiagnosticsSummary")

            diagnostics_screen.item.unselectScreen()
        }
    }

    Row{
        anchors.horizontalCenter: root.horizontalCenter ; anchors.horizontalCenterOffset: -width/6
        anchors.verticalCenter: root.verticalCenter ; anchors.verticalCenterOffset: -height / 4
        spacing: 40 * main.screenScaleX
        Column{
            id: labels
            width: 400 * main.screenScaleX
            spacing: itemSpacing

            Text{
                text: qsTr("Product Model") + application.emptyString
                font.pointSize: fontSize
                width: 400 * main.screenScaleX
                horizontalAlignment: Text.AlignRight
            }

            Text{
                text: qsTr("Serial Number") + application.emptyString
                font.pointSize: fontSize
                width: 400 * main.screenScaleX
                horizontalAlignment: Text.AlignRight
            }

            Text  {
                text: qsTr("Machine Serial Number") + application.emptyString
                font.pointSize: fontSize
                width: 400 * main.screenScaleX
                horizontalAlignment: Text.AlignRight
            }



            Text{
                text: qsTr("Tuner Type") + application.emptyString
                font.pointSize: fontSize
                width: 400 * main.screenScaleX
                horizontalAlignment: Text.AlignRight
            }

            Text{
                text: qsTr("Software Version") + application.emptyString
                font.pointSize: fontSize
                width: 400 * main.screenScaleX
                horizontalAlignment: Text.AlignRight
            }

            Text{
                visible: machineinfo.nucleusFirmwareVersion !== ""
                text: qsTr("Nucleus Firmware Version") + application.emptyString
                font.pointSize: fontSize
                width: 400 * main.screenScaleX
                horizontalAlignment: Text.AlignRight
            }

            Text{
                text: qsTr("Product Version") + application.emptyString
                font.pointSize: fontSize
                width: 400 * main.screenScaleX
                horizontalAlignment: Text.AlignRight
            }

            Text{
                text: qsTr("BIOS Version") + application.emptyString
                font.pointSize: fontSize
                width: 400 * main.screenScaleX
                horizontalAlignment: Text.AlignRight
            }

            Text{
                visible: false // hide this for now to save screen space
                text: qsTr("Bootloader Version") + application.emptyString
                font.pointSize: fontSize
                width: 400 * main.screenScaleX
                horizontalAlignment: Text.AlignRight
            }

            Text{
                text: qsTr("System Software Sum") + application.emptyString
                font.pointSize: fontSize
                width: 400 * main.screenScaleX
                horizontalAlignment: Text.AlignRight
            }

            Text{
                id: labelNucleusLowerboardInfo
                visible: main.lowerSystem === "NUCLEUS" ? true : false
                text: qsTr("Lowerboard Info") + application.emptyString
                font.pointSize: fontSize
                width: 400 * main.screenScaleX
                horizontalAlignment: Text.AlignRight
            }
        }
        Column{
            id:values
            spacing: itemSpacing

            width: 400 * main.screenScaleX

            Text{
                text: (machineinfo.modelString + " " + machineinfo.productTypeString) + application.emptyString
                font.pointSize: fontSize
                width: 400 * main.screenScaleX
                horizontalAlignment: Text.AlignLeft
            }

            Text{
                text: main.serialNumber
                font.pointSize: fontSize
                width: 400 * main.screenScaleX
                horizontalAlignment: Text.AlignLeft
            }

            Text{
                text: (main.lowerSystem === "NUCLEUS" ? (machineinfo.serialNumber) : qsTr("Not Available") ) + application.emptyString
                font.pointSize: fontSize
                width: 400 * main.screenScaleX
                horizontalAlignment: Text.AlignLeft
            }


            Text{
                text: tv.tunerType ? tv.tunerType : qsTr("Not Installed") + application.emptyString
                font.pointSize: fontSize
                width: 400 * main.screenScaleX
                horizontalAlignment: Text.AlignLeft
            }

            Text{
                text: application.appVersion
                font.pointSize: fontSize
                width: 400 * main.screenScaleX
                horizontalAlignment: Text.AlignLeft
            }

            Text{
                visible: machineinfo.nucleusFirmwareVersion !== ""
                text: machineinfo.nucleusFirmwareVersion
                font.pointSize: fontSize
                width: 400 * main.screenScaleX
                horizontalAlignment: Text.AlignLeft
            }

            Text{
                text: main.productVersion
                font.pointSize: fontSize
                width: 400 * main.screenScaleX
                horizontalAlignment: Text.AlignLeft
            }

            Text{
                text: root.biosVersion
                font.pointSize: fontSize
                width: 400 * main.screenScaleX
                horizontalAlignment: Text.AlignLeft
            }

            Text{
                text: root.systemChecksum
                font.pointSize: fontSize
                width: 400 * main.screenScaleX
                horizontalAlignment: Text.AlignLeft

                MouseArea {
                    anchors.fill: parent
                    onClicked: root.showPkgList = true
                }
                BorderImage {
                    id: selectionCursor
                    visible: main.isTft && diagnostics_screen.item !== null && diagnostics_screen.item.currentSelectedIndex >= 0 && cursorState === "softwareSum"
                    border { left: 70 * main.screenScaleX; top: 5 * main.screenScaleY; bottom: 5 * main.screenScaleY; right: 70 * main.screenScaleX }
                    anchors { left: parent.left; leftMargin: -35 * main.screenScaleX; verticalCenter: parent.verticalCenter }
                    source: "../" + main.graphicsPath + "tft/maintenance_menus_cursor.png"
                    width: 640 * main.screenScaleX
                    height: 56 * main.screenScaleY
                    horizontalTileMode: BorderImage.Stretch
                }
            }

            Text{
                visible: labelNucleusLowerboardInfo.visible
                text: qsTr("Click to show") + application.emptyString
                font.pointSize: fontSize
                width: paintedWidth
                horizontalAlignment: Text.AlignLeft

                MouseArea {
                    anchors.fill: parent
                    onClicked: root.showLowerboardInfoList = true
                }

                BorderImage {
                    id: labelNucleusLowerboardInfoSelectionCursor
                    visible: main.isTft && diagnostics_screen.item !== null && diagnostics_screen.item.currentSelectedIndex >= 0 && cursorState === "lowerboardInfo"
                    border { left: 70 * main.screenScaleX; top: 5 * main.screenScaleY; bottom: 5 * main.screenScaleY; right: 70 * main.screenScaleX }
                    anchors {
                        horizontalCenter: parent.horizontalCenter
                        verticalCenter: parent.verticalCenter
                    }
                    source: "../" + main.graphicsPath + "tft/maintenance_menus_cursor.png"
                    width: parent.width + 60
                    height: parent.paintedHeight + 10
                    horizontalTileMode: BorderImage.Stretch
                }
            }
        }
    }

    ImageButton{
        id: factoryResetButton

        wrapWidth: 300
        visible: !root.isSetupWizard

        anchors.right: root.right ; anchors.rightMargin: 10 * main.screenScaleX
        anchors.bottom: root.bottom ; anchors.bottomMargin: 80 * main.screenScaleY

        upimage:"../" + main.graphicsPath + "200/TRU_200_other_small_Button_Up.png"
        downimage:"../" + main.graphicsPath + "200/TRU_200_other_small_Button_Down.png"

        label: qsTr("RESET FACTORY DEFAULTS") + application.emptyString
        label_under: true
        label_y_offset: 5 * main.screenScaleY
        label_color: "black"

        onClicked: {
            resetConfirmationPrompt.show()
        }
    }

    Image {
        source: "../" + main.graphicsPath + "tft/NAV_selector_2.png"
        visible: main.isTft && diagnostics_screen.item !== null && diagnostics_screen.item.currentSelectedIndex >= 0 && cursorState === "reset"
        anchors.verticalCenter: factoryResetButton.verticalCenter
        anchors.right: parent.right
        anchors.rightMargin: 130 * main.screenScaleX
        z: factoryResetButton.z - 1
    }

    ConfirmationPrompt {
        id: resetConfirmationPrompt
        x: 300 * main.screenScaleX ; y: 300 * main.screenScaleY
        visible: false
        prompt: qsTr("Are you sure?\nALL setup will be cleared.") + application.emptyString

        onYesClicked: {
            statisticManager.resetAll();
            errorManager.clearAllError()
            options.resetToDefaults()
            tv.channelList.clearChannels()
            workoutStats.clearAll()
            slidesFileManager.deleteCurrentSlides()
            facilitySlidesManager.deleteCurrentSlides()
            resetEthernet.start()
            clear_network_interfaces.start()
            resetSoftwareSources.start()
            main.restartRequired = true
            syncDisk.start()
            hide()
        }

        onNoClicked: {
            hide()
        }
    }

    Process {
        id: resetEthernet

        onFinished: { dataExport.getNetworkAddresses() }

        program: "scripts/configure_network.sh"
        arguments: ["enp2s0"]
    }

    Process {
        id: clear_network_interfaces

        onFinished: { dataExport.getNetworkAddresses() }

        program: "scripts/clear_network_interfaces.sh"
    }

    // Disable any *daily.list or *testing.list in /etc/apt/sources.list.d
    Process {
        id: resetSoftwareSources
        program: "bash"
        arguments: "scripts/resetSoftwareSources.sh"
    }


    SlidesFileManager {
        id: slidesFileManager
    }

    SlidesFileManager {
        id: facilitySlidesManager
        slidesDestination: "/data/facility/user"
    }

    Loader {
        id: packagelistView
        x: 200 * main.screenScaleX
        y: -20
        source: root.showPkgList ? "PackageListView.qml" : ""

        Connections {
            target: packagelistView.item
            ignoreUnknownSignals: true
            onClose: {
                print("close pkg view")
                root.showPkgList = false
            }
        }
    }

    Loader {
        id: lowerboardInfoView
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.verticalCenter: parent.verticalCenter
        source: root.showLowerboardInfoList ? "LowerboardInfoView.qml" : ""

        Connections {
            target: lowerboardInfoView.item
            ignoreUnknownSignals: true
            onClose: {
                root.showLowerboardInfoList = false
            }
        }
    }

    Process {
        id: getSystemChecksumProcess
        Component.onCompleted: start()
        program: "bash"
        arguments: [ "scripts/list_installed_packages.sh", "-s" ]
        onReadyReadStandardOutput: {
            root.systemChecksum = readAllStandardOutput()
            root.systemChecksum = root.systemChecksum.trim()
        }
    }

    Text {
        id: bottomHelpText
        visible: main.isTft && diagnostics_screen.item !== null && diagnostics_screen.item.currentSelectedIndex >= 0 && !resetConfirmationPrompt.visible

        height: 48 * main.screenScaleY
        font { family: "arial"; pixelSize: 36 * main.screenScaleY; bold: true }
        color: "#6c6c6c"
        text: {
            if (root.showPkgList)
                return qsTr("use <img src='../graphics/tft/arrow_up.png' /><img src='../graphics/tft/arrow_down.png' /> to navigate, press BACK to close") + application.emptyString
            else
                return qsTr("press ENTER to select") + application.emptyString
        }

        anchors.bottom: parent.bottom
        anchors.bottomMargin: 25 * main.screenScaleY
        anchors.horizontalCenter: parent.horizontalCenter
    }

    Process {
        id: getBiosVerProcess

        Component.onCompleted: start()
        program: "sudo"
        arguments: ["cat", "/sys/class/dmi/id/bios_version"]
        onReadyReadStandardOutput: {
            var version = String(readAllStandardOutput())
            root.biosVersion = version.trim()
            print("Bios Version: " + root.biosVersion)
        }
    }

}
