
import QtQuick 2.4
import Process 0.1
import "."
import "../Television"
import ".."
import "../Keypad"
import FileIO 1.0
import VLCVideo 1.0
import Components 1.0

Item {
    id: root
    property string tuner_id: tv.tunerType
    property bool isSetupWizard: false
    property bool isActive: (main.state === "DiagnosticState" && ((diagnostics_screen.item !== null && diagnostics_screen.item.currentSelectedIndex >= 0) || main.isTouch)) || root.isSetupWizard

    width: 1166 * main.screenScaleX
    height: 568 * main.screenScaleY

    Connections {
        target: root.isActive ? keymapper : null

        onBackPressed: {
            main.debugKeys("backPressed", "DiagnosticsTVAdvanced")
            diagnostics_screen.item.unselectScreen()
        }
    }

    function doSave() {
        // take the channels in scanChannelList and dump them to tv.channelList
        tv.channelList.channels.clear()
        for(var i=0 ; i < scanChannelList.channels.count ; i++) {
            var item = scanChannelList.channels.get(i)
            var words = String(item.name).split(" ")
            if(words[0] === "service_id"){
                //console.log("channel name=" + item.name)
                //console.log("service string" + words[1])
                words[0]="Service "
                item.name=words.join(" ")
                //console.log("new name is:" + item.name)
            }

            tv.channelList.addChannel(item)
        }
        tv.channelList.saveChannels(tv.channelFile)
        tv.channelList.readChannels(tv.channelFile)
//        root.chanlistChanged = false
        syncDisk.start()
    }

    function deleteAllChannels() {
        scanChannelList.channels.clear()
        root.doSave()
    }

    Component.onCompleted: {

        // get current channel list from TV element
        for(var i=0 ; i < tv.channelList.channels.count ; i++) {
            var item = tv.channelList.channels.get(i)
            scanChannelList.addChannel(item)
        }
    }

    Component.onDestruction: if (root.isActive) tv.on = false

    onIsActiveChanged: {
        if (isActive){
            if (channelList.currentIndex >= 0)
                previewTv.previewChannel(channelList.currentIndex)
        } else {
            tv.on = false
        }
    }

    AlphaKeypad {
        id: nameKeypad
        show_entry: true
        anchors { horizontalCenter: parent.horizontalCenter ; bottom: parent.bottom }
        visible: false
        z: 9999
        onClose: hide()

        onValueEntered: {
            scanChannelList.channels.setProperty(channelList.currentIndex, "name", value)
            root.doSave()
            hide()
        }
    }

    Rectangle {
        id: channelListBox

        color: "lightgray"
        width: 725 * main.screenScaleX
        height: 460 * main.screenScaleY
        clip:true
        anchors.top: rightControlArea.top
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.horizontalCenterOffset: -rightControlArea.width/2

        Item {
            id: dataArrows

            width: 40 * main.screenScaleX
            height: parent.height

            anchors { top: parent.top; right: parent.right ; rightMargin: ( Qt.application.layoutDirection === Qt.RightToLeft ? -20 : -5 ) * main.screenScaleX }
            Image {
                id: dataUpArrow
                visible: !(channelList.contentY < 10)
                source: "../" + main.graphicsPath + "Swipe_Arrows_Left.png"
                rotation: 90
                anchors { top: parent.top; topMargin: 35 * main.screenScaleY; right: parent.right }
            }
            Image {
                id: dataDownArrow
                visible: !(channelList.contentY + channelList.height > channelList.contentHeight - 10)
                source: "../" + main.graphicsPath + "Swipe_Arrows_Right.png"
                rotation: 90
                anchors { bottom: parent.bottom; bottomMargin: 35 * main.screenScaleY; right: parent.right }
            }
        }

        GridView {
            id: channelList

            property int imageClickIndex

            function removeChannel() {
                scanChannelList.channels.remove(channelList.currentIndex)
                root.doSave()
            }

            Connections {
                target: main.isTft && !main.blockKeys && root.isActive && channelList.count > 0 ? keymapper : null

                onUpButtonPressed: {
                    main.debugKeys("upButtonPressed", "DiagnosticsTVAdvanced")
                    channelList.moveCurrentIndexUp()
                }

                onDownButtonPressed:{
                    main.debugKeys("downButtonPressed", "DiagnosticsTVAdvanced")
                    channelList.moveCurrentIndexDown()
                }

                onLeftButtonPressed:{
                    main.debugKeys("leftButtonPressed", "DiagnosticsTVAdvanced")
                    channelList.moveCurrentIndexLeft()
                }

                onRightButtonPressed:{
                    main.debugKeys("rightButtonPressed", "DiagnosticsTVAdvanced")
                    channelList.moveCurrentIndexRight()
                }

                onEnter2Pressed:{
                    main.debugKeys("enter2Pressed", "DiagnosticsTVAdvanced")
                    channelList.currentItem.showIconSelector()
                }

                onDoubleLeftPressed: {
                    main.debugKeys("doubleLeftPressed", "DiagnosticsTVAdvanced")
                    deletePopup.show()
                }

            }

            Connections {
                target: main.isTft && !main.blockKeys && root.isActive ? keymapper : null

                onDoubleRightPressed: {
                    main.debugKeys("doubleRightPressed", "DiagnosticsTVAdvanced")
                    addChannelLoader.loadItem()
                }
            }

            onCurrentIndexChanged: {
                if (currentIndex >= 0){
                    previewTimer.index = currentIndex
                    previewTimer.restart()
                }
            }

            Image {
                id: highlightImage
                visible: channelList.currentIndex >= 0
                source: "../" + main.graphicsPath + "tft/TV_menus_cursor.png"
                x: channelList.currentItem ? (channelList.currentItem.x - 11 * main.screenScaleX - channelList.contentX) : -9 * main.screenScaleX
                y: channelList.currentItem ? (channelList.currentItem.y - 11 * main.screenScaleY - channelList.contentY) : -9 * main.screenScaleY
            }
            anchors.left: parent.left
            anchors.top: parent.top
            anchors {
                leftMargin: 30 * main.screenScaleX
                topMargin: 10 * main.screenScaleY
                bottomMargin: 5 * main.screenScaleY
                rightMargin: 5 * main.screenScaleX
            }
            model: scanChannelList.channels
            width: 640 * main.screenScaleX
            height: 450 * main.screenScaleY
            cellWidth: 160 * main.screenScaleX
            cellHeight: 150 * main.screenScaleY

            delegate: Component {
                Item {
                    function showIconSelector(){
                        channelList.imageClickIndex = index
                        iconSelector.show()
                    }
                    width: 160 * main.screenScaleX; height: 150 * main.screenScaleY
                    Item {
                        width: 110 * main.screenScaleX; height: 135 * main.screenScaleY
                        anchors { left: parent.left; top: parent.top }

                        Rectangle{
                            id: iconBg
                            color: "white"
                            height: 110 * main.screenScaleY; width: 110 * main.screenScaleX

                            Image {
                                id: iconImage
                                anchors.horizontalCenter: parent.horizontalCenter
                                anchors.top: parent.top
                                source: icon ?"../" +  main.graphicsPath+ "TvIcons/default/channelIcons/" + icon :"../" +  main.graphicsPath+ "TvIcons/default/channelIcons/tv_default.png"
                                MouseArea {
                                    anchors.fill: parent
                                    onClicked: {
                                        if (channelList.currentIndex === index){
                                            showIconSelector()
                                        } else {
                                            channelList.currentIndex = index
                                        }
                                    }
                                }
                            }
                        }

                        Text {
                            anchors { horizontalCenter: iconBg.horizontalCenter; top: iconBg.bottom; topMargin: 0 }
                            verticalAlignment: Text.AlignVCenter
                            text: {
                                if (number && name && number != name) {
                                    return Globals.truncate(name, 23) + " " + number
                                } else if (name) {
                                    return Globals.truncate(name, 26)
                                } else if (number) {
                                    return number
                                } else {
                                    return ""
                                }
                            }
                            font.bold: true
                            font.pointSize: 12 * main.screenScaleY
                            width: 110 * main.screenScaleX
                            horizontalAlignment: Text.AlignHCenter
                            lineHeight: 0.85
                            wrapMode: Text.WrapAnywhere
                            MouseArea {
                                anchors.fill: parent
                                onClicked: {
                                    channelList.currentIndex = index
                                    nameKeypad.show()
                                }
                            }
                        }
                    }
                }
            }
        }
    }

    ModalDialog {
        id: deletePopup
        dismissable: true
        blockKeys: true

        Connections {
            target: main.isTft && deletePopup.visible ? keymapper : null

            onEnter2Pressed: {
                main.debugKeys("enter2Pressed", "DiagnosticsTVAdvanced", "(deletePopup)")
                channelList.removeChannel()
                deletePopup.hide()
            }

            onDoubleRightPressed: {
                main.debugKeys("doubleRightPressed", "DiagnosticsTVAdvanced", "(deletePopup)")
                deletePopup.hide()
                deleteAllPopup.show()
            }
        }

        BorderImage {   // pop-up dialog background
            id: border

            x: 332 * main.screenScaleX
            y: 161 * main.screenScaleY
            width: 800 * main.screenScaleX
            height: 390 * main.screenScaleY
            source: "../" + main.graphicsPath + "Pop_Up_Lrg_Grey.png"
            border { top: 152 * main.screenScaleY; bottom: 165 * main.screenScaleY; left: 145 * main.screenScaleX; right: 144 * main.screenScaleX }
            Text {
                id: warningText
                width: 501 * main.screenScaleX
                color: "#ffffff"
                text: qsTr("DELETE CHANNEL?") + application.emptyString
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.top: parent.top
                anchors.topMargin: 35 * main.screenScaleY
                horizontalAlignment: Text.AlignHCenter
                wrapMode: Text.WordWrap
                font.bold: true
                font.pixelSize: 40 * main.screenScaleY
            }

            Item {
                id: tftControls2
                visible: main.isTft
                width: 240 * main.screenScaleX
                height: 220 * main.screenScaleY
                anchors {
                    top: warningText.bottom
                    horizontalCenter: parent.horizontalCenter
                }

                Text {
                    id: video1_dp
                    width: 182 * main.screenScaleX
                    height: 50 * main.screenScaleY
                    anchors.left: parent.left
                    anchors.top: parent.top
                    anchors.topMargin: 25 * main.screenScaleY
                    Text {
                        id: v1_menu_dp
                        text: qsTr("ENTER") + application.emptyString
                        font { pixelSize: 18 * main.screenScaleY; family: "arial"; bold: true }
                        x: 0
                        y: 3 * main.screenScaleY
                    }
                    Image {
                        id: v1_equals_dp
                        source: "../" + main.graphicsPath + "tft/equals.png"
                        x: 72 * main.screenScaleX
                        y: 5 * main.screenScaleY
                    }
                    Text {
                        id: v1_instr_dp
                        text: qsTr("Delete Channel") + application.emptyString
                        font { pixelSize: 18 * main.screenScaleY; family: "arial"; bold: true }
                        x: 105 * main.screenScaleX
                        y: 3 * main.screenScaleY
                    }
                }

                Text {
                    id: video2_dp
                    width: 182 * main.screenScaleX
                    height: 50 * main.screenScaleY
                    anchors.left: parent.left
                    anchors.top: video1_dp.bottom
                    anchors.topMargin: 5 * main.screenScaleY
                    Text {
                        id: v2_image_dp
                        text: qsTr("BACK") + application.emptyString
                        font { pixelSize: 18 * main.screenScaleY; family: "arial"; bold: true }
                        x: 0
                    }
                    Image {
                        id: v2_equals_dp
                        source: "../" + main.graphicsPath + "tft/equals.png"
                        x: 72 * main.screenScaleX
                        y: 5 * main.screenScaleY
                    }
                    Text {
                        id: v2_instr_dp
                        text: qsTr("Cancel") + application.emptyString
                        font { pixelSize: 18 * main.screenScaleY; family: "arial"; bold: true }
                        x: 105 * main.screenScaleX
                        y: 3 * main.screenScaleY
                    }
                }

                Text {
                    id: video3_dp
                    width: 182 * main.screenScaleX
                    height: 50 * main.screenScaleY
                    anchors.left: parent.left
                    anchors.top: video2_dp.bottom
                    anchors.topMargin: 5 * main.screenScaleY
                    Image {
                        id: v3_image_dp
                        source: "../" + main.graphicsPath + "tft/FWD_icon.png"
                        x: 0
                    }
                    Image {
                        id: v3_equals_dp
                        source: "../" + main.graphicsPath + "tft/equals.png"
                        x: 72 * main.screenScaleX
                        y: 5 * main.screenScaleY
                    }
                    Text {
                        id: v3_instr_dp
                        text: qsTr("To Delete All Channels") + application.emptyString
                        font { pixelSize: 18 * main.screenScaleY; family: "arial"; bold: true }
                        wrapMode: Text.WordWrap
                        x: 105 * main.screenScaleX
                        y: 3 * main.screenScaleY
                    }
                }
            }
            Item {
                id: touchControls2
                visible: main.isTouch
                width: 240 * main.screenScaleX
                height: 220 * main.screenScaleY
                anchors {
                    top: warningText.bottom
                    horizontalCenter: parent.horizontalCenter
                }

                Item {
                    id: row1
                    width: 182 * main.screenScaleX
                    height: 50 * main.screenScaleY
                    anchors.left: parent.left
                    anchors.top: parent.top
                    anchors.topMargin: 5 * main.screenScaleY
                    ImageButton {
                        id: deleteBtn
                        upimage: "../" + main.graphicsPath + "205/SM_Button_RED.png"
                        downimage: "../" + main.graphicsPath + "205/SM_Button_ORANGE.png"
                        onClicked: {
                            channelList.removeChannel()
                            deletePopup.hide()
                        }
                    }
                    Text {
                        text: qsTr("Delete Channel") + application.emptyString
                        font { pixelSize: 18 * main.screenScaleY; family: "arial"; bold: true }
                        x: 72 * main.screenScaleX
                        anchors.verticalCenter: deleteBtn.verticalCenter
                    }
                }

                Item {
                    id: row2
                    width: 182 * main.screenScaleX
                    height: 50 * main.screenScaleY
                    anchors.left: parent.left
                    anchors.top: row1.bottom
                    anchors.topMargin: 15 * main.screenScaleY
                    ImageButton {
                        id: cancelBtn
                        upimage: "../" + main.graphicsPath + "205/SM_Button_RED.png"
                        downimage: "../" + main.graphicsPath + "205/SM_Button_ORANGE.png"
                        onClicked: {
                            deletePopup.dismissed()
                        }
                    }
                    Text {
                        text: qsTr("Cancel") + application.emptyString
                        font { pixelSize: 18 * main.screenScaleY; family: "arial"; bold: true }
                        x: 72 * main.screenScaleX
                        anchors.verticalCenter: cancelBtn.verticalCenter
                    }
                }

                Item {
                    id: row3
                    width: 182 * main.screenScaleX
                    height: 50 * main.screenScaleY
                    anchors.left: parent.left
                    anchors.top: row2.bottom
                    anchors.topMargin: 15 * main.screenScaleY
                    ImageButton {
                        id: deleteAllBtn
                        upimage: "../" + main.graphicsPath + "205/SM_Button_RED.png"
                        downimage: "../" + main.graphicsPath + "205/SM_Button_ORANGE.png"
                        onClicked: {
                            deletePopup.hide()
                            deleteAllPopup.show()
                        }
                    }
                    Text {
                        text: qsTr("Delete ALL Channels") + application.emptyString
                        font { pixelSize: 18 * main.screenScaleY; family: "arial"; bold: true }
                        wrapMode: Text.WordWrap
                        x: 72 * main.screenScaleX
                        anchors.verticalCenter: deleteAllBtn.verticalCenter
                    }
                }
            }
        }
        Component.onCompleted: hide()
        onTimedOut: hide()
    }

    Loader {
        id: addChannelLoader

        function loadItem() {
           sourceComponent = addChannelComponent
        }

        function destroyItem() {
            sourceComponent = null
        }

        onLoaded: addChannelLoader.item.show()

        Component {
            id: addChannelComponent
            AddChannelPopup {
                id: addChannelPopup
                onChannelAdded: {
                    console.log("channelAdded", norm, network, number, freq)
                    var item = {id: "A"+freq, number: number, freq: freq, name: network, enabled:"true", analog:true, norm: norm}
                    scanChannelList.addChannel(item)
                    root.doSave()
                    var idx = scanChannelList.findChannel(item.id)
                    if (idx >= 0){
                        channelList.currentIndex = idx
                    }
                    hide()
                    addChannelLoader.destroyItem()
                }
                onDismissed: {
                    addChannelLoader.destroyItem()
                }
            }
        }
    }

    ModalDialog {
        id: deleteAllPopup
        dismissable: true
        blockKeys: true

        Connections {
            target: main.isTft && deleteAllPopup.visible ? keymapper : null

            onEnter2Pressed: {
                main.debugKeys("enter2Pressed", "DiagnosticsTVAdvanced", "(deleteAllPopup)")
                root.deleteAllChannels()
                deleteAllPopup.hide()
            }
        }

        BorderImage {   // pop-up dialog background
            id: border2

            x: 332 * main.screenScaleX
            y: 161 * main.screenScaleY
            width: 800 * main.screenScaleX
            height: 390 * main.screenScaleY
            source: "../" + main.graphicsPath + "Pop_Up_Lrg_Grey.png"
            border { top: 152 * main.screenScaleY; bottom: 165 * main.screenScaleY; left: 145 * main.screenScaleX; right: 144 * main.screenScaleX }
            Text {
                id: warningText2
                width: 501 * main.screenScaleX
                color: "#ffffff"
                text: qsTr("DELETE ALL?") + application.emptyString
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.top: parent.top
                anchors.topMargin: 35 * main.screenScaleY
                horizontalAlignment: Text.AlignHCenter
                wrapMode: Text.WordWrap
                font.bold: true
                font.pixelSize: 40 * main.screenScaleY
            }

            Item {
                id: tftControls3
                visible: main.isTft
                width: 240 * main.screenScaleX
                height: 220 * main.screenScaleY
                anchors {
                    top: warningText2.bottom
                    horizontalCenter: parent.horizontalCenter
                }

                Text {
                    id: deleteAllText
                    width: 182 * main.screenScaleX
                    height: 50 * main.screenScaleY
                    anchors.left: parent.left
                    anchors.top: parent.top
                    anchors.topMargin: 25 * main.screenScaleY
                    Text {
                        text: qsTr("ENTER") + application.emptyString
                        font { pixelSize: 18 * main.screenScaleY; family: "arial"; bold: true }
                        x: 0
                        y: 3 * main.screenScaleY
                    }
                    Image {
                        source: "../" + main.graphicsPath + "tft/equals.png"
                        x: 72 * main.screenScaleX
                        y: 5 * main.screenScaleY
                    }
                    Text {
                        text: qsTr("Delete ALL Channels") + application.emptyString
                        font { pixelSize: 18 * main.screenScaleY; family: "arial"; bold: true }
                        x: 105 * main.screenScaleX
                        y: 3 * main.screenScaleY
                    }
                }

                Text {
                    id: backText
                    width: 182 * main.screenScaleX
                    height: 50 * main.screenScaleY
                    anchors.left: parent.left
                    anchors.top: deleteAllText.bottom
                    anchors.topMargin: 5 * main.screenScaleY
                    Text {
                        text: qsTr("BACK") + application.emptyString
                        font { pixelSize: 18 * main.screenScaleY; family: "arial"; bold: true }
                        x: 0
                    }
                    Image {
                        source: "../" + main.graphicsPath + "tft/equals.png"
                        x: 72 * main.screenScaleX
                        y: 5 * main.screenScaleY
                    }
                    Text {
                        text: qsTr("Cancel") + application.emptyString
                        font { pixelSize: 18 * main.screenScaleY; family: "arial"; bold: true }
                        x: 105 * main.screenScaleX
                        y: 3 * main.screenScaleY
                    }
                }
            }
            Item {
                id: touchControls3
                visible: main.isTouch
                width: 240 * main.screenScaleX
                height: 220 * main.screenScaleY
                anchors {
                    top: warningText2.bottom
                    horizontalCenter: parent.horizontalCenter
                }

                Item {
                    id: deleteall1
                    width: 182 * main.screenScaleX
                    height: 50 * main.screenScaleY
                    anchors.left: parent.left
                    anchors.top: parent.top
                    anchors.topMargin: 25 * main.screenScaleY
                    ImageButton {
                        id: deleteAllBtn2
                        upimage: "../" + main.graphicsPath + "205/SM_Button_RED.png"
                        downimage: "../" + main.graphicsPath + "205/SM_Button_ORANGE.png"
                        onClicked: {
                            root.deleteAllChannels()
                            deleteAllPopup.hide()
                        }
                    }
                    Text {
                        text: qsTr("Delete ALL Channels") + application.emptyString
                        font { pixelSize: 18 * main.screenScaleY; family: "arial"; bold: true }
                        x: 72 * main.screenScaleX
                        anchors.verticalCenter: deleteAllBtn2.verticalCenter
                    }
                }

                Item {
                    width: 182 * main.screenScaleX
                    height: 50 * main.screenScaleY
                    anchors.left: parent.left
                    anchors.top: deleteall1.bottom
                    anchors.topMargin: 15 * main.screenScaleY
                    ImageButton {
                        id: cancelBtn2
                        upimage: "../" + main.graphicsPath + "205/SM_Button_RED.png"
                        downimage: "../" + main.graphicsPath + "205/SM_Button_ORANGE.png"
                        onClicked: {
                            deleteAllPopup.dismissed()
                        }
                    }
                    Text {
                        text: qsTr("Cancel") + application.emptyString
                        font { pixelSize: 18 * main.screenScaleY; family: "arial"; bold: true }
                        x: 72 * main.screenScaleX
                        anchors.verticalCenter: cancelBtn2.verticalCenter
                    }
                }
            }
        }
        Component.onCompleted: hide()
        onTimedOut: hide()
    }

    IconSelectorPopup {
        id: iconSelector
        blockKeys: true
        listenKeys: iconSelector.visible
        visible: false
        x: 130 * main.screenScaleX
        y: 97 * main.screenScaleY
        width: 1080 * main.screenScaleX
        height: 486 * main.screenScaleY
        onIconSelected: {
            scanChannelList.channels.setProperty(channelList.imageClickIndex, "icon", iconSource)
            root.doSave() //save after we assign an icon
            hide()
        }

        onExitSelected: {
            hide()
        }
    }

    Timer {
        id: previewTimer
        property int index: 0

        interval: 500
        running: false
        repeat: false
        onTriggered: {
            previewTv.previewChannel(previewTimer.index)
        }
    }

    Rectangle {
        id: rightControlArea

        width: 280 * main.screenScaleX
        height: 460 * main.screenScaleY
        color: "#7f8082"
        anchors { left: channelListBox.right; top: parent.top; topMargin: 98 * main.screenScaleY }

        VLCSurface{
            id: previewTv
            player: tv.player
            aspect: tv.aspect
            playing: channelList.currentIndex >= 0 && root.isActive
            width: ( iconSelector.visible ? 180 : 240 ) * main.screenScaleX
            height: width/tv.aspect
            anchors { top: parent.top; right: parent.right; margins: 20 }
            anchors.topMargin: ( iconSelector.visible ? -180 : 20 ) * main.screenScaleY
            onPlayingChanged: tv.on = playing
            z: 1000

            function previewChannel(index) {
                var mrl = scanChannelList.mrl(index)
                tv.on = true
                tv.mrl = mrl
            }
        }

        Item {
            id: tftControls
            visible: main.isTft
            width: 240 * main.screenScaleX
            height: 220 * main.screenScaleY
            anchors {
                bottom: parent.bottom
                bottomMargin: 10 * main.screenScaleY
                left: parent.left
                leftMargin: 20 * main.screenScaleX
            }

            Text {
                id: video1
                visible: channelList.count > 0
                width: 182 * main.screenScaleX
                height: 50 * main.screenScaleY
                anchors.left: parent.left
                anchors.top: parent.top
                anchors.topMargin: 45 * main.screenScaleY
                Text {
                    id: v1_menu
                    text: qsTr("ENTER") + application.emptyString
                    font { pixelSize: 18 * main.screenScaleY; family: "arial"; bold: true }
                    x: 0
                    y: 3 * main.screenScaleY
                }
                Image {
                    id: v1_equals
                    source: "../" + main.graphicsPath + "tft/equals.png"
                    x: 72 * main.screenScaleX
                    y: 5 * main.screenScaleY
                }
                Text {
                    id: v1_instr
                    text: qsTr("Edit Channel") + application.emptyString
                    font { pixelSize: 18 * main.screenScaleY; family: "arial"; bold: true }
                    x: 105 * main.screenScaleX
                    y: 3 * main.screenScaleY
                }
            }

            Text {
                id: video2
                visible: channelList.count > 0
                width: 182 * main.screenScaleX
                height: 50 * main.screenScaleY
                anchors.left: parent.left
                anchors.top: video1.bottom
                anchors.topMargin: 10 * main.screenScaleY
                Image {
                    id: v2_image
                    source: "../" + main.graphicsPath + "tft/REW_icon.png"
                    x: 0
                }
                Image {
                    id: v2_equals
                    source: "../" + main.graphicsPath + "tft/equals.png"
                    x: 72 * main.screenScaleX
                    y: 5 * main.screenScaleY
                }
                Text {
                    id: v2_instr
                    text: qsTr("Delete Channel") + application.emptyString
                    font { pixelSize: 18 * main.screenScaleY; family: "arial"; bold: true }
                    x: 105 * main.screenScaleX
                    y: 3 * main.screenScaleY
                }
            }

            Text {
                id: video3
                width: 182 * main.screenScaleX
                height: 50 * main.screenScaleY
                anchors.left: parent.left
                anchors.top: video2.bottom
                anchors.topMargin: 10 * main.screenScaleY
                Image {
                    id: v3_image
                    source: "../" + main.graphicsPath + "tft/FWD_icon.png"
                    x: 0
                }
                Image {
                    id: v3_equals
                    source: "../" + main.graphicsPath + "tft/equals.png"
                    x: 72 * main.screenScaleX
                    y: 5 * main.screenScaleY
                }
                Text {
                    id: v3_instr
                    text: qsTr("Add a Channel") + application.emptyString
                    font { pixelSize: 18 * main.screenScaleY; family: "arial"; bold: true }
                    wrapMode: Text.WordWrap
                    x: 105 * main.screenScaleX
                    y: 3 * main.screenScaleY
                }
            }
        }
        Item {
            id: touchControls
            visible: main.isTouch
            width: 240 * main.screenScaleX
            height: 200 * main.screenScaleY
            anchors {
                bottom: parent.bottom
                bottomMargin: 10 * main.screenScaleY
                left: parent.left
                leftMargin: 20 * main.screenScaleX
            }

            Item {
                id: deleteRow
                visible: scanChannelList.channels.count > 0
                anchors.top: parent.top
                anchors.left: parent.left
                height: deleteButton.height
                ImageButton {
                    id: deleteButton
                    upimage: "../" + main.graphicsPath + "205/SM_Button_RED.png"
                    downimage: "../" + main.graphicsPath + "205/SM_Button_ORANGE.png"
                    onClicked: {
                        deletePopup.show()
                    }
                }
                Text {
                    text: qsTr("Delete Channel") + application.emptyString
                    anchors.left: deleteButton.right
                    anchors.leftMargin: 20 * main.screenScaleX
                    anchors.verticalCenter: deleteButton.verticalCenter
                    font { pixelSize: 18 * main.screenScaleY; bold: true }
                }
            }
            Item {
                id: addRow
                visible: !options.iptvEnabled
                anchors.top: deleteRow.bottom
                anchors.topMargin: 10 * main.screenScaleY
                anchors.left: parent.left
                height: addButton.height
                ImageButton {
                    id: addButton
                    upimage: "../" + main.graphicsPath + "205/SM_Button_BLUE.png"
                    downimage: "../" + main.graphicsPath + "205/SM_Button_ORANGE.png"
                    onClicked: {
                        addChannelLoader.loadItem()
                    }
                }
                Text {
                    text: qsTr("Add Channel") + application.emptyString
                    anchors.left: addButton.right
                    anchors.leftMargin: 20 * main.screenScaleX
                    anchors.verticalCenter: addButton.verticalCenter
                    font { pixelSize: 18 * main.screenScaleY; bold: true }
                }
            }
            Item {
                id: iptvAddRow
                visible: options.iptvEnabled
                anchors.top: deleteRow.bottom
                anchors.topMargin: 10 * main.screenScaleY
                anchors.left: parent.left
                height: iptvAddButton.height
                ImageButton {
                    id: iptvAddButton
                    upimage: "../" + main.graphicsPath + "205/SM_Button_BLUE.png"
                    downimage: "../" + main.graphicsPath + "205/SM_Button_ORANGE.png"
                    onClicked: {
                    }
                }
                Text {
                    text: qsTr("Add Channel") + application.emptyString
                    anchors.left: iptvAddButton.right
                    anchors.leftMargin: 20 * main.screenScaleX
                    anchors.verticalCenter: iptvAddButton.verticalCenter
                    font { pixelSize: 18 * main.screenScaleY; bold: true }
                }
            }
        }

    }

    // When scan is complete, show how many services were found.
    Text {
        id: channelsFoundText
        visible: !iconSelector.visible
        text: {
            if (channelList.count > 0)
                return qsTr("Number of Channels:") + " " + channelList.count + application.emptyString
            else
                return qsTr("No Channels Configured") + application.emptyString
        }
        anchors.bottom: channelListBox.top
        anchors.bottomMargin: 15 * main.screenScaleY
        anchors.left: channelListBox.left
        font { pixelSize: 18 * main.screenScaleY; bold: true }
    }

    ChannelList {
        id: scanChannelList
    }

    FileIO {
        id: fileio
    }
}
