import QtQuick 2.4
import ".."
import Components 1.0


Rectangle {
    id: root
    width: 1366 * main.screenScaleX
    height: 768 * main.screenScaleY
    anchors.fill: parent
    state: ""
    color: "transparent"

    property int topOffset: 130
    property int itemSpacing: 0
    property int menuItemWidth: 150
    property int menuItemHeight: 75
    property bool isSetupWizard: false
    property string keyDown: ""
    property bool isActive: (main.state === "DiagnosticState" && diagnostics_screen.item !== null && diagnostics_screen.item.currentSelectedIndex >= 0) || isSetupWizard


    signal close()
    signal inclineCalibrationComplete()

    Connections {
        target: main.isTft && root.isActive && !goingToCalibrateMessage.visible && !calibratingMessage.visible ? keymapper : null

        onUpButtonPressed: {
            main.debugKeys("upButtonPressed", "DiagnosticsTreadmillCalibration")
            machinecontrol.treadmillInclineUp()
            root.keyDown = "up"
        }

        onUpButtonReleased: {
            main.debugKeys("upButtonReleased", "DiagnosticsTreadmillCalibration")
            machinecontrol.treadmillInclineStop()
            root.keyDown = ""
        }
        onDownButtonReleased: {
            main.debugKeys("downButtonReleased", "DiagnosticsTreadmillCalibration")
            machinecontrol.treadmillInclineStop()
            root.keyDown = ""
        }
        onInclineUpReleased: {
            main.debugKeys("inclineUpReleased", "DiagnosticsTreadmillCalibration")
            machinecontrol.treadmillInclineStop()
            root.keyDown = ""
        }
        onInclineDownReleased: {
            main.debugKeys("inclineDownReleased", "DiagnosticsTreadmillCalibration")
            machinecontrol.treadmillInclineStop()
            root.keyDown = ""
        }

        onDownButtonPressed: {
            main.debugKeys("downButtonPressed", "DiagnosticsTreadmillCalibration")
            machinecontrol.treadmillInclineDown()
            root.keyDown = "down"
        }

        onInclineUpPressed: {
            main.debugKeys("inclineUpPressed", "DiagnosticsTreadmillCalibration")
            machinecontrol.treadmillInclineUp()
            root.keyDown = "up"
        }

        onInclineDownPressed: {
            main.debugKeys("inclineDownPressed", "DiagnosticsTreadmillCalibration")
            machinecontrol.treadmillInclineDown()
            root.keyDown = "down"
        }

        onBackPressed: {
            main.debugKeys("backPressed", "DiagnosticsTreadmillCalibration")
            if (!isSetupWizard)
                diagnostics_screen.item.unselectScreen()
        }

        onEnter2Pressed: {
            main.debugKeys("enter2Pressed", "DiagnosticsTreadmillCalibration")
            startCalibrationTimer.start()
        }

        onRightButtonPressed: {
            main.debugKeys("rightButtonPressed", "DiagnosticsTreadmillCalibration")
            if (isSetupWizard)
                setupWizard.changeState()
        }
    }

    Row{
        id: controlsArea
        spacing: 0
        anchors.verticalCenter: parent.verticalCenter
        anchors.horizontalCenter: parent.horizontalCenter

        Rectangle{

            height: 250 * main.screenScaleY
            width: 300 * main.screenScaleX
            color: "transparent"
        Column{
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.verticalCenter: parent.verticalCenter
            Text{
                id:modelString
                text: qsTr("Model: ") + application.emptyString + machineinfo.modelString
            }
            Text{
                text: qsTr("Maximum Incline: ") + application.emptyString + machineinfo.treadmillInclineMaxPercentGrade/10
            }
            Text{
                text: qsTr("Minimum Incline: ") + application.emptyString + machineinfo.treadmillInclineMinPercentGrade/10
            }
            Text{
                text: qsTr("Maximum Incline ADC: ") + application.emptyString + machineinfo.treadmillCalibratedInclineMaxAdc
            }
            Text{
                text: qsTr("Minimum Incline ADC: ") + application.emptyString + machineinfo.treadmillCalibratedInclineMinAdc
            }
            Text{
                text: qsTr("Actual Speed in MPH: ") + application.emptyString + machinecontrol.treadmillSpeedActual / 10.0
            }
        }
        }

        Item {
            id: tftInclineAdc
            visible: main.isTft
            height: 250 * main.screenScaleY
            width: 500 * main.screenScaleX

            Image {
                source: "../" + main.graphicsPath + "Arrow_Up_Button.png"
                anchors { bottom: inclineAdcValue.top; bottomMargin: 10 * main.screenScaleY; horizontalCenter: inclineAdcValue.horizontalCenter }
                visible: root.keyDown === "up"
            }

            Text {
                id: inclineAdcValue
                text: qsTr("Incline ADC = ") + machinecontrol.treadmillInclineADCActual + application.emptyString
                font { pixelSize: 40 * main.screenScaleY; bold: true }
                anchors.centerIn: parent
            }

            Image {
                source: "../" + main.graphicsPath + "Arrow_Down_Button.png"
                anchors { top: inclineAdcValue.bottom; topMargin: 10 * main.screenScaleY; horizontalCenter: inclineAdcValue.horizontalCenter }
                visible: root.keyDown === "down"
            }
        }

        Rectangle{
            id: inclineControlPanel
            visible: main.isTouch
            color: "transparent"
            height: 250 * main.screenScaleY
            width: 300 * main.screenScaleX
            Column{
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.verticalCenter: parent.verticalCenter
                spacing: 20 * main.screenScaleX
                ImageButton{
                    id: inclineUpButton
                    upimage: "../" + main.graphicsPath + "netpulse/UpArrow_blue.png"
                    downimage: "../" + main.graphicsPath + "netpulse/UpArrow_PRESSED.png"
                    onIsDownChanged: {
                        if(isDown) machinecontrol.treadmillInclineUp()
                        else machinecontrol.treadmillInclineStop()
                    }
                }
                Text{
                    anchors.horizontalCenter: parent.horizontalCenter
                    text: machinecontrol.treadmillInclineADCActual
                    font.pixelSize: 40 * main.screenScaleY
                    font.bold: true

                }

                ImageButton{
                    id: inclineDownButton
                    upimage: "../" + main.graphicsPath + "netpulse/DownArrow_blue.png"
                    downimage: "../" + main.graphicsPath + "netpulse/DownArrow_PRESSED.png"
                    onIsDownChanged: {
                        if(isDown) machinecontrol.treadmillInclineDown()
                        else machinecontrol.treadmillInclineStop()
                    }
                }
            }

        }

        Item{
            visible: main.isTouch
            height: inclineControlPanel.height
            width: 300 * main.screenScaleX
            ImageButton{
                id: setZeroButton
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.verticalCenter: parent.verticalCenter
                upimage: "../" + main.graphicsPath + "200/TRU_200_other_small_Button_Up.png"
                downimage: "../" + main.graphicsPath + "200/TRU_200_other_small_Button_Down.png"
                label: qsTr("CALIBRATE") + application.emptyString
                label_color: "black"
                label_under: true
                beep:false
                onIsDownChanged: if(isDown) startCalibrationTimer.start()
            }
        }

        MessagePopup{
            id:calibratingMessage
            message: "Calibrating..."
            dismissable: false
            Connections {
                target: machinecontrol
                onIsCalibratingChanged: {
                    if(isCalibrating) {
                        calibratingMessage.show()
                        calibratingMessage.message = qsTr("CALIBRATING...")+application.emptyString
                    }
                }
                onCalibrationComplete: {
                    if(result){
                        calibratingMessage.showMessage(qsTr("CALIBRATION SUCCESSFUL")+application.emptyString,4)
                        if (isSetupWizard)
                            bottomHelpText.text = qsTr("press") + ' <img src="../" + main.graphicsPath + "tft/arrow_right.png" /> ' + qsTr("to continue")
                    }
                    else
                       calibratingMessage.showMessage(qsTr("CALIBRATION FAILED")+application.emptyString,4)
                }
            }

        }
        MessagePopup{
            id:goingToCalibrateMessage
            dismissable: false

        }

        Timer{
            id: startCalibrationTimer
            interval: 1000
            repeat: true
            running: false

            property int counter: 3

            function updateGoingToCalibrateMessage(){
                goingToCalibrateMessage.message = qsTr("STARTING CALIBRATION IN ") +"<br>" + counter + application.emptyString
            }

            onRunningChanged: if(running) {
                                  buzzer.warningBeep()
                                  goingToCalibrateMessage.show();
                                  updateGoingToCalibrateMessage()
                              }
            onTriggered: {
                counter--;
                if(counter == 0){
                    counter = 3
                    startCalibrationTimer.stop()
                    machinecontrol.calibrationStart()
                    goingToCalibrateMessage.hide()
                }
                else
                {
                    buzzer.warningBeep()
                    updateGoingToCalibrateMessage();
                }
            }

        }



//        Item{
//            height: inclineControlPanel.height
//            width: 150 * main.screenScaleX
//            ImageButton{
//                id: testButton
//                anchors.horizontalCenter: parent.horizontalCenter
//                anchors.verticalCenter: parent.verticalCenter
//                upimage: "../" + main.graphicsPath + "200/TRU_200_other_small_Button_Up.png"
//                downimage: "../" + main.graphicsPath + "200/TRU_200_other_small_Button_Down.png"
//                label: "TEST"
//                label_color: "black"
//            }
//        }
    }

    Text{
        id: endexInstructionText
        visible: false
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.bottom: controlsArea.top
        anchors.bottomMargin: 25 * main.screenScaleY
        width: 750 * main.screenScaleX
        height: 150 * main.screenScaleY
        wrapMode: Text.WordWrap
        text: "<b>" + qsTr("Calibrating the Incline:") + "</b><br>1." + qsTr("Press the \"CALIBRATE\" button to calibrate machine") + application.emptyString
    }

    Text{
        id: dciInstructionText
        visible: false
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.bottom: controlsArea.top
        anchors.bottomMargin: 25 * main.screenScaleY
        width: 750 * main.screenScaleX
        height: 150 * main.screenScaleY
        wrapMode: Text.WordWrap
        text: "<b>" + qsTr("Calibrating the Incline:") + "</b><br>" + qsTr("Press the \"CALIBRATE\" button to calibrate machine") + application.emptyString
    }

    Text{
        id: tftInstructions
        visible: main.isTft
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.bottom: controlsArea.top
        anchors.bottomMargin: 25 * main.screenScaleY
        width: 750 * main.screenScaleX
        height: 150 * main.screenScaleY
        wrapMode: Text.WordWrap
        text: {
            var str = "<b>" + qsTr("Calibrating the Incline:") + "</b>"
            str += "<ul>"
            str += "<li>" + qsTr("Press ENTER to begin the incline calibration") + "</li>"
            str += "<li>" + qsTr("Use the UP and DOWN arrow keys to adjust incline level") + "</li>"
            str += "</ul>"
            return str
        }
    }

    Text {
        id: bottomHelpText
        visible: main.isTft && root.isActive && !goingToCalibrateMessage.visible && !calibratingMessage.visible

        height: 48 * main.screenScaleY
        font { family: "arial"; pixelSize: 36 * main.screenScaleY; bold: true }
        color: "#6c6c6c"
        text: qsTr("press ENTER to begin calibration") + application.emptyString

        anchors.bottom: parent.bottom
        anchors.bottomMargin: 25 * main.screenScaleY
        anchors.horizontalCenter: parent.horizontalCenter
    }

    //Component.onCompleted: machinecontrol.treadmillSpeedTarget = 5
    Component.onDestruction: machinecontrol.treadmillSpeedTarget = 0
}
