// Diagnostics Software Update Page

import QtQuick 2.4
import StorageMgr 1.0
import Process 0.1
import ".."
import Components 1.0

Rectangle {
    id: root
    width: 1366 * main.screenScaleX
    height: 768 * main.screenScaleY
    anchors.fill: parent
    color: "transparent"

    property int fontSize: 20 * main.screenScaleY
    property int topOffset: 130 * main.screenScaleY
    property int itemSpacing: 5 * main.screenScaleY
    property string firmwareVersion: nucleusfirmwareloader.firmwareVersionString
    property string firmwareUpdateFile: nucleusfirmwareloader.updateFile
    property bool firmwareUpdating: nucleusfirmwareloader.isUpdating
    property bool firmwareUpdateAvailable: nucleusfirmwareloader.isUpdateAvailable
    property bool softwareUpdating: updatingDialog.visible
    property bool checkingForUpdates: checkUpdates.processState == Process.Running
    property bool softwareUpdatesAvailable: checkUpdates.packages.length > 0
    /* This property indicates the combined status of firmware and software update progress */
    property bool updateInProgress: softwareUpdating

    property string cursorState: "" // check, firmware, or software

    onUpdateInProgressChanged: {
    }

    Connections {
        target: main.isTft && main.state === "DiagnosticState" && root.visible && diagnostics_screen.item !== null && diagnostics_screen.item.currentSelectedIndex >= 0 && cursorState !== "" && !softwareUpdating && !firmwareUpdating  ? keymapper : null

        onUpButtonPressed: {
            main.debugKeys("upButtonPressed", "DiagnosticsUpdate")
            if (cursorState === "firmware") {
                if (checkForUpdatesButton.visible)
                    cursorState = "check"
                else
                    cursorState = "software"
            } else if (cursorState === "software" || cursorState === "check") {
                if (bootloadButton.visible)
                    cursorState = "firmware"
            }
        }

        onDownButtonPressed: {
            main.debugKeys("downButtonPressed", "DiagnosticsUpdate")
            if (cursorState === "firmware") {
                if (checkForUpdatesButton.visible)
                    cursorState = "check"
                else
                    cursorState = "software"
            } else if (cursorState === "software" || cursorState === "check") {
                if (bootloadButton.visible)
                    cursorState = "firmware"
            }
        }

        onEnter2Pressed: {
            main.debugKeys("enter2Pressed", "DiagnosticsUpdate")
            if (checkingForUpdates || softwareUpdating || firmwareUpdating) // safeguard
                return

            if (cursorState === "firmware" && bootloadButton.enabled) {
                bootloadButton.clicked()
            } else if (cursorState === "software" && packageUpdateButton.enabled) {
                packageUpdateButton.clicked()
            } else if (cursorState === "check" && checkForUpdatesButton.enabled) {
                checkForUpdatesButton.clicked()
            }
        }
    }

    Connections {
        target: main.isTft && main.state === "DiagnosticState" && root.visible && diagnostics_screen.item !== null && diagnostics_screen.item.currentSelectedIndex >= 0 && !softwareUpdating && !firmwareUpdating ? keymapper : null

        onBackPressed: {
            main.debugKeys("backPressed", "DiagnosticsUpdate")
            diagnostics_screen.item.unselectScreen()
        }
    }

    onFirmwareUpdatingChanged: {
        if(firmwareUpdating)
            firmwareUpdatingDialog.show()
        else
            firmwareUpdatingDialog.hide()
    }

    Connections {
        target: nucleusfirmwareloader
        onFault: {
            print("Diagnostics Update: " + message)
            firmwareUpdatingDialog.hide()
            bootloadErrorReceivedDialogText.text = message
            bootloadErrorReceivedDialog.show()
        }
        onStatus: {
            firmwareUpdatingDialog.text = message
        }
        onUpdateSuccessful: {
            main.restartRequired = true
            restartMsg.visible = true
        }
    }

    signal close()

    ModalDialog{
        id:bootloadErrorReceivedDialog
        blockKeys: true
        dismissable: true

        BorderImage {   // pop-up dialog background
            id: errorborder

            x: 332 * main.screenScaleX
            y: 161 * main.screenScaleY
            width: 800 * main.screenScaleX
            height: 350 * main.screenScaleY
            source: "../" + main.graphicsPath + "Pop_Up_Lrg_Grey.png"
            border { top: 152 * main.screenScaleY; bottom: 165 * main.screenScaleY; left: 145 * main.screenScaleX; right: 144 * main.screenScaleX }

            Text {
                id: bootloadErrorReceivedDialogText
                anchors.fill: parent
                anchors.verticalCenter: parent.verticalCenter
                color: "#ffffff"
                anchors.horizontalCenter: parent.horizontalCenter
                horizontalAlignment: Text.AlignHCenter
                verticalAlignment: Text.AlignVCenter
                wrapMode: Text.WordWrap
                font.bold: true
                font.pixelSize: 50 * main.screenScaleY

            }
            MouseArea{
                anchors.fill: parent
                onClicked: bootloadErrorReceivedDialog.hide()
            }
        }
        Component.onCompleted: hide()
    }

    Item{
        id: informationSection
        //color: "blue"
        //opacity: 0.3
        //z: 5
        width: childrenRect.width
        height: childrenRect.height
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.left: parent.left
        anchors.leftMargin: 50 * main.screenScaleY

        //anchors.verticalCenter: parent.verticalCenter
        anchors.top: root.top
        anchors.topMargin: 50 * main.screenScaleY
        Row{
            spacing: 200 * main.screenScaleX
            Column{
                id: labels
                spacing: itemSpacing

                Text{
                    text: qsTr("Application Version") + application.emptyString
                    font.pointSize: fontSize
                }
                Text{
                    text: qsTr("Nucleus Firmware Version") + application.emptyString
                    font.pointSize: fontSize
                }
            }
            Column{
                id:values
                spacing: itemSpacing

                Text{
                    text: application.appVersion
                    font.pointSize: fontSize
                }
                Text{
                    text: machineinfo.nucleusFirmwareVersion === "" ? qsTr("NOT AVAILABLE") + application.emptyString : machineinfo.nucleusFirmwareVersion
                    font.pointSize: fontSize
                }
            }
        }
    }

    Item{
        id: firmwareUpdateSection

        width: parent.width
        height: childrenRect.height


        anchors {
            top: informationSection.bottom ; topMargin: 50 * main.screenScaleY
            left: parent.left ; leftMargin: 80 * main.screenScaleX
        }

        Text {
            id: restartMsg
            visible: false
            text: qsTr("Software updated. Restart console.") + application.emptyString
            font.pointSize: fontSize
            anchors { horizontalCenter: parent.horizontalCenter ; top: parent.top }
        }

        Text {
            id: updateCheckingText
            visible: checkUpdates.processState == Process.Running
            text: qsTr("Checking for software updates...") + application.emptyString
            font.pointSize: fontSize
            anchors { horizontalCenter: parent.horizontalCenter ; horizontalCenterOffset: -80 * main.screenScaleX ; top: restartMsg.bottom }
        }

        Text {
            id: packageUpdateText
            visible: checkUpdates.packages.length > 0
            text: qsTr("Software updates are available.") + application.emptyString
            font.pointSize: fontSize
            anchors {
                left: packageUpdateButton.right
                leftMargin: 15 * main.screenScaleX
                verticalCenter: packageUpdateButton.verticalCenter
            }
        }

        Text{
            id: hexFileStatusText
            font.pointSize: fontSize
            anchors {
                left: bootloadButton.right
                leftMargin: 15 * main.screenScaleX
                verticalCenter: bootloadButton.verticalCenter
            }
            visible: !restartMsg.visible && !updateCheckingText.visible
            text:
            {
                if( bootloadButton.visible ) {
                    return qsTr("Firmware to load: ") + application.emptyString + firmwareVersion + "\n" + firmwareUpdateFile
                }
                else
                    return ""
            }
        }

        ImageButton {
            id: packageUpdateButton

            visible: root.softwareUpdatesAvailable
            onVisibleChanged: {
                if (visible)
                    root.cursorState = "software"
            }
            label_color: "#000000"
            label_under: true
            label_y_offset: 10 * main.screenScaleY
            label: qsTr("Update Software") + application.emptyString
            upimage: "../" + main.graphicsPath + "205/IPOD_Wheel_Center_Up.png"
            downimage: "../" + main.graphicsPath + "205/IPOD_Wheel_Center_Down.png"
            anchors.left: parent.left
            anchors.top: restartMsg.bottom
            onClicked: {
                // clear list of packages before starting upgrade so button disappears
                checkUpdates.packages = ""
                updatePackages.start()
            }
        }

        ImageButton {
            id: bootloadButton
            label_color: "#000000"
            label_under: true
            label_y_offset: 10 * main.screenScaleY
            upimage: "../" + main.graphicsPath + "205/IPOD_Wheel_Center_Up.png"
            downimage: "../" + main.graphicsPath + "205/IPOD_Wheel_Center_Down.png"
            anchors {
                left: parent.left
                top: packageUpdateButton.bottom
                topMargin: 20 * main.screenScaleY}

            label: qsTr("Load Firmware") + application.emptyString
            visible: firmwareUpdateAvailable && !updateCheckingText.visible
            onVisibleChanged: {
                if (visible)
                    root.cursorState = "firmware"
            }
            onClicked: {
                print("Diagnostics Update: Loading firmware:" + firmwareUpdateFile)
                nucleusfirmwareloader.startFirmwareLoad(firmwareUpdateFile)
            }
        }

        // check for updates button visible only while not already checking or update button shown
        ImageButton {
            id: checkForUpdatesButton

            visible: (checkUpdates.processState != Process.Running) && !packageUpdateButton.visible && !bootloadButton.visible
            onVisibleChanged: {
                if (visible)
                    root.cursorState = "check"
            }
            label_color: "#000000"
            label: qsTr("Check for Updates") + application.emptyString
            label_under: true
            label_y_offset: 5 * main.screenScaleY
            upimage: "../" + main.graphicsPath + "205/IPOD_Wheel_Center_Up.png"
            downimage: "../" + main.graphicsPath + "205/IPOD_Wheel_Center_Down.png"
            anchors.left: parent.left
            anchors.top: restartMsg.bottom

            onClicked: {
                checkUpdates.packages = ""
                checkUpdates.start()
            }
        }
    }

    Text {
        id: instructions

        width: parent.width - 100

        anchors { bottom: parent.bottom ; bottomMargin: 90 * main.screenScaleY ;  horizontalCenter: parent.horizontalCenter }
        horizontalAlignment: Text.AlignLeft
        wrapMode: Text.WordWrap
        text: {
            if(root.firmwareUpdating || root.softwareUpdating)
                return qsTr("Software is now being updated.  DO NOT power off the machine while software update is taking place.")
            else if(root.checkingForUpdates)
                return qsTr("Checking the network and connected USB devices for software updates.  This may take several seconds.  If updates are found, options for updating will be available above.")
            else if(root.softwareUpdatesAvailable || root.firmwareUpdateAvailable)
                return qsTr("Use the controls above to begin updating software.  Updates may take several minutes, and the machine power must not be interrupted.")
            else
                return qsTr("The machine software and firmware appear to be current.  Insert a software USB memory device and press the button above to check for updates.")
        }
    }

    StorageMgr {
        id: storage
    }

    ModalDialog {
        id: updatingDialog
        blockKeys: true
        visible: false  // shown when update process starts

        BorderImage {   // pop-up dialog background
            id: border

            x: 332 * main.screenScaleX
            y: 161 * main.screenScaleY
            width: 800 * main.screenScaleX
            height: 350 * main.screenScaleY
            source: "../" + main.graphicsPath + "Pop_Up_Lrg_Grey.png"
            border { top: 152 * main.screenScaleY; bottom: 165 * main.screenScaleY; left: 145 * main.screenScaleX; right: 144 * main.screenScaleX }

            Text {
                id: dialogText
                x: 149 * main.screenScaleX
                y: 35 * main.screenScaleY
                width: 501 * main.screenScaleX
                height: 99 * main.screenScaleY
                color: "#ffffff"
                text: qsTr("Updating software...") + application.emptyString
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.top: parent.top
                anchors.topMargin: 35 * main.screenScaleY
                horizontalAlignment: Text.AlignHCenter
                wrapMode: Text.WordWrap
                font.bold: true
                font.pixelSize: 40 * main.screenScaleY
            }
        }
    }

    // The following process gathers a list of packages that may be updated
    Process {
        id: checkUpdates
        property string packages

        program: "bash"
        arguments: [ "scripts/list_upgrades.sh" ]
        onReadyReadStandardOutput: {
            packages += readAllStandardOutput()
        }
        onStarted: {
            cursorState = "";
            console.log("checking updates")
        }
        onFinished: console.log("packages upgradable:" + packages)
    }

    // The following process updates packages using apt-get
    Process {
        id: updatePackages

        program: "bash"
        arguments: ["scripts/do_upgrades.sh"]

        onReadyReadStandardOutput: {
            console.log(readAllStandardOutput())
        }
        onReadyReadStandardError: {
            console.log(readAllStandardError())
        }
        onStarted: { updatingDialog.show() ; console.log("updating packages...") }
        onFinished: {
            checkUpdates.packages = ""
            checkUpdates.start()
            print("Diagnostics Update: package update complete.")
            main.restartRequired = true
            restartMsg.visible = true
            updatingDialog.hide()
        }
    }

    ModalDialog{
        id: firmwareUpdatingDialog
        blockKeys: true

        //visible: bootloader.connected && bootloader.progress > 0
        property alias text: bootLoadStatusText.text

        BorderImage {   // pop-up dialog background
            id: firmwareUpdatingDialogBackground

            x: 332 * main.screenScaleX
            y: 161 * main.screenScaleY
            width: 800 * main.screenScaleX
            height: 350 * main.screenScaleY
            source: "../" + main.graphicsPath + "Pop_Up_Lrg_Grey.png"
            border { top: 152 * main.screenScaleY; bottom: 165 * main.screenScaleY; left: 145 * main.screenScaleX; right: 144 * main.screenScaleX }

            Text{
                id: bootLoadStatusText
                text:""
                color: "white"
                font.bold: true
                font.pixelSize: 50 * main.screenScaleY
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.bottom: bootloadProgress.top
                anchors.bottomMargin: 5 * main.screenScaleY
            }

            ProgressBar {
                id: bootloadProgress
                width: 400 * main.screenScaleX
                height: 50 * main.screenScaleY
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.verticalCenter: parent.verticalCenter
                value: nucleusfirmwareloader.progress
            }
        }
        Component.onCompleted: hide()

    }

    Component.onCompleted: {
        console.log("starting software update check...")
        checkUpdates.start()
        nucleusfirmwareloader.findHexFile()
    }
}
