import QtQuick 2.4
import Components 1.0

Item { // two-button home screen
    id: home_screen

    property bool netpulseAvailable: options.netpulseEnabled && netpulse.connected
    property bool showCardio360: false
    property string imagedir: main.graphicsPath + "100/"
    property bool entertainmentShown: true
    property bool buttonsEnabled: true
    property alias showingWarningGuide: warning_guide.visible
    property bool showMonumentsButton: false

    signal loginPressed()
    signal registerPressed()
    signal quickstartPressed()
    signal signoutPressed()

    width: 1366 * main.screenScaleX
    height: 768 * main.screenScaleY
    anchors.fill: parent

    Item {
        id: home_buttons

        height: 430 * main.screenScaleY
        //width: 710
        width: parent.width
        property int numButtons: (showCardio360 || netpulseAvailable || showMonumentsButton) ? 3 : 2

        //anchors.horizontalCenter: parent.horizontalCenter
        //anchors.horizontalCenterOffset: -50 * main.screenScaleX
        anchors.left: parent.left ; anchors.leftMargin: 0
        anchors.verticalCenter: parent.verticalCenter
        anchors.verticalCenterOffset: 50 * main.screenScaleY

        Item {
            id: netpulse_item

            property bool signedIn: netpulse.loggedIn
            property string signedInText: qsTr("WELCOME BACK") + " " + netpulse.userLogin.userName + "!!" + application.emptyString

            height: 320 * main.screenScaleY
            width: home_screen.netpulseAvailable ? 300 * main.screenScaleX : 0

            anchors.left: parent.left
            anchors.leftMargin: 100 * main.screenScaleX
            anchors.verticalCenter: parent.verticalCenter
            anchors.verticalCenterOffset: -100 * main.screenScaleY
            visible: home_screen.netpulseAvailable
            ImageButton{
                id: netpulse_button

                anchors.horizontalCenter: parent.horizontalCenter
                anchors.horizontalCenterOffset: 0
                anchors.verticalCenter: parent.verticalCenter
                anchors.verticalCenterOffset: 0

                enabled: !parent.signedIn && buttonsEnabled

                fontsize: 16 * main.screenScaleY
                label: netpulse_item.signedIn ? netpulse_item.signedInText : qsTr("SIGN IN") + application.emptyString
                label_under: true
                label_color: "black"
                label_y_offset: -20 * main.screenScaleY

                icon: imagedir + "ID_icon_home.png"
                icon_y_offset: 0
                icon_x_offset: 0

                upimage: netpulse_item.signedIn ? imagedir + "WF_button_SIGNED_IN.png" : imagedir + "WF_button.png"
                downimage: netpulse_item.signedIn ? imagedir + "WF_button_SIGNED_IN.png" :imagedir + "WF_button_PRESSED.png"

                reenableDelay: 1000
                onClicked: loginPressed();

                mouseAreaScale: 0.7
            }

            ImageButton{
                id:createAccountBanner
                anchors.top: netpulse_button.bottom
                anchors.topMargin: 0
                anchors.horizontalCenter: netpulse_button.horizontalCenter
                anchors.horizontalCenterOffset: 0
                width: 259 * main.screenScaleX
                height: 67 * main.screenScaleY

                visible: !netpulse_item.signedIn
                enabled: buttonsEnabled
                upimage: imagedir + "CREATE_ACCT_banner.png"
                downimage: imagedir + "CREATE_ACCT_banner_PRESSED.png"

                reenableDelay: 1000
                onClicked: registerPressed()
                mouseAreaScale: 1.2

                Text{
                    anchors.horizontalCenter: parent.horizontalCenter
                    anchors.horizontalCenterOffset: 0
                    anchors.verticalCenter: parent.verticalCenter
                    anchors.verticalCenterOffset: 0
                    font.bold: true
                    font.pointSize: 12 * main.screenScaleY
                    text:qsTr("CREATE ACCOUNT") + application.emptyString
                    color: "white"
                }
            }

            ImageButton{
                id:signoutBanner
                anchors.top: netpulse_button.bottom
                anchors.topMargin: 0
                anchors.horizontalCenter: netpulse_button.horizontalCenter
                anchors.horizontalCenterOffset: 0
                width: 259 * main.screenScaleX
                height: 67 * main.screenScaleY

                visible: netpulse_item.signedIn


                upimage: imagedir + "SIGN_OUT_banner.png"
                downimage: imagedir + "SIGN_OUT_banner.png"

                reenableDelay: 1000
                onClicked: signoutPressed();

                mouseAreaScale: 0.7

                Text{
                    anchors.horizontalCenter: parent.horizontalCenter
                    anchors.horizontalCenterOffset: 0
                    anchors.verticalCenter: parent.verticalCenter
                    anchors.verticalCenterOffset: 0
                    font.bold: true
                    font.pointSize: 12 * main.screenScaleY
                    text:qsTr("SIGN OUT") + application.emptyString
                    color: "white"
                }
            }


        }

        ImageButton {
            id: monumentsButton
            onClicked: {
                if (beltStoppingPopup.visible) {
                    return
                }

                main.state = "AllWorkoutsState"
                workouts_all.selectMonuments()
            }

            width: visible ? 328 * main.screenScaleX : 0
            height: visible ? 335 * main.screenScaleY : 0
            visible: showMonumentsButton && !netpulse_item.visible
            enabled: buttonsEnabled
            fontsize: 16 * main.screenScaleY
            anchors.verticalCenter: parent.verticalCenter
            anchors.verticalCenterOffset: -96 * main.screenScaleY

            anchors.left: parent.left
            anchors.leftMargin: 62 * main.screenScaleX

            upimage: imagedir + "alpine_home-button.png"
            downimage: imagedir + "alpine_home-button.png"

            label: qsTr("MONUMENTS") + application.emptyString
            label_under: true
            label_color: "black"
            label_y_offset: +15 * main.screenScaleY
            Text {
                font.pixelSize: 30 * main.screenScaleY
                font.bold: true
                color: "white"
                text: qsTr("HIGH INCLINE WORKOUTS") + application.emptyString
                width: parent.width * 0.8
                wrapMode: Text.WordWrap
                horizontalAlignment: Text.AlignHCenter
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.bottom: parent.bottom
                anchors.bottomMargin: 109 * main.screenScaleY
                lineHeight: 0.8
            }

        }

        // Cardio 360 button only on ellipticals
        ImageButton {
            id: cardio360_button

            reenableDelay: 1000
            onClicked: {
                if (main.isLateralTrainer) {
                    main.quickStart("Cardio_360_Quick_Start_LateralTrainer.xml")
                } else {
                    main.quickStart("Cardio_360_Quick_Start.xml")
                }
            }
            onPressAndHold: {
                demoC360Notice.showWithTimeout(3);
                main.quickStart("Cardio_360_Demo.xml")
            }
            width: visible ? 300 * main.screenScaleX : 0
            visible: showCardio360 && !netpulse_item.visible
            enabled: buttonsEnabled
            fontsize: 16 * main.screenScaleY
            anchors.verticalCenter: parent.verticalCenter
            anchors.verticalCenterOffset: -100 * main.screenScaleY

            anchors.left: parent.left
            anchors.leftMargin: 100 * main.screenScaleX

            icon: imagedir + "Cardio360_Logo.png"
            icon_y_offset: 0

            label: qsTr("Cardio360") + application.emptyString
            label_under: true
            label_color: "black"
            label_y_offset: -20 * main.screenScaleY

            upimage: imagedir + "WF_button.png"
            downimage: imagedir + "WF_button_PRESSED.png"
            mouseAreaScale: 0.7

            // Banner with "QUICK START" text
            Image {
                anchors.top: parent.top ; anchors.topMargin: 35 * main.screenScaleY
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.horizontalCenterOffset: -20 * main.screenScaleX

                source: imagedir + "SIGN_OUT_banner.png"

                Text {
                    text: qsTr("QUICK START", "cardio360 quickstart") + application.emptyString
                    verticalAlignment: Text.AlignVCenter
                    horizontalAlignment: Text.AlignHCenter
                    color: "white"
                    font.bold: true
                    font.pointSize: 12 * main.screenScaleY

                    anchors.fill: parent
                }
            }

            MessagePopup {
                id: demoC360Notice
                message: qsTr("Cardio360 Demo") + application.emptyString
            }
        }

        ImageButton {
            id: quick_start_button
            fontsize: 16 * main.screenScaleY

            label:qsTr("QUICK START") + application.emptyString
            label_under: true;
            label_y_offset: -35 * main.screenScaleY
            label_color: "black"

            enabled: (buttonsEnabled && machinecontrol.isBeltMoving === false && machinecontrol.isInclineMoving === false && nucleus.systemReady === true) || options.manufacturingTestModeEnabled === true

            anchors.verticalCenter: parent.verticalCenter
            anchors.verticalCenterOffset: -100 * main.screenScaleY

            upimage: imagedir + "LG_QS_button.png"
            downimage: imagedir + "LG_QS_button_PRESSED.png"

            anchors.left: {
                if (netpulseAvailable)
                    return netpulse_item.right
                else if (showCardio360)
                    return cardio360_button.right
                else if (showMonumentsButton)
                    return monumentsButton.right
                return parent.left
            }

            anchors.leftMargin: ( showCardio360 || netpulseAvailable ? 31 : (showMonumentsButton ? 3 : 201 ) ) * main.screenScaleX

            icon: imagedir + "home_Buttons_GO_ICON.png"
            icon_y_offset: 0
            icon_x_offset: 5 * main.screenScaleX
            reenableDelay: 1000
            onClicked: {
                quickstartPressed()
            }
            beep: machineinfo.productTypeString == "Treadmill" ? false : true
            mouseAreaScale: 0.7

        }


        // Workout Finder Button
        ImageButton {
            id: workout_finder_button
            fontsize: 16 * main.screenScaleY

            anchors.verticalCenter: parent.verticalCenter
            anchors.verticalCenterOffset: -100 * main.screenScaleY

            enabled: buttonsEnabled || options.manufacturingTestModeEnabled === true

            label: qsTr("WORKOUT FINDER") + application.emptyString
            label_under: true
            label_color: "black"
            label_y_offset: -20 * main.screenScaleY

            icon: imagedir + "home_Buttons_WF_ICON.png"
            icon_y_offset: 0
            icon_x_offset: -7 * main.screenScaleX

            anchors.left: quick_start_button.right
            anchors.leftMargin: ( showCardio360 || netpulseAvailable ? 31 : (showMonumentsButton ? 63 : 93 ) * main.screenScaleX)

            anchors.horizontalCenterOffset: ( showMonumentsButton ? -530 : 0 ) * main.screenScaleX

            upimage: imagedir + "WF_button.png"
            downimage: imagedir + "WF_button_PRESSED.png"

            onClicked: {
                if (main.isCSA || main.isLateralTrainer || main.isAlpineRunner) {
                    main.state = "AllWorkoutsState"
                } else {
                    main.state = "MenuState"
                }
            }
            mouseAreaScale: 0.7

        }
    }

    WarningGuide {
        id: warning_guide
        z:1
        visible: false
    }

    Image {
        id: bluetoothSmartLogo
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 40 * main.screenScaleY
        anchors.right: parent.right
        anchors.rightMargin: 450 * main.screenScaleX
        source: main.graphicsPath + "Bluetooth/Bluetooth_SRlogo.png"
    }

    Item {
        id: warning_panel

        visible: !entertainmentShown
        width: childrenRect.width
        height: childrenRect.height

        anchors { bottom: parent.bottom; bottomMargin: 17 * main.screenScaleY ; left: parent.left ; leftMargin: 30 * main.screenScaleX }

        MouseArea {
            id: warning_active_area

            onClicked: {
                home_screen.showingWarningGuide = true
            }
            anchors.fill: parent
        }

        Row {
            // column with warning /!\ and info button
            Column {
                id: warning_row
                spacing: -15 * main.screenScaleX
                Image { sourceSize.height: 59 * main.screenScaleY; anchors.horizontalCenter: parent.horizontalCenter; source: main.graphicsPath + "Icon_Warning.png"; }
            }
            Column {
                id: warning_text_column

                width: 500 * main.screenScaleX
                height: childrenRect.height
                spacing: 2 * main.screenScaleX

                Text{   height: 50 * main.screenScaleY; text: qsTr("WARNING:") + application.emptyString
                        anchors.left: parent.left; anchors.leftMargin: 14 * main.screenScaleX; verticalAlignment: Text.AlignBottom;
                        font.pixelSize: 22 * main.screenScaleY; font.bold: true ; color: "#404040"
                }
                Row {
                    id: row1
                    width: parent.width
                    spacing: 2 * main.screenScaleX
                    Image {
                        anchors.verticalCenter: parent.verticalCenter
                        fillMode: Image.PreserveAspectCrop
                        source: main.graphicsPath + "Bullet_Triangle_Gray.png"
                    }

                    Text{
                        id: warning_link
                        width: 422 * main.screenScaleX
                        font.pixelSize: 14 * main.screenScaleY
                        anchors.verticalCenter: parent.verticalCenter
                        horizontalAlignment: Text.AlignLeft
                        verticalAlignment: Text.AlignVCenter
                        wrapMode: Text.Wrap
                        //width: parent.width

                        text: qsTr("Read and understand all instructions and warnings prior to use.") +application.emptyString
                    }
                }
                Text{
                    width: 450 * main.screenScaleX
                    text: "<ul><li>" + qsTr("Obtain a medical exam before beginning any exercise program.  If at any time during exercise you feel faint, dizzy, or experience pain, \
stop and consult your physician.") + "</li><li>" + qsTr("All exercise equipment is potentially hazardous.  If attention is not paid to the conditions of the equipment usage, death or serious injury \
could occur.") + "</li></ul></p>" + application.emptyString
                    font.family: "Liberation Sans"
                    font.pixelSize: 13 * main.screenScaleY
                    textFormat: Text.RichText
//                    font.letterSpacing: -0.5
                    horizontalAlignment: Text.AlignLeft
                    wrapMode: Text.Wrap
                    anchors { left: parent.left ; leftMargin: -23 * main.screenScaleX }

                } // Text end
            } // Column warning_text_column end
        } // Row warning_row end
    } // Item warning_panel end
} // end home_screen Item
