import QtQuick 2.4
import ".." // to access ImageButton
import Components 1.0

FocusScope {
    id: root

    property bool isSetupWizard: false

    signal languageSelected(string lang)

    width: 1366 * main.screenScaleX
    height: 720 * main.screenScaleY

    Connections {
        target: root.visible && root.opacity > 0 ? keymapper : null

        onRightButtonPressed: {
            main.debugKeys("rightButtonPressed", "LanguageMenu")
            language_path.incrementCurrentIndex();
        }

        onLeftButtonPressed: {
            main.debugKeys("leftButtonPressed", "LanguageMenu")
            language_path.decrementCurrentIndex();
        }

        // Allow minus to act as left, as workaround for unconfigured keypad during Setup Wizard
        onMinusPressed: {
            main.debugKeys("minusPressed", "LanguageMenu")
            language_path.decrementCurrentIndex();
        }

        onUpButtonPressed: {
            main.debugKeys("upButtonPressed", "LanguageMenu")
            language_path.incrementCurrentIndex();
        }

        onDownButtonPressed: {
            main.debugKeys("downButtonPressed", "LanguageMenu")
            language_path.decrementCurrentIndex();
        }

        onEnter2Pressed: {
            main.debugKeys("enter2Pressed", "LanguageMenu")
            languageSelected(language_path.currentItem);
        }

        onBackPressed: {
            main.debugKeys("backPressed", "LanguageMenu")
            languageSelected("") // return null means cancel
        }
    }

    onOpacityChanged: {
        if (opacity === 1.0)
            language_path.setIndexToCurrentLanguage()
    }

    // map background
    Image {
        source: "../" + main.graphicsPath + "LanguageMenu/Language_Bkgr.png"
        anchors.fill: parent
    }

    // back button
    Row {
        id: row1

        visible: !root.isSetupWizard && main.isTouch
        x: 1183 * main.screenScaleX
        y: 16 * main.screenScaleY
        anchors.top: parent.top
        anchors.topMargin: 16 * main.screenScaleY
        anchors.right: parent.right
        anchors.rightMargin: 56 * main.screenScaleX

        ImageButton {
            id: back_button
            upimage: "../" + main.graphicsPath + "navbar/Navigation_Arrow_Disabled.png"
            downimage: "../" + main.graphicsPath + "navbar/Navigation_Arrow_Down.png"
            onClicked: languageSelected("") // return null means cancel
            mouseAreaScale: 1.5
            labelClickable: true
            label: qsTr("BACK") + application.emptyString
            font.bold: true
            label_color: "#A0A0A0"
            label_x_offset: 50 * main.screenScaleX
        }

    } // end back button row

    Image {
        id: marker

        x:1019
        y:341
        anchors.horizontalCenterOffset: -21 * main.screenScaleX
        anchors.horizontalCenter: parent.horizontalCenter
        visible: true
        opacity: 0
        z: 8
        source: "../" + main.graphicsPath + "LanguageMenu/Language_Down.png"
    }

    // lay out the array of language button options
    PathView {
        id: language_path

        property string currentItem: model[currentIndex].lang
        property int o: 38

        function setIndexToCurrentLanguage() {
            for (var i = 0, l = model.length; i < l; i++) {
                if (model[i].lang === application.currentLanguage) {
                    currentIndex = i;
                    break;
                }
            }
        }

        interactive: false
        preferredHighlightBegin: 0.17; preferredHighlightEnd: 0.17
        highlightRangeMode: PathView.StrictlyEnforceRange
        highlight: Component {
            Image {
                source: "../" + main.graphicsPath + "tft/NAV_selector_2.png"
                visible: main.isTft
                width: 244 * main.screenScaleX
                height: 174 * main.screenScaleY
            }
        }
        anchors {
            top: parent.top
            topMargin: 100 * main.screenScaleY
            left: parent.left
            leftMargin: 50 * main.screenScaleX
        }

        // img: flag image   lang: language code   caption: label under button
        // add application.emptyString to end of caption to force re-translation when new language selected
        model: [
            { img: "Language_USA.png", lang: "en", caption: qsTr("ENGLISH") + application.emptyString } ,
            { img: "Language_Russian.png", lang: "ru", caption: qsTr("RUSSIAN") + application.emptyString } ,
            { img: "Language_French.png", lang: "fr", caption: qsTr("FRENCH") + application.emptyString } ,
            { img: "Language_Mandarin.png", lang: "zh", caption: qsTr("CHINESE") + application.emptyString } ,
            { img: "Language_German.png", lang: "de", caption: qsTr("GERMAN") + application.emptyString } ,
            { img: "Language_Nederlandse.png", lang: "nl", caption: qsTr("DUTCH") + application.emptyString } ,
            { img: "Language_Saudiarabia.png", lang: "ar", caption: qsTr("ARABIC") + application.emptyString } ,
            { img: "Language_Spanish.png", lang: "es", caption: qsTr("SPANISH") + application.emptyString } ,
            { img: "Language_Portuguese.png", lang: "pt", caption: qsTr("PORTUGUESE") + application.emptyString } ,
            { img: "Language_Korean.png", lang: "ko", caption: qsTr("KOREAN") + application.emptyString } ,
            { img: "Language_Japanese.png", lang: "ja", caption: qsTr("JAPANESE") + application.emptyString } ,
            { img: "Language_Italian.png", lang: "it", caption: qsTr("ITALIAN") + application.emptyString } ,

        ]

        path: Path {
            startX: 233; startY: 116 // USA
            PathLine { x: 438 * main.screenScaleX; y: 73 * main.screenScaleY } // Russian
            PathLine { x: 644 * main.screenScaleX; y: 61 * main.screenScaleY } // French
            PathLine { x: 852 * main.screenScaleX; y: 74 * main.screenScaleY } // Chinese
            PathLine { x: 1047 * main.screenScaleX; y: 116 * main.screenScaleY } // Germany
            PathLine { x: 1207 * main.screenScaleX; y: 233 * main.screenScaleY } // Nederlands
            PathLine { x: 1047 * main.screenScaleX; y: 341 * main.screenScaleY } // Arabic
            PathLine { x: 870 * main.screenScaleX; y: 379 * main.screenScaleY } // Spanish
            PathLine { x: 644 * main.screenScaleX; y: 394 * main.screenScaleY } // Planguage_path.ortugese
            PathLine { x: 438 * main.screenScaleX; y: 382 * main.screenScaleY } // Klanguage_path.orean
            PathLine { x: 233 * main.screenScaleX; y: 337 * main.screenScaleY } // Japanese
            PathLine { x: 77 * main.screenScaleX; y: 233 * main.screenScaleY } // Italian
            PathLine { x: 233 * main.screenScaleX; y: 116 * main.screenScaleY }
        }

        // delegate for each of the language buttons from the model above
        delegate: ImageButton {
            id: flag_button

            //            x: modelData.x
            //            y: modelData.y

            upimage: "../" + main.graphicsPath + "/LanguageMenu/" + (modelData.lang === application.currentLanguage ? "Language_Down.png" : "Language_Disabled.png")
            downimage: "../" + main.graphicsPath + "/LanguageMenu/" + "Language_Down.png"

            icon: "../" + main.graphicsPath + "/LanguageMenu/" + modelData.img
            icon_y_offset: -3 * main.screenScaleY
            icon_x_offset: -3 * main.screenScaleX

            label: modelData.caption
            fontsize: 16 * main.screenScaleY
            label_color: "black"
            label_under: true
            label_x_offset: -6 * main.screenScaleX

            reenableDelay: 1000

            onClicked: languageSelected( modelData.lang )

        } // end delegate for repeater

    } // end repeater

    // White band under "LANGUAGE"
    Rectangle {
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 59 * main.screenScaleY
        height: 83 * main.screenScaleY
        opacity: 0.400

    }

    Text {
        height: 78 * main.screenScaleY
        text: qsTr("LANGUAGE") + application.emptyString

        style: Text.Normal
        font.pointSize: 70 * main.screenScaleY
        font.bold: true
        smooth: true

        verticalAlignment: Text.AlignVCenter
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 58 * main.screenScaleY
    }

    // This functions returns the human-readable name of a language, given the
    // language code
    function getLanguageName(lang) {
        switch(lang) {
        case "en":
            return qsTr("ENGLISH") + application.emptyString
        case "es":
            return qsTr("SPANISH")  + application.emptyString
        case "fr":
            return qsTr("FRENCH")  + application.emptyString
        case "de":
            return qsTr("GERMAN") + application.emptyString
        case "it":
            return qsTr("ITALIAN") + application.emptyString
        case "nl":
            return qsTr("DUTCH") + application.emptyString
        case "pt":
            return qsTr("PORTUGUESE") + application.emptyString
        case "ru":
            return qsTr("RUSSIAN") + application.emptyString
        case "ja":
            return qsTr("JAPANESE") + application.emptyString
        case "ko":
            return qsTr("KOREAN") + application.emptyString
        case "zh":
            return qsTr("CHINESE") + application.emptyString
        case "ar":
            return qsTr("ARABIC") + application.emptyString
        }
        return ""
    }

    // This functions returns the name of the icon file associated with the given
    // language code.  This functions does not return the full path to the
    // LanguageMenu/ directory, where these files are
    function getLanguageIcon(lang) {
        switch(lang) {
        case "en":
            return "Language_USA.png"
        case "es":
            return "Language_Spanish.png"
        case "fr":
            return "Language_French.png"
        case "de":
            return "Language_German.png"
        case "it":
            return "Language_Italian.png"
        case "nl":
            return "Language_Nederlandse.png"
        case "pt":
            return "Language_Portuguese.png"
        case "ru":
            return "Language_Russian.png"
        case "ja":
            return "Language_Japanese.png"
        case "ko":
            return "Language_Korean.png"
        case "zh":
            return "Language_Mandarin.png"
        case "ar":
            return "Language_Saudiarabia.png"
        }
        return ""
    }
}
