import QtQuick 2.4

Item {
    id: root
    property string ipodState: ""
    property bool keysAccepted: false
    property bool allowFullscreen: false
    state: root.ipodState + "State"
    width: 500 * main.screenScaleX
    height: 380 * main.screenScaleY
    Text {
        id: connectedText
        text: qsTr("iPod Connected") + application.emptyString
        font { pixelSize: 36 * main.screenScaleY; family: "arial"; bold: true }
        horizontalAlignment: Text.AlignHCenter
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.top: parent.top
        anchors.topMargin: 40 * main.screenScaleY
    }
    Image {
        id: volInstructions // displayed when unselected only
        source: "../" + main.graphicsPath + "tft/vol-up-down_icons.png"
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 125 * main.screenScaleY
    }
    Item {
        id: navDirections
        width: 270 * main.screenScaleX
        height: 190 * main.screenScaleY
        anchors.centerIn: parent
        Text {
            id: text_n1
            text: qsTr("use") + application.emptyString
            font { pixelSize: 28 * main.screenScaleY; family: "arial"; bold: true }
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.top: parent.top
        }
        Item {
            id: text_n2
            width: 240 * main.screenScaleX
            height: 32 * main.screenScaleY
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.top: text_n1.bottom
            anchors.topMargin: 15 * main.screenScaleY
            Item {
                anchors.left: parent.left
                width: 90 * main.screenScaleX
                Image {
                    id: arrowRew
                    source: "../" + main.graphicsPath + "tft/REW_icon.png"
                    anchors.left: parent.left
                }
                Image {
                    id: arrowFwd
                    source: "../" + main.graphicsPath + "tft/FWD_icon.png"
                    anchors.right: parent.right
                }
            }
            Item {
                anchors.right: parent.right
                width: 90 * main.screenScaleX
                Image {
                    id: arrowDown
                    source: "../" + main.graphicsPath + "tft/arrow_down.png"
                    anchors.left: parent.left
                }
                Image {
                    id: arrowUp
                    source: "../" + main.graphicsPath + "tft/arrow_up.png"
                    anchors.right: parent.right
                }
            }
        }
        Text {
            id: text_n3
            text: qsTr("to navigate") + application.emptyString
            font { pixelSize: 28 * main.screenScaleY; family: "arial"; bold: true }
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.top: text_n2.bottom
            anchors.topMargin: 15 * main.screenScaleY
        }
        Text {
            id: text_n4
            text: qsTr("menu.") + application.emptyString
            font { pixelSize: 28 * main.screenScaleY; family: "arial"; bold: true }
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.top: text_n3.bottom
            anchors.topMargin: 15 * main.screenScaleY
        }
    }
    Item {
        id: playScreenInstructions
        width: 270 * main.screenScaleX
        height: 190 * main.screenScaleY
        anchors.centerIn: parent
        Text {
            id: text_p1
            visible: ipodmanager.playStatus === "playing"
            text: qsTr("use") + application.emptyString
            font { pixelSize: 28 * main.screenScaleY; family: "arial"; bold: true }
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.top: parent.top
        }
        Item {
            id: text_p2
            visible: ipodmanager.playStatus === "playing"
            width: 145 * main.screenScaleX
            height: 32 * main.screenScaleY
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.top: text_p1.bottom
            anchors.topMargin: 15 * main.screenScaleY
            Image {
                id: rewImage
                source: "../" + main.graphicsPath + "tft/REW_icon.png"
                anchors.left: parent.left
            }
            Image {
                id: fwdImage
                source: "../" + main.graphicsPath + "tft/FWD_icon.png"
                anchors.right: parent.right
            }
        }
        Text {
            id: text_p3
            visible: ipodmanager.playStatus === "playing"
            text: qsTr("to advance or replay.") + application.emptyString
            font { pixelSize: 28 * main.screenScaleY; family: "arial"; bold: true }
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.top: text_p2.bottom
            anchors.topMargin: 15 * main.screenScaleY
        }
        Text {
            id: text_p4
            width: 182 * main.screenScaleX
            height: 50 * main.screenScaleY
            anchors.left: image_p5.left
            anchors.leftMargin: -5 * main.screenScaleX
            anchors.top: text_p3.bottom
            anchors.topMargin: 15 * main.screenScaleY
            Text {
                id: p4_menu
                text: qsTr("MENU") + application.emptyString
                font { pixelSize: 18 * main.screenScaleY; family: "arial"; bold: true }
                x: 0
                y: 3 * main.screenScaleY
            }
            Image {
                id: p4_equals
                source: "../" + main.graphicsPath + "tft/equals.png"
                x: 62 * main.screenScaleX
            }
            Text {
                text: qsTr("ENTER") + application.emptyString
                font { pixelSize: 18 * main.screenScaleY; family: "arial"; bold: true }
                x: 111 * main.screenScaleX
                y: 3 * main.screenScaleY
            }
        }
        Image {
            id: image_p5
            source: "../" + main.graphicsPath + "tft/vol-up-down_icons.png"
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.top: text_p4.bottom
            anchors.topMargin: 15 * main.screenScaleY
        }
    }
    Item {
        id: medVideoControls
        width: 280 * main.screenScaleX
        height: 220 * main.screenScaleY
        anchors {
            bottom: parent.bottom
            bottomMargin: 30 * main.screenScaleY
            right: parent.right
            rightMargin: 20 * main.screenScaleX
        }
        Text {
            id: video1
            width: 182 * main.screenScaleX
            height: 40 * main.screenScaleY
            anchors.left: parent.left
            anchors.top: parent.top
            anchors.topMargin: 45 * main.screenScaleY
            visible: root.allowFullscreen
            Image {
                source: "../" + main.graphicsPath + "netpulse/Fullscreen_icon.png"
                x: 0
            }
            Image {
                source: "../" + main.graphicsPath + "tft/equals.png"
                x: 62 * main.screenScaleX
            }
            Text {
                text: qsTr("ENTER") + application.emptyString
                font { pixelSize: 18 * main.screenScaleY; family: "arial"; bold: true }
                x: 111 * main.screenScaleX
                y: 3 * main.screenScaleY
            }
        }
        Text {
            id: video3
            width: 182 * main.screenScaleX
            height: 40 * main.screenScaleY
            anchors.left: parent.left
            anchors.top: video1.bottom
            anchors.topMargin: 15 * main.screenScaleY
            Text {
                text: qsTr("CHAN") + application.emptyString
                font { pixelSize: 18 * main.screenScaleY; family: "arial"; bold: true }
                x: 0
                y: 3 * main.screenScaleY
            }
            Image {
                source: "../" + main.graphicsPath + "tft/equals.png"
                x: 62 * main.screenScaleX
            }
            Text {
                text: "<img src=\"../" + main.graphicsPath + "tft/REW_icon.png\" /> &nbsp;<img src=\"../" + main.graphicsPath + "tft/FWD_icon.png\" />"
                font { pixelSize: 18 * main.screenScaleY; family: "arial"; bold: true }
                x: 111 * main.screenScaleX
                y: -5
            }
        }
        Image {
            id: video4
            source: "../" + main.graphicsPath + "tft/vol-up-down_icons.png"
            anchors.left: parent.left
            anchors.leftMargin: 6 * main.screenScaleX
            anchors.top: video3.bottom
            anchors.topMargin: 15 * main.screenScaleY
        }
    }
    states: [
        State {
            name: "not_connectedState"
            PropertyChanges { target: connectedText; visible: false }
            PropertyChanges { target: volInstructions; visible: false }
            PropertyChanges { target: navDirections; visible: false }
            PropertyChanges { target: playScreenInstructions; visible: false }
            PropertyChanges { target: medVideoControls; visible: false }
        },
        State {
            name: "playing_menuState"
            PropertyChanges { target: connectedText; visible: true }
            PropertyChanges { target: volInstructions; visible: root.keysAccepted === false }
            PropertyChanges { target: navDirections; visible: root.keysAccepted }
            PropertyChanges { target: playScreenInstructions; visible: false }
            PropertyChanges { target: medVideoControls; visible: false }
        },
        State {
            name: "notplaying_menuState"
            PropertyChanges { target: connectedText; visible: true }
            PropertyChanges { target: volInstructions; visible: false }
            PropertyChanges { target: navDirections; visible: root.keysAccepted }
            PropertyChanges { target: playScreenInstructions; visible: false }
            PropertyChanges { target: medVideoControls; visible: false }
        },
        State {
            name: "playing_notmenuState"
            PropertyChanges { target: connectedText; visible: true }
            PropertyChanges { target: volInstructions; visible: root.keysAccepted === false }
            PropertyChanges { target: navDirections; visible: false }
            PropertyChanges { target: playScreenInstructions; visible: root.keysAccepted && !videoView.visible }
            PropertyChanges { target: medVideoControls; visible: root.keysAccepted && videoView.visible }
        },
        State {
            name: "notplaying_notmenuState"
            PropertyChanges { target: connectedText; visible: true }
            PropertyChanges { target: volInstructions; visible: false }
            PropertyChanges { target: navDirections; visible: false }
            PropertyChanges { target: playScreenInstructions; visible: root.keysAccepted }
            PropertyChanges { target: medVideoControls; visible: false }
        }
    ]
}
