
import QtQuick 2.4
import VLCVideo 1.0
import Components 1.0

import ".."

Image {

    id: root

    property bool showCloseButton: true
    property int highlightedItem:1
    property bool isDialogVisible: false
    property variant menu
    property int menu_bottom_margin: 70
    property bool videoShown: false
    property bool viewShowing: false
    property bool keysAccepted: false
    property bool allowFullscreen: false
    property variant currentBtPlayer: bluetoothAdapter.currentConnectedDevice !== null ? bluetoothAdapter.currentConnectedDevice.player : undefined
    property bool ipodVideoShowing: false

    // possible dialogState values
    // - idle: mediaBrowserNoDeviceConnectedDialog is displayed
    // - connecting: btConnectionStatusDialog is displayed
    // - help: btHelpDialog is displayed
    // - connected: mediaBrowserNoDeviceConnectedDialog is displayed
    property string dialogState: "idle"

    onDialogStateChanged: {
        if(dialogState === "idle") {
            btConnectionStatusDialog.hide()
            mediaBrowserNoDeviceConnectedDialog.show()
            btHelpDialog.hide()
        } else if(dialogState === "connecting") {
            btConnectionStatusDialog.show()
            mediaBrowserNoDeviceConnectedDialog.hide()
            btHelpDialog.hide()
        } else if(dialogState === "help") {
            btConnectionStatusDialog.hide()
            mediaBrowserNoDeviceConnectedDialog.hide()
            btHelpDialog.show()
        } else if(dialogState === "connected") {
            btConnectionStatusDialog.hide()
            mediaBrowserNoDeviceConnectedDialog.hide()
            btHelpDialog.hide()
        } else if(dialogState === "disconnecting") {
            btConnectionStatusDialog.show()
            mediaBrowserNoDeviceConnectedDialog.hide()
            btHelpDialog.hide()
        }
    }

    function toggleFullscreen() {
        if (root.allowFullscreen) {
            if (tv.player.fullscreen) {
                fullscreenVideoFrame.endFullscreen()
            } else {
                fullscreenVideoFrame.showFullscreen(tv.player)
            }
        }
    }

    function showVideo(show) {
        if(show) {
            tv.tuneChannelID("IPODINPUT")
            root.videoShown = true
        }
        else
            root.videoShown = false
    }

    function shown() {
        viewShowing = true
        if(audioManager.ipodPlaying)
            audioManager.ipodRequest()
        if(audioManager.ipodPlayingVideo) {
            // if an ipod video is already allowed and we're not showing it, show it.
            if(audioManager.ipodVideoAllowed) {
                root.showVideo(true)
            }
            else // request showing the videov
                audioManager.ipodVideoRequest()
        }
        if (audioManager.btconnected) {
            audioManager.btRequest()
        }

    }

    function hidden() {
        viewShowing = false
    }

    signal close()

    signal upPressed()
    signal downPressed()
    signal rightPressed()
    signal leftPressed()
    signal centerPressed()
    signal menuPressed()
    signal menuItemPressed(int index)
    signal playPausePressed()
    signal nextTrackPressed()
    signal previousTrackPressed()

    source: "../" + main.graphicsPath + "netpulse/Center_Gray_Box.png"

    // mouse area to mask anything under this pop-up
    MouseArea {
        anchors.fill: parent
    }

    function getIndexFromMenuItem(i)
    {
        var item = ipodmenulistview.model.get(i)
        return item.index
    }

    MouseArea{
        id: cover_area
        visible: mediaBrowserNoDeviceConnectedDialog.visible
        z: 99
        anchors.fill: parent
        anchors.rightMargin: 70 * main.screenScaleX
    }

    ModalDialog {
        id: mediaBrowserNoDeviceConnectedDialog
        opacity: main.isTouch || root.keysAccepted ? 1.0 : 0.5
        isTop: false
        isTransparent: true
        visible: (!bluetoothAdapter.connected &&
                  !btConnectionStatusDialog.visible)

        width: root.width * 0.74
        height: width / 2

        anchors.verticalCenter: root.verticalCenter
        anchors.horizontalCenter: root.horizontalCenter

        Connections {
            target: main.isTft && !main.blockKeys && root.keysAccepted && mediaBrowserNoDeviceConnectedDialog.visible ? keymapper : null
            onEnter2Pressed: {
                main.debugKeys("enter2Pressed", "MediaBrowser", "(connectionDialog)")
                dialogState = "connecting"
            }
        }

        BorderImage {   // pop-up dialog background
            id: border
            anchors.fill: parent
            anchors.topMargin: -15 * main.screenScaleY
            anchors.bottomMargin: -33 * main.screenScaleY
            anchors.leftMargin: -14 * main.screenScaleX
            anchors.rightMargin: -33 * main.screenScaleX

            anchors.verticalCenter: parent.verticalCenter
            anchors.horizontalCenter: parent.horizontalCenter

            source: "../" + main.graphicsPath + "Pop_Up_Lrg_Grey.png"
            border { top: height*0.33; bottom: height*0.33; left: width*0.33; right: width*0.33 }

            Rectangle{
                id: referenceArea
                color:"transparent"
                opacity: 0.3
                height: parent.height + parent.anchors.topMargin + parent.anchors.bottomMargin
                width: parent.width + parent.anchors.rightMargin + parent.anchors.leftMargin
                anchors.top: parent.top
                anchors.left: parent.left
                anchors.topMargin: -parent.anchors.topMargin
                anchors.leftMargin: -parent.anchors.leftMargin
            }

            Text {
                id: dialogText
                anchors.verticalCenter: referenceArea.verticalCenter
                anchors.horizontalCenter: referenceArea.horizontalCenter
                anchors.verticalCenterOffset: -60 * main.screenScaleY
                width: referenceArea.width * 0.8
                height: referenceArea.height * 0.5
                color: "white"
                text: qsTr("NO DEVICE CONNECTED") + application.emptyString
                horizontalAlignment: Text.AlignHCenter
                wrapMode: Text.WordWrap
                font.bold: true
                font.family: "sans serif"
                font.pixelSize: (text.length >= 22 * main.screenScaleX ? 48 : 62) * main.screenScaleY
            }
            Item {
                id: btConnectionPromptBox
                anchors.verticalCenter: referenceArea.verticalCenter
                anchors.horizontalCenter: referenceArea.horizontalCenter
                anchors.verticalCenterOffset: 70 * main.screenScaleY
                width: referenceArea.width * 0.5
                height: referenceArea.height * 0.4

                Column{
                    spacing: 10 * main.screenScaleX
                    anchors.horizontalCenter: parent.horizontalCenter
                    anchors.verticalCenter: parent.verticalCenter
                    Text{
                        id: btAudioDeviceText
                        anchors.horizontalCenter: parent.horizontalCenter
                        text: qsTr("BLUETOOTH AUDIO DEVICE?") + application.emptyString
                        font.bold: true
                        font.family: "sans serif"
                        font.pixelSize: dialogText.font.pixelSize * 0.3
                        color: "white"
                    }
                    ImageButton {
                        id: btScanButton
                        visible: main.isTouch
                        enabled: !bluetoothAdapter.connectedHeadset && !bluetoothAdapter.discovering && !bluetoothAdapter.pairing
                        anchors.horizontalCenter: parent.horizontalCenter
                        upimage: "../" + main.graphicsPath + "224/224_Data_ToolBar_Round.png"
                        downimage: "../" + main.graphicsPath + "224/224_Data_ToolBar_Round_Down.png"
                        icon: "../" + main.graphicsPath + "Bluetooth/Bluetooth_icon_small.png"
                        onClicked: {
                            dialogState = "connecting"
                        }
                    }
                    Item {
                        id: btScanTextItem
                        visible: main.isTft
                        anchors.horizontalCenter: parent.horizontalCenter
                        width:implicitWidth
                        height:implicitHeight
                        Image {
                            id:btTextImage
                            source: "../" + main.graphicsPath + "Bluetooth/Bluetooth_icon_small.png"
                            anchors.verticalCenter: parent.verticalCenter
                            anchors.left:parent.left
                        }
                        Text {
                            id: btScanTextTft
                            anchors.verticalCenter: parent.verticalCenter
                            anchors.left: btTextImage.right
                            anchors.leftMargin: 10 * main.screenScaleX
                            text: qsTr("press ENTER to search for devices") + application.emptyString
                            font.bold: true
                            font.family: "sans serif"
                            font.pixelSize: 24 * main.screenScaleY
                            color: "#ffffff"
                        }
                    }

                    Text{
                        id: btAudioDeviceMustBeDiscoverableText
                        visible: !bluetoothAdapter.connectedHeadset
                        anchors.horizontalCenter: parent.horizontalCenter
                        text: qsTr("DEVICE MUST BE DISCOVERABLE") + application.emptyString
                        font.bold: true
                        font.family: "sans serif"
                        font.pixelSize: dialogText.font.pixelSize * 0.3
                        color: "white"
                    }
                    Text{
                        id: btAudioHeadsetNotAllowedText
                        visible: bluetoothAdapter.connectedHeadset
                        width: 670 * main.screenScaleX
                        wrapMode: Text.WordWrap
                        anchors.horizontalCenter: parent.horizontalCenter
                        horizontalAlignment: Text.AlignHCenter
                        text: qsTr("Listening to Bluetooth audio while headset is connected is not supported. Please disconnect headset to continue.") + application.emptyString
                        font.bold: true
                        font.family: "sans serif"
                        font.pixelSize: dialogText.font.pixelSize * 0.3
                        color: "white"
                    }
                }
            }
            ImageButton{
                id: btHelpButton
                visible: main.isTouch && !bluetoothAdapter.connectedHeadset
                upimage: "../" + main.graphicsPath + "netpulse/GRAYbutton_video.png"
                downimage: "../" + main.graphicsPath + "netpulse/GRAYbutton_video_PRESSED.png"
                anchors.bottom: btConnectionPromptBox.bottom
                anchors.left: btConnectionPromptBox.right
                width: 50 * main.screenScaleX
                height: 50 * main.screenScaleY
                onClicked: {
                    dialogState = "help"
                }
                label: "?"
                label_under: false
                label_color: "black"
            }
        }


    }


    ModalDialog {
        id: btHelpDialog
        isTop: false
        isTransparent: true
        visible: false
        z: mediaBrowserNoDeviceConnectedDialog.z + 1

        width: root.width * 0.74
        height: width / 2

        anchors.verticalCenter: parent.verticalCenter
        anchors.horizontalCenter: parent.horizontalCenter

        Connections {
            target: main.isTft && !main.blockKeys && root.keysAccepted && btHelpDialog.visible ? keymapper : null
            onBackPressed: {
                main.debugKeys("backPressed", "MediaBrowser", "(btHelpDialog)")
                helpExitButton.clicked()
            }
        }

        BorderImage {   // pop-up dialog background
            id: border1

            anchors.fill: parent
            anchors.topMargin: -15 * main.screenScaleY
            anchors.bottomMargin: -33 * main.screenScaleY
            anchors.leftMargin: -14 * main.screenScaleX
            anchors.rightMargin: -33 * main.screenScaleX

            anchors.verticalCenter: parent.verticalCenter
            anchors.horizontalCenter: parent.horizontalCenter

            source: "../" + main.graphicsPath + "Pop_Up_Lrg_Grey.png"
            border { top: height*0.33; bottom: height*0.33; left: width*0.33; right: width*0.33 }

            Rectangle{
                id: helpDialogReferenceArea
                color:"transparent"
                opacity: 0.3
                height: parent.height + parent.anchors.topMargin + parent.anchors.bottomMargin
                width: parent.width + parent.anchors.rightMargin + parent.anchors.leftMargin
                anchors.top: parent.top
                anchors.left: parent.left
                anchors.topMargin: -parent.anchors.topMargin
                anchors.leftMargin: -parent.anchors.leftMargin
            }

            ImageButton{
                id: helpExitButton
                visible: main.isTouch
                upimage: "../" + main.graphicsPath + "Keypad/KeyPad_X_Large.png"
                downimage: "../" + main.graphicsPath + "Keypad/KeyPad_X_Large.png"
                anchors.top: helpDialogReferenceArea.top
                anchors.topMargin: 50 * main.screenScaleY
                anchors.right: helpDialogReferenceArea.right
                anchors.rightMargin: 50 * main.screenScaleX
                onClicked: {
                    dialogState = "idle"
                }
            }
            Text{
                id: fromYourDeviceText
                anchors.top: helpDialogReferenceArea.top
                anchors.topMargin: 15 * main.screenScaleY
                anchors.horizontalCenter: helpDialogReferenceArea.horizontalCenter
                width: helpDialogReferenceArea.width * 0.8
                text: qsTr("FROM YOUR DEVICE:") + application.emptyString
                color: "white"
                horizontalAlignment: Text.AlignHCenter
                wrapMode: Text.WordWrap
                font.bold: true
                font.family: "sans serif"
                font.pixelSize: helpDialogReferenceArea.height * 0.12
            }

            property string appleDeviceString: qsTr("- APPLE DEVICE: go to Settings, then Bluetooth") + application.emptyString
            property string androidDeviceString: qsTr("- ANDROID DEVICE: go to Bluetooth Settings") + application.emptyString
            property string confirmConnectionString: qsTr("- Confirm connection from your device") + application.emptyString
            property string navigateAndPlayString: qsTr("- NAVIGATE and PLAY content from your device, connect ear buds and control volume from this console.") + application.emptyString
            property string dialogString: appleDeviceString + "\n\n" + androidDeviceString + "\n\n" + confirmConnectionString + "\n\n" + navigateAndPlayString

            Item{
                id: appleDeviceTextContainer
                width: helpDialogReferenceArea.width * 0.8
                anchors.horizontalCenter: helpDialogReferenceArea.horizontalCenter

                anchors.top: fromYourDeviceText.bottom
                anchors.topMargin: 25 * main.screenScaleY

                anchors.bottom: helpDialogReferenceArea.bottom
                anchors.bottomMargin: 10 * main.screenScaleY
            }

            Text{
                id: appleDeviceText
                anchors.fill: appleDeviceTextContainer

                text: parent.dialogString
                color: "white"
                horizontalAlignment: Text.AlignLeft
                wrapMode: Text.WordWrap
                font.bold: true
                font.family: "sans serif"
                font.pixelSize: getNewFontPixelSize()
                transformOrigin: Item.TopLeft

                function getNewFontPixelSize(){
                    switch(application.currentLanguage) {
                    case "en":
                        return 23
                    case "es":
                        return 21
                    case "fr":
                        return 18
                    case "de":
                        return 19
                    case "it":
                        return 21
                    case "nl":
                        return 21
                    case "pt":
                        return 21
                    case "ru":
                        return 16
                    case "ja":
                        return 23
                    case "ko":
                        return 24
                    case "zh":
                        return 26
                    case "ar":
                        return 24
                    }
                    return 26
                }
            }


        }
        onTimedOut: hide()
    }

    // close button
    ImageButton {
        id: close_button

        z: 200

        visible: root.showCloseButton && main.isTouch
        width: 48 * main.screenScaleX
        height: 48 * main.screenScaleY
        anchors {   right: parent.right ; rightMargin: 40 * main.screenScaleX ;
            top: parent.top ; topMargin: 40 * main.screenScaleY
        }
        upimage: "../" + main.graphicsPath + "Keypad/KeyPad_X_Large.png"
        downimage: "../" + main.graphicsPath + "Keypad/KeyPad_X_Large.png"

        onClicked: close()
        mouseAreaScale: 2.0

    }

    Connections {
        target: root.viewShowing ? audioManager : null

        ignoreUnknownSignals: true

        onBtconnectedChanged: {
            if (audioManager.btconnected && viewShowing) {
                audioManager.btRequest()
            }
        }
    }

    function btControlsHandler(button){
        root.currentBtPlayer.restartMenuTimer();
        if(root.currentBtPlayer.isMenu){
            switch(button){
            case "up":
                if(bt_menulistview.currentIndex > 0)
                    bt_menulistview.currentIndex--
                break;
            case "down":
                if(bt_menulistview.currentIndex + 1 < bt_menulistview.count)
                    bt_menulistview.currentIndex++
                break;
            case "left":
                root.currentBtPlayer.previousFolder()
                break;
            case "right":
                root.currentBtPlayer.selectItem(bt_menulistview.currentIndex)
                break;
            case "center":
                root.currentBtPlayer.selectItem(bt_menulistview.currentIndex)
                break;
            case "menu":
                root.currentBtPlayer.isMenu = false
                break;
            default:
                break;
            }
        } else {
            switch(button){
            case "up":
                break;
            case "down":
                break;
            case "left":
                root.currentBtPlayer.previous()
                break;
            case "right":
                root.currentBtPlayer.next();
                break;
            case "center":
                if(root.currentBtPlayer.isPlaying){
                    root.currentBtPlayer.pause()
                }else{
                    root.currentBtPlayer.play()
                }
                break;
            case "menu":
                root.currentBtPlayer.isMenu = true
                break;
            default:
                break;
            }
        }
    }

    // Bluetooth playlist - Key navigation
    Connections {
        target: main.isTft && root.opacity > 0 && keysAccepted && bluetoothAdapter.connected ? keymapper : null

        onDoubleLeftPressed: {
            main.debugKeys("doubleLeftPressed", "MediaBrowser", "(bt menu)")
            btControlsHandler("left")
        }
        onDoubleRightPressed: {
            main.debugKeys("doubleRightPressed", "MediaBrowser", "(bt menu)")
            btControlsHandler("right")
        }
        onUpButtonPressed: {
            main.debugKeys("upButtonPressed", "MediaBrowser", "(bt menu)")
            btControlsHandler("up")
        }
        onDownButtonPressed: {
            main.debugKeys("downButtonPressed", "MediaBrowser", "(bt menu)")
            btControlsHandler("down")
        }
        onEnter2Pressed: {
            main.debugKeys("enter2Pressed", "MediaBrowser")
            btControlsHandler("menu")
        }
    }

    IPodMenuControl{

        id:bt_menu
        property string selectedItemHeading: ""
        opacity: main.isTouch || root.keysAccepted ? 1.0 : 0.5
        x: 31 * main.screenScaleX
        y: 20 * main.screenScaleY
        //visible: isMenuVisible
        anchors.top: parent.top
        anchors.topMargin: 36 * main.screenScaleY
        anchors.bottom: parent.bottom
        anchors.bottomMargin: root.menu_bottom_margin
        anchors.left: parent.left
        anchors.leftMargin: 31 * main.screenScaleX
        visible: bluetoothAdapter.connected && root.currentBtPlayer && root.currentBtPlayer.isMenu

        heading: bluetoothAdapter.connected && root.currentBtPlayer && root.currentBtPlayer.menuHeading !== "" ? root.currentBtPlayer.menuHeading : "Menu"

        Text {
            anchors.fill: parent
            anchors.topMargin: 80 * main.screenScaleY
            anchors.bottomMargin: 20 * main.screenScaleY
            anchors.leftMargin: 30 * main.screenScaleX
            anchors.rightMargin: 20 * main.screenScaleX

            visible: !bt_menulistview.visible

            text: "No Menu Available"
        }

        ListView {
            id: bt_menulistview

            anchors.fill: parent
            anchors.topMargin: 80 * main.screenScaleY
            anchors.bottomMargin: 20 * main.screenScaleY
            anchors.leftMargin: 30 * main.screenScaleX
            anchors.rightMargin: 20 * main.screenScaleX
            clip: true
            onMovingChanged: root.upPressed()
            currentIndex: 1
            highlight: Rectangle { color: "lightsteelblue"; radius: 1 * main.screenScaleX }
            pressDelay: 200
            highlightMoveDuration: 1
            //model: testmodel
            model: root.currentBtPlayer && root.currentBtPlayer.menu
            visible: root.currentBtPlayer ? root.currentBtPlayer.menuSize > 0 : false
            delegate: Component {
                Row {
                    Image {
                        source: "../" + main.graphicsPath + "tft/toggle_arrow_black.png"
                        visible: type === "folder"
                    }
                    Text {
                        text: name
                        width: bt_menulistview.width
                        height: name == "" ? 0 : implicitHeight
                        MouseArea{
                            anchors.fill: parent
                            onClicked: {
                                root.currentBtPlayer.selectItem(index)
                                //menuItemPressed(index)
                            }
                            onPressed: {
                                bt_menulistview.currentIndex = index
                                buzzer.buttonPress()
                            }
                        }
                    }
                }
            }
        }
    }

    NowPlayingControl {
        id: bt_now_playing
        opacity: main.isTouch || root.keysAccepted ? 1.0 : 0.5

        x: 31 * main.screenScaleX
        y: 20 * main.screenScaleY
        //visible: !isMenuVisible
        // connect data model for song meta-data here (duration, title, etc.)
        duration: root.currentBtPlayer ? root.currentBtPlayer.duration / 1000 : 0
        //title: title
        title: root.currentBtPlayer && root.currentBtPlayer.title !== "" ? root.currentBtPlayer.title : "Title info not available"
        artist: root.currentBtPlayer && root.currentBtPlayer.artist !== "" ? root.currentBtPlayer.artist : "Artist info not available"
        album: root.currentBtPlayer && root.currentBtPlayer.album !== "" ? root.currentBtPlayer.album : "Album info not available"
        position: root.currentBtPlayer ? root.currentBtPlayer.position / 1000 : 0

        visible: bluetoothAdapter.connected && root.currentBtPlayer && !root.currentBtPlayer.isMenu
        // scrub event happens when user moves slider
        // onScrub: { now_playing.position = new_time }

        anchors.top: parent.top
        anchors.topMargin: 36 * main.screenScaleY
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 80 * main.screenScaleY
        anchors.left: parent.left
        anchors.leftMargin: 31 * main.screenScaleX


    }

    ImageButton {
        id: bt_menu_button
        visible: bluetoothAdapter.connected && main.isTouch
        anchors.top: bluetooth_controls.bottom
        anchors.topMargin: -285 * main.screenScaleY
        anchors.left: bluetooth_controls.right
        anchors.leftMargin: 30 * main.screenScaleX
        fontsize: 14 * main.screenScaleY
        label: qsTr("MENU") + application.emptyString
        upimage: "../" + main.graphicsPath + "205/Lrg_Button_Up.png"
        downimage: "../" + main.graphicsPath + "205/Lrg_Button_Down.png"
        onClicked: {
            btControlsHandler("menu")
        }
    }

    ImageButton{
        id: bt_disconnect_button
        visible: main.isTouch && bluetoothAdapter.connected
        upimage: "../" + main.graphicsPath + "205/Lrg_Button_Up.png"
        downimage: "../" + main.graphicsPath + "205/Lrg_Button_Down.png"
        icon: "../" + main.graphicsPath + "Bluetooth/Bluetooth_icon_small.png"
        icon_x_offset: -2 * main.screenScaleX
        icon_y_offset: 0
        anchors.horizontalCenter: bt_menu_button.horizontalCenter
        anchors.verticalCenter: bt_nike_plus_button.verticalCenter
        onClicked: if(bluetoothAdapter.connected) {
                       dialogState = "disconnecting"
                       bluetoothAdapter.disconnect()
                   }
        Image{
            source: "../" + main.graphicsPath + "Bluetooth/small_red_X.png"
            width: 18 * main.screenScaleX
            height: 17 * main.screenScaleY
            x: 20 * main.screenScaleX
            y: 23 * main.screenScaleY
            fillMode: "PreserveAspectFit"
            smooth: true
        }
    }

    ImageButton{
        id: bt_nike_plus_button
        anchors {
            top: bluetooth_controls.bottom ; topMargin: -50 * main.screenScaleY
            horizontalCenter: bluetooth_controls.horizontalCenter
        }
        upimage:"../" + main.graphicsPath + "205/SM_Button_Up.png"
        downimage:"../" + main.graphicsPath + "205/SM_Button_Down.png"
        icon: ""
        label: "Nike + iPod"
        fontsize: 30 * main.screenScaleY
        label_color: "white"
        label_x_offset: 120 * main.screenScaleX
        enabled: false
        visible: bluetoothAdapter.connected && main.isTouch
    }

    Item {
        id: bluetooth_controls
        x: 562 * main.screenScaleX

        Connections {
            target: main.isTft && !main.blockKeys && root.keysAccepted && bluetoothAdapter.connected && (!root.currentBtPlayer || !root.currentBtPlayer.isMenu) ? keymapper : null

            onUpButtonPressed: {
                main.debugKeys("upButtonPressed", "MediaBrowser", "(bluetooth controls)")
                volume_controls.volumeUp()
            }
            onDownButtonPressed: {
                main.debugKeys("downButtonPressed", "MediaBrowser", "(bluetooth controls)")
                volume_controls.volumeDown()
            }
        }

        visible: bluetoothAdapter.connected && main.isTouch
        width: 300 * main.screenScaleX
        height: 300 * main.screenScaleY
        anchors.top: parent.top
        anchors.topMargin: 86 * main.screenScaleY
        ImageButton {
            id: bt_up_button
            x: 43 * main.screenScaleX
            y: -93
            anchors.bottom: bt_center_button.verticalCenter
            anchors.bottomMargin: 42 * main.screenScaleY
            anchors.horizontalCenterOffset: 0
            anchors.horizontalCenter: bt_center_button.horizontalCenter
            upimage: "../" + main.graphicsPath + "205/IPOD_Wheel_Top_Up.png"
            downimage: "../" + main.graphicsPath + "205/IPOD_Wheel_Top_Down.png"
            icon: "../" + main.graphicsPath + "205/IPOD_Controls_Up.png"
            mouseAreaScale: 0.7
            enabled: root.currentBtPlayer && root.currentBtPlayer.isMenu ? true : false
            onClicked: btControlsHandler("up")

        }
        ImageButton {
            id: bt_center_button
            x: 114 * main.screenScaleX
            y: 66 * main.screenScaleY

            upimage: (root.currentBtPlayer && root.currentBtPlayer.isPlaying) ? "../" + main.graphicsPath + "205/IPOD_Wheel_Center_Down.png" : "../" + main.graphicsPath + "205/IPOD_Wheel_Center_Up.png"
            downimage: "../" + main.graphicsPath + "205/IPOD_Wheel_Center_Down.png"
            icon: "../" + main.graphicsPath + "205/IPOD_Controls_Select.png"

            onClicked: {
                btControlsHandler("center")
            }
            mouseAreaScale: 0.7
        }

        ImageButton {
            id: bt_down_button
            anchors.horizontalCenterOffset: 1 * main.screenScaleX
            anchors.top: bt_center_button.verticalCenter
            anchors.topMargin: 42 * main.screenScaleY
            anchors.horizontalCenter: bt_center_button.horizontalCenter
            upimage: "../" + main.graphicsPath + "205/IPOD_Wheel_Bottom_Up.png"
            downimage: "../" + main.graphicsPath + "205/IPOD_Wheel_Bottom_Down.png"
            icon: "../" + main.graphicsPath + "205/IPOD_Controls_Down.png"
            mouseAreaScale: 0.7
            enabled: (root.currentBtPlayer && root.currentBtPlayer.isMenu) ? true : false
            onClicked: btControlsHandler("down")

        }

        ImageButton {
            id: bt_left_button
            x: 0
            y: 116 * main.screenScaleY
            anchors.right: bt_center_button.horizontalCenter
            anchors.rightMargin: 36 * main.screenScaleX
            anchors.verticalCenterOffset: 0
            anchors.verticalCenter: bt_center_button.verticalCenter
            anchors.topMargin: 0
            upimage: "../" + main.graphicsPath + "205/IPOD_Wheel_Left_Up.png"
            downimage: "../" + main.graphicsPath + "205/IPOD_Wheel_Left_Down.png"
            icon: "../" + main.graphicsPath + "205/IPOD_Controls_Back.png"
            onClicked: {
                btControlsHandler("left")
            }
            mouseAreaScale: 0.7

        }

        ImageButton {
            id: bt_right_button
            anchors.verticalCenterOffset: 0
            anchors.left: bt_center_button.horizontalCenter
            anchors.leftMargin: 41 * main.screenScaleX
            anchors.verticalCenter: bt_center_button.verticalCenter
            upimage: "../" + main.graphicsPath + "205/IPOD_Wheel_Right_Up.png"
            downimage: "../" + main.graphicsPath + "205/IPOD_Wheel_Right_Down.png"
            icon: "../" + main.graphicsPath + "205/IPOD_Controls_Forward.png"
            onClicked: {
                btControlsHandler("right")
            }
            mouseAreaScale: 0.7

        }

        Rectangle {
            id: bt_wheel_well
            // helpful for alignment of circular button array, as buttons have shadows
            x: 75 * main.screenScaleX
            y: 43 * main.screenScaleY
            width: 285 * main.screenScaleX
            height: width
            color: "#ffffff"
            radius: width*0.5
            anchors.verticalCenterOffset: -2 * main.screenScaleY
            anchors.horizontalCenterOffset: -2 * main.screenScaleX
            z: -1
            anchors.horizontalCenter: bt_center_button.horizontalCenter
            anchors.verticalCenter: bt_center_button.verticalCenter
            opacity: 0
        }
    } // end ipod wheel bluetooth


    // Help pane for Bluetooth TFT
    BluetoothTftHelp {
        id: bt_help_pane
        keysAccepted: root.keysAccepted
        visible: main.isTft && bluetoothAdapter.connected
        isPlaying: root.currentBtPlayer ? root.currentBtPlayer.isPlaying : false
        isMenu: root.currentBtPlayer ? root.currentBtPlayer.isMenu : false
        x: 532 * main.screenScaleX
        anchors.top: parent.top
    }

    ConfirmationPromptTft {
        id: confirmDisconnectDialog
        isTop: false
        visible: false
        anchors.centerIn: parent
        prompt: qsTr("This will disconnect the device. Are you sure?") + application.emptyString
        onYesClicked: {
            if(bluetoothAdapter.connected) {
                bluetoothAdapter.disconnect()
            }
            confirmDisconnectDialog.hide()
        }
        onNoClicked: {
            confirmDisconnectDialog.hide()
        }
    }

    BluetoothDeviceSelectionDialog{
        id: btConnectionStatusDialog
        width: root.width * 0.74
        height: width / 2
        isTop: false
        list: bluetoothAdapter.scannedDevices
        keysAccepted: root.keysAccepted
        pairingAllowed: !(bluetoothAdapter.pairing || bluetoothAdapter.connectingHeadset)

        anchors.horizontalCenter: root.horizontalCenter
        anchors.verticalCenter: root.verticalCenter
        opacity: main.isTouch || root.keysAccepted ? 1.0 : 0.5

        onClosed: dialogState = "idle"
        onDeviceConnected: dialogState = "connected"
        onDeviceDisconnected: dialogState = "idle"
    }

}

