import QtQuick 2.4
import Components 1.0

Item {
    id: root

    property variant activeConnections
    property bool preventEthDisconnect: false

    signal disconnectRequest(string interfaceName)

    function refresh() {
        // Force re-selection of current item
        cnxList.currentIndex = -1
        cnxList.currentIndex = 0
    }

    width: childrenRect.width
    height: childrenRect.height

    Text {
        id: activeCnxText
        text: qsTr("Active Connections") + ":" + application.emptyString
        anchors {
            top: parent.top
            left: parent.left
        }
    }

    Rectangle {
        id: connectionsListBox
        color: "#808080"
        width: 290 * main.screenScaleX
        height: 310 * main.screenScaleY
        border { width: 2 * main.screenScaleX; color: "black" }
        anchors { left: parent.left; top: activeCnxText.bottom; topMargin: 5 * main.screenScaleY }
        clip: true

        ListView {
            id: cnxList

            visible: !netConnections.isRefreshing
            anchors.fill: parent
            anchors.margins: 5 * main.screenScaleX
            model: netConnections.list
            delegate: connDelegate
            highlight: Component {
                Rectangle {
                    height: 44 * main.screenScaleY
                    width: parent.width
                    color: "#9d9d9d"
                }
            }
        }

        Text {
            id: refreshingText
            visible: netConnections.isRefreshing
            text: qsTr("Refreshing...") + application.emptyString
            anchors { top: parent.top; left: parent.left; topMargin: 10 * main.screenScaleY; leftMargin: 10 * main.screenScaleX }
        }
    }

    Component {
        id: connDelegate
        Row {
            height: 44 * main.screenScaleY
            spacing: 10 * main.screenScaleX

            Image {
                id: padlock
                source: encrypted ? main.graphicsPath + "padlock.png" : main.graphicsPath + "padlock-unlocked.png"
                Text {
                    id: problemX
                    visible: (intf === "enp2s0" && (!netConnections.wiredEnabled || netConnections.wireDisconnected)) || (intf === "wlp5s0" || intf === "wlp6s0") && !netConnections.wirelessEnabled
                    color: "#ff3300"
                    font.pixelSize: 24 * main.screenScaleY
                    text: "X"
                    anchors { bottom: parent.bottom; left: parent.left }
                }
            }

            Item {
                id: spacingItem
                width: 10 * main.screenScaleX
                height: 10 * main.screenScaleY
            }

            Text {
                text: essid ? essid : ""
                font { pixelSize: 26 * main.screenScaleY }
                width: 170 * main.screenScaleX
                verticalAlignment: Text.AlignVCenter
                MouseArea {
                    anchors.fill: parent
                    onClicked: {
                        cnxList.currentIndex = index
                    }
                }
            }
            ImageButton {
                upimage: main.graphicsPath + "Keypad/KeyPad_X.png"
                downimage: upimage
                enabled: !(intf === "enp2s0" && root.preventEthDisconnect)
                onClicked: {
                    disconnectRequest(intf)
                }
            }
        }
    }

    Row {
        id: ethInfo
        spacing: 40 * main.screenScaleX
        visible: cnxList.currentIndex >= 0 && cnxList.model.get(cnxList.currentIndex).intf === "enp2s0"
        anchors { left: connectionsListBox.right; leftMargin: 70 * main.screenScaleX; top: connectionsListBox.top; topMargin: 40 * main.screenScaleY }
        Column {
            Text { text: qsTr("Interface") + application.emptyString; font.pointSize: 22 * main.screenScaleY  }
            Text { text: qsTr("Status") + application.emptyString; font.pointSize: 22 * main.screenScaleY }
            Text { text: qsTr("IP Address") + application.emptyString; font.pointSize: 22 * main.screenScaleY; visible: !netConnections.wireDisconnected }
            Text { text: qsTr("Subnet Mask") + application.emptyString; font.pointSize: 22 * main.screenScaleY; visible: !netConnections.wireDisconnected }
            Text { text: qsTr("Wired MAC Address") + application.emptyString; font.pointSize: 22 * main.screenScaleY }
            Text { text: qsTr("Wireless MAC Address") + application.emptyString; font.pointSize: 22 * main.screenScaleY; visible: netConnections.wireDisconnected }
        }

        Column {
            Text { text: qsTr("Ethernet") + application.emptyString; font { pointSize: 22 * main.screenScaleY } }
            Text {
                text: {
                    if (netConnections.wireDisconnected) {
                        return qsTr("Wire Disconnected")
                    } else if (netConnections.wiredEnabled) {
                        return qsTr("Connected")
                    } else {
                        return qsTr("No Connection")
                    }
                }
                color: netConnections.wireDisconnected ? "gray" : "black"
                font { pointSize: 22 * main.screenScaleY }
            }
            Text { text: netConnections.wiredIp; font.pointSize: 22 * main.screenScaleY; visible: !netConnections.wireDisconnected }
            Text { text: netConnections.wiredNetmask; font.pointSize: 22 * main.screenScaleY; visible: !netConnections.wireDisconnected }
            Text { text: netConnections.wiredMac; font.pointSize: 22 * main.screenScaleY }
            Text { text: netConnections.wirelessMac; font.pointSize: 22 * main.screenScaleY; visible: netConnections.wireDisconnected}
        }
    }

    Row {
        id: wirelessInfo
        spacing: 40 * main.screenScaleX
        visible: cnxList.currentIndex >= 0 && (cnxList.model.get(cnxList.currentIndex).intf === "wlp5s0" || cnxList.model.get(cnxList.currentIndex).intf === "wlp6s0")
        anchors { left: connectionsListBox.right; leftMargin: 70 * main.screenScaleX; top: connectionsListBox.top; topMargin: 40 * main.screenScaleY }
        Column {
            Text { text: qsTr("Status") + application.emptyString; font { pointSize: 22 * main.screenScaleY } }
            Text { text: qsTr("Signal Strength") + application.emptyString; font { pointSize: 22 * main.screenScaleY } }
            Text { text: qsTr("IP Address") + application.emptyString; font { pointSize: 22 * main.screenScaleY } }
            Text { text: qsTr("Subnet Mask") + application.emptyString; font { pointSize: 22 * main.screenScaleY } }
            Text { text: qsTr("MAC Address") + application.emptyString; font { pointSize: 22 * main.screenScaleY } }
        }

        Column {
            Text {
                text: {
                    if (netConnections.wirelessEnabled) {
                        return qsTr("Connected") + application.emptyString
                    } else {
                        return qsTr("No Connection") + application.emptyString
                    }
                }
                font { pointSize: 22 * main.screenScaleY }
            }
            Text { text: netConnections.signalStrength; font { pointSize: 22 * main.screenScaleY } }
            Text { text: netConnections.wirelessIp; font { pointSize: 22 * main.screenScaleY } }
            Text { text: netConnections.wirelessNetmask; font { pointSize: 22 * main.screenScaleY } }
            Text { text: netConnections.wirelessMac; font { pointSize: 22 * main.screenScaleY } }
        }
    }
}
