import QtQuick 2.4
import Components 1.0

Item {
    id: root

    property int rpm: 0
    property int paceTarget: 0
    property int paceLevel: 0
    property bool showPaceSetter: false
    property bool bikeModeEnabled: false

    signal levelUp()
    signal levelDown()

    width: 344 * main.screenScaleX
    height: 225 * main.screenScaleY
    state: showPaceSetter ? "PACESETTER" : "NOPACESETTER"

    function getIcon()
    {
        if(root.bikeModeEnabled)
            return main.graphicsPath + "224/PACE-CADENCE_icon_bikemode.png"
        else
            return main.graphicsPath + "netpulse/PACE-SPEED_icon_GRAY.png"
    }

    Image {
        id: paceSetterShape

        anchors.horizontalCenter: parent.horizontalCenter
        anchors.verticalCenter: parent.verticalCenter
        source: main.graphicsPath + "224/Pace_Setter_Shape.png"
    }

    Image{
        id:paceIcon

        anchors.horizontalCenter: parent.horizontalCenter
        anchors.horizontalCenterOffset:-80
        anchors.verticalCenter: parent.verticalCenter
        anchors.verticalCenterOffset: -65 * main.screenScaleY
        source: root.getIcon()
    }

    Text {
        id: rpmValue

        anchors.horizontalCenter: parent.horizontalCenter
        anchors.horizontalCenterOffset: ( main.isTft && !showPaceSetter ? 40 : 0 ) * main.screenScaleX
        anchors.verticalCenter: parent.verticalCenter
        anchors.verticalCenterOffset: ( main.isTft && !showPaceSetter ? -22 : -35 ) * main.screenScaleY
        color: "black"
        font.pointSize: 32 * main.screenScaleY
        font.bold: true
        text: root.rpm
    }

    Text {
        id: rpmLabelValue

        anchors.horizontalCenter: parent.horizontalCenter
        anchors.horizontalCenterOffset: ( main.isTft && !showPaceSetter ? 40 : 0 ) * main.screenScaleX
        anchors.verticalCenter: parent.verticalCenter
        anchors.verticalCenterOffset: ( (main.isTft && !showPaceSetter ? 18 : 0 ) + ( text.length > 3 * main.screenScaleX ? 0 : -5 ) * main.screenScaleY)
        color: "black"
        font.pointSize: text.length > 3 * main.screenScaleX ? 9 * main.screenScaleY : 12 * main.screenScaleY
        horizontalAlignment: Text.AlignHCenter
        width: 150 * main.screenScaleX
        wrapMode: Text.WordWrap
        font.bold: true
        text: qsTr("RPM") + application.emptyString
    }

    Text {
        id: paceSetterLabel

        anchors.top: parent.top
        anchors.topMargin: 25 * main.screenScaleY
        anchors.left: parent.left
        anchors.leftMargin: 30 * main.screenScaleX
        color: "black"
        font.pointSize: 12 * main.screenScaleY
        font.bold: true
        text: qsTr("PACE SETTER") + application.emptyString
    }

    ImageButton {
        id: paceSetterLevelUpButton
        visible: main.isTouch

        anchors.horizontalCenter: parent.horizontalCenter
        anchors.horizontalCenterOffset: 95 * main.screenScaleX
        anchors.verticalCenter: parent.verticalCenter
        anchors.verticalCenterOffset: -59 * main.screenScaleY
        downimage: main.graphicsPath + "Arrow_Up_Button_Pressed.png"
        upimage: main.graphicsPath + "Arrow_Up_Button.png"
        icon: main.graphicsPath + "224/Plus_Sign.png"
        onClicked: root.levelUp()
    }

    ImageButton {
        id: paceSetterLevelDownButton
        visible: main.isTouch

        anchors.horizontalCenter: parent.horizontalCenter
        anchors.horizontalCenterOffset: 95 * main.screenScaleX
        anchors.verticalCenter: parent.verticalCenter
        anchors.verticalCenterOffset: 11 * main.screenScaleY
        downimage: main.graphicsPath + "Arrow_Down_Button_Pressed.png"
        upimage: main.graphicsPath + "Arrow_Down_Button.png"
        icon: main.graphicsPath + "224/Minus_Sign.png"
        onClicked: root.levelDown()
    }

    Text {
        id: paceSetterLevelLabel
        visible: main.isTouch

        anchors.horizontalCenter: paceSetterLevelUpButton.horizontalCenter
        anchors.top: paceSetterLevelDownButton.bottom
        anchors.topMargin: -8 * main.screenScaleY
        color: "black"
        font.pointSize: 10 * main.screenScaleY
        font.bold: true
        text: qsTr("LEVEL") + application.emptyString
    }

    Text {
        id: paceSetterLevel
        visible: main.isTouch

        anchors.horizontalCenter: paceSetterLevelUpButton.horizontalCenter
        anchors.verticalCenter: parent.verticalCenter
        anchors.verticalCenterOffset: -27 * main.screenScaleY
        color: "black"
        font.pointSize: 18 * main.screenScaleY
        font.bold: true
        text: root.paceLevel
    }

    PaceSetterMeter{
        id: paceSetterMeter

        rpm: root.rpm
        paceTarget: root.paceTarget
        anchors.horizontalCenter: rpmValue.horizontalCenter
        anchors.horizontalCenterOffset: 0
        anchors.bottom: paceSetterShape.bottom
        anchors.bottomMargin: 57 * main.screenScaleY
    }

    states: [
        State {
            name: "PACESETTER"
            PropertyChanges {target: paceSetterShape; visible: true}
            PropertyChanges {target: paceSetterLabel; visible: true}
            PropertyChanges {target: paceSetterLevelLabel; visible: main.isTouch}
            PropertyChanges {target: paceSetterLevel; visible: main.isTouch}
            PropertyChanges {target: paceSetterLevelUpButton; visible: main.isTouch}
            PropertyChanges {target: paceSetterLevelDownButton; visible: main.isTouch}
            PropertyChanges {target: paceSetterMeter; visible: true}
            PropertyChanges {target: paceIcon; visible: false}
        },
        State {
            name: "NOPACESETTER"
            PropertyChanges {target: paceSetterShape; visible: false}
            PropertyChanges {target: paceSetterLabel; visible: false}
            PropertyChanges {target: paceSetterLevelLabel; visible: false}
            PropertyChanges {target: paceSetterLevel; visible: false}
            PropertyChanges {target: paceSetterLevelUpButton; visible: false}
            PropertyChanges {target: paceSetterLevelDownButton; visible: false}
            PropertyChanges {target: paceSetterMeter; visible: false}
            PropertyChanges {target: paceIcon; visible: true}
        }
    ]
} // end paceSetter
