import QtQuick 2.4
import Components 1.0

Item {
    id: root

    property bool unlocked: false
    property int currentSpeed
    property int currentSpeedMetric
    property int currentIncline

    signal speedChange(real speed)
    signal inclineChange(int incline)

    state: unlocked ? "unlocked" : "locked"
    height: childrenRect.height
    width: childrenRect.width
    // list of quick speeds
    ListModel {
        id: speeds
        ListElement { speed: 3 }
        ListElement { speed: 4 }
        ListElement { speed: 6 }
        ListElement { speed: 7 }
        ListElement { speed: 8 }
    }

    ListModel {
        id: km_speeds
        ListElement { speed: 5 }
        ListElement { speed: 7 }
        ListElement { speed: 9 }
        ListElement { speed: 11 }
        ListElement { speed: 13 }
    }

    // list of quick inclines
    ListModel {
        id: inclines
        ListElement { incline: 0 }
        ListElement { incline: 3 }
        ListElement { incline: 5 }
        ListElement { incline: 7 }
        ListElement { incline: 9 }
    }
    ListModel {
        id: inclinesAlpineRunner
        ListElement { incline: 0 }
        ListElement { incline: 5 }
        ListElement { incline: 10 }
        ListElement { incline: 15 }
        ListElement { incline: 20 }
    }

    Row {
        Text {
            id: unlockText

            visible: !root.unlocked
            font.pointSize: 14 * main.screenScaleY
            font.bold: true
            text: qsTr("UNLOCK QUICK KEYS") + application.emptyString
            width: 250 * main.screenScaleX
            wrapMode: Text.WordWrap
            verticalAlignment: Text.AlignVCenter
            anchors.verticalCenter: parent.verticalCenter
        }

        Item {
            id: buttons

            width: buttons_row.width
            height: buttons_row.height

            SliderControl {
                id: slider

                z:30
                minValue: 0
                maxValue: 100
                clickableTrack: false
                anchors.fill: parent; anchors.leftMargin: 35 * main.screenScaleX ; anchors.rightMargin: 35 * main.screenScaleX
                showButtons: false
                showValue: false
                thumbImage: (Qt.application.layoutDirection === Qt.RightToLeft) ? main.graphicsPath + "224/224_Data_ToolBar_Slider_Arrow_Left.png" : main.graphicsPath + "224/224_Data_ToolBar_Slider_Arrow.png"
                trackImage: main.graphicsPath + "224/Unlock_Quick_Keys_Gradiant.png"
                trackImageOpacity: 0.6
                thumbMouseAreaScale: 1.3
                onReleased: {
                    if(value > 65) {
                        root.unlocked = true
                        value = 0
                    }
                    else
                        sliderSnap.start()
                }
                NumberAnimation on value { id: sliderSnap ; to: 0;  duration: 200; easing.type: Easing.Linear }
            }

            Row {
                id: buttons_row
                //visible: root.unlocked
                spacing: 15 * main.screenScaleX

                ImageButton {
                    id: incline
                    toggle: true
                    visible: root.unlocked
                    icon: main.graphicsPath + "netpulse/QUICKINCLINE_button_icon.png"
                    upimage: main.graphicsPath + "224/224_Data_ToolBar_Round.png"
                    downimage: main.graphicsPath + "224/224_Data_ToolBar_Round_Green.png"
                    radioGroup: [ incline, speed ]
                }

                ImageButton {
                    id: speed
                    toggle: true
                    visible: root.unlocked
                    icon: main.graphicsPath + "netpulse/QUICKSPEED_button_icon.png"
                    upimage: main.graphicsPath + "224/224_Data_ToolBar_Round.png"
                    downimage: main.graphicsPath + "224/224_Data_ToolBar_Round_Green.png"
                    radioGroup: [ incline, speed ]
                }

                Row {
                    id: speed_buttons

                    spacing: 15 * main.screenScaleX
                    visible: root.visible && speed.isDown
                    enabled: root.unlocked

                    Component {
                        id: speedButtonDelegate
                        ImageButton {
                            property bool selected: {
                                if(workoutScreen.unitState === "METRIC") {
                                    if(workoutManager.treadSpeedMetricGUI === speed * 10) {
                                        return true
                                    } else {
                                        return false
                                    }
                                } else {
                                    if(workoutManager.treadSpeedGUI === speed * 10) {
                                        return true
                                    } else {
                                        return false
                                    }
                                }
                            }
                            label: "<center><table border=0>" +
                                   "<tr><td><center><p style=\"font-size:36px\">" + speed + "</p></center></td></tr>" +
                                   "<tr><td><center><p style=\"font-size:12px\">" + (workoutScreen.unitState === "METRIC" ? "KPH" : "MPH") + "</p></center></td></tr>" +
                                   "</table>"
                            textFormat: Text.RichText
                            lineHeight: 0.8
                            label_color: "white"
                            upimage: selected ? main.graphicsPath + "224/224_Data_ToolBar_Round_Down.png" : main.graphicsPath + "224/DATA_BLUE_button.png"
                            downimage: main.graphicsPath + "224/224_Data_ToolBar_Round_Down.png"
                            onClicked: {
                                root.speedChange(speed)
                            }
                        } // end ImageButton delegate
                    }

                    Repeater {
                        model: workoutScreen.unitState === "METRIC" ? km_speeds : speeds
                        delegate: speedButtonDelegate

                    } // end Repeater
                } // speeds

                Row {
                    id: incline_buttons

                    spacing: 15 * main.screenScaleX
                    visible: incline.isDown
                    opacity: root.unlocked ? 1.0 : 0.5

                    Component {
                        id: inclineButtonDelegate
                        ImageButton {
                            property bool selected: currentIncline === incline*10
                            label: "<center><table border=0>" +
                                   "<tr><td><center><p style=\"font-size:36px\">" + incline + "</p></center></td></tr>" +
                                   "<tr><td><center><p style=\"font-size:12px\">%</p></center></td></tr>" +
                                   "</table>"
                            textFormat: Text.RichText
                            lineHeight: 0.8
                            label_color: "white"
                            upimage: selected ? main.graphicsPath + "224/224_Data_ToolBar_Round_Down.png" : main.graphicsPath + "224/DATA_PURPLE_button.png"
                            downimage: main.graphicsPath + "224/224_Data_ToolBar_Round_Down.png"
                            onClicked: root.inclineChange(incline)
                            y: ( selected || isDown ? -1 : 0 ) * main.screenScaleY // Adjust for image height difference
                        } // end ImageButton delegate
                    }
                    Repeater {
                        model: main.isAlpineRunner ? inclinesAlpineRunner : inclines
                        delegate: inclineButtonDelegate

                    } // end Repeater
                } // inclines
            } // end buttons_row
        } // end Item buttons
    } // end Row

    states: [
        State {
            name: "locked"
            PropertyChanges { target: slider ; opacity: 1.0 }
            PropertyChanges { target: speed ; isDown: true }
        },
        State {
            name: "unlocked"
            PropertyChanges { target: slider ; opacity: 0 }
            PropertyChanges { target: speed ; isDown: true }
        }
    ]
}
