import QtQuick 2.4
import VLCVideo 1.0
//import QtAV 1.6
import QtMultimedia 5.7
import Components 1.0
import Process 0.1

Item {
    id: root

    property bool muted: !audioManager.virtActiveAllowed
    property bool playing: videoView.playbackState === MediaPlayer.PlayingState
    property string videosPresent: "va"
    property variant videoModel: oiVideos

    function stopVideo() {
        state = "MenuState"
        print("Stop Video")
        videoView.stop()
        videoView.source = ""
    }

    // start out showing a menu of video thumbnails
    Component.onCompleted: {
        console.log("Starting oiDetect")
        oiDetect.start()
        state = "MenuState"
    }

    Process { id: oiDetect
        program: "scripts/detect_outsideInteractive.sh"

        onReadyReadStandardOutput: {
            var output = String(readAllStandardOutput())
            output = output.trim()
            console.log( "Outside Interactive Videos installed " + output)
            root.videosPresent = output
            console.log("oiDetect root.videosPresent = " + root.videosPresent )
            root.videoModel = getVideoModel()
        }
        onReadyReadStandardError: {
            var output = String(readAllStandardError())
            output = output.trim()
            console.log( "oiDetect Error " + output)
        }
    }

    Image {
        id: background
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.verticalCenter: parent.verticalCenter

        source: main.graphicsPath + "netpulse/DATA_gray shape_120612.png"
    }

    // List Model of videos - name displayed as title, file is video file, thumbnail shows in menu

    //Outdoor Interactive Videos
    ListModel {
        id: oiVideos

        property int numColumns: 4

        ListElement { speed: "1.7"; name: QT_TR_NOOP("Hills of Bali");        file: "/data/video/OI/BaliTrueFitA_V_Compressed_Cut.mp4";                thumbnail: "/data/video/OI/Bali_Screenshot.JPG"}
        ListElement { speed: "1.4"; name: QT_TR_NOOP("Australian Outback");   file: "/data/video/OI/AustralianOutbackTrueFitA_V_Compressed_Cut_1.mp4"; thumbnail: "/data/video/OI/Australian-Outback_Screenshot.JPG"}
        ListElement { speed: "1.0"; name: QT_TR_NOOP("Central Park");         file: "/data/video/OI/CentralParkTrueA_V_Compressed_Cut.mp4";            thumbnail: "/data/video/OI/Central_Park_Screenshot.JPG"}
        ListElement { speed: "1.4"; name: QT_TR_NOOP("Falmouth Road Race");   file: "/data/video/OI/New_Balance_Falmouth_Road_Race_Compressed.mp4";    thumbnail: "/data/video/OI/New_Balance_Falmouth_Road_Race_Screenshot.JPG"}
        ListElement { speed: "1.5"; name: QT_TR_NOOP("Niagara Falls");        file: "/data/video/OI/NiagaraTrueFitA_V_Compressed.mp4";                 thumbnail: "/data/video/OI/Niagara_Falls_Screen_Shot.JPG"}
        ListElement { speed: "1.45"; name: QT_TR_NOOP("Washington Mall");     file: "/data/video/OI/WashMallTrueFitA_V_Compressed.mp4";                thumbnail: "/data/video/OI/Washington_Mall_Screenshot.JPG"}
        ListElement { speed: "1.0"; name: QT_TR_NOOP("Alpine Mountians");     file: "/data/video/OI/Alpine-Mountains_1.0.mp4";                         thumbnail: "/data/video/OI/Alpine-Mountains-Screenshot.JPG"}
        ListElement { speed: "1.0"; name: QT_TR_NOOP("Mediterranean Beach");  file: "/data/video/OI/Mediterranean-Beach_1.0.mp4";                      thumbnail: "/data/video/OI/Mediterranean-Beach-Screenshot.JPG"}
    }

    //Outdoor Interactive Videos
    ListModel {
        id: oiVideosModest

        property int numColumns: 2

        ListElement { speed: "1.7"; name: QT_TR_NOOP("Hills of Bali");        file: "/data/video/OI/BaliTrueFitA_V_Compressed_Cut.mp4";                 thumbnail: "/data/video/OI/Bali_Screenshot.JPG"}
        ListElement { speed: "1.4"; name: QT_TR_NOOP("Australian Outback");   file: "/data/video/OI/AustralianOutbackTrueFitA_V_Compressed_Cut_1.mp4";  thumbnail: "/data/video/OI/Australian-Outback_Screenshot.JPG"}
        ListElement { speed: "1.0"; name: QT_TR_NOOP("Alpine Mountians");     file: "/data/video/OI/Alpine-Mountains_1.0.mp4";                         thumbnail: "/data/video/OI/Alpine-Mountains-Screenshot.JPG"}
        ListElement { speed: "1.0"; name: QT_TR_NOOP("Mediterranean Beach");  file: "/data/video/OI/Mediterranean-Beach_1.0.mp4";                      thumbnail: "/data/video/OI/Mediterranean-Beach-Screenshot.JPG"}
    }

    // Virtual Active Videos
    ListModel {
        id: vaVideos

        property int numColumns: 3

        ListElement { speed: "1.0"; name: QT_TR_NOOP("Wild California Run") ; file: "/data/video/TFRN0104_tfe01.mp4"; thumbnail: "/data/video/TFRN0104.png"}
        ListElement { speed: "1.0"; name: QT_TR_NOOP("Germany Run") ; file: "/data/video/TFRN0103_tfe01.mp4"; thumbnail: "/data/video/TFRN0103.png"}
        ListElement { speed: "1.0"; name: QT_TR_NOOP("Chicago Run") ; file: "/data/video/TFRN0102_tfe01.mp4"; thumbnail: "/data/video/TFRN0102.png"}
        ListElement { speed: "1.0"; name: QT_TR_NOOP("American Southwest II") ; file: "/data/video/TFRN0101_tfe01.mp4"; thumbnail: "/data/video/TFRN0101.png"}
        ListElement { speed: "1.0"; name: QT_TR_NOOP("Trinity Mountains") ; file: "/data/video/TFHK0101_tfe01.mp4"; thumbnail: "/data/video/TFHK0101.png"}
        ListElement { speed: "1.0"; name: QT_TR_NOOP("Northern Italy") ; file: "/data/video/TFBK0101_tfe01.mp4"; thumbnail: "/data/video/TFBK0101.png"}
    }


    // component for video thumbnail to be shown in grid.  Mouse area to select and start video on click
    Component {
        id: videoThumb
        Item {
            property variant myData: model
            width: parent.columnWidth ; height: parent.rowHeight;

            function startThisVideo() {
                videoView.source = file
                videoView.playbackRate = parseFloat(speed)
                root.state = "PlayingState"
                print("Play Video " + file + "(" + name + ")" + " at speed (" + videoView.playbackRate + ")")
                videoView.play()
                miscStats.incrementVideoUsage(file)
            }

            Image { id: thumb ; width: parent.width - 10 * main.screenScaleX ; height: parent.height - 20 * main.screenScaleY ; source: thumbnail ; fillMode: Image.PreserveAspectFit ; anchors.horizontalCenter: parent.horizontalCenter}
            Text {
                anchors { top: thumb.bottom ;horizontalCenter: thumb.horizontalCenter }
                width: parent.width - 10 * main.screenScaleX ; height: 20 * main.screenScaleY ;
                horizontalAlignment: Text.AlignHCenter
                text: qsTr(name) + application.emptyString
            }

            MouseArea {
                anchors.fill: thumb
                preventStealing: true
                onClicked: {
                    parent.startThisVideo()
                }

                Rectangle {
                    id: stimArea

                    anchors.fill: parent
                    color: main.showStimulusArea ? "red" : "transparent"
                    opacity: 0.3
                }
            }
        }
    }

    // grid layout of video thumbnails
    Grid {
        id: videoMenu

        property int columnWidth: (width - (columns-1) * spacing)/columns
        property int rowHeight: (height - spacing)/rows
        columns: root.videoModel.numColumns; rows: 2
        spacing: 15 * main.screenScaleX
        anchors { fill: parent ; margins: 30 * main.screenScaleX }
        horizontalItemAlignment: Grid.AlignHCenter
        verticalItemAlignment: Grid.AlignVCenter

        Repeater {
            model: root.videoModel
            delegate: videoThumb
        }
    }

    function getVideoModel() {
        switch(root.videosPresent) {
            case "oi":
                console.log("case oi, returning oiVideos, root.vidsPresent=" + root.videosPresent)
                if (options.modestyMode)
                    return oiVideosModest
                else
                    return oiVideos
             case "va":
                 console.log("case va, returning vaVideos, root.vidsPresent=" + root.videosPresent)
                 console.log("case va")
                 return vaVideos
             default:
                 console.log("case default")
                 return null
        }
    }

    // Video window to play video
    Video {
        id: videoView
        visible: true
       // backgroundColor: "transparent"
        //videoCodecPriority: ["FFmpeg"]
        fillMode: VideoOutput.PreserveAspectCrop
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.verticalCenter: parent.verticalCenter
        height: parent.height
        width: parent.width - (2 * 10 * main.screenScaleX)
        state: "not-fullscreen"

        onStatusChanged: {
            if(status === MediaPlayer.EndOfMedia) {
                root.stopVideo()
            }
        }

        function toggleState() {
            if(videoView.state === "not-fullscreen") {
                videoView.state = "fullscreen"
            } else {
                videoView.state = "not-fullscreen"
            }
        }

        MouseArea {
            anchors.fill: parent
            onClicked: {
                videoView.toggleState()
            }
        }

        Connections {
            target: audioManager

            onVirtActiveAllowedChanged : {
                if(audioManager.virtActiveAllowed === true) {
                    videoView.muted = false
                } else {
                    videoView.muted = true
                }
            }
        }

        /* This was taken from main.qml, where the full screen video frame was
           handled. The original implementation used a separate VLCSurface to
           display the full screen video, which was not ideal. So fullscreen
           video vs non-fullscreen is handled here and the corresponding data
           overlay was also implemented here.
        */
        VideoDataOverlay {
            id: videoOverlay

            visible: (main.state === "RunState") && videoView.state === "fullscreen"
            isTreadmill: main.isTreadmill
            leftSideDisplay: workoutScreen.sideDataDisplay.leftDisplay
            rightSideDisplay: workoutScreen.sideDataDisplay.rightDisplay

            showHR: heartRateManager.heartRateAvailable
            heartRate: heartRateManager.heartRate
            incline: workoutManager.treadInclineGUI
            speed: workoutScreen.unitState == "ENGLISH" ? workoutManager.treadSpeedGUI : workoutManager.treadSpeedMetricGUI.toFixed(1)
            speedUnits: (workoutScreen.unitState === "ENGLISH" ? qsTr("MPH") : qsTr("KPH") ) + application.emptyString
            rpm: machinecontrol.pedalRPM
            level: workoutManager.workloadLevel
            // show the channel change button only if it is the TV that is fullscreen
            showChannelButton: tv.fullscreen && !tv.isIpodInput
            opacity: 0.5
            enabled: (visible && opacity > 0.0)
            anchors.fill: parent
            showData: (main.state === "RunState")
            onScreenButtonPressed: if(videoView.state === "fullscreen") videoView.toggleState()
            onChannelButtonPressed: {
                if (netpulseAvailable) {
                    if(netpulse.visible)
                        netpulse.hide()
                    else
                        netpulse.showPage("tv")
                }
                else
                    tv_menu.menuOpen = (tv_menu.menuOpen ? false : true)
            }
            onStopButtonPressed: {
                console.log("VideoOverlay: Stop button pressed")
                workoutScreen.stopButtonPressedHandler()
            }
        }

        states: [
            State {
                name: "not-fullscreen"
                PropertyChanges {
                    target: videoView
                    parent: root
                    height: root.height
                    width: root.width - (2 * 10 * main.screenScaleX)
                }
            },
            State {
                name: "fullscreen"
                PropertyChanges {
                    target: videoView
                    parent: main
                    height: main.height
                    width: main.width
                }
            }
        ]
    }


    Column {
        id: controls
        spacing: 15 * main.screenScaleX

        anchors { verticalCenter: parent.verticalCenter ; right: parent.right ; rightMargin: 25 * main.screenScaleX }
        visible: videoView.visible && ! root.fullscreen

        ImageButton{
            id: stopButton

            downimage: main.graphicsPath + "netpulse/GRAYbutton_video_PRESSED.png"
            upimage: main.graphicsPath + "netpulse/GRAYbutton_video.png"
            icon: main.graphicsPath + "netpulse/Stop_icon_BLACK.png"
            onClicked: root.stopVideo()
        }

        ImageButton{
            id: sizeButton

            downimage: main.graphicsPath + "netpulse/GRAYbutton_video_PRESSED.png"
            upimage: main.graphicsPath + "netpulse/GRAYbutton_video.png"
            icon: main.graphicsPath + "netpulse/Fullscreen_icon.png"
            onClicked: videoView.toggleState()
        }

        Connections {
            target: videoView
            onStateChanged: {
                if(videoView.state === "not-fullscreen") {
                    controls.z = videoView.z + 1
                }
            }
        }
    }

    states: [
        State {
            name: "MenuState"
            PropertyChanges { target: videoMenu ; visible: true }
            PropertyChanges { target: videoView; visible: false }
        },
        State {
            name: "PlayingState"
            PropertyChanges { target: videoMenu ; visible: false }
            PropertyChanges { target: videoView; visible: true }
        }
    ]
}
