import QtQuick 2.4
import "string_format.js" as Format
import "program_setup.js" as Fields
import Components 1.0

Item {
    id: c360Content

    property variant model
    property bool saveSelected: false

    signal itemOpened()

    function validate() {
        // if all entries are zero, issue a warning prompt to user and do not start workout
        for (var i = 0; i < c360Content.model.count; i++) {
            if (c360Content.model.get(i).dataValue !== 0) {
                return 0
            }
        }
        invalidEntryWarning.showWithTimeout(5)
        return 1
    }

    function getPhaseTitle(item) {
        switch(item.fieldIndex) {
        case 1: return QT_TR_NOOP("START UP, STRIDE FORWARD");
        case 2: return QT_TR_NOOP("STRIDE FORWARD \n& PUSH ARMS");
        case 3: return QT_TR_NOOP("STAND ON SIDES,\nLEFT ARM ONLY");
        case 4: return QT_TR_NOOP("STAND ON SIDES,\nRIGHT ARM ONLY");
        case 5: return QT_TR_NOOP("REVERSE STRIDE\n& BEND KNEES");
        case 6: return QT_TR_NOOP("STRIDE FORWARD\n& LIFT HEELS");
        case 7: return QT_TR_NOOP("STRIDE FORWARD\n& PULL ARMS");
        case 8: return main.isCSA ? QT_TR_NOOP("HOLD CENTER GRIPS,\nREVERSE STRIDE & LIFT TOES") : QT_TR_NOOP("HOLD SIDE RAILS,\nREVERSE STRIDE & LIFT TOES");
        case 9: return QT_TR_NOOP("STAND ON SIDES, CHANGE GRIP,\nPUSH & PULL ARMS");
        case 10: return QT_TR_NOOP("RECOVER, STRIDE FORWARD");
        default: return "";
        }
    }

    Connections {
        target: main.isTft && setupScreenManager.state === "C360Step2" ? keymapper : null

        onUpButtonPressed: {
            main.debugKeys("upButtonPressed", "SetupCustomC360")
            if (saveSelected) {
                saveSelected = false
                myC360ListView.currentIndex = myC360ListView.count - 1
                return
            }
            myC360ListView.decrementCurrentIndex()
        }

        onDownButtonPressed: {
            main.debugKeys("downButtonPressed", "SetupCustomC360")
            if (saveSelected) return
            if (myC360ListView.currentIndex === myC360ListView.count - 1 && saveItem.visible) {
                saveSelected = true
                return
            }
            myC360ListView.incrementCurrentIndex()
        }

        onLeftButtonPressed: {
            main.debugKeys("leftButtonPressed", "SetupCustomC360")
            if (saveSelected) {
                saveSelected = false
                return
            }
            myC360ListView.currentItem.decrementSlider()
        }

        onRightButtonPressed: {
            main.debugKeys("rightButtonPressed", "SetupCustomC360")
            if (saveSelected) return
            myC360ListView.currentItem.incrementSlider()
        }

        onEnter2Pressed: {
            main.debugKeys("enter2Pressed", "SetupCustomC360")
            if (options.saveWorkoutEnabled && !mainProgItem.saveHasHappened)
                setupScreenManager.state = "SaveWorkoutScreen"
        }
    }

    // Reset saved flag when any data is changed
    Connections {
        target: c360Content.model ? c360Content.model : null
        ignoreUnknownSignals: true
        onDataChanged: {
            mainProgItem.saveHasHappened = false
        }
    }

    MessagePopup {
        id: invalidEntryWarning
        message: qsTr("Cannot Start Workout - All Phases are Set to 0:00") + application.emptyString
        Component.onCompleted: hide()
    }

    ListView {
        id: myC360ListView
        height: main.isTouch ? 700 * main.screenScaleY : 555 * main.screenScaleY
        width: 500 * main.screenScaleX
        model: c360Content.model
        delegate: myStep2Delegate2
        interactive: true
        highlightRangeMode: ListView.ApplyRange
        preferredHighlightBegin: 155
        preferredHighlightEnd: 390
        cacheBuffer: 400
        clip: true
        //interactive: (childrenRect.height > parent.height) ? true : false
    }

    Item {
        id: swipeArrows
        anchors { left: myC360ListView.right ; leftMargin: 10 * main.screenScaleX ; top: myC360ListView.top; topMargin: 50 * main.screenScaleY }
        width: 34 * main.screenScaleX
        height: 529 * main.screenScaleY //127 * 2 + 275
        Image {
            id: up
            source: main.graphicsPath + "200/Swipe_Arrow_Up_Large.png"
            opacity: myC360ListView.contentY > 10 ? 1.0 : 0.0
            anchors { top: parent.top; left: parent.left }
        }

        Image {
            id: down
            source: main.graphicsPath + "200/Swipe_Arrow_Down_Large.png"
            opacity: !myC360ListView.atYEnd ? 1.0 : 0.0
            anchors { bottom: parent.bottom; left: parent.left }
        }

    }

    Text {
        id: prog_setup_desc_text
        anchors.top: parent.top
        anchors.topMargin: 155 * main.screenScaleY
        anchors.right: parent.right
        anchors.rightMargin: 65 * main.screenScaleX
        width: 450 * main.screenScaleX
        text: qsTranslate("Setup", Fields.prog_setup_custom_c360_time_desc) + application.emptyString
        color: "black"
        wrapMode: Text.WordWrap
        horizontalAlignment: Text.AlignRight
        lineHeight: 1.0
        font.pixelSize: text.length > 300 * main.screenScaleX ? 24 * main.screenScaleY : 28 * main.screenScaleY
    }

    Keypad {
        id: keypad

        width: 320 * main.screenScaleX
        anchors.right: parent.right
        anchors.rightMargin: 500 * main.screenScaleX
        anchors.top: parent.top
        anchors.topMargin: 400 * main.screenScaleY
        show_entry: false
        clear_after_enter: true
        visible: main.isTouch
        length:3

        // convert a keypad entered 3-digit value to a quarter of minute value (1 = 0:15 ,etc.)
        function toQuarters(timestring) {
            timestring = timestring.toString()  // ensure it is a string and not a number
            var mins = 0
            if(timestring.length >2 )
                mins = parseInt(timestring[0])
            var secs = parseInt(timestring.slice(-2))
            var seconds = mins*60 + secs
            return seconds / 15
        }

        onValueEntered: {
            if (keypad.value) {
                var quarts = toQuarters(keypad.value).toFixed(0)
                if(quarts > 8)
                    quarts = 8
                mainProgItem.valueEntered = true;
                model.setProperty(myC360ListView.currentIndex, "dataValue", quarts)
                myC360ListView.currentItem.updateSlider(quarts)
                mainProgItem.valueEntered = false
            }
        }

        onKeyPress: {
            if (key != "ENTER") {
                // allow the display of invalid values (fractional quarts, etc.) as keypad value is entered
                // by not setting valueEntered, the slider is not quantizing or limiting input
                var quarts = toQuarters(keypad.value)
                model.setProperty(myC360ListView.currentIndex, "dataValue", quarts)
            }
        }
    }

    Component {
        id: myStep2Delegate2

        Item {
            id: c360DataElement
            state: ListView.isCurrentItem ? "C360Details" : ""
            property real detailsStep2Opacity: 0

            function updateSlider(val) {
                c360SliderObject.value = val
            }

            function incrementSlider(val) {
                c360SliderObject.incrementValue()
            }

            function decrementSlider(val) {
                c360SliderObject.decrementValue()
            }

            width: 425 * main.screenScaleX
            height: 80 * main.screenScaleY
            x: 10 * main.screenScaleX

            Image {
                id: c360Background
                anchors.left: parent.left
                anchors.leftMargin: 5 * main.screenScaleX
                anchors.top: parent.top
                anchors.topMargin: 10 * main.screenScaleY
                width: 425 * main.screenScaleX
                height: parent.height
                source: main.graphicsPath + "setup/Setup_Small_Down.png"
                z: 1

                MouseArea {
                    anchors.fill: parent
                    onClicked: {
                        // round out and save the value of the element we're leaving, in case of leftover keypad input
                        if(keypad.value) {
                            var quarts = keypad.toQuarters(keypad.value).toFixed(0)
                            if(quarts > 8)
                                quarts = 8
                            mainProgItem.valueEntered = true;
                            myC360ListView.model.setProperty(myC360ListView.currentIndex, "dataValue", quarts);
                        }

                        keypad.clear()
                        myC360ListView.currentIndex = index
                    }
                }
            }

            Text {
                id: c360ItemName
                anchors.verticalCenter: c360ItemValue.verticalCenter
                anchors.left: parent.left
                anchors.leftMargin: 20 * main.screenScaleX
                text: {
                    var txt = qsTr(c360Content.getPhaseTitle(model))
                    if (application.currentLanguage != "en")
                        txt = txt.replace("\n", " ")
                    return txt + application.emptyString
                }
                width: 320 * main.screenScaleX
                wrapMode: Text.WordWrap
                font.pointSize: text.length > 50 * main.screenScaleX ? 11 * main.screenScaleY : 14 * main.screenScaleY
                font.bold: true
                smooth: true
                color: "black"
                z: 2
            }
            Text {
                id: c360ItemUnits
                anchors.top: parent.top
                anchors.topMargin: 32 * main.screenScaleY
                anchors.right: parent.right
                anchors.rightMargin: 20 * main.screenScaleX
                text: model.units
                font.pointSize: 14 * main.screenScaleY
                font.bold: true
                smooth: true
                color: "black"
                z: 2
            }
            Text {
                id: c360ItemValue
                anchors.bottom: c360ItemUnits.bottom
                anchors.bottomMargin: -2 * main.screenScaleY
                anchors.right: c360ItemUnits.left
                anchors.rightMargin: 5 * main.screenScaleX
                text: Format.formatTimeString(model.dataValue * 15)
                font.pointSize: 20 * main.screenScaleY
                font.bold: true
                smooth: true
                color: "black"
                z: 2
            }
            Text {
                id: c360ItemUnitsDetails
                anchors.top: parent.top
                anchors.topMargin: 87 * main.screenScaleY
                anchors.right: parent.right
                anchors.rightMargin: 15 * main.screenScaleX
                text: model.units
                font.pointSize: 20 * main.screenScaleY
                font.bold: true
                smooth: true
                color: "black"
                z: 2
                visible: false
            }
            Text {
                id: c360ItemValueDetails
                anchors.bottom: c360ItemUnitsDetails.bottom
                anchors.bottomMargin: -4 * main.screenScaleY
                anchors.right: c360ItemUnitsDetails.left
                anchors.rightMargin: 5 * main.screenScaleX
                text: Format.formatTimeString(model.dataValue * 15)
                font.pointSize: 34 * main.screenScaleY
                font.bold: true
                smooth: true
                color: "black"
                z: 2
                visible: false
            }

            Text {
                id: c360IndexValue
                text: model.selectedIndex
                font.pointSize: 24 * main.screenScaleY
                color: "black"
                visible: false
            }

            Item {
                id: c360Details
                height: 155 * main.screenScaleY
                width: 460 * main.screenScaleX
                anchors.top: c360DataElement.top
                anchors.topMargin: 85 * main.screenScaleY
                anchors.left: c360DataElement.left
                anchors.leftMargin: 50 * main.screenScaleX
                opacity: c360DataElement.detailsStep2Opacity
                Component.onCompleted: {
                    c360SliderObject.value = model.dataValue
                }

                Image {
                    id: c360DataIndicatorBackground
                    anchors.horizontalCenter: parent.horizontalCenter
                    anchors.verticalCenter: parent.verticalCenter
                    source: main.graphicsPath + "setup/Setup_Large_Up_Step2.png"
                }

                SliderControl {
                    id: c360SliderObject

                    onValueChanged: {
                        if (!valueEntered) {
                            myC360ListView.model.setProperty(index, "dataValue", value);
                        }
                    }
                    showValue: false
                    maxValue: model.maxValue
                    minValue: model.minValue
                    value: model.dataValue
                    precision: model.precision
                    stepValue: 1

                    anchors.top: parent.top
                    anchors.topMargin: 75 * main.screenScaleY
                    anchors.left: parent.left
                    anchors.leftMargin: 40 * main.screenScaleX
                    width: 380 * main.screenScaleX
                    height: 34 * main.screenScaleY
                }
            }

            states: [
                State {
                    name: "C360Details"
                    PropertyChanges { target: c360Background; height: 160 * main.screenScaleY; width: 455 * main.screenScaleX; anchors.leftMargin: -1 * main.screenScaleX; anchors.topMargin: 1 * main.screenScaleY; source: main.graphicsPath + "setup/Setup_Large_Up_Step1.png" }
                    PropertyChanges { target: c360ItemValue; visible: false}
                    PropertyChanges { target: c360ItemUnits; visible: false}
                    PropertyChanges { target: c360ItemValueDetails; visible: true }
                    PropertyChanges { target: c360ItemUnitsDetails; visible: true }
                    PropertyChanges { target: c360DataElement; height: 225 * main.screenScaleY } // Fill the entire list area with the detailed view
                    PropertyChanges { target: c360DataElement; detailsStep2Opacity: 1} // Make details visible
                }
            ]

            transitions: [
                Transition {
                    to: "C360Details"
                    reversible: true
                }
            ]
        }
    }

    Text {
        id: pressEnterText
        visible: main.isTft
        font { family: "arial"; pixelSize: 36 * main.screenScaleY; bold: true }
        color: "#000000"
        text: qsTr("press START to begin") + (options.saveWorkoutEnabled ? ", "+qsTr("press ENTER to save") : "") + application.emptyString
        anchors {
            bottom: parent.bottom
            bottomMargin: 70 * main.screenScaleY
            left: parent.left
            leftMargin: 140 * main.screenScaleX
        }
    }

    Text {
        id: bottomHelpText
        visible: main.isTft

        font { family: "arial"; pixelSize: 36 * main.screenScaleY; bold: true }
        color: "#6c6c6c"
        text: qsTr("step 2 of 2") + application.emptyString

        anchors {
            bottom: parent.bottom
            bottomMargin: 25 * main.screenScaleY
            horizontalCenter: parent.horizontalCenter
        }
    }

    Image {
        id: navSelector
        source: main.graphicsPath + "tft/NAV_selector_2.png"
        visible: main.isTft && saveSelected
        smooth: true
        anchors.horizontalCenter: saveItem.horizontalCenter
        anchors.verticalCenter: saveItem.verticalCenter
        anchors.verticalCenterOffset: 25 * main.screenScaleY
    }

    Item {
        id: saveItem
        visible: main.isTft && options.saveWorkoutEnabled
        width: childrenRect.width
        height: childrenRect.height
        ImageButton {
            id: saveButton
            width: 126 * main.screenScaleX
            height: 76 * main.screenScaleY
            fontsize: 16 * main.screenScaleY

            label: qsTr("SAVE?") + (mainProgItem.saveCount > 0 && !mainProgItem.saveHasHappened ? "*" : "") + application.emptyString
            label_under: true
            label_y_offset: 25 * main.screenScaleY
            label_color: "black"
            wrapWidth: 80

            enabled: !mainProgItem.saveHasHappened
            disabledOpacity: 1.0
            upimage: mainProgItem.saveHasHappened ? main.graphicsPath + "tft/nav_icon_SAVED-green.png" : main.graphicsPath + "tft/nav_icon_SAVED.png"
            downimage:upimage
            beep: false
            mouseAreaScale: 0.7
        }
        anchors { bottom: parent.bottom; bottomMargin: 100 * main.screenScaleY; right: parent.right; rightMargin: 100 * main.screenScaleX }
    }
}
