import QtQuick 2.4
import Components 1.0
import Process 0.1

FocusScope {
    id: root
    width: 1366 * main.screenScaleX
    height: 768 * main.screenScaleY

    signal setupWizardComplete()
    signal languageSelected(string lang)

    property bool isNucleus: false
    property bool nucleusUpdateAvailable: nucleusfirmwareloader.isUpdateAvailable
    property bool softwareUpdatesAvailable: checkUpdates.packages.length > 0

    onOpacityChanged: if(opacity) state = "IntroState"

    Loader{
        id: setupWizardScreens
        width: 1366 * main.screenScaleX
        height: 700 * main.screenScaleY
        anchors { fill: parent ; topMargin: 68 * main.screenScaleY }
        source: "Diagnostics/DiagnosticsSetup.qml"
        onLoaded: {
            if(item.hasOwnProperty("isSetupWizard"))
                    item.isSetupWizard = true
        }
    }

    Connections{
        target: setupWizardScreens.item
        ignoreUnknownSignals: true
        onLanguageSelected: {
            languageSelected(lang)
            if (main.isTft)
                root.changeState()
            else
                nextButton.enabled = true
        }
        onItemSelected: {
            if (main.isTft)
                root.changeState()
            else
                nextButton.enabled = true
        }
        onTimeSet: {
            if (main.isTft)
                root.changeState()
        }
        //onInclineCalibrationComplete: nextButton.enabled = true
    }

    Text {
        id: titleText

        font.pointSize: 36 * main.screenScaleY
        anchors { horizontalCenter: root.horizontalCenter ; top: root.top ; topMargin: 10 * main.screenScaleY }
    }

    ImageButton { id: nextButton
        visible: main.isTouch //|| root.state === "TvSetupState"
        downimage: main.graphicsPath + "setup/Start_Button_Down.png"
        upimage: main.graphicsPath + "setup/Start_Button.png"

        label: qsTr("NEXT") + application.emptyString
        label_color: "black"
        label_under: true
        fontsize: 18 * main.screenScaleY

        anchors {
            bottom: parent.bottom ; bottomMargin: 25 * main.screenScaleY
            right: parent.right
//            rightMargin: ( (root.state === "DateTimeState" && main.isTft) ? 48 : 46 ) * main.screenScaleX
            rightMargin: 46 * main.screenScaleX
        }

        onClicked: {
            changeState()
        }
    }

    ImageButton { id: skipTvButton
        downimage: main.graphicsPath + "setup/Start_Button_Down.png"
        upimage: main.graphicsPath + "setup/Start_Button.png"
        visible: false

        label: qsTr("SKIP TV SETUP") + application.emptyString
        label_color: "black"
        label_under: true
        fontsize: 18 * main.screenScaleY

        anchors {
            bottom: parent.bottom ; bottomMargin: 25 * main.screenScaleY
            right: parent.right ; rightMargin: 46 * main.screenScaleX
        }

        onClicked:
        {
            console.log(setupWizardScreens.item.scanner)
            skipTvConfirmation.show()
        }
    }

    ConfirmationPrompt { id: skipTvConfirmation
        x: 303 * main.screenScaleX
        y: 229 * main.screenScaleY
        prompt: qsTr("Skipping TV setup - Are you sure?") + application.emptyString
        Component.onCompleted: hide()
        onYesClicked: { hide(); changeState() }
        onNoClicked: hide()
    }

    function changeState()
    {
        if(root.state === "IntroState") {
            root.state = "LanguageState"
        }
        else if(root.state === "LanguageState") {
            options.setupWizardCompleted = true
            root.state = "ProductStateNucleus"
        }
        else if (root.state === "ProductStateNucleus") {
            root.state = "NetworkState"
        }
        else if(root.state === "OptionState")
            root.state = "NetworkState"
        else if(root.state === "NetworkState") {
            if(isNucleus && root.nucleusUpdateAvailable || root.softwareUpdatesAvailable)
                root.state = "SoftwareUpdateState"
            else
                root.state = "TvSetupState"
        } else if (root.state === "SoftwareUpdateState")
            root.state = "DateTimeState"
        else if(root.state === "DateTimeState"){
            setupWizardScreens.item.saveDateTime()

            root.state = "UnitsState"
        } else if (root.state === "UnitsState") {
            if (isNucleus) {
                root.state = "TvSetupState"
            }

            if(machineinfo.productTypeString === "Treadmill") {
                if (!isNucleus) {
                    root.state = "InclineCalibrationState"
                } else if (isNucleus && !machinecontrol.isCalibrated) {
                    root.state = "InclineCalibrationState"
                } else {
                    root.state = "TvSetupState"
                }
            } else if (machineinfo.modelString === "TS1000" || machineinfo.modelString === "XS1000") {
                root.state = "StrideCalibrationState"
            } else {
                root.state = "TvSetupState"
            }
        }
        else if(root.state === "InclineCalibrationState")
            root.state = "TvSetupState"
        else if (root.state === "StrideCalibrationState")
            root.state = "TvSetupState"
        else if (root.state === "TvSetupState") {
            setupWizardScreens.item.doSave()
            root.state = "SetupCompleteState"
        }
        else if(root.state === "SetupCompleteState")
            setupWizardComplete()
    }

    states: [
        State {name: "IntroState"
            PropertyChanges { target: setupWizardScreens; source: "SetupWizardIntro.qml"}
            PropertyChanges { target: nextButton; enabled: true}
            PropertyChanges { target: titleText; text: "" }
        },
        State {name: "LanguageState"
            PropertyChanges { target: setupWizardScreens; source: "LanguageMenu/LanguageMenu.qml"}
            PropertyChanges { target: nextButton; enabled: false}
            PropertyChanges { target: titleText; text: qsTr("Language") }
        },
        State {name: "ProductStateNucleus"
            PropertyChanges { target: setupWizardScreens; source: "Diagnostics/DiagnosticsSetupNucleus.qml"}
            PropertyChanges { target: nextButton; enabled: true}
            PropertyChanges { target: titleText; text: qsTr("Product Setup") }
        },
        State {name: "OptionState"
            PropertyChanges { target: setupWizardScreens;  source: "Diagnostics/DiagnosticsOption.qml"}
            PropertyChanges { target: nextButton; enabled: true}
        },
        State {name: "NetworkState"
            PropertyChanges { target: setupWizardScreens; source: "Diagnostics/DiagnosticsNetwork.qml"}
            PropertyChanges { target: nextButton; enabled: true}
        },
        State {name: "SoftwareUpdateState"
            PropertyChanges { target: setupWizardScreens; source: "Diagnostics/DiagnosticsUpdate.qml"}
            PropertyChanges { target: nextButton; enabled: true}
        },
        State {name: "DateTimeState"
            PropertyChanges { target: setupWizardScreens; source: "Diagnostics/DiagnosticsClockSetup.qml" }
            PropertyChanges { target: nextButton; visible: main.isTouch && setupWizardScreens.item.state === "TimeZoneState" }
            PropertyChanges { target: nextButton; enabled: true}
            PropertyChanges { target: titleText; text: qsTr("Clock Setup") }
        },
        State {name: "UnitsState"
            PropertyChanges { target: setupWizardScreens; source: "SetupWizardUnits.qml" }
            PropertyChanges { target: nextButton; visible: main.isTouch }
            PropertyChanges { target: nextButton; enabled: true}
            PropertyChanges { target: titleText; text: qsTr("Default System of Units") }
        },
        State {name: "InclineCalibrationState"
            PropertyChanges { target: setupWizardScreens; source: "Diagnostics/DiagnosticsTreadmillCalibration.qml"}
            PropertyChanges { target: nextButton; enabled: true}
            PropertyChanges { target: titleText; text: qsTr("Incline Calibration") }
        },
        State {name: "StrideCalibrationState"
            PropertyChanges { target: setupWizardScreens; source: "Diagnostics/DiagnosticsStrideEllipticalCalibration.qml"}
            PropertyChanges { target: nextButton; enabled: true}
            PropertyChanges { target: titleText; text: qsTr("Stride Calibration") }
        },
        State {name: "InclineCalibrationTestState"
            PropertyChanges { target: setupWizardScreens; source: "Diagnostics/DiagnosticsSummary.qml"}
            PropertyChanges { target: nextButton; enabled: true}
            PropertyChanges { target: titleText; text: qsTr("Summary") }
        },
        State {name: "TvSetupState"
            PropertyChanges { target: setupWizardScreens; source: "Diagnostics/DiagnosticsTVSetup.qml" }
            PropertyChanges { target: nextButton; visible: main.isTouch }
            PropertyChanges { target: nextButton; enabled: setupWizardScreens.item.scanner !== undefined && !setupWizardScreens.item.scanner.scanning }
            PropertyChanges { target: titleText; text: qsTr("TV Setup") }
        },
        State {name: "SetupCompleteState"
            PropertyChanges { target: setupWizardScreens; source: "SetupWizardComplete.qml"}
            PropertyChanges { target: nextButton; enabled: true}
            PropertyChanges { target: titleText; text: ""}

        }
    ]

    // The following process gathers a list of packages that may be updated
    Process {
        id: checkUpdates
        property string packages

        program: "bash"
        arguments: [ "scripts/list_upgrades.sh" ]
        onReadyReadStandardOutput: {
            packages += readAllStandardOutput()
        }
        onStarted: {
            packages = ""
            nucleusfirmwareloader.findHexFile()
            console.log("checking updates")
        }
        onFinished: console.log("packages upgradable:" + packages)
    }
}
