import QtQuick 2.4
import Components 1.0

ModalDialog {
    id: root

    property real oldSpeed
    property real newSpeed
    property bool banner: false

    function show() {
        if(!banner) {
            main._dialogShowing = true
            dialogManager.alertShown(root)
        }
        visible = true
    }

    function hide() {
        root.stopTimer()
        visible = false
        main._dialogShowing = false
        dialogManager.alertHidden(root)
    }

    state: banner ?  "banner" : "dialog"

    states: [
        State {
            name: "dialog"
            AnchorChanges {
                target: root
                anchors { horizontalCenter: parent.horizontalCenter ; verticalCenter: parent.verticalCenter }
            }
            PropertyChanges { target: root ; width: dialogBorder.width ; height: dialogBorder.height }
            PropertyChanges { target: bannerBackground ; visible: false }
            PropertyChanges { target: dialogBorder ; visible: true }
            PropertyChanges { target: speedChangeValue ; font.pixelSize: 64 * main.screenScaleY }
            PropertyChanges { target: speedChangeIndicator ; anchors.verticalCenterOffset: 50 * main.screenScaleY ; anchors.leftMargin: 50 * main.screenScaleX ; arrowScale: 1.0 }
            ParentChange { target: speedChangeIndicator ; parent: dialogBorder }
            ParentChange { target: speedChangeText ; parent: dialogBorder }
            AnchorChanges {
                target: speedChangeText
                anchors { top: parent.top ;  verticalCenter: undefined }
            }

            ParentChange { target: countdownText; parent: dialogBorder }
            PropertyChanges { target: countdownText; font.pixelSize: 96 * main.screenScaleY ; anchors.rightMargin: 100 * main.screenScaleX}
        },
        State {
            name: "banner"
            AnchorChanges {
                target: root
                anchors { horizontalCenter: parent.horizontalCenter ; verticalCenter: undefined }
            }
            PropertyChanges { target: root ; width: bannerBackground.width ; height: bannerBackground.height ; y:0 }
            PropertyChanges { target: bannerBackground ; visible: true }
            PropertyChanges { target: dialogBorder ; visible: false }
            PropertyChanges { target: speedChangeValue ; font.pixelSize: 40 * main.screenScaleY }

            PropertyChanges { target: speedChangeIndicator ; anchors.verticalCenterOffset: 0 ; anchors.leftMargin: 30 * main.screenScaleX ; arrowScale: 0.7}
            ParentChange { target: speedChangeIndicator ; parent: bannerBackground }
            ParentChange { target: speedChangeText ; parent: bannerBackground }
            AnchorChanges {
                target: speedChangeText
                anchors { top: undefined; verticalCenter: parent.verticalCenter }
            }
            ParentChange { target: countdownText; parent: bannerBackground}
            PropertyChanges { target: countdownText; font.pixelSize: 40 * main.screenScaleY; anchors.rightMargin: 10 * main.screenScaleX}
        }

    ]

    BorderImage {   // pop-up dialog background
        id: dialogBorder

        visible: !root.banner
        anchors.horizontalCenter: root.horizontalCenter
        anchors.verticalCenter: root.verticalCenter
        width: 800 * main.screenScaleX
        height: 350 * main.screenScaleY
        source: main.graphicsPath + "Pop_Up_Lrg_Grey.png"
        border { top: 152 * main.screenScaleY; bottom: 165 * main.screenScaleY; left: 145 * main.screenScaleX; right: 144 * main.screenScaleX }

    }

    // Speed change banner
    BorderImage {   // pop-up dialog background
        id: bannerBackground

        visible: root.banner
        width: 931 * main.screenScaleX
        height: 86 * main.screenScaleY

        source: main.graphicsPath + "Pop_Up_Narrow_Grey.png"
        border { top: 10 * main.screenScaleY; bottom: 10 * main.screenScaleY; left: 10 * main.screenScaleX; right: 10 * main.screenScaleX}
    }

    Text {
        id: speedChangeText

        color: "#ffffff"
        text: qsTr("SPEED CHANGE") + application.emptyString
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.topMargin: 35 * main.screenScaleY
        horizontalAlignment: Text.AlignHCenter
        wrapMode: Text.WordWrap
        font.bold: true
        font.pixelSize: 40 * main.screenScaleY
    }

    Text { // show count down to timeout of prompt (started by startTimeout(seconds) method of ModalDialog superclass
        id: countdownText

        color: "#ffffff"

        // display count down (with a leading 0 if remaining seconds < 10
        text: ":" + ((countDown.toString().length < 2) ? "0" : "") + countDown
        font.bold: true
        font.pixelSize: 96 * main.screenScaleY

        anchors.right: parent.right
        anchors.verticalCenter: speedChangeIndicator.verticalCenter
    }

    Row {
        id: speedChangeIndicator

        property real arrowScale: 1.0

        spacing: 20 * main.screenScaleX
        anchors.left: parent.left ; anchors.leftMargin: 30 * main.screenScaleX
        anchors.verticalCenter: parent.verticalCenter

        Image{
            id: speedChangeArrow
            source: main.graphicsPath + "224/SPEEDCHANGE_arrow.png"
            transformOrigin: Item.Center
            rotation: newSpeed > oldSpeed ? 0 : 180
            scale: speedChangeIndicator.arrowScale
            anchors.verticalCenter: parent.verticalCenter
        }

        Text { // show count down to timeout of prompt (started by startTimeout(seconds) method of ModalDialog superclass
            id: speedChangeValue

            x: 350 * main.screenScaleX
            y: 168 * main.screenScaleY
            color: "#ffffff"

            // display count down (with a leading 0 if remaining seconds < 10
            text: workoutScreen.unitState === "METRIC" ? Globals.mileToKm(newSpeed).toFixed(1) + " KPH" : newSpeed.toFixed(1) + " MPH"
            font.bold: true
            font.pixelSize: 64 * main.screenScaleY

            anchors.verticalCenter: parent.verticalCenter
        }
    }
}
