// import QtQuick 2.4 // to target S60 5th Edition or Maemo 5
import QtQuick 2.4
import ".."
import Components 1.0

ModalDialog {
    id: root

    property string iconsSource: "qml/" + main.graphicsPath+ "TvIcons/default/channelIcons/"
    property bool listenKeys: false

    signal iconSelected(string iconSource)
    signal exitSelected()

    function loadIconList() {
        var images = storageMgr.listFiles(root.iconsSource, ["*.png", "*.jpg"])
        iconListModel.clear()
        for (var i = 0; i < images.length; i++) {
            if (images[i].indexOf("tv_default") >= 0){
                iconListModel.insert(0, {imageSource: images[i]})
                continue
            }
            iconListModel.append({ imageSource: images[i] })
        }
        gridView.currentIndex = 0
    }

    Connections {
        target: main.isTft && root.listenKeys ? keymapper : null

        onBackPressed: {
            main.debugKeys("backPressed", "IconSelectorPopup")
            root.hide()
            root.exitSelected()
        }
    }

    Component.onCompleted: loadIconList()

    onVisibleChanged: {
        if (!visible) {
            gridView.currentIndex = 0
            gridView.contentY = 0
        }
    }

    ListModel {
        id: iconListModel

        ListElement { imageSource: "fx.png" }
    }

    Rectangle {   // pop-up dialog background
        id: border

        x: parent.x
        y: parent.y
        width: parent.width
        height: parent.height
        color: "white"
        clip: true

        Image {
            visible: main.isTouch
            anchors.right: parent.right
            anchors.top: parent.top
            anchors.topMargin: 20 * main.screenScaleY
            anchors.rightMargin: 20 * main.screenScaleX
            source: "../" + main.graphicsPath + "Keypad/KeyPad_X_Large.png"
            z:1000
            MouseArea {
                anchors.fill: parent
                onClicked: {
                    hide()
                    exitSelected()
                }
            }
        }

        Item {
            id: dataArrows

            width: 40 * main.screenScaleX
            height: parent.height
            z:1000
            anchors { top: parent.top; right: parent.right ; rightMargin: ( Qt.application.layoutDirection === Qt.RightToLeft ? -20 : -5 ) * main.screenScaleX }
            Image {
                id: dataUpArrow
                visible: !gridView.atYBeginning
                source: "../" + main.graphicsPath + "Swipe_Arrows_Left.png"
                rotation: 90
                anchors { top: parent.top; topMargin: 35 * main.screenScaleY; right: parent.right }
            }
            Image {
                id: dataDownArrow
                visible: !gridView.atYEnd
                source: "../" + main.graphicsPath + "Swipe_Arrows_Right.png"
                rotation: 90
                anchors { bottom: parent.bottom; bottomMargin: 35 * main.screenScaleY; right: parent.right }
            }
        }

        GridView {
            id: gridView

            Connections {
                target: main.isTft && root.listenKeys ? keymapper : null

                onUpButtonPressed: {
                    main.debugKeys("upButtonPressed", "IconSelectorPopup")
                    gridView.moveCurrentIndexUp()
                }

                onDownButtonPressed:{
                    main.debugKeys("downButtonPressed", "IconSelectorPopup")
                    gridView.moveCurrentIndexDown()
                }

                onLeftButtonPressed:{
                    main.debugKeys("leftButtonPressed", "IconSelectorPopup")
                    gridView.moveCurrentIndexLeft()
                }

                onRightButtonPressed:{
                    main.debugKeys("rightButtonPressed", "IconSelectorPopup")
                    gridView.moveCurrentIndexRight()
                }

                onEnter2Pressed: {
                    main.debugKeys("enter2Pressed", "IconSelectorPopup")
                    gridView.currentItem.selectIcon()
                }

            }

            Image {
                id: highlightImage
                visible: main.isTft
                source: "../" + main.graphicsPath + "tft/TV_menus_cursor.png"
                x: gridView.currentItem ? (gridView.currentItem.x - 11 * main.screenScaleX - gridView.contentX) : -11 * main.screenScaleX
                y: gridView.currentItem ? (gridView.currentItem.y - 11 * main.screenScaleY - gridView.contentY) : -11 * main.screenScaleY
            }
            width: parent.width; height: parent.height
            anchors.fill: parent
            anchors {
                leftMargin: 25 * main.screenScaleX
                rightMargin: 25 * main.screenScaleX
                topMargin: 25 * main.screenScaleY
            }

            cellWidth: 170 * main.screenScaleX
            cellHeight: 153 * main.screenScaleY
            model: iconListModel
            delegate: Component {
                Rectangle {
                    function selectIcon(){
                        root.iconSelected(model.imageSource)
                    }
                    color: main.showStimulusArea ? "red" : "white"
                    opacity: main.showStimulusArea ? 0.3 : 1
                    width: 170 * main.screenScaleX
                    height: 153 * main.screenScaleY
                    Image {
                        anchors.fill: parent
                        source: "../" + main.graphicsPath + "TvIcons/default/channelIcons/" + model.imageSource
                        MouseArea {
                            anchors.fill: parent
                            onClicked: {
                                selectIcon()
                            }
                        }
                    }

                }
            }
        }
    }

}
