// Television control buttons for channel guide, fullscreen, and stop/turn-off.

import QtQuick 2.4
import Components 1.0

Item{
    id: root

    property int ccOptions: 0
    property int ccTrack: 0
    property bool showChannelButton: true
    property bool tuning: false
    property bool showSizeButton: true
    property string currentChannelName
    property bool allowFullscreen: true
    property bool acceptKeys: false
    property bool showTftButtonHelp: true
    property bool showMenuHelp: true
    property bool allowTftCc: false
    property bool showChannelNumber: true

    signal stop()
    signal openMenu()
    signal ccClicked()
    signal sizeButtonClicked()
    signal menuButtonClicked()
    signal channelUpClicked()
    signal channelDownClicked()

    Connections {
        target: main.isTft && !main.blockKeys && root.visible && root.acceptKeys ? keymapper : null

        onStartPressed: {
            main.debugKeys("startPressed", "TelevisionControls")
            if (!root.allowTftCc)
                return

            if (root.ccOptions > 0)
                root.ccClicked()
        }

        onDoubleLeftPressed: {
            main.debugKeys("doubleLeftPressed", "TelevisionControls")
            root.channelDownClicked()
        }

        onDoubleRightPressed: {
            main.debugKeys("doubleRightPressed", "TelevisionControls")
            root.channelUpClicked()
        }
    }

    //Rectangle { anchors.fill: parent ; color: "blue" ; opacity: 0.1 }
    Column{
        id: topHalf

        visible: root.showChannelButton && main.isTouch
        spacing: 0
        //anchors.fill: parent
        anchors { horizontalCenter: parent.horizontalCenter ; top: parent.top }

        ImageButton{
            id: channelButton

            anchors { horizontalCenter: parent.horizontalCenter ; horizontalCenterOffset: 5 * main.screenScaleX }
            downimage: main.graphicsPath + "205/IPOD_Wheel_Center_Down.png"
            upimage: main.graphicsPath + "205/IPOD_Wheel_Center_Up.png"
            icon: main.graphicsPath + "Media_Icon_Remote.png"
            icon_x_offset: -3 * main.screenScaleX
            onClicked: root.openMenu();
            opacity: options.cabEnabled ? 0 : 1.0
        }

        Text {
            id: channel_text
            text: qsTr("CHANNEL") + application.emptyString
            font.bold: true
            font.pixelSize: 12 * main.screenScaleY
            anchors.horizontalCenter: parent.horizontalCenter
            opacity: options.cabEnabled ? 0 : 1.0
        }

        Row {
            id: channelRow

            spacing: 0
            anchors.horizontalCenter: parent.horizontalCenter
            visible: main.isTouch

            ImageButton {
                id: channel_down_button

                repeat: false
                upimage: main.graphicsPath + "Media_Channel_Left.png"
                downimage: main.graphicsPath + "Media_Channel_Left_Pressed.png"
                icon: main.graphicsPath + "netpulse/MINUS_icon_BLACK.png"
                //icon_y_offset: -5 * main.screenScaleY

                onClicked: root.channelDownClicked()
                mouseAreaScale: 1.25
            }

            // channel numeric display
            Text {
                id: channel_value

                width: 80 * main.screenScaleX
                height: parent.height
                text: root.showChannelNumber ? root.currentChannelName : ""
                anchors.verticalCenter: parent.verticalCenter
                horizontalAlignment: Text.AlignHCenter
                verticalAlignment: Text.AlignVCenter
                font.bold: true
                font.pixelSize: 30 * main.screenScaleY
            }

            ImageButton {
                id: channel_up_button

                repeat: false
                icon: main.graphicsPath + "netpulse/PLUS_icon_BLACK.png"
                icon_x_offset: -2 * main.screenScaleX
                upimage: main.graphicsPath + "Media_Channel_Right.png"
                downimage: main.graphicsPath + "Media_Channel_Right_Pressed.png"
                onClicked: root.channelUpClicked()
                mouseAreaScale: 1.25
            }

        } // channel up/down
    }

    Column {
        id: bottomHalf

        visible: main.isTouch
        anchors {
            bottom: parent.bottom
            bottomMargin: 5 * main.screenScaleY
            horizontalCenter: parent.horizontalCenter
        }

        ImageButton{
            id: ccButton

            anchors.horizontalCenter: parent.horizontalCenter

            visible: root.ccOptions > 0
            downimage: main.graphicsPath + "netpulse/GRAYbutton_video_PRESSED.png"
            upimage: main.graphicsPath + "netpulse/GRAYbutton_video.png"
            icon: main.graphicsPath + "CC_icon.png"
            onClicked: root.ccClicked()
            opacity: options.cabEnabled ? 0 : 1.0
        }
        Text {
            visible: root.ccOptions > 0
            text: root.ccTrack ? root.ccTrack : qsTr("OFF") + application.emptyString
            width: 0  // don't consider width of this label in positioning of parent button
            anchors { left: ccButton.right; verticalCenter: ccButton.verticalCenter }
//            x: 77 * main.screenScaleX
//            y: 25 * main.screenScaleY
            opacity: options.cabEnabled ? 0 : 1.0
        }

        Row {
            spacing: 20 * main.screenScaleX

            anchors.horizontalCenter: parent.horizontalCenter

            ImageButton{
                id: stopButton

                downimage: main.graphicsPath + "netpulse/GRAYbutton_video_PRESSED.png"
                upimage: main.graphicsPath + "netpulse/GRAYbutton_video.png"
                icon: main.graphicsPath + "netpulse/Stop_icon_BLACK.png"
                onClicked: root.stop()
            }

            ImageButton{
                id: sizeButton

                visible: root.showSizeButton && root.allowFullscreen
                downimage: main.graphicsPath + "netpulse/GRAYbutton_video_PRESSED.png"
                upimage: main.graphicsPath + "netpulse/GRAYbutton_video.png"
                icon: main.graphicsPath + "netpulse/Fullscreen_icon.png"
                onClicked: root.sizeButtonClicked()

            }
        } // end Row
    }

    Item {
        id: medVideoControls
        visible: main.isTft && root.showTftButtonHelp
        width: 200 * main.screenScaleX
//        height: 250 * main.screenScaleY
        height: (video0.visible ? 300 : 250) * main.screenScaleY
        anchors {
            bottom: parent.bottom
            bottomMargin: 20 * main.screenScaleY
            left: parent.left
            leftMargin: 20 * main.screenScaleX
        }

        Item {
            id: video0
            visible: root.allowTftCc && root.ccOptions > 0
            width: 182 * main.screenScaleX
            height: 50 * main.screenScaleY
            anchors.left: parent.left
            anchors.top: parent.top
            anchors.topMargin: 35 * main.screenScaleY
            Image {
                source: main.graphicsPath + "CC_icon.png"
                x: 0
                y: -8 * main.screenScaleY
            }
            Image {
                source: main.graphicsPath + "tft/equals.png"
                x: 62 * main.screenScaleX
            }
            Text {
                text: qsTr("START") + application.emptyString
                font { pixelSize: 18 * main.screenScaleY; family: "arial"; bold: true }
                x: 111 * main.screenScaleX
            }
        }

        Text {
            id: video1
            width: 182 * main.screenScaleX
            height: 50 * main.screenScaleY
            anchors.left: parent.left
            anchors.top: video0.visible ? video0.bottom : parent.top
            anchors.topMargin: ( video0.visible ? 10 : 45 ) * main.screenScaleY
            visible: root.allowFullscreen
            Image {
                source: main.graphicsPath + "netpulse/Fullscreen_icon.png"
                x: 0
                y: -15 * main.screenScaleY
            }
            Image {
                source: main.graphicsPath + "tft/equals.png"
                x: 62 * main.screenScaleX
            }
            Text {
                text: qsTr("ENTER") + application.emptyString
                font { pixelSize: 18 * main.screenScaleY; family: "arial"; bold: true }
                x: 111 * main.screenScaleX
            }
        }

        Text {
            id: video2
            width: 182 * main.screenScaleX
            height: 50 * main.screenScaleY
            anchors.left: parent.left
            anchors.top: video1.bottom
            anchors.topMargin: 10 * main.screenScaleY
            visible: root.showMenuHelp
            Image {
                id: v2_image
                source: main.graphicsPath + "Media_Icon_Remote.png"
                x: 0
                y: -20 * main.screenScaleY
            }
            Image {
                id: v2_equals
                source: main.graphicsPath + "tft/equals.png"
                x: 62 * main.screenScaleX
            }
            Image {
                id: v2_arrows
                source: main.graphicsPath + "netpulse/audio_button_TV.png"
                x: 111 * main.screenScaleX
                y: -20 * main.screenScaleY
            }
        }

        Text {
            id: video3
            width: 182 * main.screenScaleX
            height: 50 * main.screenScaleY
            anchors.left: parent.left
            anchors.top: video2.visible ? video2.bottom : video1.bottom
            anchors.topMargin: 10 * main.screenScaleY
            visible: true
            Text {
                text: qsTr("CHAN") + application.emptyString
                font { pixelSize: 18 * main.screenScaleY; family: "arial"; bold: true }
                x: 0
                y: 3 * main.screenScaleY
            }
            Image {
                source: main.graphicsPath + "tft/equals.png"
                x: 62 * main.screenScaleX
            }
            Text {
                text: "<img src=" + main.graphicsPath + "tft/REW_icon.png\" /> &nbsp;<img src=" + main.graphicsPath + "tft/FWD_icon.png\" />"
                x: 111 * main.screenScaleX
            }
        }
        Image {
            id: video4
            source: main.graphicsPath + "tft/vol-up-down_icons.png"
            height: implicitHeight
            anchors.left: parent.left
            anchors.leftMargin: 6 * main.screenScaleX
            anchors.top: video3.bottom
            anchors.topMargin: 10 * main.screenScaleY
        }
    }

}
