import QtQuick 2.4
import "string_format.js" as StrFormat
import Components 1.0
import TrueTouch 1.0

Rectangle{
    id: root

    property bool showHUD: false
    property bool bikeModeEnabled: machinecontrol.machineMode === MachineControl.MODE_CONSTANT_TORQUE && machineinfo.productTypeString == "Bike"
    property string textColor: "black"
    property variant leftSideDisplay
    property variant rightSideDisplay
    property int leftSideCounter: 0
    property int rightSideCounter: 0
    property bool isTreadmill: main.isTreadmill
    property real speed: workoutScreen.unitState == "ENGLISH" ? (workoutManager.treadSpeedGUI/10).toFixed(1) : (workoutManager.treadSpeedMetricGUI/10.0).toFixed(1)
    property string speedUnits: (workoutScreen.unitState === "ENGLISH" ? qsTr("MPH") : qsTr("KPH") ) + application.emptyString
    property bool showHR: heartRateManager.heartRateAvailable
    property int targetHR: aWorkoutRunData.targetHeartRate
    property bool targetHRAvailable: workoutScreen.hrTargetVisibility
    property bool showHeadsetButton: true

    color: "grey"

    signal sizeClicked()
    signal stopButtonPressed()

    function reset() {
        root.showData = true
        leftSideCounter = 0
        rightSideCounter = 0
        dataTimer.restart()
    }

     Row{
        id:displayBar

        width: parent.width
        visible: showHUD
        height: showHUD ? 103 * main.screenScaleY : 0
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.top: parent.top
        spacing: 2 * main.screenScaleX

        BorderImage{
            id: leftDisplay

            height: parent.height
            width: 370 * main.screenScaleX
            source:main.graphicsPath + "FullscreenVideo_bar.png"
            Text{
                id: leftLabelText

                anchors { top: parent.top ; topMargin: 10 * main.screenScaleY ; left: parent.left ; leftMargin: 30 * main.screenScaleX }
                font.pixelSize: 20 * main.screenScaleY
                font.bold: true
                color: textColor
                text: leftSideCounter === -1 || !root.visible ? "" : qsTranslate(leftSideDisplay.sourceFile, leftSideDisplay.displayModel.get(leftSideCounter).label)
            }

            Text{
                id: leftValueText

                anchors { bottom: parent.bottom ; bottomMargin: 0 ; left: parent.left ; leftMargin: 30 * main.screenScaleX }
                font.pixelSize: 50 * main.screenScaleY
                font.bold: true
                color: textColor
                text: leftSideCounter === -1 || !root.visible ? "--" : leftSideDisplay.getData(leftSideCounter)
            }

            Text {
                id: leftUnitText

                anchors { left: leftValueText.right ; leftMargin: 8 * main.screenScaleX ; baseline: leftValueText.baseline }
                font.pointSize: 12 * main.screenScaleY
                font.bold: true
                text: leftSideCounter === -1 || !root.visible ? "" : leftSideDisplay.getUnit(leftSideCounter)
                color: "black"
            }
        }

        BorderImage{
            id: levelDisplay

            height: parent.height
            width: 206 * main.screenScaleX
            source:main.graphicsPath + "FullscreenVideo_bar.png"

            function getIcon()
            {
                if( isTreadmill )
                    return main.graphicsPath + "netpulse/WORKLOAD-INCLINE_icon_GRAY.png"
                else if(bikeModeEnabled)
                    return main.graphicsPath + "224/GEAR-LEVEL_icon_bikemode.png"
                else
                    return main.graphicsPath + "224/WORKLOADlevel_icon_GRAY.png"
            }

            function getLabel()
            {
                if(root.isTreadmill) {
                    return qsTr("INCLINE")
                }
                else if(bikeModeEnabled)
                    return qsTr("GEAR")
                else
                    return qsTr("LEVEL")
            }

            Text{
                id: levelLabelText

                anchors { bottom: parent.bottom ; bottomMargin: 10 * main.screenScaleY ; horizontalCenter: parent.horizontalCenter ; horizontalCenterOffset: -15 * main.screenScaleX }
                font.pixelSize: 20 * main.screenScaleY
                font.bold: true
                color: textColor
                text: levelDisplay.getLabel() + application.emptyString
            }

            Text{
                id: levelValueText
                anchors { bottom: levelLabelText.top ; bottomMargin: -10 * main.screenScaleY ; horizontalCenter: levelLabelText.horizontalCenter ; horizontalCenterOffset: 0 }
                font.pixelSize: 50 * main.screenScaleY
                font.bold: true
                color: textColor
                text: root.isTreadmill ? (workoutManager.treadInclineGUI/10.0).toFixed(1) : workoutManager.workloadLevel
            }

            Text{
                id: levelUnitText
                anchors { baseline: levelValueText.baseline; left: levelValueText.right }
                font.pixelSize: 12 * main.screenScaleY
                font.bold: true
                color: textColor
                text: root.isTreadmill ? (qsTr("%") + application.emptyString) : ""
            }

            Image {
                anchors { top: parent.top ; topMargin: 10 * main.screenScaleY ; right: parent.right ; rightMargin: 10 * main.screenScaleX }
                source: levelDisplay.getIcon()
            }
        }

        BorderImage{
            id: bpmDisplay

            property bool showingTarget: (rightSideCounter & 1) && root.targetHRAvailable
            height: parent.height
            width: 206 * main.screenScaleX
            source:main.graphicsPath + "FullscreenVideo_bar.png"

            Text{
                id: bpmDisplayLabel

                visible: root.showHR
                anchors { bottom: parent.bottom ; bottomMargin: 10 * main.screenScaleY ; horizontalCenter: parent.horizontalCenter }
                font.pixelSize: 20 * main.screenScaleY
                font.bold: true
                color: textColor
                text: bpmDisplay.showingTarget ? qsTr("TARGET") : qsTr("BPM")
            }

            Text{
                id:bpmDisplayValue
                visible: root.showHR
                anchors.bottom: bpmDisplayLabel.top
                anchors { bottomMargin: -10 * main.screenScaleY ; horizontalCenter: bpmDisplayLabel.horizontalCenter ; horizontalCenterOffset: 0 }
                font.pixelSize: 50 * main.screenScaleY
                font.bold: true
                color: textColor
                text: bpmDisplay.showingTarget ? root.targetHR : aWorkoutRunData.heartRate.toFixed(0)
            }

            BeatingHeart {
                id: hrIcon

                visible: root.showHR
                anchors { right: parent.right ; rightMargin: 5 * main.screenScaleX ; verticalCenter: bpmDisplayValue.verticalCenter }
            }
        }

        BorderImage{
            id: rpmSpeedDisplay

            height: parent.height
            width: 206 * main.screenScaleX
            source:main.graphicsPath + "FullscreenVideo_bar.png"

            Text{
                id: rpmSpeedDisplayLabel
                anchors { bottom: parent.bottom ; bottomMargin: 10 * main.screenScaleY ; horizontalCenter: parent.horizontalCenter ; horizontalCenterOffset: 15 * main.screenScaleX }
                font.pixelSize: 20 * main.screenScaleY
                font.bold: true
                color: textColor
                text: (root.isTreadmill ? qsTr("SPEED") : qsTr("RPM")) + application.emptyString
            }

            Text{
                id: rpmSpeedDisplayValue
                anchors { bottom: rpmSpeedDisplayLabel.top ; bottomMargin: -10 * main.screenScaleY ; horizontalCenter: rpmSpeedDisplayLabel.horizontalCenter ; horizontalCenterOffset: 0 }
                font.pixelSize: 50 * main.screenScaleY
                font.bold: true
                color: textColor
                text: root.isTreadmill ? root.speed.toFixed(1) : aWorkoutRunData.rpm.toFixed(0)
            }

            Text{
                id: rpmSpeedDisplayUnits
                anchors { baseline: rpmSpeedDisplayValue.baseline ; left: rpmSpeedDisplayValue.right }
                font.pixelSize: 10 * main.screenScaleY
                font.bold: true
                color: textColor
                text: root.isTreadmill ? (speedUnits + application.emptyString) : ""
            }

            Image{
                anchors { top: parent.top ; topMargin: 10 * main.screenScaleY ; left: parent.left ; leftMargin: 10 * main.screenScaleX }
                source: main.graphicsPath + "netpulse/PACE-SPEED_icon_GRAY.png"
            }
        }

        BorderImage{
            id: rightDisplay
            height: parent.height
            width: 370 * main.screenScaleX
            source:main.graphicsPath + "FullscreenVideo_bar.png"

            Text{
                id: rightLabelText

                anchors { top: parent.top ; topMargin: 10 * main.screenScaleY ; right: parent.right ; rightMargin: 30 * main.screenScaleX }
                font.pixelSize: 20 * main.screenScaleY
                font.bold: true
                color: textColor
                text: rightSideCounter === -1 || !root.visible ? "" : qsTranslate(rightSideDisplay.sourceFile, rightSideDisplay.displayModel.get(rightSideCounter).label)
            }

            Text{
                id: rightValueText

                anchors { bottom: parent.bottom ; bottomMargin: 0 ; right: rightUnitText.left ; rightMargin: 8 * main.screenScaleX }
                font.pixelSize: 50 * main.screenScaleY
                font.bold: true
                color: textColor
                text: rightSideCounter === -1 || !root.visible ? "--" : rightSideDisplay.getData(rightSideCounter)
            }

            Text {
                id: rightUnitText

                anchors { right: parent.right ; rightMargin: 10 * main.screenScaleX ; baseline: rightValueText.baseline}
                font.pointSize: 12 * main.screenScaleY
                font.bold: true
                text: rightSideCounter === -1 || !root.visible ? "" : rightSideDisplay.getUnit(rightSideCounter)
                color: "black"
            }
        }
    }

    Rectangle{
        id: tvControlsBar

        anchors { top: displayBar.bottom ; right: parent.right ; bottom: parent.bottom }
        color:"transparent"
        width: visible ? 183 * main.screenScaleX : 0
        // show the tv controls if there's enough room for them
        visible: showHUD

        VolumeControls{
            id: volumeControls
            anchors.horizontalCenter: parent.horizontalCenter
            muteButtonDownimage: main.graphicsPath + "netpulse/GRAYbutton_video_PRESSED.png"
            muteButtonUpimage: main.graphicsPath + "netpulse/GRAYbutton_video.png"
            showHeadsetButton: root.showHeadsetButton

            // synchronize the control display with actual volume if changed elsewhere
            Connections {
                target: audioManager
                onVolumeChanged:
                    if(audioManager.volume != volumeControls.percent)
                        volumeControls.vol_setting = audioManager.volume * (volumeControls.vol_max - volumeControls.vol_min)/100
                onMuteChanged: volumeControls.muted = audioManager.mute
            }

            onMutedChanged: audioManager.setMute(muted)
            onPercentChanged: audioManager.setVolume(percent)
            onBluetoothHeadsetButtonClicked: {
                if(bluetoothAdapter.connectedHeadset === true){
                    bluetoothAdapter.disconnectHeadset()
                } else {
                    btDeviceSelectionDialog.show()
                    btDeviceSelectionDialog.state = "list"
                }
            }
        }

        ImageButton{
            id: sizeButton

            anchors { horizontalCenter: parent.horizontalCenter ; top: volumeControls.bottom ; topMargin: -100 * main.screenScaleY }
            downimage: main.graphicsPath + "netpulse/GRAYbutton_video_PRESSED.png"
            upimage: main.graphicsPath + "netpulse/GRAYbutton_video.png"
            icon: main.graphicsPath + "netpulse/Fullscreen_icon.png"
            onClicked: root.sizeClicked()
        }

        ImageButton {
            id: stopButton

            anchors { bottom: parent.bottom ; bottomMargin: 15 * main.screenScaleY ; right: parent.right ; rightMargin: 20 * main.screenScaleX }
            fontsize: 14 * main.screenScaleY
            label_color: "black"
            label_under: true
            downimage: main.graphicsPath + "224/224_Data_Stop_Down.png"
            upimage: main.graphicsPath + "224/224_Data_Stop_Disabled.png"
            label: qsTr("STOP") + "/" + qsTr("PAUSE") + application.emptyString
            label_y_offset: 10 * main.screenScaleY
            visible: true

            onClicked: {
                root.sizeClicked()
                root.stopButtonPressed()
            }
            mouseAreaScale: 1.75
        }
    }

    Timer {
        id: dataTimer
        interval: 5000
        repeat: true
        running: true
        onTriggered: {
            if (!root.visible)
                return // avoid unnecessary processing
            rightSideCounter = rightSideDisplay.getNextIndex(rightSideCounter)
            leftSideCounter = leftSideDisplay.getNextIndex(leftSideCounter)
        }
    }
} // end fullScreenTV
