import QtQuick 2.4
import VLCVideo 1.0
import Components 1.0

Image {

    id: root

    signal close()
    signal openMenu()

    property alias screen: tvContainer
    property bool tunedToCabChannel: tv.tunedToCab()

    source: main.graphicsPath + "netpulse/Center_Gray_Box.png"

    // background mouse area to mask any areas underneath this pop-up
    MouseArea {
        anchors.fill: parent
    }

    Row {
        id: tvRow
        anchors.fill: parent
        anchors.leftMargin: 23 * main.screenScaleX

        Rectangle {
            id: tvContainer

            color: "black"
            width: 720 * main.screenScaleX
            height: 405 * main.screenScaleY
            anchors.verticalCenter: parent.verticalCenter

            VLCSurface {
                id: vlcSurface
                player: tv.player
                playing: root.visible && (tv.playing || tv.tuning)
                aspect: tv.aspect
                onPlayingChanged: print("TV window playing:" + playing)
                anchors.fill: parent
            }

        }

        Item {
            width: 200 * main.screenScaleX

            anchors {
                top: parent.top ; topMargin: 30 * main.screenScaleY
                bottom: parent.bottom ; bottomMargin: 30 * main.screenScaleY
            }

            Text {
                id: channelName

                visible: tv.playing || tv.tuning
                anchors { top: parent.top ; topMargin: 40 * main.screenScaleY ; left: parent.left ; leftMargin: 15 * main.screenScaleX }
                wrapMode: Text.WrapAtWordBoundaryOrAnywhere
                width: 250 * main.screenScaleX
                color: "white"
                text: {
                    if (root.tunedToCabChannel) {
                        return ""
                    } else if (tuningIndicator.visible) {
                        // Truncate because "tuning..." text is in the way
                        return Globals.truncate(tv.getTVChannelName(), 22)
                    }
                    return tv.getTVChannelName()
                }
            }
            Text {
                id: tuningIndicator

                visible: tv.tuning
                width: 300 * main.screenScaleX
                height: 80 * main.screenScaleY
                anchors { top: channelName.bottom; topMargin: 0 ; left: parent.left ; leftMargin: 15 * main.screenScaleX }
                color: "white"
                text: qsTr("tuning...") + application.emptyString
            }

            TelevisionControls {
                id: tvControls

                acceptKeys: root.visible && !tv_menu.menuOpen
                showMenuHelp: false
                tuning: tv.tuning
                currentChannelName: tv.getTVChannelNumber()
                showSizeButton: false
                showChannelNumber: !root.tunedToCabChannel
                allowFullscreen: false
                allowTftCc: false
                ccOptions: tv.numCaptionTracks
                ccTrack: tv.captionTrack
                onCcClicked: {
                    tv.captionTrack = (tv.captionTrack + 1) % tv.numCaptionTracks
                }
                onSizeButtonClicked: {
                    fullscreenVideoFrame.showFullscreen(tv.player)
                }
                onStop: root.close()
                onOpenMenu: {
                    tv_menu.menuOpen = (tv_menu.menuOpen ? false : true)
                    root.openMenu()
                }
                onChannelUpClicked: (root.tunedToCabChannel && options.cabEnabled) ? nucleus.cabChannelUp() : tv.channelUp()
                onChannelDownClicked: (root.tunedToCabChannel && options.cabEnabled) ? nucleus.cabChannelDown() : tv.channelDown()

                anchors {
                    top: parent.top ; topMargin: 90 * main.screenScaleY ; bottom: parent.bottom ; bottomMargin: 30 * main.screenScaleY
                    left: parent.left ; leftMargin: ( main.isTouch ? 75 : 30 ) * main.screenScaleX ; right: parent.right ; rightMargin: 30 * main.screenScaleX
                }
            }
        }
    }
    ImageButton {
        id: close_button

        onClicked: close()

        visible: main.isTouch
        width: 48 * main.screenScaleX
        height: 48 * main.screenScaleY
        anchors.right: parent.right
        anchors.rightMargin: 40 * main.screenScaleX
        anchors.top: parent.top
        anchors.topMargin: 40 * main.screenScaleY
        upimage: main.graphicsPath + "Keypad/KeyPad_X_Large.png"
        downimage: main.graphicsPath + "Keypad/KeyPad_X_Large.png"
        mouseAreaScale: 2.0


    }
}
