
import QtQuick 2.4
import "string_format.js" as StrFormat
import Components 1.0


Item{
    id: root

    property bool isTreadmill: true
    property int incline:105
    property int speed: 0
    property string speedUnits
    property bool showHR: false
    property int heartRate
    property int rpm: 0
    property int level:10
    property bool showData: true
    property bool showChannelButton: true
    property string message
    property bool dataHidingAuto: false
    property bool showHelpText: true

    property variant leftSideDisplay
    property variant rightSideDisplay
    property int leftSideCounter: 0
    property int rightSideCounter: 0

    signal screenButtonPressed()
    signal channelButtonPressed()
    signal stopButtonPressed()

    function showMessage(message) {
        root.message = message
        messageTimer.start()
    }

    function reset() {
        root.showData = true
        leftSideCounter = 0
        rightSideCounter = 0
        dataTimer.restart()
    }

    onVisibleChanged: {
        if(visible) {
            if(root.dataHidingAuto)
                overlayTimer.restart()
        }
    }

    MouseArea {
        x: 0
        y: 0
        anchors.rightMargin: 0
        anchors.bottomMargin: 0
        anchors.leftMargin: 0
        anchors.topMargin: 0
        anchors.fill: parent
        onClicked: {
            if(!root.showData && root.dataHidingAuto) {
                root.showData = true
                overlayTimer.restart()
            }
            else {
                screenButtonPressed()
            }
        }
    }

    ImageButton {
        id: showDataButton
        visible: !root.showData && root.visible
        x: 45 * main.screenScaleX; y: 165 * main.screenScaleY
        upimage: main.graphicsPath + "rightArrow_button_UP.png"
        downimage: main.graphicsPath + "rightArrow_button_DOWN.png"
        mouseAreaScale: 3.0
        onClicked: {
            root.showData = true
        }
    }

    Image {
        id: leftDisplay

        source: main.graphicsPath + "FullscreenDataBar.png"
        anchors { left: parent.left ; verticalCenter: parent.verticalCenter }

        Behavior on anchors.leftMargin { NumberAnimation { duration: 200; easing.type: Easing.InOutQuad } }

        Image {
            id: toggleArea
            visible: main.isTouch

            anchors { left: parent.left; bottom: parent.top }
            source: main.graphicsPath + "fullscreenDataBarSmall.png"
            MouseArea {
                anchors.fill: parent
                onClicked: {
                    root.showData = false
                }
            }
            Image {
                source: main.graphicsPath + "Keypad/KeyPad_X_Large.png"
                anchors { horizontalCenter: parent.horizontalCenter; verticalCenter: parent.verticalCenter }
            }
        }

        Text {
            id: leftVarLabelDisplay

            anchors { top: parent.top ; topMargin: 10 * main.screenScaleY; left: parent.left ; leftMargin: 10 * main.screenScaleX }
            height: paintedHeight
            width: parent.width - 10 * main.screenScaleX
            color: "black"
            font { pointSize: 10 * main.screenScaleY ; bold: true }
            text: leftSideCounter === -1 || !root.visible ? "" : qsTranslate(leftSideDisplay.sourceFile, leftSideDisplay.displayModel.get(leftSideCounter).label)
            wrapMode: Text.Wrap
        }

        Text {
            id: leftVarValueDisplay

            width: parent.width - 10 * main.screenScaleX
            height: paintedHeight
            color: "black"
            font { pointSize: 30 * main.screenScaleY ; bold: true }
            horizontalAlignment: Text.AlignHCenter
            text: leftSideCounter === -1 || !root.visible ? "--" : leftSideDisplay.getData(leftSideCounter)
            anchors { left: parent.left ; leftMargin: 0
                      top: leftVarLabelDisplay.bottom; topMargin: 2 * main.screenScaleY }
        }
        Text {
            id: leftVarUnitsDisplay

            anchors { right: parent.right; rightMargin: 0
                    top: leftVarValueDisplay.bottom ; topMargin: 1 * main.screenScaleY
            }

            width: parent.width
            color: "black"
            text: leftSideCounter === -1 ? "" : leftSideDisplay.getUnit(leftSideCounter)
            font { pointSize: 10 * main.screenScaleY ; bold: true }
            horizontalAlignment: Text.AlignHCenter
            wrapMode: Text.Wrap
        }

        Text { // fixed incline or level display
            id: leftDataLabel

            anchors { top: parent.top ; topMargin: 130 * main.screenScaleY }
            width: parent.width
            color: "black"
            font { pointSize: 10 * main.screenScaleY ; bold: true }
            text: root.isTreadmill ? qsTr("INCLINE") : qsTr("LEVEL")+application.emptyString
            horizontalAlignment: Text.AlignHCenter
            anchors.left: parent.left
            anchors.leftMargin: 0
            wrapMode: Text.Wrap
        }


        Text { // fixed incline or level display
            id: leftDataUnits

            anchors { top: parent.top ; topMargin: 200 * main.screenScaleY }
            width: parent.width
            color: "black"
            font { pointSize: 10 * main.screenScaleY ; bold: true }
            text: root.isTreadmill ? (qsTr("%") + application.emptyString) : ""
            horizontalAlignment: Text.AlignHCenter
            anchors.left: parent.left
            anchors.leftMargin: 0
            wrapMode: Text.Wrap
        }

        Text {
            id: leftDataValue

            width: parent.width
            height: 59.7 * main.screenScaleY
            color: "black"
            font { pointSize: 30 * main.screenScaleY ; bold: true }
            text: root.isTreadmill ? (root.incline/10.0).toFixed(1) : root.level
            horizontalAlignment: Text.AlignHCenter
            anchors { left: parent.left ; leftMargin: 0
                      top: parent.top ; topMargin: 148 * main.screenScaleY }
        }

        ImageButton {
            id: screenChange
            visible: main.isTouch
            x: 26 * main.screenScaleX
            y: 235 * main.screenScaleY
            onClicked: screenButtonPressed()
            icon: main.graphicsPath + "netpulse/Fullscreen_icon.png"
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 5 * main.screenScaleY

            upimage: main.graphicsPath + "netpulse/GRAYbutton_video.png"
            downimage: main.graphicsPath + "netpulse/GRAYbutton_video_PRESSED.png"
        }
        Item {
            id: keyInstructions
            property bool useIpodText: audioManager.videoSource === "ipod"
            visible: main.isTft && root.showHelpText
            x: 3 * main.screenScaleX
            y: 258 * main.screenScaleY
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.horizontalCenterOffset: -10 * main.screenScaleX
            width: 100 * main.screenScaleX
            height: 72 * main.screenScaleY

            Image {
                id: image1
                visible: main.isTft
                y: -5 * main.screenScaleY
                source: main.graphicsPath + "netpulse/Fullscreen_icon.png"
            }

            Text {
                id: text2
                visible: main.isTft
                y: -5 * main.screenScaleY
                text: " = "
                wrapMode: Text.WordWrap
                font.pixelSize: 24 * main.screenScaleY
                font.bold: true
                horizontalAlignment: Text.AlignHCenter
                anchors.left: image1.right
            }

            Text {
                visible: main.isTft
                id: text3
                text: qsTr("ENTER") + application.emptyString
                wrapMode: Text.WordWrap
                font.pixelSize: 16 * main.screenScaleY
                font.bold: true
                horizontalAlignment: Text.AlignHCenter
                y: 5 * main.screenScaleY
                anchors { left: text2.right }
            }
        }
    }

    Image {
        id: rightDisplay

        source: main.graphicsPath + "FullscreenDataBar.png"
        mirror: true
        anchors { right: parent.right; verticalCenter: parent.verticalCenter }
        Behavior on anchors.rightMargin { NumberAnimation { duration: 200; easing.type: Easing.InOutQuad } }

        Image {  // fixed hr display
            id: hrDisplay

            visible: root.showHR
            anchors { right: parent.right; bottom: parent.top }
            source: main.graphicsPath + "fullscreenDataBarSmall.png"
            mirror: true

            BeatingHeart {
                id: heart
            }

            Text {
                id: hrValue

                width: parent.width
                height: 59.7 * main.screenScaleY
                color: "black"
                font { pointSize: 30 * main.screenScaleY ; bold: true }
                text: root.heartRate
                horizontalAlignment: Text.AlignHCenter
                anchors { right: parent.right; rightMargin: 0
                          top: parent.top ; topMargin: 5 * main.screenScaleY }
            }

            Text {
                id: hrDataLabel

                anchors { bottom: parent.bottom ; bottomMargin: 5 * main.screenScaleY}
                width: parent.width
                color: "black"
                font { pointSize: 11 * main.screenScaleY ; bold: true }
                text: qsTr("BPM")+application.emptyString
                horizontalAlignment: Text.AlignHCenter
                anchors.right: parent.right
                anchors.rightMargin: 0
                wrapMode: Text.Wrap
            }
        }

        Text {
            id: rightVarLabelDisplay

            anchors { top: parent.top ; topMargin: 10 * main.screenScaleY ; right: parent.right ; rightMargin: 0 }
            width: parent.width
            color: "black"
            font { pointSize: 11 * main.screenScaleY ; bold: true }
            text: rightSideCounter === -1 || !root.visible ? "" : qsTranslate(rightSideDisplay.sourceFile, rightSideDisplay.displayModel.get(rightSideCounter).label)
            horizontalAlignment: Text.AlignHCenter
            wrapMode: Text.WordWrap
        }

        Text {
            id: rightVarValueDisplay

            width: parent.width
            height: paintedHeight
            color: "black"
            font { pointSize: 30 * main.screenScaleY ; bold: true }
            text: rightSideCounter === -1 ? "--" : rightSideDisplay.getData(rightSideCounter)

            horizontalAlignment: Text.AlignHCenter
            anchors { right: parent.right; rightMargin: 0
                      top: rightVarLabelDisplay.bottom ; topMargin: 5 * main.screenScaleY}
        }
        Text {
            id: rightVarUnitsDisplay

            anchors { bottom: parent.bottom ; bottomMargin: 5 * main.screenScaleY}
            width: parent.width
            color: "black"
            text: rightSideCounter === -1 ? "" : rightSideDisplay.getUnit(rightSideCounter)
            font { pointSize: 11 * main.screenScaleY ; bold: true }
            horizontalAlignment: Text.AlignHCenter
            anchors { right: parent.right; rightMargin: 0
                      top: rightVarValueDisplay.bottom ; topMargin: 5 * main.screenScaleY }
            wrapMode: Text.Wrap
        }

        Text {
            id: rightDataLabel // fixed speed/rpm display

            anchors { top: parent.top ; topMargin: 130 * main.screenScaleY }
            width: parent.width
            color: "black"
            font { pointSize: 11 * main.screenScaleY ; bold: true }
            text: (root.isTreadmill ? qsTr("SPEED") : qsTr("RPM")) + application.emptyString
            horizontalAlignment: Text.AlignHCenter
            anchors.right: parent.right
            anchors.rightMargin: 0
            wrapMode: Text.Wrap
        }

        Text {
            id: rightDataUnits// fixed speed/rpm display

            anchors { top: parent.top ; topMargin: 200 * main.screenScaleY }
            width: parent.width
            color: "black"
            font { pointSize: 11 * main.screenScaleY ; bold: true }
            text: root.isTreadmill ? (speedUnits + application.emptyString) : ""
            horizontalAlignment: Text.AlignHCenter
            anchors.right: parent.right
            anchors.rightMargin: 0
            wrapMode: Text.Wrap
        }

        Text {
            id: rightDataValue

            width: parent.width
            height: 59.7 * main.screenScaleY
            color: "black"
            font { pointSize: 30 * main.screenScaleY ; bold: true }
            text: root.isTreadmill ? (root.speed/10.0).toFixed(1) : root.rpm
            horizontalAlignment: Text.AlignHCenter
            anchors { right: parent.right; rightMargin: 0
                      top: parent.top ; topMargin: 148 * main.screenScaleY }
        }

        ImageButton {
            id: channelButton
            visible: main.isTouch && root.showChannelButton
            x: 26 * main.screenScaleX
            y: 235 * main.screenScaleY
            downimage: main.graphicsPath + "205/IPOD_Wheel_Center_Down.png"
            upimage: main.graphicsPath + "205/IPOD_Wheel_Center_Up.png"
            icon: main.graphicsPath + "Media_Icon_Remote.png"
            icon_x_offset: -3 * main.screenScaleX
            scale: 0.90
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.horizontalCenterOffset: 5 * main.screenScaleX
            anchors.bottom: parent.bottom
            anchors.bottomMargin: -6 * main.screenScaleY
            onClicked: channelButtonPressed()
        }

        Item {
            id: keyInstructions2
            property bool useIpodText: audioManager.videoSource === "ipod"
            visible: main.isTft && root.showHelpText
            x: 20 * main.screenScaleX
            y: 243 * main.screenScaleY
            anchors.horizontalCenter: parent.horizontalCenter
            width: 100 * main.screenScaleX
            height: 72 * main.screenScaleY

            Image {
                id: remoteIcon
                y: -2 * main.screenScaleY
                visible: main.isTft && !keyInstructions2.useIpodText
                source: main.graphicsPath + "Media_Icon_Remote.png"
            }
            Text {
                id: text1_1
                visible: main.isTft && !keyInstructions2.useIpodText
                text: " = "
                wrapMode: Text.WordWrap
                font.pixelSize: 24 * main.screenScaleY
                font.bold: true
                horizontalAlignment: Text.AlignHCenter
                anchors.left: remoteIcon.right
            }

            Image {
                source: main.graphicsPath + "netpulse/audio_button_TV.png"
                visible: main.isTft && !keyInstructions2.useIpodText
                anchors.left: text1_1.right
            }
        }
    }

    Text {
        id: overlayMessageText

        text: root.message
        font.pointSize: 30 * main.screenScaleY
        color: "light gray"
        anchors { top: root.top ; horizontalCenter: root.horizontalCenter }
        width: root.width
        horizontalAlignment: Text.AlignHCenter
        visible: messageTimer.running
    }

    ImageButton {
        id: stopButton
        visible: main.isTouch

        anchors.bottom: parent.bottom
        anchors.bottomMargin: 15 * main.screenScaleY
        anchors.right: parent.right
        anchors.rightMargin: 20 * main.screenScaleX
        fontsize: 14 * main.screenScaleY
        label_color: "black"
        label_under: true
        downimage: main.graphicsPath + "224/224_Data_Stop_Down.png"
        upimage: main.graphicsPath + "224/224_Data_Stop_Disabled.png"
        label: qsTr("STOP") + "/" + qsTr("PAUSE") + application.emptyString
        label_y_offset: 10 * main.screenScaleY

        onClicked: stopButtonPressed()
        mouseAreaScale: 1.75
    }


    Timer {
        id: overlayTimer
        interval: 5000
        repeat: false
        onTriggered: root.showData = false
    }

    Timer {
        id: messageTimer
        interval: 5000
        repeat: false
        running: false
    }

    Timer {
        id: dataTimer
        interval: 5000
        repeat: true
        running: true
        onTriggered: {
            if (!root.visible)
                return // avoid unnecessary processing
            rightSideCounter = rightSideDisplay.getNextIndex(rightSideCounter)
            leftSideCounter = leftSideDisplay.getNextIndex(leftSideCounter)
        }
    }

    state: root.showData ? "dataShown" : "dataHidden"

    states: [
    State { name: "dataShown"
        PropertyChanges { target: leftDisplay ; anchors.leftMargin: 0}
        PropertyChanges { target: rightDisplay ; anchors.rightMargin: 0}
    },
    State { name: "dataHidden"
        PropertyChanges { target: leftDisplay ; anchors.leftMargin: -leftDisplay.width }
        PropertyChanges { target: rightDisplay ; anchors.rightMargin: -rightDisplay.width }
    } ]
}
