// import QtQuick 2.4 // to target S60 5th Edition or Maemo 5
import QtQuick 2.4

Item {
    id: root

    signal accept()
    signal decline()

    anchors.fill: parent
    width: 1366 * main.screenScaleX
    height: 768 * main.screenScaleY

    onVisibleChanged: {
        if (!visible)
            buttonView.currentIndex = 2
    }

    Image {
        id: background
        z: -2
        anchors.fill: parent
        source: main.graphicsPath + "Background.png"
    }

    Item {
        id: header
        anchors { left: parent.left; leftMargin: 82 * main.screenScaleX; top: parent.top; topMargin: 40 * main.screenScaleY }
        Image {
            id: warningImage
            source: main.graphicsPath + "Icon_Warning.png"
        }
        Text {
            id: warningText
            text: qsTr("WARNING")+":" + application.emptyString
            anchors { verticalCenter: warningImage.verticalCenter; left: warningImage.right; leftMargin: 10 * main.screenScaleX }
            font { pixelSize: 30 * main.screenScaleY; bold: true }
            color: "#f58c1f"
        }
        Text {
            text: qsTr("Read and understand all the instructions and warnings prior to use.") + application.emptyString
            anchors { bottom: warningText.bottom; left: warningText.right; leftMargin: 5 * main.screenScaleX; bottomMargin: 3 * main.screenScaleY }
            font {
                pixelSize: {
                    if (application.currentLanguage === "fr")
                        return 18 * main.screenScaleY
                    else if (application.currentLanguage === "ru")
                        return 20 * main.screenScaleY
                    else
                        return 22 * main.screenScaleY
                }
                bold: true
            }
            color: "#f58c1f"
        }
    }

    function warningTextCol1(isTread) {
        var text = "<ul>" +
                "<li>" + qsTr("Obtain proper instruction prior to use.") + "</li>" +
                "<p><li>" + qsTr("Obtain a medical exam before beginning any exercise program. If at any time during exercise you feel faint, dizzy, or experience pain, stop and consult your physician.") + "</li></p>" +
                "<p><li>" + qsTr("Heart rate display may be inaccurate and should be used for reference only.") + "</li></p>" +
                "<p><li>" + qsTr("Keep children away at all times.") + "</li></p>" +
                "<p><li>" + qsTr("Do not wear loose or dangling clothing while using the machine.") + "</li></p>" +
                "<p><li>" + qsTr("Care should be used when mounting or dismounting machine.") + "</li></p>";
        if (isTread) {
            text += "<p><li>" + qsTr("Inspect the machine for incorrect, worn, or loose components and do not use until corrected, replaced, or tightened prior to use.") + "</li></p>" +
                    "<p><li>" + qsTr("Disconnect all power before servicing the machine.") + "</li></p>" +
                    "<p><li>" + qsTr("Do not operate electrically powered machines in damp or wet locations.") + "</li></p>" +
                    "<p><li>" + qsTr("All exercise equipment is potentially hazardous. If attention is not paid to the conditions of the equipment usage, death or serious injury could occur.") + "</li></p>";
        }
        text += "</ul>" + application.emptyString

        return text
    }

    function warningTextCol2(isTread) {
        var text = ""

        if (isTread) {
            text += "<ul>" +
                    "<p><li>" + qsTr("Straddle treadbelt before starting.") + "</li></p>" +
                    "<p><li>" + qsTr("Read, understand, and test the emergency stop procedures before use.") + "</li></p>" +
                    "<p><li>" + qsTr("ALWAYS ATTACH THE EMERGENCY STOP SAFETY CLIP TO CLOTHING PRIOR TO USE!") + "</li></p>" +
                    "<p><li>" + qsTr("Prior to use, inspect safety clip cord to ensure it is free of tangles or knots, and that the red magnetic key will easily disengage from machine.") + "</li></p>" +
                    "</ul></p>" + application.emptyString

        } else {
            text += "<ul>"
            text += "<p><li>" + qsTr("Inspect the machine for incorrect, worn, or loose components and do not use until corrected, replaced, or tightened prior to use.") + "</li></p>" +
                    "<p><li>" + qsTr("Disconnect all power before servicing the machine.") + "</li></p>" +
                    "<p><li>" + qsTr("Do not operate electrically powered machines in damp or wet locations.") + "</li></p>" +
                    "<p><li>" + qsTr("All exercise equipment is potentially hazardous. If attention is not paid to the conditions of the equipment usage, death or serious injury could occur.") + "</li></p>" +
                    "</ul>" + application.emptyString
        }

        return text
    }

    Text {
        id: frenchText
        width: 600 * main.screenScaleX
        visible: application.currentLanguage === "en"
        height: !visible ? 0 : (paintedHeight + 20)
        anchors { top: parent.top ; topMargin: 110 * main.screenScaleY; left: parent.left; leftMargin: 70 * main.screenScaleX }
        font { pixelSize: 18 * main.screenScaleY }
        text: "AVERTISSEMENT!  Prenez connaissance du manuel d'instruction et consigne de sécurité avant l'utilisation." // !! do not mark for translation
        wrapMode: Text.WordWrap
    }

    Text {
        id: leftColumn
        width: 600 * main.screenScaleX
        anchors { top: frenchText.bottom; left: parent.left; leftMargin: 40 * main.screenScaleX }
        font { pixelSize: application.currentLanguage === "ru" ? 17 * main.screenScaleY : 18 * main.screenScaleY }
        text: warningTextCol1(main.isTreadmill)
        wrapMode: Text.WordWrap
    }
    Text {
        id: treadmillText
        width: 600 * main.screenScaleX
        visible: main.isTreadmill
        height: !visible ? 0 : (paintedHeight + 20)
        anchors { top: parent.top ; topMargin: 110 * main.screenScaleY; left: leftColumn.right; leftMargin: 20 * main.screenScaleX }
        wrapMode: Text.WordWrap
        font { pixelSize: 18 * main.screenScaleY }
        text: qsTr("FOR TREADMILL USE:") + application.emptyString

    }
    Text {
        id: rightColumn
        width: 600 * main.screenScaleX
        anchors { top: treadmillText.bottom; left: leftColumn.right; leftMargin: -10 * main.screenScaleX }
        font { pixelSize: application.currentLanguage === "ru" ? 17 * main.screenScaleY : 18 * main.screenScaleY }
        text: warningTextCol2(main.isTreadmill)
        wrapMode: Text.WordWrap
    }

    Image {
        source: main.graphicsPath + "tft/NAV_selector.png"
        smooth: true
        x: buttonView.currentItem ? buttonView.x + buttonView.currentItem.x - 20 * main.screenScaleX : buttonView.x
        y: buttonView.y
        Behavior on x {
            SmoothedAnimation {
                duration: 150
            }
        }
    }

    ListView {
        id: buttonView

        Connections {
            target: main.isTft && buttonView.visible ? keymapper : null

            onLeftButtonPressed: {
                main.debugKeys("leftButtonPressed", "WarningScreen")
                buttonView.decrementCurrentIndex()
            }

            onRightButtonPressed: {
                main.debugKeys("rightButtonPressed", "WarningScreen")
                buttonView.incrementCurrentIndex()
            }
            onEnter2Pressed: {
                main.debugKeys("enter2Pressed", "WarningScreen")
                if (buttonView.currentIndex === 0)
                    root.decline()
                else if (buttonView.currentIndex === 2)
                    root.accept()
            }
            onBackPressed: {
                main.debugKeys("enter2Pressed", "WarningScreen")
                root.decline()
            }
        }
        orientation: ListView.Horizontal
        currentIndex: 2
        width: 600 * main.screenScaleX
        height: 213 * main.screenScaleY
        anchors { bottom: parent.bottom; bottomMargin: 90 * main.screenScaleY; right: parent.right; rightMargin: 100 * main.screenScaleX }
        model: buttonVisualModel
    }
    VisualItemModel {
        id: buttonVisualModel

        Item {
            id: declineItem
            width: 200 * main.screenScaleX
            height: 213 * main.screenScaleY
            Image {
                id: image1
                source: main.graphicsPath + "tft/nav_icon_DECLINE.png"
                anchors { top: parent.top; topMargin: 40 * main.screenScaleY; horizontalCenter: parent.horizontalCenter }
            }
            Text {
                text: qsTr("DECLINE") + application.emptyString
                anchors { top: image1.bottom; topMargin: 30 * main.screenScaleY; horizontalCenter: parent.horizontalCenter }
                color: "#c4151a"
                font { bold: true }
            }
        }
        Item {
            id: middleItem
            width: 200 * main.screenScaleX
            height: 213 * main.screenScaleY
            Image {
                source: main.graphicsPath + "Bullet_Triangle_Gray.png"
                x: 18 * main.screenScaleX
                y: 12 * main.screenScaleY
            }
            Text {
                id: text1
                text: qsTr("I have read and understand all instructions and warnings.") + application.emptyString
                lineHeight: 1.1
                width: 130 * main.screenScaleX
                wrapMode: Text.WordWrap
                anchors {
                    top: parent.top
                    topMargin: 20 * main.screenScaleY
                    horizontalCenter: parent.horizontalCenter
                    horizontalCenterOffset: 3 * main.screenScaleX
                }
                font { pixelSize: application.currentLanguage === "fr" ? 16 * main.screenScaleY : 18 * main.screenScaleY }
            }
            Text {
                text: qsTr("ACCEPT or DECLINE") + application.emptyString
                width: 140 * main.screenScaleX
                wrapMode: Text.WordWrap
                horizontalAlignment: Text.AlignHCenter
                anchors { top: parent.top; topMargin: 150 * main.screenScaleY; horizontalCenter: parent.horizontalCenter }
                font { bold: true }
            }
        }
        Item {
            id: acceptItem
            width: 200 * main.screenScaleX
            height: 213 * main.screenScaleY
            Image {
                id: image2
                source: main.graphicsPath + "tft/nav_icon_ACCEPT.png"
                anchors { top: parent.top; topMargin: 40 * main.screenScaleY; horizontalCenter: parent.horizontalCenter }
            }
            Text {
                text: qsTr("ACCEPT") + application.emptyString
                anchors { top: image2.bottom; topMargin: 30 * main.screenScaleY; horizontalCenter: parent.horizontalCenter }
                color: "#5e9832"
                font { bold: true }
            }
        }
    }

    Text {
        id: bottomHelpText

        font { family: "arial"; pixelSize: 36 * main.screenScaleY; bold: true }
        color: "#6c6c6c"
        text: {
            switch (buttonView.currentIndex){
                case 0:
                    return qsTr("press ENTER to DECLINE") + application.emptyString
                case 1:
                    return qsTr("use <img src='" + main.graphicsPath + "/tft/arrow_left.png' /> or <img src='" + main.graphicsPath + "/tft/arrow_right.png' /> to ACCEPT or DECLINE") + application.emptyString
                case 2:
                    return qsTr("press ENTER to ACCEPT") + application.emptyString
                default:
                    return ""
            }
        }

        anchors {
            bottom: parent.bottom
            bottomMargin: 25 * main.screenScaleY
            horizontalCenter: parent.horizontalCenter
        }
    }
}
