import QtQuick 2.4
import Components 1.0

// prompt user for ending the workout

ModalDialog {
    id: root

    signal resumeClicked()
    signal stopClicked()

    Connections{
        target:keymapper
        onStopPressed: if (root.visible) stopClicked()
        onStopPausePressed:if(root.visible)stopClicked()
        onStartQuickStartPressed: if(root.visible && machinecontrol.treadmillSpeedActual == 0)resumeClicked()
        onStartPressed: if (root.visible && machinecontrol.treadmillSpeedActual == 0) resumeClicked()
    }

    BorderImage {   // pop-up dialog background
        id: border

        x: 0
        y: 0
        width: 800 * main.screenScaleX
        height: 350 * main.screenScaleY
        source: main.graphicsPath + "Pop_Up_Lrg_Grey.png"
        border { top: 152 * main.screenScaleY; bottom: 165 * main.screenScaleY; left: 145 * main.screenScaleX; right: 144 * main.screenScaleX }

        Text {
            id: endPromptText
            x: 149 * main.screenScaleX
            y: 35 * main.screenScaleY
            width: 501 * main.screenScaleX
            height: 99 * main.screenScaleY
            color: "#ffffff"
            text: machineinfo.productTypeString === "Treadmill" && machinecontrol.isBeltMoving !== false ? qsTr("Waiting for belt to stop.") : qsTr("WOULD YOU LIKE TO END THIS WORKOUT?") + application.emptyString
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.top: parent.top
            anchors.topMargin: 35 * main.screenScaleY
            horizontalAlignment: Text.AlignHCenter
            wrapMode: Text.WordWrap
            font.bold: true
            font.pixelSize: 40 * main.screenScaleY
        }

        ImageButton {
            id: stopButton

            x: 538 * main.screenScaleX
            y: 157 * main.screenScaleY
            label_y_offset: -65 * main.screenScaleY
            label: qsTr("STOP") + application.emptyString
            smooth: true
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 22 * main.screenScaleY
            upimage: main.graphicsPath + "Small_Stop.png"
            downimage: main.graphicsPath + "Small_Stop_Down.png"
            onClicked: stopClicked()
        }

        ImageButton {
            id: resumeButton
            property bool isInFault: false
            property bool isReady: {
                if(main.lowerSystem === "BRAINBOARD") {
                    return true
                } else if(main.lowerSystem === "NUCLEUS") {
                    return nucleus.systemReady
                }
                else {
                    return true
                }
            }

            x: 149 * main.screenScaleX
            y: 178 * main.screenScaleY
            label_y_offset: -65 * main.screenScaleY
            label: qsTr("RESUME") + application.emptyString
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 22 * main.screenScaleY
            upimage: main.graphicsPath + "Small_Start.png"
            downimage: main.graphicsPath + "Small_Start_Down.png"
            onClicked: resumeClicked()
            enabled: machinecontrol.isBeltMoving === false && machinecontrol.isInclineMoving === false && nucleus.systemReady === true
            Connections {
                target: errorManager
                onNucleusNonRecoverableFaultTriggered: resumeButton.isInFault = true
                onNucleusRecoverableFaultTriggered: resumeButton.isInFault = true
                onNucleusFaultCleared: resumeButton.isInFault = false
            }
        }

        Text { // show count down to timeout of prompt (started by startTimeout(seconds) method of ModalDialog superclass
            id: countdownText

            x: 350 * main.screenScaleX
            y: 168 * main.screenScaleY
            color: "#ffffff"
            visible: root.isCounting
            // display count down (with a leading 0 if remaining seconds < 10
            text: ":" + ((countDown.toString().length < 2) ? "0" : "") + countDown
            font.bold: true
            font.pixelSize: 96 * main.screenScaleY

            anchors.horizontalCenter: parent.horizontalCenter
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 73 * main.screenScaleY
        }
    }
}

