import QtQuick 2.4
import Components 1.0

Item {
    id: root

    // menu property is a menu from workout_menus.js to be displayed in the list
    property variant menu
    property int defaultIndex: main.isCSA ? 2 : 0

    signal workoutSelected( variant item )

    onOpacityChanged: {
        if (opacity <= 0.0) {
            carousel.model = undefined
            carousel.model = menuModel
            carousel.pathView.positionViewAtIndex(0, PathView.SnapPosition)
            carousel.currentIndex = defaultIndex
        } // reset selected item each time menu is hidden
    }

    width: 1366 * main.screenScaleX ; height: 768 * main.screenScaleY

    function selectMonuments() {
        carousel.pathView.positionViewAtIndex(5, PathView.SnapPosition)
        carousel.currentIndex = 5
    }

    function doNext() {
        if (carousel.selectedData.program)
            workoutSelected(carousel.selectedData)
    }

    Connections {
        target: main.isTft && root.opacity > 0 && root.visible ? keymapper : null

        onUpButtonPressed: {
            main.debugKeys("upButtonPressed", "WorkoutMenuAll")
            carousel.decrementCurrentIndex()
        }

        onDownButtonPressed: {
            main.debugKeys("downButtonPressed", "WorkoutMenuAll")
            carousel.incrementCurrentIndex()
        }

        onEnter2Pressed: {
            main.debugKeys("enter2Pressed", "WorkoutMenuAll")
            root.doNext()
        }

        onBackPressed: {
            main.debugKeys("backPressed", "WorkoutMenuAll")
            navbar.goBack()
        }
    }

    Text {
        id: title

        text: qsTr("ALL PRESET WORKOUTS") + application.emptyString
        font.pointSize: 22 * main.screenScaleY
        font.bold: true
        anchors { top: parent.top ; topMargin: 70 * main.screenScaleY; right: parent.right; rightMargin: 100 * main.screenScaleX }
    }
    onMenuChanged: {
        menuModel.changeMenu(menu)
        browser.model = undefined
        browser.model = menuModel
        carousel.currentIndex = defaultIndex
        browser.currentIndex = defaultIndex
    }
    MenuModel {
        id: menuModel
        Component.onCompleted: {
            changeMenu(menu)
            carousel.currentIndex = defaultIndex
            browser.currentIndex = defaultIndex
        }
    }

    SelectList {
        id: carousel
        property int lastIndex: currentIndex

        model: menuModel
        onCurrentIndexChanged: {
            if (lastIndex != currentIndex) {
                lastIndex = currentIndex
                menu_slider.value = currentIndex
                browser.currentIndex = currentIndex
            }
        }
        width: 350 * main.screenScaleX
        anchors {   top: parent.top ; topMargin: 160 * main.screenScaleY ;
                    bottom: parent.bottom ; bottomMargin: 100 * main.screenScaleY;
                    right: parent.right ; rightMargin: 50 * main.screenScaleX
        }
    }

    Image {
        source: main.graphicsPath + "327_Pointer_Arrow.png"
        anchors { right: carousel.left ; verticalCenter: carousel.verticalCenter }
    }

    SliderControl {
        id: menu_slider

        orientation: Qt.Vertical
        anchors { top: carousel.top ; bottom: carousel.bottom ; right: carousel.left ; rightMargin: 50 * main.screenScaleX }
        trackImage: main.graphicsPath + "200/Blue_Slider.png"
        thumbImage: main.isTft ? main.graphicsPath + "tft/red_scrolling_noarrows.png" : main.graphicsPath + "205/Arrows_Scrolling_Menu.png"
        thumbMouseAreaScale: 1.8
        maxValue: menuModel.count-1
        minValue: 0
        showButtons: false
        showValue: false
        onValueChanged: {
            carousel.currentIndex = value
        }
    }

    // re-translate the menu strings when the language changes
    Connections {
        target: application
        onLanguageChanged: { menuModel.updateStrings() }
    }

    ProgramBrowser {
        id: browser
        property int lastIndex: currentIndex

        Keys.onLeftPressed: { decrementCurrentIndex() ; carousel.decrementCurrentIndex(); description_flip_timer.restart() }
        Keys.onRightPressed: { incrementCurrentIndex() ; carousel.incrementCurrentIndex(); description_flip_timer.restart() }
        onLeftArrowPressed: carousel.decrementCurrentIndex()
        onRightArrowPressed: carousel.incrementCurrentIndex()

        showArrows: main.isTouch && carousel.selectedData !== undefined && !carousel.selectedData.shim

        opacity: root.opacity
        focus: main.state === "AllWorkoutsState"

        currentIndex: carousel.currentIndex
        onCurrentIndexChanged: {
            if (lastIndex != currentIndex && browser.moving) {
                lastIndex = currentIndex
                carousel.currentIndex = currentIndex
            }
        }

        model: menuModel
        slideDuration: 50
    }

    Text {
        id: bottomHelpText
        visible: main.isTft

        font { family: "arial"; pixelSize: 36 * main.screenScaleY; bold: true }
        color: "#6c6c6c"
        text: qsTr("press ENTER to select, press BACK to exit") + application.emptyString

        anchors {
            bottom: parent.bottom
            bottomMargin: 25 * main.screenScaleY
            horizontalCenter: parent.horizontalCenter
        }
    }

    ImageButton {
        id: next_button

        enabled: main.state == "AllWorkoutsState"
        visible: main.isTouch && carousel.selectedData !== undefined && !carousel.selectedData.shim

        label: qsTr("NEXT") + application.emptyString
        label_under: true
        label_color: "black"

        anchors.bottom: parent.bottom
        anchors.bottomMargin: 30 * main.screenScaleY
        anchors.right: parent.right
        anchors.rightMargin: 30 * main.screenScaleX

        upimage: main.graphicsPath + "setup/Start_Button.png"
        downimage: main.graphicsPath + "setup/Start_Button_Down.png"
        onClicked: {
            root.doNext()
        }
    }
}
