import TrackView 1.0
import QtQuick 2.4
import WorkoutRunData 1.0
import PID 1.0
import WorkoutManager 1.0
import StorageMgr 1.0
import Components 1.0
import TrueTouch 1.0

import "MediaBrowser"
import "views.js" as TheViews

FocusScope {
    id: root
    width: 1366 * main.screenScaleX
    height: 768 * main.screenScaleY

    focus: main.state === "RunState"

    property alias container: workoutViewContainer

    property bool hrTargetVisibility: workoutProgram.isHRCProgram || workoutProgram.programIndex === WorkoutProgram.TREAD_GERKIN_TEST_PROG || workoutProgram.programIndex === WorkoutProgram.FITNESS_TEST_PROG
    property bool c360Available: workoutProgram.isC360Program
    property bool netpulseAvailable: options.netpulseEnabled && netpulse.connected
    property bool c360VideoAvailable: workoutProgram.isVideoProgram
    property bool showPaceSetter: workoutProgram.displayDataVars.paceSetterAvailable
    property alias currentViewName: workoutViewContainer.currentViewName
    property bool freezeTV: workoutViewContainer.isMoving || (workoutViewContainer.currentViewName != "TV_VIEW")
    property bool showingTV: currentViewName === "TV_VIEW"
    property bool workoutActive:  (main.state === "RunState") || (aWorkoutRunData.mode == WorkoutRunData.WORKOUT_MODE) || (aWorkoutRunData.mode == WorkoutRunData.WARM_UP_MODE) || (aWorkoutRunData.mode == WorkoutRunData.COOL_DOWN_MODE)
    property bool bikeModeEnabled: machinecontrol.machineMode === MachineControl.MODE_CONSTANT_TORQUE && machineinfo.productTypeString == "Bike"
    property string unitState
    property variant stopPrompt: main.isTft ? tftStopPrompt : _stopPrompt
    property alias sideDataDisplay: sideDataDisplay
    property bool browserFullscreen: false
    property bool bikeModePromptShowing: bikeModePrompt.visible
    property bool tvMenuShowing: false
    property bool ipodVideoShown: false

    signal workoutStopped()
    signal workoutStarted()
    signal workoutPaused()
    signal workoutResumed()

    function showC360Message(message) {
        print("WorkoutScreen: C360 Message shown = "+message)
        if(netpulseAvailable) {
            infoBanner.showMessage(message, 3)
        } else {
            viewContainerBanner.showMessage(message, 5)
        }
    }

    function showMessage(message) {
        print("WorkoutScreen: Message shown = "+message)
        if(netpulseAvailable) {
            infoBanner.showMessage(message, 3)
        }
        else {
            infoPopup.showMessage(message, 3)
        }
    }

    function showBannerMessage(message) {
        print("WorkoutScreen: Message shown = "+message)
        infoBanner.showMessage(message, 3)
    }

    Connections {
        target: nucleus
        onSystemReadyChanged: {
            if(stopPrompt.visible === true) {
                if(nucleus.systemReady === true) {
                    stopPrompt.startTimeout(options.resumeWorkoutTimeout)
                }
            }
        }
    }

    function stopButtonPressedHandler(){
        urlKeypad.process.write("CMD hide\n")
        inputKeypad.process.write("CMD hide\n")

        // CSA Cardio 360 can be in "intro mode". Show popup anyway.
        if (workoutActive || (main.isCSA && workoutProgram.isC360Program)) {
            if(options.resumeWorkoutTimeout){
                stopPrompt.show()
                if(main.lowerSystem === "BRAINBOARD") {
                    stopPrompt.startTimeout(options.resumeWorkoutTimeout)
                }
                workoutPaused()
            }
            else {
                stopPrompt.show()
                workoutPaused()
            }
        }
        if(workoutProgram.isFitnessTest)
            stopWorkout();
        if(workoutProgram.isHRCProgram)
            workoutManager.stopHRC()
    }

    function showBikeModePrompt() {
        bikeModePrompt.show()
        bikeModePrompt.startTimeout(5)
    }

    function resumeWorkout() {
        if (isTreadmill) {
            workoutManager.treadSpeed = 5
        }
        workoutManager.resume()
        aWorkoutRunData.resumeTime()
        workoutResumed()
    }

    Connections {
        target: main.state === "RunState" ? keymapper : null

        onLevelUpPressed: if(workoutActive && !stopPrompt.visible) {
                              workoutManager.stopHRC()
                              workoutManager.stopFitnessTest()
                              workoutManager.increaseWorkloadLevel();
                          }
        onLevelDownPressed: if(workoutActive && !stopPrompt.visible) {
                                workoutManager.stopHRC()
                                workoutManager.stopFitnessTest()
                                workoutManager.decreaseWorkloadLevel();
                            }
        onInclineUpPressed: if(workoutActive && !stopPrompt.visible) {
                                workoutManager.stopHRC()
                                workoutManager.increaseIncline()
                            }
        onInclineDownPressed: if(workoutActive && !stopPrompt.visible) {
                                  workoutManager.stopHRC()
                                  workoutManager.decreaseIncline();
                              }
        onSpeedUpPressed: if(workoutActive && !stopPrompt.visible) {
                              workoutManager.stopHRC()
                              if(root.unitState === "ENGLISH") {
                                  workoutManager.increaseSpeed(workoutManager.withLimit);
                              } else {
                                  workoutManager.increaseSpeedMetric(workoutManager.withLimit);
                              }
                          }
        onSpeedUpFirstPressed: if(workoutActive && !stopPrompt.visible) workoutManager.speedUpEnabled = true;
        onSpeedUpReleased: if(workoutActive && !stopPrompt.visible) workoutManager.speedUpEnabled = false;

        onSpeedDownPressed: if(workoutActive && !stopPrompt.visible) {
                                workoutManager.stopHRC()
                                if(root.unitState === "ENGLISH") {
                                    workoutManager.decreaseSpeed();
                                } else {
                                    workoutManager.decreaseSpeedMetric();
                                }
                            }
        onStopPausePressed: {
            stopButtonPressedHandler()
        }

        onStrideUpPressed: {
            workoutManager.increaseStrideLevel()
        }

        onStrideDownPressed: {
            workoutManager.decreaseStrideLevel()
        }

        // TFT handling
        onStopPressed: {
            console.log("TFT Console: Stop button pressed")
            stopButtonPressedHandler()
        }

        onStartPressed: {
            if(workoutActive && isTft && machinecontrol.treadmillSpeedActual == 0) {
                if (stopPrompt.visible) {
                    stopPrompt.hide()
                    root.resumeWorkout()
                }
            }
        }

        onStartQuickStartPressed: {
            if(workoutActive && isTft && machinecontrol.treadmillSpeedActual == 0) {
                if (stopPrompt.visible) {
                    stopPrompt.hide()
                    root.resumeWorkout()
                }
            }
        }

        onPlusPressed: if(workoutActive) workoutManager.increaseWorkloadLevel();
        onMinusPressed: if(workoutActive) workoutManager.decreaseWorkloadLevel();
    }

    Connections {
        target: main.isTft && main.state === "RunState" && !isTreadmill && !tftStopPrompt.visible && !(currentViewName === "IPOD_VIEW" && root.ipodVideoShown) ? keymapper : null

        onBackPressed: {
            main.debugKeys("backPressed", "WorkoutScreen")

            console.log("TFT: Back button pressed. Stopping workout")
            stopButtonPressedHandler()
        }
    }

    Connections {
        target: main.state === "RunState" && ["TV_VIEW", "IPOD_VIEW"].indexOf(workoutViewContainer.currentViewName) === -1 ? keymapper : null

        onUpButtonPressed: {
            main.debugKeys("upButtonPressed", "WorkoutScreen")
            volume_controls.volumeUp();
        }

        onDownButtonPressed: {
            main.debugKeys("downButtonPressed", "WorkoutScreen")
            volume_controls.volumeDown();
        }
    }

    Connections{
        target: workoutManager
        onChangingSpeed: {
            if (newspeed > 0) {
                speedChangePrompt.newSpeed = newspeed
                speedChangePrompt.oldSpeed = oldspeed
                speedChangePrompt.show()
            }
        }

    }

    Loader {
        source: workoutProgram.programIndex === WorkoutProgram.STRIDE_INTERVALS_PROG ? "progs/stride_intervals.qml" : ""

    }

    TelevisionFullscreen {
        id: browserFullscreenFrame

        showHeadsetButton: !options.netpulseEnabled
        leftSideDisplay: sideDataDisplay.leftDisplay
        rightSideDisplay: sideDataDisplay.rightDisplay
        visible: root.browserFullscreen
        showHUD: true
        anchors.fill: parent

        onStopButtonPressed: {
            console.log("TelevisionFullScreen: Stop button pressed")
            stopButtonPressedHandler()
        }
        z:9999999999

        onSizeClicked: {
            root.browserFullscreen = false
        }
    }

    SpeedChangePrompt{
        id:speedChangePrompt

        banner: netpulseAvailable
        isTransparent: true
        onTimedOut: hide()
        onVisibleChanged: {
            if(visible) {
                if(workoutActive === true) {
                    buzzer.warningBeep()
                    startTimeout(3)
                }
            }
        }
        onTriggered: buzzer.warningBeep()
        Component.onCompleted: hide()
    }

    StrideChangePrompt{
        id:strideChangePrompt

        banner: netpulseAvailable
        isTransparent: true
        onTimedOut: hide()
        onVisibleChanged: if(visible) {
                              buzzer.buttonPress()
                              startTimeout(3)
                          }
        Component.onCompleted: hide()
    }

    Timer {
        id: safetyKeyPollTimer

        repeat: true
        running: root.workoutActive && isTreadmill && main.lowerSystem === "BRAINBOARD"
        interval: 1000
        onTriggered: {
            // end workout if safety key found to be out
            if(!machinecontrol.estop)
                stopWorkout()
        }
    }

//    onOpacityChanged: {
//        if(opacity)
//        {
//            volume_controls.vol_setting = 5
//        }
//    }

    function start() {
        print("Workout start.")
        // check safety key just before workout starts
        if(!machinecontrol.estop && isTreadmill) {
            stopWorkout()
            return
        }
        if(options.metricUnits == 0) {
            root.unitState = "ENGLISH"
        } else {
            root.unitState = "METRIC"
        }
        setViews()
        sideDataDisplay.reset()
        videoOverlay.reset()
        workoutStarted()

        for(var i = 0 ; i < dataToggleModel.count; i++){
            var item = dataToggleModel.get(i)
            item.thestate = "Enabled"
        }
    }

    function stopWorkout() {
        console.debug("WorkoutScreen: Workout stopped")
        fan.fanSpeed = 0
        toolbar.close()
        tv_menu.menuOpen = false
        fullscreenVideoFrame.endFullscreen()

        if(bikeModeEnabled == true && machineinfo.productTypeString == "Bike") {
            machinecontrol.machineMode = MachineControl.MODE_CONSTANT_POWER
        }

        workoutStopped();
        heartRateCenter.hrCruiseEnabled = false
        speedKeyPadIcon.isDown = false
        inclineKeyPadIcon.isDown = false
        sideDataDisplay.reset()

    }

    function setViews()
    {
        var viewGroup = { views: [], defaultview: TheViews.trackViewDef }

        if(netpulseAvailable) {
            viewGroup.views.push(TheViews.landingViewDef)
            viewGroup.views.push(TheViews.entertainmentViewDef)
        }
        else {
            viewGroup.views.push(TheViews.ipodViewDef)
            if(tv.channelList.channels.count)
                viewGroup.views.push(TheViews.tvViewDef)
        }

        if(c360VideoAvailable) {
            viewGroup.views.push(TheViews.videoWorkoutViewDef)
            if (main.isTft) viewGroup.views.push(TheViews.toolsViewDef)
        }
        else if(c360Available) {
            viewGroup.views.push(TheViews.c360ViewDef)
            if (main.isTft) viewGroup.views.push(TheViews.toolsViewDef)
        }
        else {
            viewGroup.views.push(TheViews.trackViewDef)
            if (workoutProgram.isMonumentWorkout) {
                viewGroup.views.push(TheViews.monumentViewDef)
            } else {
                viewGroup.views.push(TheViews.profileViewDef)
            }
            viewGroup.views.push(TheViews.simpleViewDef)
            if (main.isTft) viewGroup.views.push(TheViews.toolsViewDef)
        }

        if(netpulseAvailable) {
            viewGroup.views.push(TheViews.NPsceneViewDef)
        }
        else if (!main.isTft) {
            viewGroup.views.push(TheViews.sceneViewDef)
        }

        // only add facility view button if some slides exist
        var slides = storageMgr.listFiles("/data/facility", ["*.jpg", "*.png"])
        var userSlides = storageMgr.listFiles("/data/facility/user", ["*.jpg", "*.png"])
        if (slides.length > 0 || userSlides.length > 0)
            viewGroup.views.push(TheViews.facilitiesViewDef)

        dataExport.getNetworkAddresses()
        if(!main.isTft && options.browserEnabled && dataExport.ipAddress) {
            viewGroup.views.push(TheViews.webViewDef)
        }

        if(netpulseAvailable)
            viewGroup.views.push(TheViews.logonViewDef)

        workoutViewContainer.setViews(viewGroup)
    }

    function displayHRPrompt(index) {
        if(netpulseAvailable) {
            infoBanner.showMessage(heartRatePrompt.getMsg(index),5)
        }
        else {
            heartRatePrompt.setMsg(index);
            heartRatePrompt.show();
            heartRatePrompt.startTimeout(5);
        }
    }

    Item{
        id: dataToggleEnums

        property int timeEnum: 0
        property int timeRemainingEnum: 1
        property int paceEnum: 2
        property int paceSetterEnum: 3
        property int distanceEnum: 4
        property int distanceRemainingEnum: 5
        property int caloriesEnum: 6
        property int calsPerHourEnum: 7
        property int wattsEnum: 8
        property int metsEnum: 9
        property int heartRateEnum: 10
        property int targetHREnum: 11
        property int strideLengthEnum: 12
    }

    ListModel{
        id: dataToggleModel

        ListElement{thestate: "Enabled"}
        ListElement{thestate: "Enabled"}
        ListElement{thestate: "Enabled"}
        ListElement{thestate: "Enabled"}
        ListElement{thestate: "Enabled"}
        ListElement{thestate: "Enabled"}
        ListElement{thestate: "Enabled"}
        ListElement{thestate: "Enabled"}
        ListElement{thestate: "Enabled"}
        ListElement{thestate: "Enabled"}
        ListElement{thestate: "Enabled"}
        ListElement{thestate: "Enabled"}
        ListElement{thestate: "Enabled"}
        ListElement{thestate: "Enabled"}
        ListElement{thestate: "Enabled"}
    }

    Image {
        id: leftDataBackground

        anchors.top: parent.top
        anchors.topMargin: -32 * main.screenScaleY
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.horizontalCenterOffset: -226 * main.screenScaleX
        width: 510 * main.screenScaleX
        height: 260 * main.screenScaleY
        source: main.graphicsPath + "224/224_Data_Data_Point_Window_Left.png"
    }

    Image {
        id: rightDataBackground

        anchors.top: parent.top
        anchors.topMargin: -32 * main.screenScaleY
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.horizontalCenterOffset: 226 * main.screenScaleX
        width: 510 * main.screenScaleX
        height: 260 * main.screenScaleY
        source: main.graphicsPath + "224/224_Data_Data_Point_Window_Right.png"
    }

    HeartRatePanel {
        id: heartRateCenter

        heartRate: aWorkoutRunData.heartRate
        heartRateMax: 220 - setupScreen.ageForProgSummary
        showTargetHeartRate: root.hrTargetVisibility
        targetHeartRate: workoutProgram.targetHR
        cruiseAllowed: heartRateManager.heartRateAvailable && !workoutProgram.isHRCProgram && !workoutProgram.isC360Program && workoutProgram.currentProgram != WorkoutProgram.FITNESS_TEST_PROG && (aWorkoutRunData.mode == WorkoutRunData.WORKOUT_MODE)
        anchors.horizontalCenter: parent.horizontalCenter

        onHrCruiseEnabledChanged: {
            workoutManager.cruiseControlEnabled = heartRateCenter.hrCruiseEnabled
            console.debug("HR Cruise: "+hrCruiseEnabled + " at HR:" + aWorkoutRunData.heartRate)
        }

        Connections {
            target: workoutManager
            onCruiseControlEnabledChanged: {
                heartRateCenter.hrCruiseEnabled = workoutManager.cruiseControlEnabled
            }
        }

        Connections{
            target: keymapper
            onCruiseControlPressed: {
                if (main.state === "RunState") {
                    heartRateCenter.hrCruiseEnabled = !heartRateCenter.hrCruiseEnabled
                }
            }
        }
    }

    PID {
        id: hrcPid
        kP: 1.0
        kI: 0.0
        kD: 1.0
        interval: 3000
        running: false
        actual: heartRateCenter.heartRate
        onOutChanged: {
            console.debug("machinecontrol.workload: " + machinecontrol.workload)
            machinecontrol.workload = machinecontrol.workload + out
            console.debug("Pid output: " + out + "  machinecontrol.workload: " + machinecontrol.workload)
        }
    }

    SideDataDisplays{
        id:sideDataDisplay

        visible: workoutViewContainer.currentViewName !== TheViews.simpleButtonDesc.name
    }

    ViewContainer{
        id:workoutViewContainer

        opacity: root.opacity
        focus: visible && (opacity > 0)
        workoutScreen: root
        defaultView: {
            if(netpulseAvailable)
                return "LANDING_VIEW"
            else
                return tv.currentChannel >=0 ? "TV_VIEW" : workoutProgram.defaultView
        }

        Binding { target: application; property: "swipeStartX"; value: workoutViewContainer.x; when: main.state === "RunState" }
        Binding { target: application; property: "swipeEndX"; value: workoutViewContainer.x + workoutViewContainer.width; when: main.state === "RunState" }
        Binding { target: application; property: "swipeStartY"; value: workoutViewContainer.y; when: main.state === "RunState" }
        Binding { target: application; property: "swipeEndY"; value: workoutViewContainer.y + workoutViewContainer.height; when: main.state === "RunState" }
    }

    Text {
        id: userHelpText
        visible: main.isTft && root.visible
        opacity: visible ? 1.0 : 0.0
        font { family: "arial"; pixelSize: 36 * main.screenScaleY; bold: true }
        color: "#6c6c6c"
        text: {
            if (container.currentViewName === "PROFILE_VIEW") {
                return qsTr("press ENTER to change graph tab") + application.emptyString
            } else if (container.currentViewName === "TV_VIEW") {
                if (tvMenuShowing)
                    return qsTr("use") + " <img src=" + main.graphicsPath + "tft/REW_icon.png\" /> &nbsp;<img src=" + main.graphicsPath + "tft/FWD_icon.png\" />"  + qsTr("to navigate, press ENTER to select") + application.emptyString
                else
                    return qsTr("use") + " <img src=" + main.graphicsPath + "tft/arrow_left.png\" /> " + qsTr("or") + " <img src=" + main.graphicsPath + "tft/arrow_right.png\" /> " + qsTr("to change workout view") + application.emptyString
            } else {
                return qsTr("use") + " <img src=" + main.graphicsPath + "tft/arrow_left.png\" /> " + qsTr("or") + " <img src=" + main.graphicsPath + "tft/arrow_right.png\" /> " + qsTr("to change workout view") + application.emptyString
            }
        }
        anchors { top: container.bottom; topMargin: -5 * main.screenScaleY }
        anchors.horizontalCenter: parent.horizontalCenter
    }

    BikeModePrompt{
        id:bikeModePrompt

        anchors.horizontalCenter: root.horizontalCenter
        anchors.verticalCenter: root.verticalCenter

        onAcceptClicked: {machinecontrol.machineMode = MachineControl.MODE_CONSTANT_TORQUE; hide();}
        onCancelClicked: {machinecontrol.machineMode = MachineControl.MODE_CONSTANT_POWER; hide();}
        onTimedOut: hide()

        Component.onCompleted: hide()
    }

    WorkoutToolbar {
        id: toolbar
        visible: main.isTouch

        onFanButtonPressed: {

            if (fan.fanSpeed === 100)
                fan.fanSpeed = 0
            else
                fan.fanSpeed = 100

        }
        showQuickKeys: machineinfo.productTypeString === "Treadmill"
        showStrideBar: main.isCSA
        showIntensifier: main.isLateralTrainer
        onSpeedChange: {
            var speedEnglish
            workoutManager.stopHRC()
            if(root.unitState === "METRIC") {
                speedEnglish = Globals.kmToMile(speed)
            } else {
                speedEnglish = speed
            }

            if (speedEnglish <= workoutManager.workoutProgram.maxSpeed) {
                if(root.unitState === "METRIC") {
                    workoutManager.setTreadSpeedMetric(speed * 10)
                } else {
                    workoutManager.treadSpeed = speed * 10
                }
            }
        }
        currentSpeed: workoutManager.treadSpeedGUI
        currentIncline: workoutManager.treadInclineGUI
        onInclineChange: {
            if(incline <= workoutManager.workoutProgram.maxIncline){
                workoutManager.stopHRC()
                workoutManager.treadIncline = incline*10
            }
       }
        cooldownEnabled: workoutProgram.cooldownEnabled
        anchors { left: parent.left ; leftMargin: 20 * main.screenScaleX }
        anchors { bottom: parent.bottom ; bottomMargin: 10 * main.screenScaleY }

        onBikeModeButtonPressed: {
            if(!bikeModeEnabled){
                root.showBikeModePrompt()
            }
        }
        workoutMode: aWorkoutRunData.mode
        onCooldownPressed: workoutManager.startCooldown()
    }

    IntensifierButton {
        id: intensifierButton

        allowed: !workoutProgram.isHRCProgram &&
                 !workoutProgram.isFitnessTest &&
                 !workoutManager.cruiseControlEnabled
        intensifierActive: workoutManager.intensifierEnabled
        onIntensifierPressed: {
            workoutManager.intensifierEnabled = !workoutManager.intensifierEnabled
        }

        visible: main.isLateralTrainer
        anchors {
            bottom: parent.bottom
            bottomMargin: 15 * main.screenScaleY
            horizontalCenter: parent.horizontalCenter
            horizontalCenterOffset: 35 * main.screenScaleX
        }
    }

    Image{
        id: bikeModeMPHGauge
        visible: bikeModeEnabled
        source: main.graphicsPath + "224/SPEED_METER_bikemode.png"
        anchors.bottom: main.isTft ? stopTftArea.top : stopButton.top
        anchors.bottomMargin: 10 * main.screenScaleY
        anchors.horizontalCenter: stopButton.horizontalCenter
        height: implicitHeight
        width: implicitWidth

        Text{
            id:value
            anchors.verticalCenter: parent.verticalCenter
            anchors.verticalCenterOffset: -5 * main.screenScaleY
            anchors.horizontalCenter: parent.horizontalCenter
            text: {
                if (root.unitState === "ENGLISH")
                    aWorkoutRunData.bikeSpeedMph.toFixed(1)
                else
                    Globals.mileToKm(aWorkoutRunData.bikeSpeedMph).toFixed(1)
            }
            font.pointSize: 36 * main.screenScaleY
            font.bold: true
        }

        Text{
            id: label
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 5 * main.screenScaleY
            anchors.horizontalCenter: parent.horizontalCenter
            text: root.unitState === "ENGLISH" ? "MPH" : "KPH"
            font.pointSize: 14 * main.screenScaleY
            font.bold: true
        }
        z: sideDataDisplay.z - 1
    }

    ImageButton {
        id: stopButton
        visible: main.isTouch

        anchors.bottom: parent.bottom
        anchors.bottomMargin: 15 * main.screenScaleY
        anchors.right: parent.right
        anchors.rightMargin: 20 * main.screenScaleX
        fontsize: 14 * main.screenScaleY
        label_color: "black"
        label_under: true
        downimage: main.graphicsPath + "224/224_Data_Stop_Down.png"
        upimage: main.graphicsPath + "224/224_Data_Stop_Disabled.png"
        label: qsTr("STOP") + "/" + qsTr("PAUSE") + application.emptyString
        label_y_offset: 10 * main.screenScaleY

        onClicked: {
            console.log("WorkoutScreen: Stop button pressed")
            stopButtonPressedHandler()
        }
        z: workoutViewContainer.z + 1
        mouseAreaScale: 1.15
    }

    Item {
        id: stopTftArea
        width: 125 * main.screenScaleX
        height: childrenRect.height
        visible: main.isTft && !isTreadmill
        anchors { bottom: parent.bottom; bottomMargin: 15 * main.screenScaleY; right: parent.right; rightMargin: 20 * main.screenScaleX }

        Text {
            id: backText
            text: qsTr("press BACK for") + application.emptyString
            width: 100 * main.screenScaleX
            font { pixelSize: 16 * main.screenScaleY; bold: true }
            wrapMode: Text.WordWrap
            horizontalAlignment: Text.AlignHCenter
            anchors { top: parent.top; horizontalCenter: parent.horizontalCenter }
        }
        Text {
            id: stopPauseText
            text: qsTr("STOP") + "/" + qsTr("PAUSE") + application.emptyString
            width: 100 * main.screenScaleX
            font { pixelSize: 16 * main.screenScaleY; bold: true }
            wrapMode: Text.WordWrap
            horizontalAlignment: Text.AlignHCenter
            anchors { top: backText.bottom; topMargin: 5 * main.screenScaleY; horizontalCenter: parent.horizontalCenter }
        }
    }

    Connections
    {
        target: popupManager
        onEstopPopupPopped: if(workoutActive && main.lowerSystem === "BRAINBOARD"){stopWorkout()}
    }

    Connections {
        target: errorManager
        onPreventUseChanged: {
            if(main.lowerSystem === "BRAINBOARD" && workoutActive && errorManager.preventUse)
                stopWorkout()
        }
    }

    TftWorkoutEndPrompt {
        id: tftStopPrompt

        rpmPause: rpmPauseTimer.wasTriggered
        x: 300 * main.screenScaleX; y: 250 * main.screenScaleY
        visible: false
        onVisibleChanged: {
            if (!visible)
                rpmPauseTimer.wasTriggered = false
        }
        onTimedOut: {
            hide()
            stopWorkout()
        }
    }

    Connections {
        target: main.isTft && main.state === "RunState" && tftStopPrompt.visible ? keymapper : null

        onBackPressed: {
            main.debugKeys("backPressed", "WorkoutScreen")
            tftStopPrompt.hide()
            stopWorkout()
        }

        onStopPausePressed: {
            main.debugKeys("stopPausePressed", "WorkoutScreen")
            tftStopPrompt.hide()
            stopWorkout()
        }

        onStopPressed: {
            main.debugKeys("stopPressed", "WorkoutScreen")
            tftStopPrompt.hide()
            stopWorkout()
        }
    }

//    Connections
//    {
//        target: personPresentDetectionManager
//        onDisplayStopPrompt: if(workoutActive){stopPrompt.show(); stopPrompt.startTimeout(30)}
//    }

    WorkoutEndPrompt {
        id: _stopPrompt

        x: 300 * main.screenScaleX ; y: 250 * main.screenScaleY
        visible: false
        onTimedOut: {
            stopWorkout()
            hide()
        }
        onStopClicked: {
            stopWorkout()
            hide()
        }
        onResumeClicked: {
            if(nucleus.systemReady === true){
                hide()
                root.resumeWorkout()
            }
        }
    }

    Timer {
        id: rpmPauseTimer
        property bool wasTriggered: false

        interval: 10000
        running: !options.disableNoPedalStop && workoutActive && !isTreadmill && !stopPrompt.visible && machinecontrol.pedalRPM == 0
        onTriggered: {
            if(!workoutActive)
                return

            rpmPauseTimer.wasTriggered = true
            if(options.resumeWorkoutTimeout){
                print("No pedal. Prompt end of workout.")
                stopPrompt.show()
                stopPrompt.startTimeout(options.resumeWorkoutTimeout)
                workoutPaused()
            }
            else{
                stopPrompt.show()
                workoutPaused()
            }

            reset()
        }

    }

    Connections {
        target: machinecontrol
        onPedalRPMChanged: {
            if(workoutActive && (pedalRPM > 0) && !options.disableNoPedalStop) {
                rpmPauseTimer.restart()
                if (stopPrompt.visible && isTft && rpmPauseTimer.wasTriggered) {
                    stopPrompt.hide()
                    rpmPauseTimer.wasTriggered = false
                    root.resumeWorkout()
                }
            }
        }
        onStrideLengthTargetChanged: {
            if (!main.isCSA)
                return

            if(!workoutActive)
                return

            strideChangePrompt.oldStride = strideChangePrompt.newStride
            strideChangePrompt.newStride = strideLengthTarget
            strideChangePrompt.show()
            strideChangePrompt.startTimeout(3)
        }

        onSafetyKeyPulled: {
            if(main.lowerSystem === "NUCLEUS" && workoutActive === true) {
                stopButtonPressedHandler();
            }
        }

        onSafetyKeyPulledDueToFault: {
            if(main.lowerSystem === "NUCLEUS" && workoutActive === true) {
                stopButtonPressedHandler();
            }
        }
    }

    HeartRatePrompts {
        id: heartRatePrompt

        x: 260 * main.screenScaleX
        y: 220 * main.screenScaleY
        visible: false
        onTimedOut: {
            hide();
        }
    }

    PaceSetter {
        id: paceSetter

        property bool isShowing: currentViewName !== TheViews.simpleButtonDesc.name

        rpm: aWorkoutRunData.rpm
        paceTarget: workoutManager.paceTarget
        paceLevel: workoutManager.paceLevel
        onLevelUp: workoutManager.increasePaceLevel()
        onLevelDown: workoutManager.decreasePaceLevel()
        showPaceSetter: root.showPaceSetter

        anchors.top: parent.top
        anchors.topMargin: -20 * main.screenScaleY
        anchors.right: parent.right
        anchors.rightMargin: 189 * main.screenScaleX

        bikeModeEnabled: root.bikeModeEnabled
        visible: isShowing && !isTreadmill
    }

    Item {
        id: levelControls

        property bool isShowing: currentViewName !== TheViews.simpleButtonDesc.name

        anchors.top: parent.top
        anchors.topMargin: 10 * main.screenScaleY
        anchors.left: parent.left
        anchors.leftMargin: 175 * main.screenScaleX
        width: 260 * main.screenScaleX
        height: 150 * main.screenScaleY
        visible: isShowing && !isTreadmill

        z: workoutViewContainer.z + 1

        function getIcon()
        {
            if( isTreadmill )
                return main.graphicsPath + "netpulse/WORKLOAD-INCLINE_icon_GRAY.png"
            else if(root.bikeModeEnabled)
                return main.graphicsPath + "224/GEAR-LEVEL_icon_bikemode.png"
            else
                return main.graphicsPath + "224/WORKLOADlevel_icon_GRAY.png"
        }

        function getLabel()
        {
            if(root.bikeModeEnabled)
                return qsTr("GEAR")
            else
                return qsTr("LEVEL")
        }

        ImageButton {
            id: levelUpButton
            visible: main.isTouch
            repeat: true
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.verticalCenter: parent.verticalCenter
            anchors.verticalCenterOffset: -45 * main.screenScaleY
            downimage: main.graphicsPath + "netpulse/UpArrow_PRESSED.png"
            upimage: main.graphicsPath + "netpulse/UpArrow_blue.png"
            icon: main.graphicsPath + "netpulse/PLUS_icon_BLACK.png"
            onClicked: keymapper.keyFunctionHandler(7) //workoutManager.increaseWorkloadLevel()
            mouseAreaScale: 1.25
        }

        Text {
            id: levelValue
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.horizontalCenterOffset: ( main.isTft ? 15 : 0 ) * main.screenScaleX
            anchors.verticalCenter: parent.verticalCenter
            anchors.verticalCenterOffset: ( main.isTft ? -20 : 0 ) * main.screenScaleY
            color: "black"
            font.pointSize: main.isTft ? 32 : 22 * main.screenScaleY
            font.bold: true
            text: workoutManager.workloadLevel
        }

        Text {
            id: levelLabel
            anchors.verticalCenter: main.isTouch ? levelValue.verticalCenter : undefined
            anchors.top: main.isTft ? levelValue.bottom : undefined
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.horizontalCenterOffset: ( main.isTouch ? 65 : 15 ) * main.screenScaleX
            color: "black"
            font.pointSize: 12 * main.screenScaleY
            font.bold: true
            text: parent.getLabel() + application.emptyString
        }

        ImageButton {
            id: levelDownButton
            visible: main.isTouch

            onClicked: keymapper.keyFunctionHandler(8) //workoutManager.decreaseWorkloadLevel()
            repeat: true
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.verticalCenter: parent.verticalCenter
            anchors.verticalCenterOffset: 45 * main.screenScaleY
            downimage: main.graphicsPath + "netpulse/DownArrow_PRESSED.png"
            upimage: main.graphicsPath + "netpulse/DownArrow_blue.png"
            icon: main.graphicsPath + "netpulse/MINUS_icon_BLACK.png"
            icon_y_offset: -5 * main.screenScaleY
            mouseAreaScale: 1.25
        }

        Image {
            id: workloadIcon

            anchors.horizontalCenter: parent.horizontalCenter
            anchors.horizontalCenterOffset: 90 * main.screenScaleX
            source: parent.getIcon()
        }
    } // end levelControls

    Item {
        id: inclineControls

        property bool isShowing: currentViewName !== TheViews.simpleButtonDesc.name

        anchors.top: parent.top
        anchors.topMargin: 10 * main.screenScaleY
        anchors.left: parent.left
        anchors.leftMargin: 185 * main.screenScaleX
        width: 250 * main.screenScaleX
        height: 150 * main.screenScaleY
        visible: isShowing && isTreadmill

        z: workoutViewContainer.z + 1

        Text {
            id: inclineValue
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.horizontalCenterOffset: 10 * main.screenScaleX
            anchors.verticalCenter: parent.verticalCenter
            anchors.verticalCenterOffset: 0
            color: "black"
            font.pointSize: 32 * main.screenScaleY
            font.bold: true
            text: (machinecontrol.treadmillInclineTarget / 10.0).toFixed(1)
        }

        Text {
            id: inclineLabel
            anchors.verticalCenter: inclineValue.verticalCenter
            anchors.horizontalCenter: inclineValue.horizontalCenter
            anchors.verticalCenterOffset: -30 * main.screenScaleY
            color: "black"
            font.pointSize: 12 * main.screenScaleY
            font.bold: true
            text: qsTr("INCLINE") + application.emptyString
        }

        Text {
            id: inclineUnits
            anchors.verticalCenter: inclineValue.verticalCenter
            anchors.horizontalCenter: inclineValue.horizontalCenter
            anchors.verticalCenterOffset: 30 * main.screenScaleY
            color: "black"
            font.pointSize: 12 * main.screenScaleY
            font.bold: true
            text: qsTr("%") + application.emptyString
        }

        Image {
            id: inclineIcon

            anchors.top: parent.top
            anchors.topMargin: 0
            anchors.right: parent.right
            anchors.rightMargin: -5 * main.screenScaleX
            source: main.graphicsPath + "netpulse/WORKLOAD-INCLINE_icon_GRAY.png"
        }


        Connections{
            target:root
            onWorkoutStarted:inclineKeyPadIcon.isDown = false
        }
    }

    ImageButton {
        id: inclineKeyPadIcon
        anchors.bottom: inclineControls.bottom
        anchors.horizontalCenter: inclineControls.horizontalCenter
        anchors.horizontalCenterOffset: -20 * main.screenScaleX
        upimage: main.graphicsPath + "224/KEYPAD_icon_tread.png"
        downimage: main.graphicsPath + "224/KEYPAD_icon_tread.png"
        toggle: true
        visible: main.isTouch && isTreadmill && !netpulseAvailable
        mouseAreaScale: 3.0
    }

    Item {
        id: speedControls

        property bool isShowing: currentViewName !== TheViews.simpleButtonDesc.name

        anchors.top: parent.top
        anchors.topMargin: 10 * main.screenScaleY
        anchors.right: parent.right
        anchors.rightMargin: 185 * main.screenScaleX
        width: 250 * main.screenScaleX
        height: 150 * main.screenScaleY
        visible: isShowing && isTreadmill

        z: workoutViewContainer.z + 1

        Text {
            id: speedValue
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.verticalCenter: parent.verticalCenter
            color: "black"
            font.pointSize: 32 * main.screenScaleY
            font.bold: true
            text: {
                if (root.unitState === "ENGLISH")
                    return (workoutManager.treadSpeedGUI / 10).toFixed(1)
                else
                    return (workoutManager.treadSpeedMetricGUI / 10).toFixed(1)
            }
        }

        Text {
            id: speeedLabel
            anchors.verticalCenter: speedValue.verticalCenter
            anchors.horizontalCenter: speedValue.horizontalCenter
            anchors.verticalCenterOffset: -30 * main.screenScaleY
            color: "black"
            font.pointSize: 12 * main.screenScaleY
            font.bold: true
            text: qsTr("SPEED") + application.emptyString
        }

        Text {
            id: speedUnits
            anchors.verticalCenter: speedValue.verticalCenter
            anchors.horizontalCenter: speedValue.horizontalCenter
            anchors.verticalCenterOffset: 30 * main.screenScaleY
            color: "black"
            font.pointSize: 12 * main.screenScaleY
            font.bold: true
            text: root.unitState === "ENGLISH" ? "MPH" : "KPH"
        }

        Image {
            id: speedIcon

            anchors.top: parent.top
            anchors.topMargin: -3 * main.screenScaleY
            anchors.left: parent.left
            anchors.leftMargin: 5 * main.screenScaleX
            source: main.graphicsPath + "netpulse/PACE-SPEED_icon_GRAY.png"
        }

        Connections{
            target:root
            onWorkoutStarted:speedKeyPadIcon.isDown = false
        }
    }

    ImageButton {
        id: speedKeyPadIcon
        anchors.bottom: speedControls.bottom
        anchors.horizontalCenter: speedControls.horizontalCenter
        anchors.horizontalCenterOffset: 20 * main.screenScaleX
        upimage: main.graphicsPath + "224/KEYPAD_icon_tread.png"
        downimage: main.graphicsPath + "224/KEYPAD_icon_tread.png"
        toggle: true
        visible: main.isTouch && isTreadmill && !netpulseAvailable
        mouseAreaScale: 3.0
    }
    function getInclineLevelFromTable(incline){

        var table = workoutManager.workoutProgram.inclineTable
        var i
        incline *= 10
        for(i = 0; i < table.length; i++)
        {
            if(table[i] === incline) return i;
            if(incline > table[i] && incline < table[i+1] && i < table.length){
                var interval = table[i+1] - table[i]
                if((incline - table[i]) < (interval / 2)) return i;
                else return i+1
            }
        }
        return -1
    }

    Keypad{
        id:inclineKeyPad
        units: "%"
        length: 3
        decimalPlaces: 1
        clear_after_enter: false
        icon: main.graphicsPath + "netpulse/WORKLOAD-INCLINE_icon_GRAY.png"
        state: inclineKeyPadIcon.isDown ? "showing" : "notshowing"
        anchors.left: parent.left
        anchors.leftMargin: -11 * main.screenScaleX
        anchors.verticalCenter: parent.verticalCenter
        anchors.verticalCenterOffset: -35 * main.screenScaleY
        z:inclineControls.z
        onClose: inclineKeyPadIcon.isDown = false

        Connections {
            target: workoutManager
            onTreadInclineGUIChanged: inclineKeyPad.setValue(workoutManager.treadInclineGUI)
        }

        onValueEntered: {
            if(val <= workoutManager.workoutProgram.maxIncline){
                var incline = workoutProgram.tableClosestValue(workoutProgram.inclineTable, val*10)
                console.log("WorkoutScreen: Incline set via on-screen keypad")
                workoutManager.stopHRC()
                workoutManager.treadIncline = incline
            }
            else
                inclineKeyPad.setValue(workoutManager.treadInclineGUI)

        }

        onStateChanged: {
            if(state === "showing"){
                inclineKeyPad.setValue(workoutManager.treadInclineGUI)
            }
        }

        states: [
            State{name: "showing"
                PropertyChanges { target: inclineKeyPad; anchors.leftMargin: -11 * main.screenScaleX}
            },
            State{name: "notshowing"
                PropertyChanges { target: inclineKeyPad; anchors.leftMargin: -350 * main.screenScaleX}
            }
        ]
        transitions: [
            Transition {
                from: "notshowing"
                to: "showing"
                reversible: true
                SequentialAnimation {
                    NumberAnimation { duration: 500; properties: "anchors.leftMargin" ;easing.type:Easing.OutBack }
                }
            }
        ]
    }

    BluetoothDeviceSelectionDialog{
        id: btHRSelectionDialog
        isTop: true
        isTransparent: false
        height: root.height * 0.42
        width: root.width * 0.60
        anchors.horizontalCenter: root.horizontalCenter
        anchors.verticalCenter: root.verticalCenter
        isLowEnergy: false

        onClosed: btHRSelectionDialog.hide()
        //onHeadsetConnected: btDeviceSelectionDialog.hide()
        //onHeadsetDisconnected: btDeviceSelectionDialog.hide()

    }

    Keypad{
        id:speedKeyPad
        units: root.unitState === "ENGLISH" ? "MPH" : "KPH"
        length: 3
        decimalPlaces: 1
        clear_after_enter: false
        icon: main.graphicsPath + "netpulse/PACE-SPEED_icon_GRAY.png"
        state: speedKeyPadIcon.isDown ? "showing" : "notshowing"
        anchors.right: parent.right
        anchors.rightMargin: -11 * main.screenScaleX
        anchors.verticalCenter: parent.verticalCenter
        anchors.verticalCenterOffset: -35 * main.screenScaleY
        z:speedControls.z
        onClose: speedKeyPadIcon.isDown = false

        property int convertedTreadSpeed: root.unitState === "METRIC" ? workoutManager.treadSpeedMetricGUI : workoutManager.treadSpeedGUI

        onConvertedTreadSpeedChanged: speedKeyPad.setValue(speedKeyPad.convertedTreadSpeed)

        Connections {
            target: workoutManager
            onTreadSpeedGUIChanged: speedKeyPad.setValue(speedKeyPad.convertedTreadSpeed)
        }

        onValueEntered: {
            var myVal = val
            var minSpeed = machineinfo.treadmillSpeedMinMph / 10
            if (root.unitState === "METRIC")
                myVal = Globals.kmToMile(parseFloat(val))
            if((myVal >= minSpeed) && myVal <= workoutManager.workoutProgram.maxSpeed) {
                workoutManager.stopHRC()
                console.log("WorkoutScreen: Speed set via on-screen keypad")
                if(root.unitState === "ENGLISH") {
                    workoutManager.treadSpeed = myVal * 10
                } else {
                    workoutManager.setTreadSpeedMetric(parseFloat(val) * 10)
                }            
            }
            else if(myVal < minSpeed){
                console.log("WorkoutScreen: Speed set via on-screen keypad. Value entered less than minimum.")
                workoutManager.stopHRC()
                workoutManager.treadSpeed = minSpeed * 10
                speedKeyPad.setValue(convertedTreadSpeed)
            }
            else
                speedKeyPad.setValue(convertedTreadSpeed)
        }

        onStateChanged: {
            if(state === "showing"){
                speedKeyPad.setValue(convertedTreadSpeed)
            }
        }

        states: [
            State{name: "showing"
                PropertyChanges { target: speedKeyPad; anchors.rightMargin: -11 * main.screenScaleX}
            },
            State{name: "notshowing"
                PropertyChanges { target: speedKeyPad; anchors.rightMargin: -350 * main.screenScaleX}
            }
        ]
        transitions: [
            Transition {
                from: "notshowing"
                to: "showing"
                reversible: true
                SequentialAnimation {
                    NumberAnimation { duration: 500; properties: "anchors.rightMargin" ;easing.type:Easing.OutBack }
                }
            }
        ]
    }


}
