import QtQuick 2.4
import WorkoutRunData 1.0
import Components 1.0

Item {
    id: root

    property real toolbarOpacity : 0
    property bool bikeModeAvailable: workoutProgram.bikeModeAvailable
    property bool changeWorkoutEnabled: false
    property bool cooldownEnabled: true
    property bool opened: false
    property bool showQuickKeys: false
    property bool showStrideBar: false
    property bool showIntensifier: false
    property int workoutMode
    property int currentSpeed
    property int currentIncline

    signal speedChange(real speed)
    signal inclineChange(int incline)
    signal bikeModeButtonPressed()
    signal cooldownPressed()
    signal fanButtonPressed()

    function close() {
        root.opened = false
    }

    onOpenedChanged: {
        if (root.opened)
            root.state = "SHOW"
        else
            root.state = "HIDE"
    }

    width: 1160 * main.screenScaleX; height: 80 * main.screenScaleY
    state: "HIDE"

    BorderImage {
        id: toolbarBackground
        anchors.verticalCenter: parent.verticalCenter
        source: main.graphicsPath + "224/224_Data_ToolBar_Gradation.png"
        width: 143 * main.screenScaleX; height: 60 * main.screenScaleY
        border.left: 20 * main.screenScaleX
        border.right: 20 * main.screenScaleX
        horizontalTileMode: BorderImage.Stretch
    }

    ImageButton {
        id: toolsButton

        anchors.verticalCenter: parent.verticalCenter
        fontsize: 12 * main.screenScaleY
        downimage: main.graphicsPath + "224/224_Data_ToolBar_Round.png"
        upimage: main.graphicsPath + "224/224_Data_ToolBar_Round.png"
        icon: main.graphicsPath + "224/224_Data_ToolBar_BLK_Arrow_right.png"
        label: qsTr("")

        onClicked: {
            root.opened = root.opened ? false : true
        }

        mouseAreaScale: 2.0
    }

    Text {
        id: toolbarLabel

        anchors.verticalCenter: parent.verticalCenter
        x: 78 * main.screenScaleX
        color: "black"
        font.pointSize: 11 * main.screenScaleY
        font.bold: true
        text: qsTr("SHOW\nTOOLS") + application.emptyString
    }

    QuickSpeedBar {
        id: quickKeys

        visible: showQuickKeys
        enabled: visible && opacity > 0
        anchors.verticalCenter: parent.verticalCenter
        opacity: root.toolbarOpacity
        onSpeedChange: root.speedChange(speed)
        onInclineChange: root.inclineChange(incline)
        currentSpeed: root.currentSpeed
        currentIncline: root.currentIncline
        x: 200 * main.screenScaleX
    }

    StrideBar {
        id: strideBar

        visible: root.showStrideBar
        enabled: visible && opacity > 0
        anchors.verticalCenter: parent.verticalCenter
        opacity: root.toolbarOpacity
        onStrideSelected: {
            workoutManager.strideLevel = stride
        }
        currentStride: workoutManager.strideLevel
        x: 170 * main.screenScaleX
    }

    Row {
        id: toolButtons
        anchors.verticalCenter: parent.verticalCenter
        anchors.left: showIntensifier ? parent.left : (showStrideBar ? strideBar.right : quickKeys.right)
        anchors.leftMargin: ( showIntensifier ? 190 : 40 ) * main.screenScaleX
        height: parent.height
        spacing: 30 * main.screenScaleX

        ImageButton {
            id: bikeModeButton

            enabled: visible && opacity > 0
            onClicked: {
                bikeModeButtonPressed()
            }

            visible: root.bikeModeAvailable && machineinfo.productTypeString == "Bike"
            anchors.verticalCenter: parent.verticalCenter
            label_color: "black"
            fontsize: 14 * main.screenScaleY
            opacity: root.toolbarOpacity
            downimage: main.graphicsPath + "224/224_Data_ToolBar_Round_Down.png"
            upimage: workoutScreen.bikeModeEnabled ? main.graphicsPath + "224/224_Data_ToolBar_Round_Green.png" : main.graphicsPath + "224/224_Data_ToolBar_Round_Disabled.png"
            icon: main.graphicsPath + "224/button_icon_bikemode.png"
        }

        ImageButton {
            id: changeWorkoutButton

            enabled: visible && opacity > 0
            visible: root.changeWorkoutEnabled
            anchors.verticalCenter: parent.verticalCenter
            fontsize: 12 * main.screenScaleY
            opacity: root.toolbarOpacity
            downimage: main.graphicsPath + "224/224_Data_ToolBar_Round_Down.png"
            upimage: main.graphicsPath + "224/224_Data_ToolBar_Round_Disabled.png"
            icon: main.graphicsPath + "224/224_Data_ToolBar_Icon_Workoutfinder.png"
            label: qsTr("")
        }

        ImageButton {
            id: coolDownButton

            enabled: visible && opacity > 0
            anchors.verticalCenter: parent.verticalCenter
            fontsize: 12 * main.screenScaleY
            opacity: root.cooldownEnabled ? root.toolbarOpacity : 0.0
            downimage: main.graphicsPath + "224/224_Data_ToolBar_Round_Down.png"
            upimage: (workoutMode == WorkoutRunData.COOL_DOWN_MODE) ? // show the cooldown button pressed when already in cooldown
                         main.graphicsPath + "224/224_Data_ToolBar_Round_Down.png" : main.graphicsPath + "224/224_Data_ToolBar_Round_Disabled.png"
            icon: main.graphicsPath + "224/224_Data_ToolBar_Icon_CoolDown.png"
            label: qsTr("")
            onClicked: cooldownPressed()
        }

        ImageButton {
            id: fanControl

            enabled: visible && opacity > 0
            anchors.verticalCenter: parent.verticalCenter
            anchors.verticalCenterOffset: 4 * main.screenScaleY
            opacity: root.toolbarOpacity
            height: parent.height
            fontsize: 12 * main.screenScaleY
            upimage: fan.fanSpeed === 100 ? main.graphicsPath + "224/224_Data_ToolBar_Round_Green.png" : main.graphicsPath + "224/224_Data_ToolBar_Round.png"
            downimage: upimage
            onClicked: fanButtonPressed()
            icon: main.graphicsPath + "224/224_Data_ToolBar_Icon_Fan.png"
            label: qsTr("") //+ application.emptyString
        }

    }

    states: [
        State {
            name: "HIDE"
            PropertyChanges {
                target: toolsButton
                icon: main.graphicsPath + "224/224_Data_ToolBar_BLK_Arrow_right.png"
            }
            PropertyChanges {
                target: toolbarLabel
                text: qsTr("SHOW\nTOOLS") + application.emptyString
            }
            PropertyChanges {
                target: toolbarBackground
                width: 143 * main.screenScaleX
            }
            PropertyChanges {
                target: root
                toolbarOpacity: 0
            }
        },
        State {
            name: "SHOW"
            PropertyChanges {
                target: toolsButton
                icon: main.graphicsPath + "224/224_Data_ToolBar_BLK_Arrow_Left.png"
            }
            PropertyChanges {
                target: toolbarLabel
                text: qsTr("HIDE\nTOOLS") + application.emptyString
            }
            PropertyChanges {
                target: toolbarBackground
                width: showIntensifier ? 400 * main.screenScaleX : (475 + toolButtons.width + (showQuickKeys ? 440 : 0) + (showStrideBar ? 530 : 0)) * main.screenScaleX
            }
            PropertyChanges {
                target: root
                toolbarOpacity: 1
            }
            PropertyChanges { target: quickKeys ; unlocked: false }
        }
    ]

    transitions: [
        Transition {
            to: "SHOW"
            from: "HIDE"
            reversible: true
            ParallelAnimation {
                NumberAnimation { duration: 400; properties: "width" }
                NumberAnimation { duration: 400; properties: "toolbarOpacity" }
            }
        }
    ]
} // end Toolbar
