import QtQuick 2.4
import ".."
import WorkoutManager 1.0
import WorkoutRunData 1.0
import Components 1.0

Item {
    id: root

    property int startElevation: workoutProgram.startElevation
    property int endElevation: workoutProgram.endElevation
    property int currentUserElevation: startElevation + aWorkoutRunData.workoutFeetClimbed
    property string climbTimeRemaining: Globals.secondsToMSString(aWorkoutRunData.climbTimeRemaining)
    property string projectedFinishTime: workoutManager.treadIncline > 0 && workoutManager.treadSpeed > 0 ? Globals.secondsToMSString(aWorkoutRunData.projectedFinishTime) : "--:--"
    property string greenFlagIcon: "../" + main.graphicsPath + "TI1000/Monuments/alpine_greenflag_icon.png"
    property string checkeredFlagIcon: "../" + main.graphicsPath + "TI1000/Monuments/alpine_checkeredflag_icon.png"
    property point flagLocation: Qt.point(-1, -1)
    property string backgroundImage: ""

    width: 1000 * main.screenScaleX
    height: 406 * main.screenScaleY

    Connections {
        target: currentViewName === "MONUMENT_VIEW" && visible && opacity > 0 ? keymapper : null

        onEnter2Pressed: {
            main.debugKeys("enter2Pressed", "MonumentViewContainer")
        }
    }

    function getPreloadImages() {
        switch (workoutProgram.programIndex) {
            case WorkoutProgram.MOUNT_EVEREST_PROG:
                return ["../" + main.graphicsPath + "TI1000/Monuments/alpine_everest.png"]
            case WorkoutProgram.EIFFEL_TOWER_PROG:
                return ["../" + main.graphicsPath + "TI1000/Monuments/alpine_eiffel_empty.png", "../" + main.graphicsPath + "TI1000/Monuments/alpine_eiffel_full.png"]
            case WorkoutProgram.GATEWAY_ARCH_PROG:
                return ["../" + main.graphicsPath + "TI1000/Monuments/alpine_arch_empty.png", "../" + main.graphicsPath + "TI1000/Monuments/alpine_arch_full.png"]
            case WorkoutProgram.MOUNT_KILIMANJARO_PROG:
                return ["../" + main.graphicsPath + "TI1000/Monuments/alpine_kilimanjaro.png"]
            case WorkoutProgram.MOUNT_RAINIER_PROG:
                return ["../" + main.graphicsPath + "TI1000/Monuments/alpine_rainier.png"]
        }
        return []
    }

    function getRenderPath() {
        switch (workoutProgram.programIndex) {
            case WorkoutProgram.MOUNT_EVEREST_PROG:
                return mtEverestRenderPath
            case WorkoutProgram.MOUNT_KILIMANJARO_PROG:
                return kilimanjaroRenderPath
            case WorkoutProgram.MOUNT_RAINIER_PROG:
                return mtRainierRenderPath
        }
        return null
    }

    function getTextItems() {
        switch (workoutProgram.programIndex) {
            case WorkoutProgram.MOUNT_EVEREST_PROG:
                return mtEverestTextItems
            case WorkoutProgram.MOUNT_KILIMANJARO_PROG:
                return kilimanjaroTextItems
            case WorkoutProgram.MOUNT_RAINIER_PROG:
                return mtRainierTextItems
        }
        return null
    }

    ListModel {
        id: mtEverestRenderPath
        // NOTE: The elevation for points inbetween base camps is interpolated
        // based on the y-value (this is done manually in the list below)
        ListElement { x: 110; y: 370; elevation: 0 }
        ListElement { x: 220; y: 340; elevation: 5667 }
        ListElement { x: 295; y: 330; elevation: 7556 }
        ListElement { x: 445; y: 280; elevation: 17000 } // BASE CAMP
        ListElement { x: 478; y: 250; elevation: 18024 }
        ListElement { x: 520; y: 238; elevation: 18433 }
        ListElement { x: 555; y: 220; elevation: 19047 }
        ListElement { x: 595; y: 202; elevation: 19900 } // "Lho La"
        ListElement { x: 670; y: 170; elevation: 21300 } // Camp 2
        ListElement { x: 690; y: 130; elevation: 24500 } // Geneva Spur
        ListElement { x: 650; y: 70; elevation: 26000 } // Camp 4
        ListElement { x: 560; y: 25; elevation: 29029 } // SUMMIT

    }

    ListModel {
        id: kilimanjaroRenderPath
        ListElement { x: 184; y: 370; elevation: 0 }
        ListElement { x: 273; y: 343; elevation: 1139 }
        ListElement { x: 348; y: 322; elevation: 2025 }
        ListElement { x: 395; y: 286; elevation: 3543 }
        ListElement { x: 459; y: 261; elevation: 4597 }
        ListElement { x: 500; y: 230; elevation: 5905 } // Machame Gate
        ListElement { x: 600; y: 210; elevation: 7574 }
        ListElement { x: 655; y: 172; elevation: 10746 }
        ListElement { x: 638; y: 145; elevation: 13000 } // Shira Peak
        ListElement { x: 626; y: 129; elevation: 13773 }
        ListElement { x: 552; y: 100; elevation: 15174 } // Lava Tower Camp
        ListElement { x: 524; y: 52; elevation: 16893 } // Mawenzi Peak
        ListElement { x: 443; y: 14; elevation: 19341 } // Uhuru Peak
    }

    ListModel {
        id: mtRainierRenderPath
        ListElement { x: 280; y: 370; elevation: 0 }
        ListElement { x: 363; y: 336; elevation: 1380 }
        ListElement { x: 386; y: 305; elevation: 2639 }
        ListElement { x: 467; y: 284; elevation: 3491 }
        ListElement { x: 500; y: 258; elevation: 4547 }
        ListElement { x: 565; y: 236; elevation: 5440 } // Alta Vista
        ListElement { x: 604; y: 204; elevation: 6785 }
        ListElement { x: 705; y: 158; elevation: 8717 }
        ListElement { x: 725; y: 123; elevation: 10188 } // Camp Muir
        ListElement { x: 676; y: 101; elevation: 10659 }
        ListElement { x: 636; y: 57; elevation: 11600 } // Disappointment Cleaver
        ListElement { x: 549; y: 37; elevation: 12796 }
        ListElement { x: 497; y: 14; elevation: 14411 } // Colombia Crest Summit
    }

    ListModel {
        id: mtEverestTextItems
        ListElement { x: 483; y: 272; label: "BASE CAMP"; elevFeet: 17000; elevMeters: 5182 }
        ListElement { x: 628; y: 196; label: '"Lho La"'; elevFeet: 19900; elevMeters: 6066 }
        ListElement { x: 701; y: 163; label: "Camp 2"; elevFeet: 21300; elevMeters: 6492 }
        ListElement { x: 720; y: 118; label: "Geneva Spur"; elevFeet: 24500; elevMeters: 7468 }
        ListElement { x: 679; y: 59; label: "Camp 4"; elevFeet: 26000; elevMeters: 7925 }
        ListElement { x: 584; y: 13; label: "SUMMIT"; elevFeet: 29029; elevMeters: 8848 }
    }

    ListModel {
        id: mtRainierTextItems
        ListElement { x: 590; y: 230; label: "Alta Vista"; elevFeet: 5440; elevMeters: 1658 }
        ListElement { x: 748; y: 107; label: "Camp Muir"; elevFeet: 10188; elevMeters: 3105 }
        ListElement { x: 665; y: 45; label: "Disappointment Cleaver"; elevFeet: 11600; elevMeters: 3536 }
        ListElement { x: 540; y: 1; label: "Colombia Crest Summit"; elevFeet: 14411; elevMeters: 4392 }
    }

    ListModel {
        id: kilimanjaroTextItems
        ListElement { x: 514; y: 232; label: "Machame Gate"; elevFeet: 5905; elevMeters: 1800 }
        ListElement { x: 665; y: 131; label: "Shira Peak"; elevFeet: 13000; elevMeters: 3962 }
        ListElement { x: 580; y: 84; label: "Lava Tower Camp"; elevFeet: 15174; elevMeters: 4625 }
        ListElement { x: 550; y: 43; label: "Mawenzi Peak"; elevFeet: 16893; elevMeters: 5149 }
        ListElement { x: 482; y: 3; label: "Uhuru Peak"; elevFeet: 19341; elevMeters: 5895 }
    }

    ListModel {
        id: eiffelTowerPlatforms
        ListElement { height: 187; label: QT_TR_NOOP("FIRST PLATFORM") }
        ListElement { height: 377; label: QT_TR_NOOP("SECOND PLATFORM") }
        ListElement { height: 906; label: QT_TR_NOOP("THIRD PLATFORM") }
        ListElement { height: 1063; label: QT_TR_NOOP("OFFICIAL HEIGHT") }
    }

    Timer {
        interval: 1000 / 60.0
        repeat: true
        running: currentViewName === "MONUMENT_VIEW"
        onTriggered: {
            canvas.requestPaint()
        }
    }

    function paintTimeRemaining() {
        if (aWorkoutRunData.mode != WorkoutRunData.WORKOUT_MODE) {
            return
        }

        var ctx = canvas.getContext("2d")
        ctx.fillStyle = Qt.rgba(0.0, 0.0, 0.0, 1.0)
        ctx.font = 'bold 17px "FreeSans"'
        ctx.textBaseline = "top"
        var timeRemainingText = qsTr("PROJECTED FINISH TIME")
        ctx.fillText(timeRemainingText, 15, 10)
        ctx.font = 'bold 48px "FreeSans"'
        ctx.fillText(root.projectedFinishTime, 15, 25)

    }

    function paintEiffelTower() {

        var progressLineWidth = 300
        var platformLineWidth = 85

        var ctx = canvas.getContext("2d")
        ctx.drawImage("../" + main.graphicsPath + "TI1000/Monuments/alpine_eiffel_full.png", 0, 0)
        ctx.save()

        var baselineY = 20
        var percentComplete = root.currentUserElevation / workoutProgram.endElevation
        var trackHeight = root.height - baselineY - 10
        var completeY = baselineY + parseInt(trackHeight * percentComplete)
        // Bound to top of screen
        completeY = Math.min(completeY, baselineY + trackHeight)
        // And to bottom of screen
        completeY = Math.max(10, completeY)

        // Make coordinates relative to top
        completeY = root.height - completeY
        baselineY = root.height - baselineY

        ctx.save()
        ctx.beginPath()
        ctx.moveTo(0,0)
        ctx.lineTo(0, completeY)
        ctx.lineTo(root.width, completeY)
        ctx.lineTo(root.width, 0)
        ctx.closePath()
        ctx.clip()
        ctx.drawImage("../" + main.graphicsPath + "TI1000/Monuments/alpine_eiffel_empty.png", 0, 0)

        ctx.restore() // Forget about clipping region

        paintTimeRemaining()

        ctx.strokeStyle = Qt.rgba(0.980, 0.650, 0.102, 1.0) // Yellow
        ctx.lineWidth = 5
        // Draw base line
        ctx.beginPath()
        ctx.moveTo(10, baselineY)
        ctx.lineTo(990, baselineY)
        ctx.stroke()

        // Paint vertical rising line
        ctx.beginPath()
        ctx.moveTo(645, baselineY)
        ctx.lineTo(645, 10)
        ctx.stroke()

        // Paint ladder bars for platform readings
        for (var i = 0; i < eiffelTowerPlatforms.count; i++) {
            var item = eiffelTowerPlatforms.get(i)
            ctx.beginPath()
            var lineY = parseInt((item.height / eiffelTowerPlatforms.get(eiffelTowerPlatforms.count - 1).height) * (baselineY - 10))
            lineY = root.height - 20 - lineY
            ctx.moveTo(645, lineY)
            ctx.lineTo(645 - platformLineWidth, lineY)
            ctx.stroke()

            ctx.beginPath()
            ctx.fillStyle = Qt.rgba(0.0, 0.0, 0.0, 1.0)
            ctx.textBaseline = "middle"
            ctx.font = 'bold 17px "FreeSans"'
            var elevation = Globals.formatWithSeparator(workoutScreen.unitState === "METRIC" ? Globals.feetToMeters(item.height).toFixed(0) : item.height)
            elevation = elevation + " " + (workoutScreen.unitState === "METRIC" ? qsTr("Meters") : qsTr("FT"))
            var str = elevation + " " + qsTr(item.label)
            var strWidth = ctx.measureText(str).width
            ctx.fillText(str, 660, lineY + 5)
            // Draw flag if platform has been reached
            if (root.currentUserElevation >= item.height) {
                ctx.drawImage(root.greenFlagIcon, 670 + strWidth - 5, lineY - 10)
            }
        }
        // Display current elevation
        ctx.textBaseline = "top"
        var userElev = Globals.formatWithSeparator(workoutScreen.unitState === "METRIC" ? Globals.feetToMeters(root.currentUserElevation).toFixed(0) : root.currentUserElevation)
        userElev = userElev + " " + (workoutScreen.unitState === "METRIC" ? qsTr("Meters") : qsTr("FT"))
        var measured = ctx.measureText(userElev)
        ctx.fillText(userElev, 320 - measured.width - 15, completeY - 10)

        // Paint red progress bar
        ctx.strokeStyle = Qt.rgba(0.925, 0.110, 0.141, 1.0)
        ctx.fillStyle = Qt.rgba(0.925, 0.110, 0.141, 1.0)
        ctx.lineWidth = 10
        ctx.lineCap = "round"
        ctx.beginPath()
        ctx.moveTo(320, completeY)
        ctx.lineTo(620, completeY)
        ctx.stroke()

    }

    function paintGatewayArch() {

        var progressLineWidth = 300
        var platformLineWidth = 85

        var ctx = canvas.getContext("2d")
        ctx.drawImage("../" + main.graphicsPath + "TI1000/Monuments/alpine_arch_full.png", 0, 0)
        ctx.save()

        var baselineY = 75
        var percentComplete = root.currentUserElevation / workoutProgram.endElevation
        var trackHeight = root.height - baselineY - 10
        var completeY = baselineY + parseInt(trackHeight * percentComplete)
        // Bound to top of screen
        completeY = Math.min(completeY, baselineY + trackHeight)
        // And to bottom of screen
        completeY = Math.max(10, completeY)

        // Make coordinates relative to top
        completeY = root.height - completeY
        baselineY = root.height - baselineY

        ctx.save()
        ctx.beginPath()
        ctx.moveTo(0,0)
        ctx.lineTo(0, completeY)
        ctx.lineTo(root.width, completeY)
        ctx.lineTo(root.width, 0)
        ctx.closePath()
        ctx.clip()
        ctx.drawImage("../" + main.graphicsPath + "TI1000/Monuments/alpine_arch_empty.png", 0, 0)

        ctx.restore() // Forget about clipping region

        paintTimeRemaining()

        ctx.strokeStyle = Qt.rgba(0.980, 0.650, 0.102, 1.0) // Yellow
        ctx.lineWidth = 5
        // Draw base line
        ctx.beginPath()
        ctx.moveTo(10, baselineY)
        ctx.lineTo(990, baselineY)
        ctx.stroke()

        // Paint vertical rising line
        ctx.beginPath()
        ctx.moveTo(676, baselineY)
        ctx.lineTo(676, 10)
        ctx.stroke()

        // Paint ladder bar - Arch only has one
        ctx.beginPath()
        ctx.moveTo(676, 10)
        ctx.lineTo(604, 10)
        ctx.stroke()
        ctx.beginPath()
        ctx.fillStyle = Qt.rgba(0.0, 0.0, 0.0, 1.0)
        ctx.textBaseline = "top"
        ctx.font = 'bold 17px "FreeSans"'
        var ladderText = qsTr("OFFICIAL HEIGHT") + " " + (workoutScreen.unitState === "METRIC" ? "192 "+qsTr("Meters") : "630 "+qsTr("FT"))
        ctx.fillText(ladderText, 686, 3)

        // Display current elevation
        ctx.beginPath()
        ctx.fillStyle = Qt.rgba(0.0, 0.0, 0.0, 1.0)
        ctx.textBaseline = "top"
        ctx.font = 'bold 17px "FreeSans"'
        var userElev = Globals.formatWithSeparator(workoutScreen.unitState === "METRIC" ? Globals.feetToMeters(root.currentUserElevation).toFixed(0) : root.currentUserElevation)
        userElev = userElev + " " + (workoutScreen.unitState === "METRIC" ? qsTr("Meters") : qsTr("FT"))
        var measured = ctx.measureText(userElev)
        ctx.fillText(userElev, 290 - measured.width - 15, completeY - 10)

        // Paint red progress bar
        ctx.strokeStyle = Qt.rgba(0.925, 0.110, 0.141, 1.0)
        ctx.fillStyle = Qt.rgba(0.925, 0.110, 0.141, 1.0)
        ctx.lineWidth = 10
        ctx.lineCap = "round"
        ctx.beginPath()
        ctx.moveTo(290, completeY)
        ctx.lineTo(660, completeY)
        ctx.stroke()

    }

    function closeEnoughForFlag(height1, height2) {
        return Math.abs(height1 - height2) <= 100
    }

    function precomputeFlagLocation() {
        // The flag location doesn't change, so precompute it to be faster
        if (workoutProgram.programIndex !== WorkoutProgram.MOUNT_EVEREST_PROG &&
            workoutProgram.programIndex !== WorkoutProgram.MOUNT_KILIMANJARO_PROG &&
            workoutProgram.programIndex !== WorkoutProgram.MOUNT_RAINIER_PROG) {
            // Only applies to mountain workouts
            return
        }

        var renderPath = getRenderPath()
        var textItems = getTextItems()
        for (var i = 0; i < textItems.count; i++) {
            var item = textItems.get(i)
            // If target is close to a base camp, wait and put the flag after the text, drawn later
            if (closeEnoughForFlag(root.endElevation, item.elevFeet)) {
                return
            }
        }

        for (var i = 0; i < renderPath.count - 1; i++) {
            if (root.endElevation >= renderPath.get(i).elevation && root.endElevation <= renderPath.get(i+1).elevation) {
                var progress = (root.endElevation - renderPath.get(i).elevation) / (renderPath.get(i+1).elevation - renderPath.get(i).elevation)
                var slope = (renderPath.get(i+1).y - renderPath.get(i).y) / (renderPath.get(i+1).x - renderPath.get(i).x)
                var dx = (progress * (renderPath.get(i+1).x - renderPath.get(i).x))
                var x = (renderPath.get(i).x + dx) * main.screenScaleX
                var dy = slope * dx
                var y = (renderPath.get(i).y + dy) * main.screenScaleY
                root.flagLocation = Qt.point(Math.round(x), Math.round(y))
            }
        }

    }

    function paintMountain() {
        var ctx = canvas.getContext("2d")

        var renderPath = getRenderPath()

        ctx.drawImage(root.backgroundImage, 0, 0)
        ctx.save()

        paintTimeRemaining()

        ctx.strokeStyle = Qt.rgba(0.980, 0.650, 0.102, 1.0)
        ctx.lineWidth = 5 * main.screenScaleX
        ctx.beginPath()
        var startPoint = renderPath.get(0)
        ctx.moveTo(startPoint.x * main.screenScaleX, startPoint.y * main.screenScaleY)
        for (var i = 1; i < renderPath.count; i++) {
            ctx.lineTo(Math.round(renderPath.get(i).x * main.screenScaleX), Math.round(renderPath.get(i).y * main.screenScaleY))
        }
        ctx.stroke()

        // Draw base line
        ctx.beginPath()
        ctx.moveTo(Math.round(10 * main.screenScaleX), Math.round(370 * main.screenScaleY))
        ctx.lineTo(Math.round(990 * main.screenScaleX), Math.round(370 * main.screenScaleY))
        ctx.stroke()

        // Track points for drawing red line (user progress)
        var indexBegin = 0
        var indexEnd = 0
        var pointBegin = null
        var pointEnd = null
        for (var i = 0; i < renderPath.count - 1; i++) {
            if (pointBegin && pointEnd) {
                break
            }
            if (root.startElevation >= renderPath.get(i).elevation && root.startElevation <= renderPath.get(i+1).elevation) {
                // Percent progress along this line
                var progress = (root.startElevation - renderPath.get(i).elevation) / (renderPath.get(i+1).elevation - renderPath.get(i).elevation)
                var slope = (renderPath.get(i+1).y - renderPath.get(i).y) / (renderPath.get(i+1).x - renderPath.get(i).x)
                var dx = (progress * (renderPath.get(i+1).x - renderPath.get(i).x))
                var x = (renderPath.get(i).x + dx) * main.screenScaleX
                var dy = slope * dx
                var y = (renderPath.get(i).y + dy) * main.screenScaleY
                pointBegin = [Math.round(x), Math.round(y)]
                indexBegin = i
            }
            if (root.currentUserElevation >= renderPath.get(i).elevation && root.currentUserElevation <= renderPath.get(i+1).elevation) {
                // Percent progress along this line
                var progress = (root.currentUserElevation - renderPath.get(i).elevation) / (renderPath.get(i+1).elevation - renderPath.get(i).elevation)
                var slope = (renderPath.get(i+1).y - renderPath.get(i).y) / (renderPath.get(i+1).x - renderPath.get(i).x)
                var dx = (progress * (renderPath.get(i+1).x - renderPath.get(i).x))
                var x = (renderPath.get(i).x + dx) * main.screenScaleX
                var dy = slope * dx
                var y = (renderPath.get(i).y + dy) * main.screenScaleY
                pointEnd = [Math.round(x), Math.round(y)]
                indexEnd = i
            }
        }
        if (!pointEnd) {
            if (root.currentUserElevation < 0) {
                // They descended below 0ft
                var pt = renderPath.get(0)
                pointEnd = [Math.round(pt.x * main.screenScaleX), Math.round(pt.y * main.screenScaleY)]
                indexEnd = 0
            } else {
                // They went past the endpoint
                var pt = renderPath.get(renderPath.count - 1)
                pointEnd = [Math.round(pt.x * main.screenScaleX), Math.round(pt.y * main.screenScaleY)]
                indexEnd = renderPath.count - 1
            }
        }

        // Draw checkered flag (unless it is drawn after text, further down)
        if (root.flagLocation.x > -1) {
            // 28x27 is the checkered flag image width/height
            ctx.drawImage(root.checkeredFlagIcon, root.flagLocation.x, root.flagLocation.y - 27 * main.screenScaleY)
        }

        //console.log("Points", pointBegin, pointEnd)

        ctx.strokeStyle = Qt.rgba(0.925, 0.110, 0.141, 1.0)
        ctx.fillStyle = Qt.rgba(0.925, 0.110, 0.141, 1.0)
        ctx.lineWidth = 10 * main.screenScaleX
        ctx.lineCap = "round"
        ctx.beginPath()
        if (root.currentUserElevation < root.startElevation) {
            // User descended backwards from start point
            ctx.moveTo(pointEnd[0], pointEnd[1])
            for (var i = indexEnd + 1; i <= indexBegin; i++) {
                var pt = renderPath.get(i)
                ctx.lineTo(Math.round(pt.x * main.screenScaleX), Math.round(pt.y * main.screenScaleY))
            }
            ctx.lineTo(pointBegin[0], pointBegin[1])
        } else {
            ctx.moveTo(pointBegin[0], pointBegin[1])
            for (var i = indexBegin + 1; i <= indexEnd; i++) {
                var pt = renderPath.get(i)
                ctx.lineTo(Math.round(pt.x * main.screenScaleX), Math.round(pt.y * main.screenScaleY))
            }
            if(Math.round(renderPath.get(indexEnd).x * main.screenScaleX) != pointEnd[0] || Math.round(renderPath.get(indexEnd).y * main.screenScaleX) != pointEnd[1])
                ctx.lineTo(pointEnd[0], pointEnd[1])
        }

        ctx.stroke()

        ctx.beginPath()
        ctx.ellipse(pointEnd[0] - 13 * main.screenScaleX, pointEnd[1] - 13 * main.screenScaleX, 26 * main.screenScaleX, 26 * main.screenScaleY)
        ctx.fill()

        ctx.beginPath()
        ctx.fillStyle = Qt.rgba(0.0, 0.0, 0.0, 1.0)
        ctx.textBaseline = "top"
        ctx.font = main.screenScaleX > 1.1 ? 'bold 24px "FreeSans"' : 'bold 17px "FreeSans"'
        var textItems = getTextItems()
        for (var i = 0; i < textItems.count; i++) {
            var str
            var item = textItems.get(i)
            var elev = Globals.formatWithSeparator(workoutScreen.unitState === "METRIC" ? item.elevMeters : item.elevFeet)
            elev = elev + " " + (workoutScreen.unitState === "METRIC" ? qsTr("Meters") : qsTr("FT"))
            str = elev + " " + qsTr(item.label)
            ctx.fillText(str, item.x * main.screenScaleX, item.y * main.screenScaleY)
            var strWidth = ctx.measureText(str).width
            if (closeEnoughForFlag(root.endElevation, item.elevFeet)) {
                // Draw checkered flag if target is close enough to this point
                var flagY = (item.y - 5) * main.screenScaleY
                if (flagY < 2) {
                    // Avoid painting over top of screen
                    flagY = 2
                }

                ctx.drawImage(root.checkeredFlagIcon, (item.x + 5) * main.screenScaleX + strWidth, flagY)
            } else {
                // Otherwise, draw green flag if they reached this point
                if (root.currentUserElevation >= item.elevFeet && item.elevFeet > root.startElevation) {
                    if (i !== textItems.count - 1) {
                        ctx.drawImage(root.greenFlagIcon, (item.x + 5) * main.screenScaleX + strWidth, item.y * main.screenScaleY)
                    }
                }
            }
        }

        // Display user elevation
        ctx.textBaseline = "top"
        var elevation = Globals.formatWithSeparator(workoutScreen.unitState === "METRIC" ? Globals.feetToMeters(root.currentUserElevation).toFixed(0) : root.currentUserElevation)
        elevation = elevation + " " + (workoutScreen.unitState === "METRIC" ? qsTr("Meters") : qsTr("FT"))
        var measured = ctx.measureText(elevation)
        ctx.fillText(elevation, pointEnd[0] - (measured.width - 25) * main.screenScaleX, pointEnd[1] - 12 * main.screenScaleY)

        ctx.restore()
    }

    Canvas {
        id: canvas
        anchors.fill: parent
        onPaint: {
            switch (workoutProgram.programIndex) {
                case WorkoutProgram.MOUNT_EVEREST_PROG:
                case WorkoutProgram.MOUNT_KILIMANJARO_PROG:
                case WorkoutProgram.MOUNT_RAINIER_PROG:
                    paintMountain()
                    return
                case WorkoutProgram.EIFFEL_TOWER_PROG:
                    paintEiffelTower()
                    return
                case WorkoutProgram.GATEWAY_ARCH_PROG:
                    paintGatewayArch()
                    break
            }

        }

        Component.onCompleted: {
            var images = getPreloadImages()
            for (var i = 0; i < images.length; i++) {
                canvas.loadImage(images[i])
            }
            if (images.length === 1) {
                // Store image for mountain
                root.backgroundImage = images[0]
            }

            precomputeFlagLocation()
        }
    }

}
